(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    843139,      28032]*)
(*NotebookOutlinePosition[    843947,      28060]*)
(*  CellTagsIndexPosition[    843903,      28056]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Frequency response of FIR filters", "Title"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " definitions"
}], "Section"],

Cell[CellGroupData[{

Cell["Load needed packages for this notebook", "Subsection"],

Cell[BoxData[{
    \(\(<< Graphics`Colors`;\)\), "\[IndentingNewLine]", 
    \(\(<< Calculus`FourierTransform`;\)\), "\[IndentingNewLine]", 
    \(\(<< Miscellaneous`Audio`;\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Set up defaults", "Subsection"],

Cell[CellGroupData[{

Cell["Turn off annoying warning messages", "Subsubsection"],

Cell[BoxData[{
    \(\(Off[General::spell];\)\), "\[IndentingNewLine]", 
    \(\(Off[General::spell1];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Set default options for specific functions", "Subsubsection"],

Cell[BoxData[{
    \(\(SetOptions[Plot, Frame \[Rule] True];\)\), "\[IndentingNewLine]", 
    \(\(SetOptions[ListPlot, Frame \[Rule] True, \ PlotJoined \[Rule] True, \ 
        Axes \[Rule] {True, False}];\)\), "\[IndentingNewLine]", 
    \(\(SetOptions[Fourier, 
        FourierParameters \[Rule] {1, \(-1\)}];\)\), "\[IndentingNewLine]", 
    \(\(SetOptions[InverseFourier, 
        FourierParameters \[Rule] {1, \(-1\)}];\)\), "\[IndentingNewLine]", 
    \(\(SetOptions[FourierTransform, \ 
        FourierParameters \[Rule] {0, \(-2\) \[Pi]}];\)\), "\
\[IndentingNewLine]", 
    \(\(SetOptions[FourierTransform, \ 
        FourierParameters \[Rule] {0, \(-2\) \[Pi]}];\)\), "\
\[IndentingNewLine]", 
    \(\(SetOptions[InverseFourierTransform, \ 
        FourierParameters \[Rule] {0, \(-2\) \[Pi]}];\)\)}], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualization functions", "Subsection"],

Cell[CellGroupData[{

Cell["Fix time variable for sampled signals", "Subsubsection"],

Cell[BoxData[
    \(\(FixTime[signal_, 
          sampleRate_] := \[IndentingNewLine]Module[{time, 
            data}, \[IndentingNewLine]time = 
            Table[i/sampleRate, {i, 1, 
                Length[signal]}]; \[IndentingNewLine]data\  = \ {time, 
                signal} // Transpose\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Generate periodic waveform from one period", "Subsubsection"],

Cell["\<\
PeriodicSignal[f, {dmin, dmax}, {t, min, max}] generates a periodic \
waveform for the interval [min, max]. It is assumed that one period of the \
function f(t) is defined over the interval [dmin, dmax].\
\>", "Text"],

Cell[BoxData[
    \(\(PeriodicSignal[
          f_, {dmin_, dmax_}, {t_, min_, 
            max_}] := \[IndentingNewLine]Module[{T, imin, 
            imax}, \[IndentingNewLine]T\  = \ 
            dmax\  - \ dmin; \[IndentingNewLine]imin = 
            Floor[\((min - dmin)\)/T]; \[IndentingNewLine]imax = 
            Ceiling[\((max - dmax)\)/T]; \ \[IndentingNewLine]Sum[
            f[t - i\ T]\ \((UnitStep[t - dmin - i\ T]\  - \ 
                  UnitStep[t - dmax - i\ T])\), {i, imin, 
              imax}]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot periodic waveforms", "Subsubsection"],

Cell[TextData[{
  "PeriodicPlot[f, {dmin, dmax}, {t, min, max}, opts] plots a a periodic \
waveform for the interval [min, max]. It is assumed that one period of the \
function f(t) is defined over the interval [dmin, dmax]. The 'opts' argument \
passed plotting options to the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function Plot[ ]."
}], "Text"],

Cell[BoxData[
    \(\(PeriodicPlot[f_, {dmin_, dmax_}, {t_, min_, max_}, 
          opts___] := \[IndentingNewLine]Module[{fnc}, \[IndentingNewLine]fnc \
= PeriodicSignal[f, {dmin, dmax}, {t, min, max}]; \[IndentingNewLine]Plot[
            fnc, {t, min, max}, opts]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot discrete-time signal as sequence of amplitude lines", \
"Subsubsection"],

Cell[BoxData[
    \(\(DiscreteListPlot[signal_, color_:  Black, 
          opts___] := \[IndentingNewLine]Module[{data, g1, 
            g2}, \[IndentingNewLine]If[
            Length[signal[\([1]\)]]\  \[Equal] \ 2, \[IndentingNewLine]data = 
              signal, \[IndentingNewLine]data = 
              FixTime[signal, 
                1]\[IndentingNewLine]]; \[IndentingNewLine]g1 = \
\(Line[{{#[\([1]\)], 0}, {#[\([1]\)], #[\([2]\)]}}] &\)\  /@ \ 
              data; \[IndentingNewLine]g2 = \({PointSize[ .015], 
                  Point[#]} &\)\  /@ \ data; \[IndentingNewLine]Show[
            Graphics[{color, g1, g2}], 
            opts]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot discrete-time signal as sequence of amplitude lines", \
"Subsubsection"],

Cell[BoxData[
    \(\(DiscreteListPlot2[signal_, color_:  Black, 
          opts___] := \[IndentingNewLine]Module[{data, g1, 
            g2}, \[IndentingNewLine]If[
            Length[signal[\([1]\)]]\  \[Equal] \ 2, \[IndentingNewLine]data = 
              signal, \[IndentingNewLine]data = 
              FixTime[signal, 
                1]\[IndentingNewLine]]; \[IndentingNewLine]g1 = \
\(Line[{{#[\([1]\)], 0}, {#[\([1]\)], #[\([2]\)]}}] &\)\  /@ \ 
              data; \[IndentingNewLine]g2 = \({PointSize[ .005], 
                  Point[#]} &\)\  /@ \ data; \[IndentingNewLine]Show[
            Graphics[{color, g1, g2}], 
            opts]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Fourier rearrange", "Subsection"],

Cell[TextData[{
  "FourierRearrange[fft] rearranges the result of an FFT (",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function Fourier[ ]), to a easier to visualize the spectrum represented \
by 'fft'. The length of the list 'fft' is assumed to be even; if it is not, \
the last term in 'fft' is dropped. "
}], "Text"],

Cell[BoxData[
    \(\(FourierRearrange[fft_, \ 
          samplingRate_] := \[IndentingNewLine]Module[{fft2, n, 
            n2}, \[IndentingNewLine]If[EvenQ[Length[fft]], \ 
            fft2\  = \ fft, \ 
            fft2\  = \ Drop[fft, \(-1\)]]; \ \[IndentingNewLine]n = 
            Length[fft]; 
          n2 = n/2; \[IndentingNewLine]{Table[\ 
                samplingRate\ i/n, {i, \(-n2\) + 1, n2}], 
              Take[fft2, {n2 + 2, n2*2}]~Join~Take[fft2, {1, n2 + 1}]} // 
            Transpose\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Short-cut functions", "Subsection"],

Cell[CellGroupData[{

Cell["Dirac delta function", "Subsubsection"],

Cell[BoxData[
    \(\(\[Delta][t_] := DiracDelta[t];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Unit step function", "Subsubsection"],

Cell[BoxData[
    \(\(u[t_] := UnitStep[t];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Pulse of width ",
  Cell[BoxData[
      \(TraditionalForm\`w\)]]
}], "Subsubsection"],

Cell[BoxData[
    \(\(p[t_, w_] := u[t + w/2] - u[t - w/2];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Hack to plot ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta](t)\)]]
}], "Subsection"],

Cell[BoxData[
    \(PlotConvert[X_, 
        w_] := \[IndentingNewLine]X\  /. \ {\[Delta][a_] \[Rule] 
            p[a, w]}\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sampler (CT to DT converter)", "Subsection"],

Cell[BoxData[
    \(\(sampler[xc_, fs_, 
          range_: {0, 5}] := \[IndentingNewLine]Table[{n, xc[n/fs]}, {n, 
            range[\([1]\)]*fs, range[\([2]\)]*fs}];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sampled frequency spectrum", "Subsection"],

Cell[BoxData[
    \(\(SampledSpectrum[X_, f_, fs_, n_:  5] := \[IndentingNewLine]Sum[
          X[f - k\ fs], {k, \(-n\), n}];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Definition of DTFT", "Subsection"],

Cell[BoxData[
    \(\(DTFT[
          xd_, \[Theta]_] := \[IndentingNewLine]Module[{n, xn, n1, 
            n2}, \[IndentingNewLine]{n, xn}\  = \ 
            xd\  // \ Transpose; \[IndentingNewLine]n1\  = \ First[n]; \ 
          n2\  = \ Last[n]; \[IndentingNewLine]Sum[
            xn[\([k - n1 + 1]\)]\ Exp[\(-I\)\ k\ \[Theta]], {k, n1, 
              n2}]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["(1) Simplest low-pass FIR filter example", "Section"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`y[n]\  = \ 1/2\ \((x[n]\  + \ x[n - 1])\)\)]]
}], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[CellGroupData[{

Cell[TextData[{
  "Define impulse response sequence ",
  Cell[BoxData[
      \(TraditionalForm\`h(n)\)]]
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(L = 2;\)\), "\[IndentingNewLine]", 
    \(hn\  = \ Table[{i, 1/L}, \ {i, 0, L - 1}]\)}], "Input"],

Cell[BoxData[
    \({{0, 1\/2}, {1, 1\/2}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Frequency response function ",
  Cell[BoxData[
      \(TraditionalForm\`H(e\^j\[Theta])\)]]
}], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  "Frequency response function ",
  Cell[BoxData[
      \(TraditionalForm\`H(e\^j\[Theta])\)]]
}], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(H\[Theta]\  = DTFT[hn, \[Theta]]\  // \ Chop; \ 
    H\[Theta]\  // \ TraditionalForm\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`1\/2 + \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Theta]\
\)\/2\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Plots of frequency response function ",
  Cell[BoxData[
      \(TraditionalForm\`H(e\^j\[Theta])\)]],
  "as a function of \[Theta]"
}], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(g1 = 
        Plot[Abs[H\[Theta]], {\[Theta], \(-\[Pi]\), \[Pi]}, \ 
          PlotStyle \[Rule] {Red}, \ PlotRange \[Rule] All, 
          PlotPoints \[Rule] 200, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(g2 = 
        Plot[Arg[H\[Theta]], {\[Theta], \(-\[Pi]\), \[Pi]}, \ 
          PlotStyle \[Rule] {Red}, \ PlotRange \[Rule] All, 
          PlotPoints \[Rule] 200, \ 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{{g1, g2}}], ImageSize \[Rule] 504];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
%%ImageSize: 504 148.328 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.151576 0.0147151 0.588604 [
[.04527 -0.0125 -6 -9 ]
[.04527 -0.0125 6 0 ]
[.19685 -0.0125 -6 -9 ]
[.19685 -0.0125 6 0 ]
[.34842 -0.0125 -6 -9 ]
[.34842 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65158 -0.0125 -3 -9 ]
[.65158 -0.0125 3 0 ]
[.80315 -0.0125 -3 -9 ]
[.80315 -0.0125 3 0 ]
[.95473 -0.0125 -3 -9 ]
[.95473 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13244 -18 -4.5 ]
[-0.0125 .13244 0 4.5 ]
[-0.0125 .25016 -18 -4.5 ]
[-0.0125 .25016 0 4.5 ]
[-0.0125 .36788 -18 -4.5 ]
[-0.0125 .36788 0 4.5 ]
[-0.0125 .4856 -18 -4.5 ]
[-0.0125 .4856 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 0 m
.04527 .00625 L
s
[(-3)] .04527 -0.0125 0 1 Mshowa
.19685 0 m
.19685 .00625 L
s
[(-2)] .19685 -0.0125 0 1 Mshowa
.34842 0 m
.34842 .00625 L
s
[(-1)] .34842 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.65158 0 m
.65158 .00625 L
s
[(1)] .65158 -0.0125 0 1 Mshowa
.80315 0 m
.80315 .00625 L
s
[(2)] .80315 -0.0125 0 1 Mshowa
.95473 0 m
.95473 .00625 L
s
[(3)] .95473 -0.0125 0 1 Mshowa
.125 Mabswid
.07559 0 m
.07559 .00375 L
s
.1059 0 m
.1059 .00375 L
s
.13622 0 m
.13622 .00375 L
s
.16653 0 m
.16653 .00375 L
s
.22716 0 m
.22716 .00375 L
s
.25748 0 m
.25748 .00375 L
s
.28779 0 m
.28779 .00375 L
s
.31811 0 m
.31811 .00375 L
s
.37874 0 m
.37874 .00375 L
s
.40905 0 m
.40905 .00375 L
s
.43937 0 m
.43937 .00375 L
s
.46968 0 m
.46968 .00375 L
s
.53032 0 m
.53032 .00375 L
s
.56063 0 m
.56063 .00375 L
s
.59095 0 m
.59095 .00375 L
s
.62126 0 m
.62126 .00375 L
s
.68189 0 m
.68189 .00375 L
s
.71221 0 m
.71221 .00375 L
s
.74252 0 m
.74252 .00375 L
s
.77284 0 m
.77284 .00375 L
s
.83347 0 m
.83347 .00375 L
s
.86378 0 m
.86378 .00375 L
s
.8941 0 m
.8941 .00375 L
s
.92441 0 m
.92441 .00375 L
s
.01496 0 m
.01496 .00375 L
s
.98504 0 m
.98504 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13244 m
.00625 .13244 L
s
[(0.2)] -0.0125 .13244 1 0 Mshowa
0 .25016 m
.00625 .25016 L
s
[(0.4)] -0.0125 .25016 1 0 Mshowa
0 .36788 m
.00625 .36788 L
s
[(0.6)] -0.0125 .36788 1 0 Mshowa
0 .4856 m
.00625 .4856 L
s
[(0.8)] -0.0125 .4856 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(1)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .16187 m
.00375 .16187 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .27959 m
.00375 .27959 L
s
0 .30902 m
.00375 .30902 L
s
0 .33845 m
.00375 .33845 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .45617 m
.00375 .45617 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.04527 .61178 m
.04527 .61803 L
s
.19685 .61178 m
.19685 .61803 L
s
.34842 .61178 m
.34842 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65158 .61178 m
.65158 .61803 L
s
.80315 .61178 m
.80315 .61803 L
s
.95473 .61178 m
.95473 .61803 L
s
.125 Mabswid
.07559 .61428 m
.07559 .61803 L
s
.1059 .61428 m
.1059 .61803 L
s
.13622 .61428 m
.13622 .61803 L
s
.16653 .61428 m
.16653 .61803 L
s
.22716 .61428 m
.22716 .61803 L
s
.25748 .61428 m
.25748 .61803 L
s
.28779 .61428 m
.28779 .61803 L
s
.31811 .61428 m
.31811 .61803 L
s
.37874 .61428 m
.37874 .61803 L
s
.40905 .61428 m
.40905 .61803 L
s
.43937 .61428 m
.43937 .61803 L
s
.46968 .61428 m
.46968 .61803 L
s
.53032 .61428 m
.53032 .61803 L
s
.56063 .61428 m
.56063 .61803 L
s
.59095 .61428 m
.59095 .61803 L
s
.62126 .61428 m
.62126 .61803 L
s
.68189 .61428 m
.68189 .61803 L
s
.71221 .61428 m
.71221 .61803 L
s
.74252 .61428 m
.74252 .61803 L
s
.77284 .61428 m
.77284 .61803 L
s
.83347 .61428 m
.83347 .61803 L
s
.86378 .61428 m
.86378 .61803 L
s
.8941 .61428 m
.8941 .61803 L
s
.92441 .61428 m
.92441 .61803 L
s
.01496 .61428 m
.01496 .61803 L
s
.98504 .61428 m
.98504 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13244 m
1 .13244 L
s
.99375 .25016 m
1 .25016 L
s
.99375 .36788 m
1 .36788 L
s
.99375 .4856 m
1 .4856 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .01472 m
.02847 .02376 L
.03355 .03363 L
.03832 .04288 L
.04291 .05178 L
.0478 .06124 L
.0525 .07034 L
.0575 .07999 L
.06232 .08928 L
.06695 .09819 L
.07188 .10765 L
.07662 .11674 L
.08119 .12545 L
.08604 .1347 L
.09072 .14358 L
.09569 .15298 L
.10048 .162 L
.10509 .17064 L
.10999 .1798 L
.11471 .18857 L
.11972 .19785 L
.12456 .20674 L
.1292 .21525 L
.13415 .22425 L
.13891 .23287 L
.14349 .2411 L
.14837 .24981 L
.15306 .25813 L
.15805 .26692 L
.16285 .27532 L
.16748 .28333 L
.17239 .2918 L
.17713 .29987 L
.18168 .30757 L
.18653 .3157 L
.1912 .32345 L
.19616 .33161 L
.20094 .33939 L
.20553 .3468 L
.21043 .3546 L
.21513 .36202 L
.22014 .36982 L
.22496 .37724 L
.2296 .38429 L
.23454 .3917 L
.23929 .39874 L
.24386 .40542 L
.24872 .41243 L
.2534 .41909 L
.25838 .42606 L
Mistroke
.26318 .43266 L
.26779 .43892 L
.2727 .44547 L
.27742 .45167 L
.28244 .45814 L
.28728 .46427 L
.29194 .47005 L
.29689 .47608 L
.30166 .48177 L
.30624 .48714 L
.31113 .49273 L
.31582 .49799 L
.32082 .50346 L
.32563 .50861 L
.33026 .51344 L
.33518 .51845 L
.33993 .52315 L
.34449 .52755 L
.34934 .53211 L
.35401 .53638 L
.35898 .54078 L
.36377 .54488 L
.36837 .5487 L
.37327 .55263 L
.37798 .55628 L
.38299 .56002 L
.38782 .56348 L
.39247 .56668 L
.39741 .56993 L
.40217 .57293 L
.40674 .57569 L
.41161 .57848 L
.4163 .58103 L
.42129 .58359 L
.42609 .58591 L
.43071 .58801 L
.43562 .5901 L
.44035 .59196 L
.4449 .59362 L
.44975 .59525 L
.45441 .59667 L
.45937 .59804 L
.46414 .59921 L
.46873 .60019 L
.47362 .60109 L
.47833 .60182 L
.48333 .60243 L
.48583 .60268 L
.48814 .60287 L
.49054 .60303 L
Mistroke
.49278 .60315 L
.49504 .60324 L
.49624 .60327 L
.49691 .60329 L
.49753 .6033 L
.49812 .60331 L
.49842 .60331 L
.49875 .60331 L
.49894 .60332 L
.49911 .60332 L
.49927 .60332 L
.49945 .60332 L
.49961 .60332 L
.49975 .60332 L
.49991 .60332 L
.5 .60332 L
.50008 .60332 L
.50023 .60332 L
.50031 .60332 L
.50039 .60332 L
.50054 .60332 L
.50068 .60332 L
.50099 .60332 L
.50132 .60331 L
.50194 .60331 L
.5025 .6033 L
.50369 .60328 L
.50479 .60325 L
.50599 .6032 L
.50728 .60315 L
.50986 .60301 L
.51229 .60284 L
.51693 .6024 L
.52187 .60179 L
.52662 .60105 L
.5312 .60021 L
.53606 .59916 L
.54075 .59801 L
.54573 .59664 L
.55053 .59516 L
.55514 .59361 L
.56005 .59181 L
.56478 .58993 L
.5698 .58778 L
.57464 .58557 L
.5793 .58329 L
.58426 .58073 L
.58903 .57812 L
.59362 .57548 L
.5985 .57252 L
Mistroke
.6032 .56954 L
.6082 .56623 L
.61301 .56289 L
.61764 .55955 L
.62257 .55586 L
.62731 .55217 L
.63188 .5485 L
.63673 .54446 L
.64141 .54044 L
.64638 .53603 L
.65117 .53165 L
.65577 .52731 L
.66067 .52257 L
.66539 .51787 L
.6704 .51275 L
.67523 .50769 L
.67988 .5027 L
.68482 .49727 L
.68958 .49192 L
.69416 .48666 L
.69904 .48095 L
.70373 .47533 L
.70871 .46924 L
.71352 .46326 L
.71814 .4574 L
.72306 .45105 L
.72779 .44482 L
.73234 .43874 L
.73719 .43216 L
.74185 .42573 L
.74681 .41878 L
.75159 .41199 L
.75619 .40536 L
.76108 .39821 L
.76578 .39123 L
.77079 .38371 L
.77561 .37637 L
.78024 .36922 L
.78518 .36153 L
.78993 .35403 L
.7945 .34675 L
.79936 .33891 L
.80404 .33129 L
.80902 .3231 L
.81381 .31513 L
.81842 .3074 L
.82333 .29909 L
.82805 .29103 L
.83307 .28239 L
.83791 .27399 L
Mistroke
.84256 .26585 L
.84751 .25712 L
.85228 .24866 L
.85687 .24046 L
.86175 .23168 L
.86644 .22318 L
.87144 .21408 L
.87625 .20527 L
.88087 .19675 L
.8858 .18764 L
.89054 .17882 L
.89509 .1703 L
.89995 .16119 L
.90462 .15239 L
.90959 .143 L
.91437 .13392 L
.91897 .12516 L
.92387 .1158 L
.92858 .10678 L
.93359 .09716 L
.93842 .08787 L
.94306 .07891 L
.948 .06937 L
.95276 .06017 L
.95733 .05131 L
.9622 .04187 L
.96689 .03277 L
.97187 .0231 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.151576 0.309017 0.187358 [
[.04527 -0.0125 -6 -9 ]
[.04527 -0.0125 6 0 ]
[.19685 -0.0125 -6 -9 ]
[.19685 -0.0125 6 0 ]
[.34842 -0.0125 -6 -9 ]
[.34842 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65158 -0.0125 -3 -9 ]
[.65158 -0.0125 3 0 ]
[.80315 -0.0125 -3 -9 ]
[.80315 -0.0125 3 0 ]
[.95473 -0.0125 -3 -9 ]
[.95473 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02798 -24 -4.5 ]
[-0.0125 .02798 0 4.5 ]
[-0.0125 .12166 -12 -4.5 ]
[-0.0125 .12166 0 4.5 ]
[-0.0125 .21534 -24 -4.5 ]
[-0.0125 .21534 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .4027 -18 -4.5 ]
[-0.0125 .4027 0 4.5 ]
[-0.0125 .49638 -6 -4.5 ]
[-0.0125 .49638 0 4.5 ]
[-0.0125 .59005 -18 -4.5 ]
[-0.0125 .59005 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 0 m
.04527 .00625 L
s
[(-3)] .04527 -0.0125 0 1 Mshowa
.19685 0 m
.19685 .00625 L
s
[(-2)] .19685 -0.0125 0 1 Mshowa
.34842 0 m
.34842 .00625 L
s
[(-1)] .34842 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.65158 0 m
.65158 .00625 L
s
[(1)] .65158 -0.0125 0 1 Mshowa
.80315 0 m
.80315 .00625 L
s
[(2)] .80315 -0.0125 0 1 Mshowa
.95473 0 m
.95473 .00625 L
s
[(3)] .95473 -0.0125 0 1 Mshowa
.125 Mabswid
.07559 0 m
.07559 .00375 L
s
.1059 0 m
.1059 .00375 L
s
.13622 0 m
.13622 .00375 L
s
.16653 0 m
.16653 .00375 L
s
.22716 0 m
.22716 .00375 L
s
.25748 0 m
.25748 .00375 L
s
.28779 0 m
.28779 .00375 L
s
.31811 0 m
.31811 .00375 L
s
.37874 0 m
.37874 .00375 L
s
.40905 0 m
.40905 .00375 L
s
.43937 0 m
.43937 .00375 L
s
.46968 0 m
.46968 .00375 L
s
.53032 0 m
.53032 .00375 L
s
.56063 0 m
.56063 .00375 L
s
.59095 0 m
.59095 .00375 L
s
.62126 0 m
.62126 .00375 L
s
.68189 0 m
.68189 .00375 L
s
.71221 0 m
.71221 .00375 L
s
.74252 0 m
.74252 .00375 L
s
.77284 0 m
.77284 .00375 L
s
.83347 0 m
.83347 .00375 L
s
.86378 0 m
.86378 .00375 L
s
.8941 0 m
.8941 .00375 L
s
.92441 0 m
.92441 .00375 L
s
.01496 0 m
.01496 .00375 L
s
.98504 0 m
.98504 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02798 m
.00625 .02798 L
s
[(-1.5)] -0.0125 .02798 1 0 Mshowa
0 .12166 m
.00625 .12166 L
s
[(-1)] -0.0125 .12166 1 0 Mshowa
0 .21534 m
.00625 .21534 L
s
[(-0.5)] -0.0125 .21534 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .4027 m
.00625 .4027 L
s
[(0.5)] -0.0125 .4027 1 0 Mshowa
0 .49638 m
.00625 .49638 L
s
[(1)] -0.0125 .49638 1 0 Mshowa
0 .59005 m
.00625 .59005 L
s
[(1.5)] -0.0125 .59005 1 0 Mshowa
.125 Mabswid
0 .04672 m
.00375 .04672 L
s
0 .06545 m
.00375 .06545 L
s
0 .08419 m
.00375 .08419 L
s
0 .10292 m
.00375 .10292 L
s
0 .14039 m
.00375 .14039 L
s
0 .15913 m
.00375 .15913 L
s
0 .17787 m
.00375 .17787 L
s
0 .1966 m
.00375 .1966 L
s
0 .23407 m
.00375 .23407 L
s
0 .25281 m
.00375 .25281 L
s
0 .27155 m
.00375 .27155 L
s
0 .29028 m
.00375 .29028 L
s
0 .32775 m
.00375 .32775 L
s
0 .34649 m
.00375 .34649 L
s
0 .36522 m
.00375 .36522 L
s
0 .38396 m
.00375 .38396 L
s
0 .42143 m
.00375 .42143 L
s
0 .44017 m
.00375 .44017 L
s
0 .4589 m
.00375 .4589 L
s
0 .47764 m
.00375 .47764 L
s
0 .51511 m
.00375 .51511 L
s
0 .53385 m
.00375 .53385 L
s
0 .55258 m
.00375 .55258 L
s
0 .57132 m
.00375 .57132 L
s
0 .00924 m
.00375 .00924 L
s
0 .60879 m
.00375 .60879 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.04527 .61178 m
.04527 .61803 L
s
.19685 .61178 m
.19685 .61803 L
s
.34842 .61178 m
.34842 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65158 .61178 m
.65158 .61803 L
s
.80315 .61178 m
.80315 .61803 L
s
.95473 .61178 m
.95473 .61803 L
s
.125 Mabswid
.07559 .61428 m
.07559 .61803 L
s
.1059 .61428 m
.1059 .61803 L
s
.13622 .61428 m
.13622 .61803 L
s
.16653 .61428 m
.16653 .61803 L
s
.22716 .61428 m
.22716 .61803 L
s
.25748 .61428 m
.25748 .61803 L
s
.28779 .61428 m
.28779 .61803 L
s
.31811 .61428 m
.31811 .61803 L
s
.37874 .61428 m
.37874 .61803 L
s
.40905 .61428 m
.40905 .61803 L
s
.43937 .61428 m
.43937 .61803 L
s
.46968 .61428 m
.46968 .61803 L
s
.53032 .61428 m
.53032 .61803 L
s
.56063 .61428 m
.56063 .61803 L
s
.59095 .61428 m
.59095 .61803 L
s
.62126 .61428 m
.62126 .61803 L
s
.68189 .61428 m
.68189 .61803 L
s
.71221 .61428 m
.71221 .61803 L
s
.74252 .61428 m
.74252 .61803 L
s
.77284 .61428 m
.77284 .61803 L
s
.83347 .61428 m
.83347 .61803 L
s
.86378 .61428 m
.86378 .61803 L
s
.8941 .61428 m
.8941 .61803 L
s
.92441 .61428 m
.92441 .61803 L
s
.01496 .61428 m
.01496 .61803 L
s
.98504 .61428 m
.98504 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02798 m
1 .02798 L
s
.99375 .12166 m
1 .12166 L
s
.99375 .21534 m
1 .21534 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .4027 m
1 .4027 L
s
.99375 .49638 m
1 .49638 L
s
.99375 .59005 m
1 .59005 L
s
.125 Mabswid
.99625 .04672 m
1 .04672 L
s
.99625 .06545 m
1 .06545 L
s
.99625 .08419 m
1 .08419 L
s
.99625 .10292 m
1 .10292 L
s
.99625 .14039 m
1 .14039 L
s
.99625 .15913 m
1 .15913 L
s
.99625 .17787 m
1 .17787 L
s
.99625 .1966 m
1 .1966 L
s
.99625 .23407 m
1 .23407 L
s
.99625 .25281 m
1 .25281 L
s
.99625 .27155 m
1 .27155 L
s
.99625 .29028 m
1 .29028 L
s
.99625 .32775 m
1 .32775 L
s
.99625 .34649 m
1 .34649 L
s
.99625 .36522 m
1 .36522 L
s
.99625 .38396 m
1 .38396 L
s
.99625 .42143 m
1 .42143 L
s
.99625 .44017 m
1 .44017 L
s
.99625 .4589 m
1 .4589 L
s
.99625 .47764 m
1 .47764 L
s
.99625 .51511 m
1 .51511 L
s
.99625 .53385 m
1 .53385 L
s
.99625 .55258 m
1 .55258 L
s
.99625 .57132 m
1 .57132 L
s
.99625 .00924 m
1 .00924 L
s
.99625 .60879 m
1 .60879 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30902 m
1 .30902 L
s
.5 0 m
.5 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .60332 m
.02847 .60044 L
.03355 .5973 L
.03832 .59435 L
.04291 .59151 L
.0478 .58849 L
.0525 .58559 L
.0575 .5825 L
.06232 .57952 L
.06695 .57666 L
.07188 .57361 L
.07662 .57068 L
.08119 .56786 L
.08604 .56486 L
.09072 .56197 L
.09569 .55889 L
.10048 .55593 L
.10509 .55309 L
.10999 .55006 L
.11471 .54714 L
.11972 .54404 L
.12456 .54105 L
.1292 .53818 L
.13415 .53512 L
.13891 .53218 L
.14349 .52935 L
.14837 .52634 L
.15306 .52344 L
.15805 .52036 L
.16285 .51739 L
.16748 .51453 L
.17239 .51149 L
.17713 .50856 L
.18168 .50575 L
.18653 .50275 L
.1912 .49987 L
.19616 .4968 L
.20094 .49385 L
.20553 .49101 L
.21043 .48798 L
.21513 .48507 L
.22014 .48198 L
.22496 .479 L
.2296 .47613 L
.23454 .47308 L
.23929 .47015 L
.24386 .46732 L
.24872 .46432 L
.2534 .46142 L
.25838 .45835 L
Mistroke
.26318 .45538 L
.26779 .45253 L
.2727 .4495 L
.27742 .44658 L
.28244 .44347 L
.28728 .44048 L
.29194 .43761 L
.29689 .43455 L
.30166 .4316 L
.30624 .42876 L
.31113 .42575 L
.31582 .42284 L
.32082 .41976 L
.32563 .41678 L
.33026 .41392 L
.33518 .41088 L
.33993 .40795 L
.34449 .40513 L
.34934 .40213 L
.35401 .39924 L
.35898 .39617 L
.36377 .39321 L
.36837 .39037 L
.37327 .38734 L
.37798 .38443 L
.38299 .38133 L
.38782 .37835 L
.39247 .37548 L
.39741 .37242 L
.40217 .36948 L
.40674 .36665 L
.41161 .36364 L
.4163 .36075 L
.42129 .35766 L
.42609 .3547 L
.43071 .35184 L
.43562 .34881 L
.44035 .34588 L
.4449 .34307 L
.44975 .34008 L
.45441 .33719 L
.45937 .33413 L
.46414 .33118 L
.46873 .32834 L
.47362 .32532 L
.47833 .32241 L
.48333 .31932 L
.48814 .31634 L
.49278 .31348 L
.49771 .31043 L
Mistroke
.50246 .3075 L
.50702 .30468 L
.51189 .30167 L
.51656 .29878 L
.52154 .29571 L
.52633 .29274 L
.53094 .2899 L
.53584 .28686 L
.54056 .28395 L
.54558 .28085 L
.55042 .27786 L
.55507 .27498 L
.56002 .27193 L
.56478 .26898 L
.56936 .26615 L
.57424 .26313 L
.57893 .26023 L
.58393 .25715 L
.58873 .25418 L
.59336 .25132 L
.59828 .24828 L
.60302 .24535 L
.60757 .24253 L
.61242 .23954 L
.61709 .23665 L
.62206 .23358 L
.62684 .23063 L
.63144 .22779 L
.63633 .22476 L
.64104 .22185 L
.64605 .21875 L
.65087 .21577 L
.65551 .2129 L
.66045 .20985 L
.66521 .20691 L
.66978 .20409 L
.67465 .20108 L
.67933 .19818 L
.68431 .19511 L
.68911 .19214 L
.69372 .18929 L
.69863 .18625 L
.70336 .18333 L
.70839 .18023 L
.71323 .17724 L
.71788 .17436 L
.72284 .1713 L
.72761 .16835 L
.7322 .16551 L
.73708 .16249 L
Mistroke
.74178 .15959 L
.74678 .1565 L
.75159 .15352 L
.75622 .15066 L
.76115 .14762 L
.7659 .14468 L
.77046 .14186 L
.77532 .13886 L
.77999 .13597 L
.78496 .1329 L
.78975 .12994 L
.79435 .1271 L
.79925 .12407 L
.80397 .12115 L
.80898 .11805 L
.81381 .11507 L
.81846 .1122 L
.82341 .10914 L
.82817 .1062 L
.83274 .10337 L
.83762 .10036 L
.84231 .09746 L
.8473 .09438 L
.8521 .09141 L
.85672 .08855 L
.86164 .08551 L
.86637 .08259 L
.87092 .07977 L
.87577 .07678 L
.88044 .0739 L
.8854 .07083 L
.89017 .06788 L
.89477 .06504 L
.89966 .06202 L
.90437 .05911 L
.90937 .05601 L
.91419 .05303 L
.91883 .05017 L
.92376 .04712 L
.92851 .04418 L
.93308 .04136 L
.93794 .03835 L
.94262 .03546 L
.9476 .03239 L
.95239 .02942 L
.957 .02657 L
.96191 .02354 L
.96663 .02062 L
.97165 .01752 L
.97619 .01472 L
Mistroke
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 148.312},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0000U2000`400?l00000o`00003oo`3ooooi
0?ooo`00o`3ooooi0?ooo`00o`3ooooi0?ooo`00o`3ooooi0?ooo`00o`3ooooi0?ooo`00;03oool3
o`0001/0oooo1Ol0000K0?ooo`?o00006P3oool2o`0001d0oooo0ol0000K0?ooo`Go00006`3oool3
o`000?l0oooo4P3oool002/0oooo00Go00000?ooo`3oool0ooooo`00000K0?ooo`04o`00003oool0
ooooo`0001`0oooo00?o00000?ooo`3oool0603oool01?l00000oooo0?ooool0000M0?ooo`03o`00
003oool0oooo01/0oooo00Co00000?ooo`3ooooo00006P3oool01Ol00000oooo0?ooo`3ooooo0000
0?l0oooo4@3oool002D0oooo1Ol000050?ooo`03o`00003oool0oooo0180oooo1Ol000030?ooo`03
o`00003oool0oooo01@0oooo1Ol000030?ooo`03o`00003oool0oooo01P0oooo00Co00000?ooo`3o
oooo00007@3oool00ol00000oooo0?ooo`0L0?ooo`03o`00003oool0oooo01h0oooo00?o00000?oo
o`3oool0@@3oool3o`0001X0oooo1Ol0000K0?ooo`?o00006@3oool2o`0001/0oooo0ol0000K0?oo
o`Go00006P3oool3o`0001L0oooo000]0?ooo`;o00007P3oool00ol00000oooo0?ooo`0K0?ooo`03
o`00003oool0oooo01P0oooo00Co00000?ooo`3ooooo00007@3oool00ol00000oooo0?ooo`0M0?oo
o`03o`00003oool0oooo01/0oooo0_l000130?ooo`05o`00003oool0oooo0?ooool000006P3oool0
1?l00000oooo0?ooool0000L0?ooo`03o`00003oool0oooo01L0oooo00Co00000?ooo`3ooooo0000
6`3oool00ol00000oooo0?ooo`0K0?ooo`04o`00003oool0ooooo`0001T0oooo00Go00000?ooo`3o
ool0ooooo`00000F0?ooo`00;`3oool00ol00000oooo0?ooo`0H0?ooo`05o`00003oool0oooo0?oo
ool00000703oool00ol00000oooo0?ooo`0H0?ooo`04o`00003oool0ooooo`0001d0oooo00?o0000
0?ooo`3oool06P3oool01Ol00000oooo0?ooo`3ooooo000001h0oooo00?o00000?ooo`3oool0>P3o
ool5o`0000D0oooo00?o00000?ooo`3oool04@3oool5o`0000<0oooo00?o00000?ooo`3oool0503o
ool5o`0000<0oooo00?o00000?ooo`3oool05`3oool01?l00000oooo0?ooool0000K0?ooo`03o`00
003oool0oooo01`0oooo00?o00000?ooo`3oool07@3oool00ol00000oooo0?ooo`0D0?ooo`00:`3o
ool01Ol00000oooo0?ooo`3ooooo000001X0oooo00Go00000?ooo`3oool0ooooo`00000K0?ooo`;o
00006P3oool01?l00000oooo0?ooool0000L0?ooo`;o0000703oool01Ol00000oooo0?ooo`3ooooo
000001X0oooo00Go00000?ooo`3oool0ooooo`0000140?ooo`;o00007@3oool00ol00000oooo0?oo
o`0K0?ooo`03o`00003oool0oooo01L0oooo00Co00000?ooo`3ooooo00006`3oool00ol00000oooo
0?ooo`0M0?ooo`03o`00003oool0oooo01X0oooo0_l0000G0?ooo`00;03oool3o`0001`0oooo0ol0
000M0?ooo`03o`00003oool0oooo01T0oooo0_l0000N0?ooo`03o`00003oool0oooo01/0oooo0ol0
000L0?ooo`?o0000A`3oool00ol00000oooo0?ooo`0G0?ooo`05o`00003oool0oooo0?ooool00000
703oool00ol00000oooo0?ooo`0G0?ooo`04o`00003oool0ooooo`0001/0oooo00?o00000?ooo`3o
ool06P3oool01Ol00000oooo0?ooo`3ooooo000001d0oooo00?o00000?ooo`3oool0503oool00?l0
oooo:`3oool01Ol00000oooo0?ooo`3ooooo000001T0oooo00Go00000?ooo`3oool0ooooo`00000K
0?ooo`;o00006@3oool01?l00000oooo0?ooool0000J0?ooo`;o0000703oool01Ol00000oooo0?oo
o`3ooooo000001T0oooo00Go00000?ooo`3oool0ooooo`00000F0?ooo`00o`3oool/0?ooo`?o0000
6`3oool3o`0001d0oooo00?o00000?ooo`3oool0603oool2o`0001`0oooo00?o00000?ooo`3oool0
6`3oool3o`0001/0oooo0ol0000G0?ooo`00o`3ooooi0?ooo`008@3oooo?o`000?l0oooo2@3oool0
01/0oooo0_l000040?ooo`05o`00003oool0oooo0?ooool000001@3oool00`000000oooo0?ooo`03
0?ooo`03o`00003oool0oooo00<0oooo00?o00000?ooo`3oool00`3oool00ol00000oooo0?ooo`04
0?ooo`03o`00003oool0oooo00<0oooo00?o00000?ooo`3oool00`3oool00ol00000oooo0?ooo`03
0?ooo`03o`00003oool0oooo00@0oooo00?o00000?ooo`3oool00`3oool00ol00000oooo0?ooo`03
0?ooo`03o`00003oool0oooo00<0oooo00?o00000?ooo`3oool0103oool00ol00000oooo0?ooo`03
0?ooo`03o`00003oool0oooo00<0oooo00?o00000?ooo`3oool00`3oool00ol00000oooo0?ooo`04
0?ooo`03o`00003oool0oooo00<0oooo00?o00000?ooo`3oool00`3oool00ol00000oooo0?ooo`03
0?ooo`03o`00003oool0oooo00@0oooo00?o00000?ooo`3oool00`3oool00ol00000oooo0?ooo`03
0?ooo`03o`00003oool0oooo00<0oooo00?o00000?ooo`3oool0103oool00ol00000oooo0?ooo`03
0?ooo`03o`00003oool0oooo00<0oooo00?o00000?ooo`3oool00`3oool00ol00000oooo0?ooo`03
0?ooo`03o`00003oool0oooo00@0oooo00?o00000?ooo`3oool00`3oool00ol00000oooo0?ooo`03
0?ooo`04o`00003oool0ooooo`000?l0oooo2@3oool001X0oooo00Co00000?ooo`3ooooo00000`3o
ool00ol00000oooo0?ooo`070?ooo`030000003oool0oooo01`0oooo00?o00000?ooo`3oool0703o
ool00ol00000oooo0?ooo`0L0?ooo`03o`00003oool0oooo01d0oooo00?o00000?ooo`3oool0703o
ool00ol00000oooo0?ooo`0L0?ooo`03o`00003oool0oooo00H0oooo00?o00000?ooo`3oool0o`3o
ool70?ooo`006P3oool01?l00000oooo0?ooool000030?ooo`?o00000P3oool00ooo0000oooo0?oo
o`1O0?ooo`03o`00003oool0oooo05l0oooo00@0o`000?ooo`3oool0oooo0_l0000a0?ooo`030000
0?l0003o0000067o000000<00000o`000?l00000HOl000000`000000oooo0?ooo`0<0?ooo`006P3o
ool01?l00000oooo0?ooool000030?ooo`03o`00003oool0oooo0080oooo00?oo`000?ooo`3oool0
G`3oool00ol00000oooo0?ooo`1O0?ooo`030?l0003oool0oooo0080oooo00?o00000?ooo`3oool0
;`3oool00`000000oooo0?ooo`060?ooo`03o`00003oool0oooo01/0oooo00?o00000?ooo`3oool0
703oool00ol00000oooo0?ooo`0K0?ooo`030000003oool0oooo01/0oooo00?o00000?ooo`3oool0
703oool00ol00000oooo0?ooo`0K0?ooo`03o`00003oool0oooo00H0oooo00<000000?ooo`3oool0
303oool001X0oooo00Co00000?ooo`3ooooo00000`3oool00ol00000oooo0?ooo`030?ooo`03ool0
003oool0oooo05h0oooo00?o00000?ooo`3oool0GP3oool00`3o0000oooo0?ooo`030?ooo`03o`00
003oool0oooo02l0oooo00<00000o`00003oool0H@3oool00`000000oooo0?ooo`1P0?ooo`03o`00
00000000oooo00d0oooo000J0?ooo`04o`00003oool0ooooo`0000<0oooo00?o00000?ooo`3oool0
0`3oool00ooo0000oooo0?ooo`1N0?ooo`03o`00003oool0oooo05h0oooo00<0o`000?ooo`3oool0
0`3oool00ol00000oooo0?ooo`0K0?ooo`?o0000103oool00ol00000oooo0?ooo`020?ooo`?o0000
1@3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo05`0oooo00?oo`000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0<0?ooo`006`3oool2o`0000@0oooo00?o00000?ooo`3oool0103o
ool00ooo0000oooo0?ooo`1M0?ooo`03o`00003oool0oooo05d0oooo00<0o`000?ooo`3oool0103o
ool00ol00000oooo0?ooo`0L0?ooo`03o`00003oool0oooo00L0oooo00Go00000?ooo`3oool0oooo
o`0000040?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0FP3oool2ool000D0oooo
00<000000?ooo`3oool0303oool00240oooo00?o00000?ooo`3oool0103oool00ooo0000oooo0?oo
o`1M0?ooo`03o`00003oool0oooo05d0oooo00<0o`000?ooo`3oool0103oool00ol00000oooo0?oo
o`0D0?ooo`Go00000`3oool00ol00000oooo0?ooo`0;0?ooo`03o`00003oool0oooo0080oooo00<0
0000o`00003oool0H@3oool00`000000oooo0?ooo`1I0?ooo`03ool0003oool0oooo00@0oooo00?o
00000000003oool03@3oool00240oooo0_l000060?ooo`03ool0003oool0oooo05`0oooo00?o0000
0?ooo`3oool0G03oool00`3o0000oooo0?ooo`040?ooo`;o00007P3oool00ol00000oooo0?ooo`0;
0?ooo`03o`00003oool0oooo0080oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`1G
0?ooo`;oo`00203oool00`000000oooo0?ooo`0<0?ooo`008@3oool00ol00000oooo0?ooo`050?oo
o`03ool0003oool0oooo05`0oooo00?o00000?ooo`3oool0G03oool00`3o0000oooo0?ooo`050?oo
o`03o`00003oool0oooo01`0oooo00?o00000?ooo`3oool01`3oool4o`0000D0oooo00<000000?oo
o`3oool0H@3oool00`000000oooo0?ooo`1E0?ooo`;oo`002P3oool00`000000oooo0?ooo`0<0?oo
o`008@3oool00ol00000oooo0?ooo`060?ooo`03ool0003oool0oooo05/0oooo00?o00000?ooo`3o
ool0F`3oool00`3o0000oooo0?ooo`060?ooo`03o`00003oool0oooo01/0oooo0_l000090?ooo`03
o`00003oool0oooo00H0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`1D0?ooo`03
ool0003oool0oooo00X0oooo00<000000?ooo`3oool0303oool00240oooo00?o00000?ooo`3oool0
1P3oool00ooo0000oooo0?ooo`1K0?ooo`03o`00003oool0oooo05/0oooo00<0o`000?ooo`3oool0
1P3oool00ol00000oooo0?ooo`0L0?ooo`03o`00003oool0oooo00L0oooo1Ol000040?ooo`030000
0?l00000oooo0640oooo00<000000?ooo`3oool0DP3oool2ool000`0oooo00?o00000000003oool0
3@3oool00240oooo00?o00000?ooo`3oool01`3oool00ooo0000oooo0?ooo`1J0?ooo`03o`00003o
ool0oooo05/0oooo00<0o`000?ooo`3oool01P3oool00ol00000oooo0?ooo`0_0?ooo`030000003o
ool0oooo0640oooo00<000000?ooo`3oool0D03oool2ool000l0oooo00<000000?ooo`3oool0303o
ool00240oooo00?o00000?ooo`3oool01`3oool00ooo0000oooo0?ooo`1J0?ooo`03o`00003oool0
oooo05/0oooo00<0o`000?ooo`3oool01P3oool00ol00000oooo0?ooo`0_0?ooo`030000003oool0
oooo0640oooo00<000000?ooo`3oool0C`3oool00ooo0000oooo0?ooo`0?0?ooo`030000003oool0
oooo00`0oooo000Q0?ooo`;o00002@3oool00ooo0000oooo0?ooo`1I0?ooo`03o`00003oool0oooo
05X0oooo00<0o`000?ooo`3oool01P3oool2o`000340oooo00<000000?ooo`3oool0H@3oool00`00
0000oooo0?ooo`1=0?ooo`;oo`004P3oool00`000000oooo0?ooo`0<0?ooo`008@3oool00ol00000
oooo0?ooo`080?ooo`03ool0003oool0oooo05T0oooo00?o00000?ooo`3oool0FP3oool00`3o0000
oooo0?ooo`070?ooo`03o`00003oool0oooo02l0oooo00<00000o`00003oool0H@3oool00`000000
oooo0?ooo`1;0?ooo`;oo`004`3oool00ol0000000000?ooo`0=0?ooo`008@3oool00ol00000oooo
0?ooo`090?ooo`03ool0003oool0oooo05P0oooo00?o00000?ooo`3oool0F@3oool00`3o0000oooo
0?ooo`080?ooo`03o`00003oool0oooo02l0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`1:0?ooo`03ool0003oool0oooo01@0oooo00<000000?ooo`3oool0303oool00240oooo00?o
00000?ooo`3oool02@3oool00ooo0000oooo0?ooo`1H0?ooo`03o`00003oool0oooo05P0oooo00?o
o`000?ooo`3oool02@3oool00ol00000oooo0?ooo`0_0?ooo`030000003oool0oooo0640oooo00<0
00000?ooo`3oool0B03oool2ool001L0oooo00<000000?ooo`3oool0303oool00240oooo00?o0000
0?ooo`3oool02P3oool00ooo0000oooo0?ooo`1G0?ooo`03o`00003oool0oooo05P0oooo00<0o`00
0?ooo`3oool02@3oool00ol00000oooo0?ooo`0_0?ooo`030000003oool0oooo0640oooo00<00000
0?ooo`3oool0AP3oool2ool001T0oooo00<000000?ooo`3oool0303oool00240oooo00?o00000?oo
o`3oool02P3oool00ooo0000oooo0?ooo`1G0?ooo`03o`00003oool0oooo05L0oooo00<0o`000?oo
o`3oool02P3oool00ol00000oooo0?ooo`0_0?ooo`0300000?l00000oooo0640oooo00<000000?oo
o`3oool0A03oool2ool001X0oooo00?o00000000003oool03@3oool00240oooo00?o00000?ooo`3o
ool02`3oool00ooo0000oooo0?ooo`1F0?ooo`03o`00003oool0oooo05L0oooo00<0o`000?ooo`3o
ool02P3oool00ol00000oooo0?ooo`0_0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3o
ool0A03oool00ooo0000oooo0?ooo`0J0?ooo`030000003oool0oooo00`0oooo000Q0?ooo`;o0000
3@3oool00ooo0000oooo0?ooo`1E0?ooo`03o`00003oool0oooo05H0oooo00<0o`000?ooo`3oool0
2P3oool2o`000340oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`120?ooo`;oo`00
7@3oool00`000000oooo0?ooo`0<0?ooo`008@3oool00ol00000oooo0?ooo`0<0?ooo`03ool0003o
ool0oooo05D0oooo00?o00000?ooo`3oool0EP3oool00`3o0000oooo0?ooo`0;0?ooo`03o`00003o
ool0oooo02l0oooo00<00000o`00003oool0H@3oool00`000000oooo0?ooo`100?ooo`;oo`007P3o
ool00ol0000000000?ooo`0=0?ooo`008@3oool00ol00000oooo0?ooo`0=0?ooo`03ool0003oool0
oooo05@0oooo00?o00000?ooo`3oool0E@3oool00`3o0000oooo0?ooo`0<0?ooo`03o`00003oool0
oooo02l0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0o0?ooo`03ool0003oool0
oooo01l0oooo00<000000?ooo`3oool0303oool000l0oooo0_l000040?ooo`04o`00003oool0oooo
0?ooo`Go00000`3oool00ol00000oooo0?ooo`0=0?ooo`03ool0003oool0oooo05@0oooo00?o0000
0?ooo`3oool0E@3oool00`3o0000oooo0?ooo`0<0?ooo`03o`00003oool0oooo02L0oooo0ol00005
0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0?@3oool2ool00280oooo00<00000
0?ooo`3oool0303oool000h0oooo00Co00000?ooo`3ooooo0000203oool01?l00000oooo0?ooool0
00030?ooo`03o`00003oool0oooo00h0oooo00?oo`000?ooo`3oool0D`3oool00ol00000oooo0?oo
o`1D0?ooo`030?l0003oool0oooo00d0oooo00?o00000?ooo`3oool0:03oool00ol00000oooo0?oo
o`040?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0>`3oool2ool002@0oooo00<0
00000?ooo`3oool0303oool000h0oooo00Co00000?ooo`3ooooo00002@3oool00ol00000oooo0?oo
o`030?ooo`03o`00003oool0oooo00h0oooo00?oo`000?ooo`3oool0D`3oool00ol00000oooo0?oo
o`1D0?ooo`030?l0003oool0oooo00d0oooo00?o00000?ooo`3oool0803oool5o`0000<0oooo00?o
00000?ooo`3oool0103oool00`00003o00000?ooo`1Q0?ooo`030000003oool0oooo03X0oooo00?o
o`000?ooo`3oool08`3oool00ol0000000000?ooo`0=0?ooo`003P3oool01?l00000oooo0?ooool0
000:0?ooo`03o`00003oool0oooo0080oooo0ol0000?0?ooo`03ool0003oool0oooo0580oooo00?o
00000?ooo`3oool0D`3oool00`3o0000oooo0?ooo`0=0?ooo`;o0000:P3oool00ol00000oooo0?oo
o`040?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0>03oool2ool002L0oooo00<0
00000?ooo`3oool0303oool000h0oooo00Co00000?ooo`3ooooo00001`3oool01Ol00000oooo0?oo
o`3ooooo000000<0oooo00?o00000?ooo`3oool03`3oool00ooo0000oooo0?ooo`1B0?ooo`03o`00
003oool0oooo05<0oooo00<0o`000?ooo`3oool03P3oool00ol00000oooo0?ooo`0X0?ooo`03o`00
003oool0oooo00@0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0f0?ooo`;oo`00
:@3oool00`000000oooo0?ooo`0<0?ooo`003P3oool01?l00000oooo0?ooool000070?ooo`05o`00
003oool0oooo0?ooool000000`3oool00ol00000oooo0?ooo`0@0?ooo`03ool0003oool0oooo0540
oooo00?o00000?ooo`3oool0DP3oool00`3o0000oooo0?ooo`0?0?ooo`03o`00003oool0oooo02L0
oooo0_l000060?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0=@3oool00ooo0000
oooo0?ooo`0Y0?ooo`030000003oool0oooo00`0oooo000?0?ooo`;o00002@3oool3o`0000@0oooo
00?o00000?ooo`3oool0403oool00ooo0000oooo0?ooo`1A0?ooo`03o`00003oool0oooo0580oooo
00<0o`000?ooo`3oool03`3oool00ol00000oooo0?ooo`0X0?ooo`03o`00003oool0oooo00@0oooo
00<00000o`00003oool0H@3oool00`000000oooo0?ooo`0c0?ooo`;oo`00:`3oool00ol000000000
0?ooo`0=0?ooo`008@3oool00ol00000oooo0?ooo`0A0?ooo`03ool0003oool0oooo0500oooo00?o
00000?ooo`3oool0D@3oool00`3o0000oooo0?ooo`0@0?ooo`03o`00003oool0oooo02l0oooo00<0
00000?ooo`3oool0H@3oool00`000000oooo0?ooo`0a0?ooo`;oo`00;P3oool00`000000oooo0?oo
o`0<0?ooo`008@3oool00ol00000oooo0?ooo`0A0?ooo`03ool0003oool0oooo0500oooo00?o0000
0?ooo`3oool0D03oool00ooo0000oooo0?ooo`0A0?ooo`03o`00003oool0oooo02l0oooo00<00000
0?ooo`3oool0H@3oool00`000000oooo0?ooo`0_0?ooo`;oo`00<03oool00`000000oooo0?ooo`0<
0?ooo`008@3oool2o`0001<0oooo00?oo`000?ooo`3oool0C`3oool00ol00000oooo0?ooo`1@0?oo
o`030?l0003oool0oooo0100oooo0_l0000a0?ooo`030000003oool0oooo0640oooo00<000000?oo
o`3oool0;P3oool00ooo0000oooo0?ooo`0`0?ooo`030000003oool0oooo00`0oooo000Q0?ooo`03
o`00003oool0oooo01<0oooo00?oo`000?ooo`3oool0CP3oool00ol00000oooo0?ooo`1?0?ooo`03
0?l0003oool0oooo0180oooo00?o00000?ooo`3oool0;`3oool00`00003o00000?ooo`1Q0?ooo`03
0000003oool0oooo02d0oooo00?oo`000?ooo`3oool0<03oool00ol0000000000?ooo`0=0?ooo`00
8@3oool00ol00000oooo0?ooo`0C0?ooo`03ool0003oool0oooo04h0oooo00?o00000?ooo`3oool0
C`3oool00`3o0000oooo0?ooo`0B0?ooo`03o`00003oool0oooo02l0oooo00<000000?ooo`3oool0
H@3oool00`000000oooo0?ooo`0[0?ooo`;oo`00=03oool00`000000oooo0?ooo`0<0?ooo`008@3o
ool00ol00000oooo0?ooo`0D0?ooo`03ool0003oool0oooo04d0oooo00?o00000?ooo`3oool0CP3o
ool00`3o0000oooo0?ooo`0C0?ooo`03o`00003oool0oooo02l0oooo00<000000?ooo`3oool0H@3o
ool00`000000oooo0?ooo`0Z0?ooo`03ool0003oool0oooo03@0oooo00<000000?ooo`3oool0303o
ool00240oooo00?o00000?ooo`3oool0503oool00ooo0000oooo0?ooo`1=0?ooo`03o`00003oool0
oooo04h0oooo00<0o`000?ooo`3oool04`3oool00ol00000oooo0?ooo`0_0?ooo`0300000?l00000
oooo0640oooo00<000000?ooo`3oool0:03oool2ool003H0oooo00?o00000000003oool03@3oool0
0240oooo00?o00000?ooo`3oool05@3oool00ooo0000oooo0?ooo`1<0?ooo`03o`00003oool0oooo
04d0oooo00<0o`000?ooo`3oool0503oool00ol00000oooo0?ooo`0_0?ooo`030000003oool0oooo
0640oooo00<000000?ooo`3oool09P3oool2ool003T0oooo00<000000?ooo`3oool0303oool00240
oooo0_l0000F0?ooo`03ool0003oool0oooo04`0oooo00?o00000?ooo`3oool0C@3oool00`3o0000
oooo0?ooo`0C0?ooo`;o0000<@3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo02D0
oooo00?oo`000?ooo`3oool0>@3oool00`000000oooo0?ooo`0<0?ooo`008@3oool00ol00000oooo
0?ooo`0F0?ooo`03ool0003oool0oooo04/0oooo00?o00000?ooo`3oool0C03oool00`3o0000oooo
0?ooo`0E0?ooo`03o`00003oool0oooo02l0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`0S0?ooo`;oo`00?03oool00`000000oooo0?ooo`0<0?ooo`008@3oool00ol00000oooo0?oo
o`0F0?ooo`03ool0003oool0oooo04/0oooo00?o00000?ooo`3oool0C03oool00`3o0000oooo0?oo
o`0E0?ooo`03o`00003oool0oooo02l0oooo00<00000o`00003oool0H@3oool00`000000oooo0?oo
o`0Q0?ooo`;oo`00?@3oool00ol0000000000?ooo`0=0?ooo`008@3oool00ol00000oooo0?ooo`0G
0?ooo`03ool0003oool0oooo04X0oooo00?o00000?ooo`3oool0B`3oool00`3o0000oooo0?ooo`0F
0?ooo`03o`00003oool0oooo01`0oooo0_l000040?ooo`03o`00003oool0oooo0080oooo0ol00005
0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0803oool00ooo0000oooo0?ooo`0n
0?ooo`030000003oool0oooo00`0oooo000Q0?ooo`03o`00003oool0oooo01L0oooo00?oo`000?oo
o`3oool0BP3oool00ol00000oooo0?ooo`1:0?ooo`03ool0003oool0oooo01L0oooo00?o00000?oo
o`3oool06`3oool01?l00000oooo0?ooool000070?ooo`05o`00003oool0oooo0?ooool00000103o
ool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo01h0oooo0_oo00110?ooo`030000003o
ool0oooo00`0oooo000Q0?ooo`03o`00003oool0oooo01P0oooo00?oo`000?ooo`3oool0B@3oool0
0ol00000oooo0?ooo`1:0?ooo`030?l0003oool0oooo01L0oooo00?o00000?ooo`3oool0503oool5
o`000080oooo00Co00000?ooo`3ooooo00002`3oool00ol00000oooo0?ooo`020?ooo`030000003o
ool0oooo0640oooo00<000000?ooo`3oool0703oool2ool004<0oooo00<000000?ooo`3oool0303o
ool00240oooo0_l0000J0?ooo`03ool0003oool0oooo04P0oooo00?o00000?ooo`3oool0B@3oool0
0`3o0000oooo0?ooo`0G0?ooo`;o00007@3oool01?l00000oooo0?ooool0000;0?ooo`03o`00003o
ool0oooo0080oooo00<00000o`00003oool0H@3oool00`000000oooo0?ooo`0K0?ooo`03ool0003o
ool0oooo0480oooo00?o00000000003oool03@3oool00240oooo00?o00000?ooo`3oool06@3oool0
0ooo0000oooo0?ooo`180?ooo`03o`00003oool0oooo04T0oooo00<0o`000?ooo`3oool0603oool0
0ol00000oooo0?ooo`0K0?ooo`04o`00003oool0ooooo`0000L0oooo1?l000050?ooo`030000003o
ool0oooo0640oooo00<000000?ooo`3oool06@3oool2ool004H0oooo00<000000?ooo`3oool0303o
ool00240oooo00?o00000?ooo`3oool06P3oool00ooo0000oooo0?ooo`170?ooo`03o`00003oool0
oooo04P0oooo00<0o`000?ooo`3oool06@3oool00ol00000oooo0?ooo`0K0?ooo`04o`00003oool0
ooooo`0000L0oooo00?o00000?ooo`3oool01P3oool00`000000oooo0?ooo`1Q0?ooo`030000003o
ool0oooo01L0oooo0_oo00180?ooo`030000003oool0oooo00`0oooo000?0?ooo`;o0000103oool0
0ol00000oooo0?ooo`030?ooo`?o00000`3oool00ol00000oooo0?ooo`0J0?ooo`03ool0003oool0
oooo04L0oooo00?o00000?ooo`3oool0B03oool00`3o0000oooo0?ooo`0I0?ooo`03o`00003oool0
oooo01`0oooo0_l000080?ooo`Go0000103oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0
oooo01H0oooo00?oo`000?ooo`3oool0B03oool00`000000oooo0?ooo`0<0?ooo`003P3oool01?l0
0000oooo0?ooool0000:0?ooo`03o`00003oool0oooo0080oooo00?o00000?ooo`3oool06`3oool0
0ooo0000oooo0?ooo`160?ooo`03o`00003oool0oooo04L0oooo00<0o`000?ooo`3oool06P3oool0
0ol00000oooo0?ooo`0_0?ooo`0300000?l00000oooo0640oooo00<000000?ooo`3oool0503oool2
ool004X0oooo00?o00000000003oool03@3oool000h0oooo00Co00000?ooo`3ooooo00001`3oool5
o`0000<0oooo00?o00000?ooo`3oool06`3oool00ooo0000oooo0?ooo`160?ooo`03o`00003oool0
oooo04L0oooo00<0o`000?ooo`3oool06P3oool00ol00000oooo0?ooo`0_0?ooo`030000003oool0
oooo0640oooo00<000000?ooo`3oool04`3oool2ool004`0oooo00<000000?ooo`3oool0303oool0
00h0oooo00Co00000?ooo`3ooooo00001`3oool01?l00000oooo0?ooool000040?ooo`03o`000000
0000000001`0oooo00?oo`000?ooo`3oool0A@3oool00ol00000oooo0?ooo`160?ooo`030?l0003o
ool0oooo01X0oooo0_l0000a0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool04@3o
ool2ool004h0oooo00<000000?ooo`3oool0303oool000h0oooo00Co00000?ooo`3ooooo0000203o
ool00ol00000ooooo`0000040?ooo`03o`00003oool0oooo01d0oooo00?oo`000?ooo`3oool0A03o
ool00ol00000oooo0?ooo`150?ooo`03ool0003oool0oooo01`0oooo00?o00000?ooo`3oool0;`3o
ool00`00003o00000?ooo`1Q0?ooo`030000003oool0oooo0100oooo00?oo`000?ooo`3oool0C@3o
ool00ol0000000000?ooo`0=0?ooo`003P3oool01?l00000oooo0?ooool000090?ooo`;o0000103o
ool00ol00000oooo0?ooo`0M0?ooo`03ool0003oool0oooo04@0oooo00?o00000?ooo`3oool0A@3o
ool00`3o0000oooo0?ooo`0L0?ooo`03o`00003oool0oooo02l0oooo00<000000?ooo`3oool0H@3o
ool00`000000oooo0?ooo`0>0?ooo`;oo`00D@3oool00`000000oooo0?ooo`0<0?ooo`003`3oool2
o`0000/0oooo00?o00000?ooo`3oool00P3oool00ol00000oooo0?ooo`0N0?ooo`03ool0003oool0
oooo04<0oooo00?o00000?ooo`3oool0A03oool00`3o0000oooo0?ooo`0M0?ooo`03o`00003oool0
oooo02l0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0<0?ooo`;oo`00D`3oool0
0`000000oooo0?ooo`0<0?ooo`008@3oool00ol00000oooo0?ooo`0N0?ooo`03ool0003oool0oooo
04<0oooo00?o00000?ooo`3oool0A03oool00`3o0000oooo0?ooo`0M0?ooo`03o`00003oool0oooo
02l0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0;0?ooo`03ool0003oool0oooo
05<0oooo00<000000?ooo`3oool0303oool00240oooo00?o00000?ooo`3oool07`3oool00ooo0000
oooo0?ooo`120?ooo`03o`00003oool0oooo04<0oooo00<0o`000?ooo`3oool07P3oool00ol00000
oooo0?ooo`0_0?ooo`0300000?l00000oooo0640oooo00<000000?ooo`3oool02@3oool2ool005D0
oooo00?o00000000003oool03@3oool00240oooo0_l0000P0?ooo`03ool0003oool0oooo0480oooo
00?o00000?ooo`3oool0@P3oool00ooo0000oooo0?ooo`0N0?ooo`;o0000<@3oool00`000000oooo
0?ooo`1Q0?ooo`030000003oool0oooo00L0oooo0_oo001H0?ooo`030000003oool0oooo00`0oooo
000Q0?ooo`03o`00003oool0oooo0200oooo00?oo`000?ooo`3oool0@@3oool00ol00000oooo0?oo
o`120?ooo`030?l0003oool0oooo01l0oooo00?o00000?ooo`3oool0;`3oool00`000000oooo0?oo
o`1Q0?ooo`030000003oool0oooo00H0oooo00?oo`000?ooo`3oool0F03oool00`000000oooo0?oo
o`0<0?ooo`008@3oool00ol00000oooo0?ooo`0Q0?ooo`03ool0003oool0oooo0400oooo00?o0000
0?ooo`3oool0@@3oool00`3o0000oooo0?ooo`0P0?ooo`03o`00003oool0oooo02l0oooo00<00000
0?ooo`3oool0H@3oool00`000000oooo0?ooo`040?ooo`;oo`00F`3oool00`000000oooo0?ooo`0<
0?ooo`008@3oool00ol00000oooo0?ooo`0Q0?ooo`03ool0003oool0oooo0400oooo00?o00000?oo
o`3oool0@@3oool00`3o0000oooo0?ooo`0P0?ooo`03o`00003oool0oooo02l0oooo00<00000o`00
003oool0H@3oool00`000000oooo0?ooo`020?ooo`;oo`00G03oool00ol0000000000?ooo`0=0?oo
o`008@3oool00ol00000oooo0?ooo`0R0?ooo`03ool0003oool0oooo03l0oooo00?o00000?ooo`3o
ool0@03oool00`3o0000oooo0?ooo`0Q0?ooo`03o`00003oool0oooo02P0oooo0_l000050?ooo`03
0000003oool0oooo0640oooo00D000000?ooo`3oool0ooooool0001O0?ooo`030000003oool0oooo
00`0oooo000Q0?ooo`03o`00003oool0oooo0280oooo00?oo`000?ooo`3oool0?`3oool00ol00000
oooo0?ooo`100?ooo`030?l0003oool0oooo0240oooo00?o00000?ooo`3oool09`3oool01?l00000
oooo0?ooool000040?ooo`030000003oool0oooo0640oooo00@000000?oooooo003oo`00H03oool0
0`000000oooo0?ooo`0<0?ooo`008@3oool2o`0002@0oooo00?oo`000?ooo`3oool0?P3oool00ol0
0000oooo0?ooo`0o0?ooo`030?l0003oool0oooo0240oooo0_l0000Y0?ooo`04o`00003oool0oooo
o`0000@0oooo00<000000?ooo`3oool0H@3oool2ool00680oooo00<000000?ooo`3oool0303oool0
0240oooo00?o00000?ooo`3oool0903oool00ooo0000oooo0?ooo`0m0?ooo`03o`00003oool0oooo
03h0oooo00?oo`000?ooo`3oool08`3oool00ol00000oooo0?ooo`0W0?ooo`04o`00003oool0oooo
o`0000@0ooooI00000000ooo000000000000001R000000h0oooo000Q0?ooo`03o`00003oool0oooo
02@0oooo00?oo`000?ooo`3oool0?@3oool00ol00000oooo0?ooo`0n0?ooo`030?l0003oool0oooo
02<0oooo00?o00000?ooo`3oool09`3oool01?l00000oooo0?ooool000040?ooo`030000003oool0
oooo05l0oooo0_oo00000`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo00`0oooo000Q0?oo
o`03o`00003oool0oooo02D0oooo00?oo`000?ooo`3oool0?03oool00ol00000oooo0?ooo`0m0?oo
o`030?l0003oool0oooo02@0oooo00?o00000?ooo`3oool09`3oool01?l00000oooo0?ooool00004
0?ooo`030000003oool0oooo05d0oooo0_oo00020?ooo`030000003oool0oooo0640oooo00<00000
0?ooo`3oool0303oool00240oooo00?o00000?ooo`3oool09@3oool00ooo0000oooo0?ooo`0l0?oo
o`03o`00003oool0oooo03d0oooo00<0o`000?ooo`3oool0903oool00ol00000oooo0?ooo`0X0?oo
o`;o00001@3oool00`00003o00000?ooo`1K0?ooo`;oo`00103oool00`000000oooo0?ooo`1P0?oo
o`03o`0000000000oooo00d0oooo000Q0?ooo`03o`00003oool0oooo02H0oooo00?oo`000?ooo`3o
ool0>`3oool00ol00000oooo0?ooo`0l0?ooo`030?l0003oool0oooo02D0oooo00?o00000?ooo`3o
ool0;`3oool00`000000oooo0?ooo`1J0?ooo`03ool0003oool0oooo00@0oooo00<000000?ooo`3o
ool0H@3oool00`000000oooo0?ooo`0<0?ooo`008@3oool2o`0002P0oooo00?oo`000?ooo`3oool0
>P3oool00ol00000oooo0?ooo`0k0?ooo`03ool0003oool0oooo02D0oooo0_l0000a0?ooo`030000
003oool0oooo05P0oooo0_oo00070?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0
303oool00240oooo00?o00000?ooo`3oool09`3oool00ooo0000oooo0?ooo`0j0?ooo`03o`00003o
ool0oooo03/0oooo00<0o`000?ooo`3oool09P3oool00ol00000oooo0?ooo`0_0?ooo`030000003o
ool0oooo05H0oooo0_oo00090?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0303o
ool00240oooo00?o00000?ooo`3oool0:03oool00ooo0000oooo0?ooo`0i0?ooo`03o`00003oool0
oooo03X0oooo00<0o`000?ooo`3oool09`3oool00ol00000oooo0?ooo`0_0?ooo`0300000?l00000
oooo05D0oooo00?oo`000?ooo`3oool02@3oool00`000000oooo0?ooo`1P0?ooo`03o`0000000000
oooo00d0oooo000Q0?ooo`03o`00003oool0oooo02T0oooo00?oo`000?ooo`3oool0>03oool00ol0
0000oooo0?ooo`0i0?ooo`03ool0003oool0oooo02P0oooo00?o00000?ooo`3oool0;`3oool00`00
0000oooo0?ooo`1C0?ooo`;oo`00303oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo
00`0oooo000?0?ooo`;o0000103oool00ol00000oooo0?ooo`020?ooo`?o0000103oool00ol00000
oooo0?ooo`0Y0?ooo`03ool0003oool0oooo03P0oooo00?o00000?ooo`3oool0>@3oool00`3o0000
oooo0?ooo`0X0?ooo`03o`00003oool0oooo02l0oooo00<000000?ooo`3oool0D@3oool2ool000h0
oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0<0?ooo`003P3oool01?l00000oooo
0?ooool000070?ooo`05o`00003oool0oooo0?ooool000000`3oool00ol00000oooo0?ooo`0Z0?oo
o`03ool0003oool0oooo03L0oooo00?o00000?ooo`3oool0>03oool00`3o0000oooo0?ooo`0Y0?oo
o`03o`00003oool0oooo02l0oooo00<000000?ooo`3oool0D03oool00ooo0000oooo0?ooo`0>0?oo
o`030000003oool0oooo0640oooo00<000000?ooo`3oool0303oool000h0oooo00Co00000?ooo`3o
oooo00001`3oool01Ol00000oooo0?ooo`3ooooo000000<0oooo00?o0000000000000000:`3oool0
0ooo0000oooo0?ooo`0f0?ooo`03o`00003oool0oooo03L0oooo00?oo`000?ooo`3oool0:@3oool2
o`000340oooo00<00000o`00003oool0CP3oool2ool00140oooo00<000000?ooo`3oool0H03oool0
0ol0000000000?ooo`0=0?ooo`003P3oool01?l00000oooo0?ooool000070?ooo`Co0000103oool0
0ol00000oooo0?ooo`0[0?ooo`03ool0003oool0oooo03H0oooo00?o00000?ooo`3oool0=`3oool0
0`3o0000oooo0?ooo`0Z0?ooo`03o`00003oool0oooo02l0oooo00<000000?ooo`3oool0C03oool2
ool001<0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0<0?ooo`003P3oool01?l0
0000oooo0?ooool000070?ooo`03o`00003oool0oooo00D0oooo00?o00000?ooo`3oool0;03oool0
0ooo0000oooo0?ooo`0e0?ooo`03o`00003oool0oooo03H0oooo00<0o`000?ooo`3oool0:`3oool0
0ol00000oooo0?ooo`0_0?ooo`030000003oool0oooo04/0oooo00?oo`000?ooo`3oool04`3oool0
0`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo00`0oooo000>0?ooo`04o`00003oool0oooo
o`0000P0oooo00?o00000?ooo`3oool0103oool00ol00000oooo0?ooo`0]0?ooo`03ool0003oool0
oooo03@0oooo00?o00000?ooo`3oool0=@3oool00ooo0000oooo0?ooo`0/0?ooo`03o`00003oool0
oooo02l0oooo00<000000?ooo`3oool0BP3oool2ool001D0oooo00<000000?ooo`3oool0H@3oool0
0`000000oooo0?ooo`0<0?ooo`003`3oool2o`0000X0oooo0_l000040?ooo`03o`00003oool0oooo
02d0oooo00?oo`000?ooo`3oool0=03oool00ol00000oooo0?ooo`0e0?ooo`030?l0003oool0oooo
02`0oooo00?o00000?ooo`3oool0;`3oool00`00003o00000?ooo`180?ooo`;oo`005`3oool00`00
0000oooo0?ooo`1P0?ooo`03o`0000000000oooo00d0oooo000Q0?ooo`03o`00003oool0oooo02h0
oooo00?oo`000?ooo`3oool0<`3oool00ol00000oooo0?ooo`0d0?ooo`030?l0003oool0oooo02d0
oooo00?o00000?ooo`3oool0703oool2o`0000@0oooo00?o00000?ooo`3oool00P3oool3o`0000D0
oooo00<000000?ooo`3oool0AP3oool2ool001T0oooo00<000000?ooo`3oool0H@3oool00`000000
oooo0?ooo`0<0?ooo`008@3oool2o`000300oooo00?oo`000?ooo`3oool0<P3oool00ol00000oooo
0?ooo`0c0?ooo`03ool0003oool0oooo02d0oooo0_l0000M0?ooo`04o`00003oool0ooooo`0000L0
oooo00Go00000?ooo`3oool0ooooo`0000040?ooo`030000003oool0oooo04D0oooo00?oo`000?oo
o`3oool06@3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo00`0oooo000Q0?ooo`03
o`00003oool0oooo02l0oooo00?oo`000?ooo`3oool0<P3oool00ol00000oooo0?ooo`0c0?ooo`03
0?l0003oool0oooo02h0oooo00?o00000?ooo`3oool06`3oool01?l00000oooo0?ooool0000;0?oo
o`03o`00003oool0oooo0080oooo00<00000o`00003oool0@`3oool2ool001`0oooo00<000000?oo
o`3oool0H03oool00ol0000000000?ooo`0=0?ooo`008@3oool00ol00000oooo0?ooo`0`0?ooo`03
ool0003oool0oooo0340oooo00?o00000?ooo`3oool0<P3oool00`3o0000oooo0?ooo`0_0?ooo`03
o`00003oool0oooo01/0oooo00Co00000?ooo`3ooooo00002`3oool00ol00000oooo0?ooo`020?oo
o`030000003oool0oooo0440oooo0_oo000N0?ooo`030000003oool0oooo0640oooo00<000000?oo
o`3oool0303oool00240oooo00?o00000?ooo`3oool0<@3oool00ooo0000oooo0?ooo`0`0?ooo`03
o`00003oool0oooo0340oooo00?oo`000?ooo`3oool0<03oool00ol00000oooo0?ooo`0K0?ooo`04
o`00003oool0ooooo`0000L0oooo1?l000050?ooo`030000003oool0oooo0400oooo00?oo`000?oo
o`3oool07P3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo00`0oooo000Q0?ooo`03
o`00003oool0oooo0340oooo00?oo`000?ooo`3oool0<03oool00ol00000oooo0?ooo`0a0?ooo`03
0?l0003oool0oooo0300oooo00?o00000?ooo`3oool06`3oool01?l00000oooo0?ooool000070?oo
o`03o`00003oool0oooo00H0oooo00<000000?ooo`3oool0?P3oool2ool00240oooo00<000000?oo
o`3oool0H@3oool00`000000oooo0?ooo`0<0?ooo`008@3oool00ol00000oooo0?ooo`0b0?ooo`03
ool0003oool0oooo02l0oooo00?o00000?ooo`3oool0<03oool00`3o0000oooo0?ooo`0a0?ooo`03
o`00003oool0oooo01`0oooo0_l000080?ooo`Go0000103oool00`00003o00000?ooo`0l0?ooo`;o
o`008`3oool00`000000oooo0?ooo`1P0?ooo`03o`0000000000oooo00d0oooo000Q0?ooo`;o0000
=03oool00ooo0000oooo0?ooo`0^0?ooo`03o`00003oool0oooo02l0oooo00?oo`000?ooo`3oool0
<@3oool2o`000340oooo00<000000?ooo`3oool0>`3oool00ooo0000oooo0?ooo`0S0?ooo`030000
003oool0oooo0640oooo00<000000?ooo`3oool0303oool00240oooo00?o00000?ooo`3oool0=03o
ool00ooo0000oooo0?ooo`0]0?ooo`03o`00003oool0oooo02h0oooo00?oo`000?ooo`3oool0<`3o
ool00ol00000oooo0?ooo`0_0?ooo`030000003oool0oooo03T0oooo0_oo000V0?ooo`030000003o
ool0oooo0640oooo00<000000?ooo`3oool0303oool00240oooo00?o00000?ooo`3oool0=03oool0
0ooo0000oooo0?ooo`0]0?ooo`03o`00003oool0oooo02h0oooo00<0o`000?ooo`3oool0<`3oool0
0ol00000oooo0?ooo`0_0?ooo`030000003oool0oooo03L0oooo0_oo000X0?ooo`030000003oool0
oooo0640oooo00<000000?ooo`3oool0303oool00240oooo00?o00000?ooo`3oool0=@3oool00ooo
0000oooo0?ooo`0/0?ooo`03o`00003oool0oooo02d0oooo00<0o`000?ooo`3oool0=03oool00ol0
0000oooo0?ooo`0_0?ooo`0300000?l00000oooo03H0oooo00?oo`000?ooo`3oool0:03oool00`00
0000oooo0?ooo`1P0?ooo`03o`0000000000oooo00d0oooo000Q0?ooo`03o`00003oool0oooo03H0
oooo00?oo`000?ooo`3oool0:`3oool00ol00000oooo0?ooo`0/0?ooo`03ool0003oool0oooo03D0
oooo00?o00000?ooo`3oool0;`3oool00`000000oooo0?ooo`0d0?ooo`;oo`00:`3oool00`000000
oooo0?ooo`1Q0?ooo`030000003oool0oooo00`0oooo000Q0?ooo`03o`00003oool0oooo03L0oooo
00?oo`000?ooo`3oool0:P3oool00ol00000oooo0?ooo`0[0?ooo`03ool0003oool0oooo03H0oooo
00?o00000?ooo`3oool0;`3oool00`000000oooo0?ooo`0b0?ooo`;oo`00;@3oool00`000000oooo
0?ooo`1Q0?ooo`030000003oool0oooo00`0oooo000Q0?ooo`;o0000>03oool00ooo0000oooo0?oo
o`0Z0?ooo`03o`00003oool0oooo02X0oooo00?oo`000?ooo`3oool0=P3oool2o`000340oooo00<0
00000?ooo`3oool0<P3oool00ooo0000oooo0?ooo`0/0?ooo`030000003oool0oooo0640oooo00<0
00000?ooo`3oool0303oool00240oooo00?o00000?ooo`3oool0>03oool00ooo0000oooo0?ooo`0Y
0?ooo`03o`00003oool0oooo02X0oooo00<0o`000?ooo`3oool0=`3oool00ol00000oooo0?ooo`0_
0?ooo`0300000?l00000oooo0300oooo0_oo000_0?ooo`030000003oool0oooo0600oooo00?o0000
0000003oool03@3oool00240oooo00?o00000?ooo`3oool0>@3oool00ooo0000oooo0?ooo`0X0?oo
o`03o`00003oool0oooo02T0oooo00<0o`000?ooo`3oool0>03oool00ol00000oooo0?ooo`0_0?oo
o`030000003oool0oooo02h0oooo0_oo000a0?ooo`030000003oool0oooo0640oooo00<000000?oo
o`3oool0303oool00240oooo00?o00000?ooo`3oool0>P3oool00ooo0000oooo0?ooo`0W0?ooo`03
o`00003oool0oooo02P0oooo00?oo`000?ooo`3oool0>@3oool00ol00000oooo0?ooo`0_0?ooo`03
0000003oool0oooo02`0oooo0_oo000c0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3o
ool0303oool000l0oooo0_l000040?ooo`03o`00003oool0oooo0080oooo0ol000040?ooo`03o`00
003oool0oooo03/0oooo00?oo`000?ooo`3oool09P3oool00ol00000oooo0?ooo`0W0?ooo`03ool0
003oool0oooo03X0oooo00?o00000?ooo`3oool0;`3oool00`00003o00000?ooo`0[0?ooo`03ool0
003oool0oooo03<0oooo00<000000?ooo`3oool0H03oool00ol0000000000?ooo`0=0?ooo`003P3o
ool01?l00000oooo0?ooool000070?ooo`05o`00003oool0oooo0?ooool000000`3oool00ol00000
oooo0?ooo`0l0?ooo`03ool0003oool0oooo02D0oooo00?o00000?ooo`3oool09P3oool00ooo0000
oooo0?ooo`0k0?ooo`03o`00003oool0oooo02l0oooo00<000000?ooo`3oool0:@3oool2ool003H0
oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0<0?ooo`003P3oool01?l00000oooo
0?ooool000070?ooo`05o`00003oool0oooo0?ooool000000`3oool00ol0000000000000000l0?oo
o`03ool0003oool0oooo02D0oooo00?o00000?ooo`3oool09@3oool00ooo0000oooo0?ooo`0k0?oo
o`;o0000:@3oool3o`0000D0oooo00<000000?ooo`3oool09`3oool2ool003P0oooo00<000000?oo
o`3oool0H@3oool00`000000oooo0?ooo`0<0?ooo`003P3oool01?l00000oooo0?ooool000080?oo
o`?o0000103oool00ol00000oooo0?ooo`0l0?ooo`03ool0003oool0oooo02D0oooo00?o00000?oo
o`3oool09@3oool00`3o0000oooo0?ooo`0l0?ooo`03o`00003oool0oooo02P0oooo00?o00000?oo
o`3oool0103oool00`000000oooo0?ooo`0V0?ooo`03ool0003oool0oooo03P0oooo00<000000?oo
o`3oool0H@3oool00`000000oooo0?ooo`0<0?ooo`003P3oool01?l00000oooo0?ooool000070?oo
o`05o`00003oool0oooo0?ooool000000`3oool00ol00000oooo0?ooo`0m0?ooo`03ool0003oool0
oooo02@0oooo00?o00000?ooo`3oool0903oool00`3o0000oooo0?ooo`0m0?ooo`03o`00003oool0
oooo02P0oooo00?o00000?ooo`3oool0103oool00`00003o00000?ooo`0T0?ooo`;oo`00>`3oool0
0`000000oooo0?ooo`1P0?ooo`03o`0000000000oooo00d0oooo000>0?ooo`04o`00003oool0oooo
o`0000L0oooo00Go00000?ooo`3oool0ooooo`0000030?ooo`03o`00003oool0oooo03h0oooo00?o
o`000?ooo`3oool08`3oool00ol00000oooo0?ooo`0S0?ooo`03ool0003oool0oooo03h0oooo00?o
00000?ooo`3oool0:03oool00ol00000oooo0?ooo`040?ooo`030000003oool0oooo0280oooo0_oo
000m0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0303oool000l0oooo0_l00009
0?ooo`?o0000103oool00ol00000oooo0?ooo`0o0?ooo`03ool0003oool0oooo0280oooo00?o0000
0?ooo`3oool08P3oool00ooo0000oooo0?ooo`0o0?ooo`03o`00003oool0oooo02P0oooo00?o0000
0?ooo`3oool0103oool00`000000oooo0?ooo`0Q0?ooo`03ool0003oool0oooo03d0oooo00<00000
0?ooo`3oool0H@3oool00`000000oooo0?ooo`0<0?ooo`008@3oool00ol00000oooo0?ooo`100?oo
o`03ool0003oool0oooo0240oooo00?o00000?ooo`3oool08@3oool00ooo0000oooo0?ooo`100?oo
o`03o`00003oool0oooo02L0oooo0_l000060?ooo`030000003oool0oooo01l0oooo0_oo00100?oo
o`030000003oool0oooo0640oooo00<000000?ooo`3oool0303oool00240oooo0_l000120?ooo`03
ool0003oool0oooo0200oooo00?o00000?ooo`3oool0803oool00ooo0000oooo0?ooo`100?ooo`;o
0000:P3oool00ol00000oooo0?ooo`040?ooo`0300000?l00000oooo01d0oooo0_oo00120?ooo`03
0000003oool0oooo0600oooo00?o00000000003oool03@3oool00240oooo00?o00000?ooo`3oool0
@P3oool00ooo0000oooo0?ooo`0O0?ooo`03o`00003oool0oooo01l0oooo00?oo`000?ooo`3oool0
@P3oool00ol00000oooo0?ooo`0_0?ooo`030000003oool0oooo01`0oooo00?oo`000?ooo`3oool0
@P3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo00`0oooo000Q0?ooo`03o`00003o
ool0oooo04<0oooo00?oo`000?ooo`3oool07P3oool00ol00000oooo0?ooo`0N0?ooo`03ool0003o
ool0oooo04<0oooo00?o00000?ooo`3oool0;`3oool00`000000oooo0?ooo`0K0?ooo`03ool0003o
ool0oooo04<0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0<0?ooo`008@3oool0
0ol00000oooo0?ooo`140?ooo`03ool0003oool0oooo01d0oooo00?o00000?ooo`3oool07@3oool0
0ooo0000oooo0?ooo`140?ooo`03o`00003oool0oooo02l0oooo00<000000?ooo`3oool06@3oool2
ool004H0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0<0?ooo`008@3oool00ol0
0000oooo0?ooo`150?ooo`03ool0003oool0oooo01`0oooo00?o00000?ooo`3oool0703oool00ooo
0000oooo0?ooo`150?ooo`03o`00003oool0oooo02l0oooo00<00000o`00003oool0603oool00ooo
0000oooo0?ooo`160?ooo`030000003oool0oooo0600oooo00?o00000000003oool03@3oool00240
oooo00?o00000?ooo`3oool0AP3oool00ooo0000oooo0?ooo`0K0?ooo`03o`00003oool0oooo01/0
oooo00?oo`000?ooo`3oool0AP3oool00ol00000oooo0?ooo`0_0?ooo`030000003oool0oooo01H0
oooo0_oo00190?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0303oool00240oooo
0_l000180?ooo`;oo`006`3oool00ol00000oooo0?ooo`0I0?ooo`;oo`00B03oool2o`000340oooo
00<000000?ooo`3oool0503oool2ool004/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`0<0?ooo`008@3oool00ol00000oooo0?ooo`190?ooo`03ool0003oool0oooo01P0oooo00?o
00000?ooo`3oool0603oool00ooo0000oooo0?ooo`190?ooo`03o`00003oool0oooo02l0oooo00<0
0000o`00003oool04`3oool00ooo0000oooo0?ooo`1;0?ooo`030000003oool0oooo0600oooo00?o
00000000003oool03@3oool00240oooo00?o00000?ooo`3oool0BP3oool00ooo0000oooo0?ooo`0G
0?ooo`03o`00003oool0oooo01P0oooo00?oo`000?ooo`3oool0B@3oool00ol00000oooo0?ooo`0_
0?ooo`030000003oool0oooo0140oooo0_oo001>0?ooo`030000003oool0oooo0640oooo00<00000
0?ooo`3oool0303oool00240oooo00?o00000?ooo`3oool0B`3oool00ooo0000oooo0?ooo`0F0?oo
o`03o`00003oool0oooo01H0oooo0_oo001<0?ooo`03o`00003oool0oooo02l0oooo00<000000?oo
o`3oool03`3oool2ool00500oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0<0?oo
o`008@3oool00ol00000oooo0?ooo`1<0?ooo`;oo`005P3oool00ol00000oooo0?ooo`0E0?ooo`03
ool0003oool0oooo04`0oooo00?o00000?ooo`3oool0;`3oool00`000000oooo0?ooo`0=0?ooo`;o
o`00DP3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo00`0oooo000Q0?ooo`03o`00
003oool0oooo04h0oooo00?oo`000?ooo`3oool04`3oool00ol00000oooo0?ooo`0D0?ooo`03ool0
003oool0oooo04d0oooo00?o00000?ooo`3oool0;`3oool00`00003o00000?ooo`0<0?ooo`03ool0
003oool0oooo0580oooo00<000000?ooo`3oool0H03oool00ol0000000000?ooo`0=0?ooo`008@3o
ool2o`000500oooo0_oo000C0?ooo`03o`00003oool0oooo0180oooo0_oo001?0?ooo`;o00007@3o
ool3o`0000@0oooo00?o00000?ooo`3oool00P3oool3o`0000D0oooo00<000000?ooo`3oool02P3o
ool2ool005D0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0<0?ooo`008@3oool0
0ol00000oooo0?ooo`1A0?ooo`;oo`004@3oool00ol00000oooo0?ooo`0@0?ooo`;oo`00DP3oool0
0ol00000oooo0?ooo`0L0?ooo`03o`00003oool0oooo00L0oooo00Go00000?ooo`3oool0ooooo`00
00040?ooo`030000003oool0oooo00P0oooo0_oo001G0?ooo`030000003oool0oooo0640oooo00<0
00000?ooo`3oool0303oool00240oooo00?o00000?ooo`3oool0D`3oool2ool000l0oooo00?o0000
0?ooo`3oool03P3oool2ool005@0oooo00?o00000?ooo`3oool0703oool00ol00000oooo0?ooo`0;
0?ooo`03o`00003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00ooo0000oooo0?ooo`1G
0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0303oool00240oooo00?o00000?oo
o`3oool0E@3oool2ool000d0oooo00?o00000?ooo`3oool0303oool2ool005H0oooo00?o00000?oo
o`3oool0703oool00ol00000oooo0?ooo`0;0?ooo`03o`00003oool0oooo0080oooo00<00000o`00
003oool01@3oool2ool005X0oooo00<000000?ooo`3oool0H03oool00ol0000000000?ooo`0=0?oo
o`006P3oool3o`0000@0oooo00?o00000?ooo`3oool0E`3oool2ool000/0oooo00?o00000?ooo`3o
ool02@3oool3ool005P0oooo00?o00000?ooo`3oool0703oool00ol00000oooo0?ooo`070?ooo`Co
00001@3oool00`000000oooo0?ooo`040?ooo`03ool0003oool0oooo05X0oooo00<000000?ooo`3o
ool0H@3oool00`000000oooo0?ooo`0<0?ooo`006`3oool00ol00000oooo0?ooo`030?ooo`03o`00
003oool0oooo05T0oooo1?oo00070?ooo`03o`00003oool0oooo00H0oooo0ooo001K0?ooo`03o`00
003oool0oooo01/0oooo0_l000090?ooo`03o`00003oool0oooo00H0oooo00<000000?ooo`3oool0
0`3oool00ooo0000oooo0?ooo`1K0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0
303oool001/0oooo00?o00000?ooo`3oool00`3oool00ol0000000000000001M0?oooa3oo`00G@3o
ool2o`0001h0oooo00?o00000?ooo`3oool01`3oool5o`0000@0oooo00<000000?ooo`3oool00P3o
ool00ooo0000oooo0?ooo`1L0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0303o
ool001/0oooo00?o00000?ooo`3oool00`3oool00ol00000oooo0?ooo`1T0?ooo`03o`00003oool0
oooo06@0oooo00?o00000?ooo`3oool0;`3oool00`00003o00000?ooo`060?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo00D0oooo00?o00000000003oool03@3oool001/0oooo00?o00000?ooo`3oool00`3oool00ol0
0000oooo0?ooo`070?ooo`03o`00003oool0oooo01`0oooo00?o00000?ooo`3oool0703oool00ol0
0000oooo0?ooo`0L0?ooo`03o`00003oool0oooo01d0oooo00?o00000?ooo`3oool0703oool00ol0
0000oooo0?ooo`0L0?ooo`03o`00003oool0oooo00H0oooo00?o00000?ooo`3oool0;`3oool01000
0000oooo0?ooool000050?ooo`030000003oool0oooo00<0oooo00?o00000?ooo`3oool00`3oool0
0ol00000oooo0?ooo`030?ooo`03o`00003oool0oooo00<0oooo00?o00000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`03o`00003oool0oooo00<0oooo00?o00000?ooo`3oool00`3oool0
0ol00000oooo0?ooo`040?ooo`03o`00003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
0ol00000oooo0?ooo`030?ooo`03o`00003oool0oooo00<0oooo00?o00000?ooo`3oool00`3oool0
0ol00000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00?o00000?ooo`3oool00`3oool0
0ol00000oooo0?ooo`030?ooo`03o`00003oool0oooo00<0oooo00?o00000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`03o`00003oool0oooo00@0oooo00?o00000?ooo`3oool00`3oool0
0ol00000oooo0?ooo`030?ooo`03o`00003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
0ol00000oooo0?ooo`030?ooo`03o`00003oool0oooo00<0oooo00?o00000?ooo`3oool00`3oool0
0ol00000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00Co00000?ooo`3oool000003P3o
ool001X0oooo0_l000050?ooo`05o`00003oool0oooo0?ooool000001@3oool00ol00000oooo0?oo
o`030?ooo`03o`00003oool0oooo00<0oooo00?o00000?ooo`3oool00`3oool00ol00000oooo0?oo
o`040?ooo`03o`00003oool0oooo00<0oooo00?o00000?ooo`3oool00`3oool00ol00000oooo0?oo
o`030?ooo`03o`00003oool0oooo00@0oooo00?o00000?ooo`3oool00`3oool00ol00000oooo0?oo
o`030?ooo`03o`00003oool0oooo00<0oooo00?o00000?ooo`3oool0103oool00ol00000oooo0?oo
o`030?ooo`03o`00003oool0oooo00<0oooo00?o00000?ooo`3oool00`3oool00ol00000oooo0?oo
o`040?ooo`03o`00003oool0oooo00<0oooo00?o00000?ooo`3oool00`3oool00ol00000oooo0?oo
o`030?ooo`03o`00003oool0oooo00@0oooo00?o00000?ooo`3oool00`3oool00ol00000oooo0?oo
o`030?ooo`03o`00003oool0oooo00<0oooo00?o00000?ooo`3oool0103oool00ol00000oooo0?oo
o`030?ooo`03o`00003oool0oooo00<0oooo00?o00000?ooo`3oool00`3oool00ol00000oooo0?oo
o`030?ooo`03o`00003oool0oooo00@0oooo00?o00000?ooo`3oool00`3oool00ol00000oooo0?oo
o`030?ooo`04o`00003oool0ooooo`000340oooob@00000>0?ooo`006`3oool00ol00000oooo0?oo
o`030?oooloo0000o`3oool90?ooo`00o`3ooooi0?ooo`00o`3ooooi0?ooo`00o`3ooooi0?ooo`00
o`3ooooi0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 503}, {147.312, 0}} -> {-0.0551454, -0.0147182, \
0.00419541, 0.00419541}, {{13.125, 240.125}, {143.75, 3.5}} -> {-4.38653, \
-0.149938, 0.0320538, 0.00825443}, {{262.812, 489.812}, {143.75, 3.5}} -> \
{-12.8248, -2.11611, 0.0329261, 0.0266378}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Output of system for simple cosine input: time-domain convolution\
\
\>", "Subsection"],

Cell[CellGroupData[{

Cell["Sampling frequency", "Subsubsection"],

Cell[BoxData[
    \(\(fs = 500;\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part of input sequence", "Subsubsection"],

Cell[BoxData[{
    \(\(f1[t_] := Cos[2  \[Pi]\ 50  t]\ ;\)\), "\n", 
    \(\(xn\  = \ Table[f1[t], {t, 0, 1 - 1/fs, 1/fs}]\  // \ N;\)\), "\n", 
    \(\(g1 = 
        DiscreteListPlot[Take[xn, {100, 150}], \ Blue, \ 
          DisplayFunction \[Rule] Identity, \ 
          Frame \[Rule] True];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`y[n] = \ x[n]\ *\ h[n]\)]]], "Subsubsection"],

Cell[BoxData[
    \(\(yn = 
        Drop[ListConvolve[Last\  /@ \ hn, xn, {1, \(-1\)}, 
            0], \(-1\)];\)\)], "Input",
  FontColor->GrayLevel[1],
  Background->RGBColor[1, 0, 0]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(g2 = 
        DiscreteListPlot[Take[yn, {100, 150}], \ Red, \ 
          DisplayFunction \[Rule] Identity, \ Frame \[Rule] True, \ 
          Evaluate[\(AbsoluteOptions[g1, 
                PlotRange]\)[\([1]\)]]];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{{g1, g2}}], \ 
        ImageSize \[Rule] 504];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
%%ImageSize: 504 148.328 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0186741 0.309017 0.294302 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21055 -0.0125 -6 -9 ]
[.21055 -0.0125 6 0 ]
[.39729 -0.0125 -6 -9 ]
[.39729 -0.0125 6 0 ]
[.58403 -0.0125 -6 -9 ]
[.58403 -0.0125 6 0 ]
[.77077 -0.0125 -6 -9 ]
[.77077 -0.0125 6 0 ]
[.95752 -0.0125 -6 -9 ]
[.95752 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -12 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -24 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -18 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21055 0 m
.21055 .00625 L
s
[(10)] .21055 -0.0125 0 1 Mshowa
.39729 0 m
.39729 .00625 L
s
[(20)] .39729 -0.0125 0 1 Mshowa
.58403 0 m
.58403 .00625 L
s
[(30)] .58403 -0.0125 0 1 Mshowa
.77077 0 m
.77077 .00625 L
s
[(40)] .77077 -0.0125 0 1 Mshowa
.95752 0 m
.95752 .00625 L
s
[(50)] .95752 -0.0125 0 1 Mshowa
.125 Mabswid
.06116 0 m
.06116 .00375 L
s
.09851 0 m
.09851 .00375 L
s
.13585 0 m
.13585 .00375 L
s
.1732 0 m
.1732 .00375 L
s
.2479 0 m
.2479 .00375 L
s
.28525 0 m
.28525 .00375 L
s
.3226 0 m
.3226 .00375 L
s
.35994 0 m
.35994 .00375 L
s
.43464 0 m
.43464 .00375 L
s
.47199 0 m
.47199 .00375 L
s
.50934 0 m
.50934 .00375 L
s
.54669 0 m
.54669 .00375 L
s
.62138 0 m
.62138 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.69608 0 m
.69608 .00375 L
s
.73343 0 m
.73343 .00375 L
s
.80812 0 m
.80812 .00375 L
s
.84547 0 m
.84547 .00375 L
s
.88282 0 m
.88282 .00375 L
s
.92017 0 m
.92017 .00375 L
s
.99486 0 m
.99486 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(-1)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(-0.5)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(0.5)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(1)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21055 .61178 m
.21055 .61803 L
s
.39729 .61178 m
.39729 .61803 L
s
.58403 .61178 m
.58403 .61803 L
s
.77077 .61178 m
.77077 .61803 L
s
.95752 .61178 m
.95752 .61803 L
s
.125 Mabswid
.06116 .61428 m
.06116 .61803 L
s
.09851 .61428 m
.09851 .61803 L
s
.13585 .61428 m
.13585 .61803 L
s
.1732 .61428 m
.1732 .61803 L
s
.2479 .61428 m
.2479 .61803 L
s
.28525 .61428 m
.28525 .61803 L
s
.3226 .61428 m
.3226 .61803 L
s
.35994 .61428 m
.35994 .61803 L
s
.43464 .61428 m
.43464 .61803 L
s
.47199 .61428 m
.47199 .61803 L
s
.50934 .61428 m
.50934 .61803 L
s
.54669 .61428 m
.54669 .61803 L
s
.62138 .61428 m
.62138 .61803 L
s
.65873 .61428 m
.65873 .61803 L
s
.69608 .61428 m
.69608 .61803 L
s
.73343 .61428 m
.73343 .61803 L
s
.80812 .61428 m
.80812 .61803 L
s
.84547 .61428 m
.84547 .61803 L
s
.88282 .61428 m
.88282 .61803 L
s
.92017 .61428 m
.92017 .61803 L
s
.99486 .61428 m
.99486 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.04248 .30902 m
.04248 .54711 L
s
.06116 .30902 m
.06116 .60332 L
s
.07983 .30902 m
.07983 .54711 L
s
.09851 .30902 m
.09851 .39996 L
s
.11718 .30902 m
.11718 .21807 L
s
.13585 .30902 m
.13585 .07092 L
s
.15453 .30902 m
.15453 .01472 L
s
.1732 .30902 m
.1732 .07092 L
s
.19188 .30902 m
.19188 .21807 L
s
.21055 .30902 m
.21055 .39996 L
s
.22923 .30902 m
.22923 .54711 L
s
.2479 .30902 m
.2479 .60332 L
s
.26657 .30902 m
.26657 .54711 L
s
.28525 .30902 m
.28525 .39996 L
s
.30392 .30902 m
.30392 .21807 L
s
.3226 .30902 m
.3226 .07092 L
s
.34127 .30902 m
.34127 .01472 L
s
.35994 .30902 m
.35994 .07092 L
s
.37862 .30902 m
.37862 .21807 L
s
.39729 .30902 m
.39729 .39996 L
s
.41597 .30902 m
.41597 .54711 L
s
.43464 .30902 m
.43464 .60332 L
s
.45331 .30902 m
.45331 .54711 L
s
.47199 .30902 m
.47199 .39996 L
s
.49066 .30902 m
.49066 .21807 L
s
.50934 .30902 m
.50934 .07092 L
s
.52801 .30902 m
.52801 .01472 L
s
.54669 .30902 m
.54669 .07092 L
s
.56536 .30902 m
.56536 .21807 L
s
.58403 .30902 m
.58403 .39996 L
s
.60271 .30902 m
.60271 .54711 L
s
.62138 .30902 m
.62138 .60332 L
s
.64006 .30902 m
.64006 .54711 L
s
.65873 .30902 m
.65873 .39996 L
s
.6774 .30902 m
.6774 .21807 L
s
.69608 .30902 m
.69608 .07092 L
s
.71475 .30902 m
.71475 .01472 L
s
.73343 .30902 m
.73343 .07092 L
s
.7521 .30902 m
.7521 .21807 L
s
.77077 .30902 m
.77077 .39996 L
s
.78945 .30902 m
.78945 .54711 L
s
.80812 .30902 m
.80812 .60332 L
s
.8268 .30902 m
.8268 .54711 L
s
.84547 .30902 m
.84547 .39996 L
s
.86415 .30902 m
.86415 .21807 L
s
.88282 .30902 m
.88282 .07092 L
s
.90149 .30902 m
.90149 .01472 L
s
.92017 .30902 m
.92017 .07092 L
s
.93884 .30902 m
.93884 .21807 L
s
.95752 .30902 m
.95752 .39996 L
s
.97619 .30902 m
.97619 .54711 L
s
.015 w
.04248 .54711 Mdot
.06116 .60332 Mdot
.07983 .54711 Mdot
.09851 .39996 Mdot
.11718 .21807 Mdot
.13585 .07092 Mdot
.15453 .01472 Mdot
.1732 .07092 Mdot
.19188 .21807 Mdot
.21055 .39996 Mdot
.22923 .54711 Mdot
.2479 .60332 Mdot
.26657 .54711 Mdot
.28525 .39996 Mdot
.30392 .21807 Mdot
.3226 .07092 Mdot
.34127 .01472 Mdot
.35994 .07092 Mdot
.37862 .21807 Mdot
.39729 .39996 Mdot
.41597 .54711 Mdot
.43464 .60332 Mdot
.45331 .54711 Mdot
.47199 .39996 Mdot
.49066 .21807 Mdot
.50934 .07092 Mdot
.52801 .01472 Mdot
.54669 .07092 Mdot
.56536 .21807 Mdot
.58403 .39996 Mdot
.60271 .54711 Mdot
.62138 .60332 Mdot
.64006 .54711 Mdot
.65873 .39996 Mdot
.6774 .21807 Mdot
.69608 .07092 Mdot
.71475 .01472 Mdot
.73343 .07092 Mdot
.7521 .21807 Mdot
.77077 .39996 Mdot
.78945 .54711 Mdot
.80812 .60332 Mdot
.8268 .54711 Mdot
.84547 .39996 Mdot
.86415 .21807 Mdot
.88282 .07092 Mdot
.90149 .01472 Mdot
.92017 .07092 Mdot
.93884 .21807 Mdot
.95752 .39996 Mdot
.97619 .54711 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0186741 0.309017 0.294302 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21055 -0.0125 -6 -9 ]
[.21055 -0.0125 6 0 ]
[.39729 -0.0125 -6 -9 ]
[.39729 -0.0125 6 0 ]
[.58403 -0.0125 -6 -9 ]
[.58403 -0.0125 6 0 ]
[.77077 -0.0125 -6 -9 ]
[.77077 -0.0125 6 0 ]
[.95752 -0.0125 -6 -9 ]
[.95752 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -12 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -24 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -18 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21055 0 m
.21055 .00625 L
s
[(10)] .21055 -0.0125 0 1 Mshowa
.39729 0 m
.39729 .00625 L
s
[(20)] .39729 -0.0125 0 1 Mshowa
.58403 0 m
.58403 .00625 L
s
[(30)] .58403 -0.0125 0 1 Mshowa
.77077 0 m
.77077 .00625 L
s
[(40)] .77077 -0.0125 0 1 Mshowa
.95752 0 m
.95752 .00625 L
s
[(50)] .95752 -0.0125 0 1 Mshowa
.125 Mabswid
.06116 0 m
.06116 .00375 L
s
.09851 0 m
.09851 .00375 L
s
.13585 0 m
.13585 .00375 L
s
.1732 0 m
.1732 .00375 L
s
.2479 0 m
.2479 .00375 L
s
.28525 0 m
.28525 .00375 L
s
.3226 0 m
.3226 .00375 L
s
.35994 0 m
.35994 .00375 L
s
.43464 0 m
.43464 .00375 L
s
.47199 0 m
.47199 .00375 L
s
.50934 0 m
.50934 .00375 L
s
.54669 0 m
.54669 .00375 L
s
.62138 0 m
.62138 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.69608 0 m
.69608 .00375 L
s
.73343 0 m
.73343 .00375 L
s
.80812 0 m
.80812 .00375 L
s
.84547 0 m
.84547 .00375 L
s
.88282 0 m
.88282 .00375 L
s
.92017 0 m
.92017 .00375 L
s
.99486 0 m
.99486 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(-1)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(-0.5)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(0.5)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(1)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21055 .61178 m
.21055 .61803 L
s
.39729 .61178 m
.39729 .61803 L
s
.58403 .61178 m
.58403 .61803 L
s
.77077 .61178 m
.77077 .61803 L
s
.95752 .61178 m
.95752 .61803 L
s
.125 Mabswid
.06116 .61428 m
.06116 .61803 L
s
.09851 .61428 m
.09851 .61803 L
s
.13585 .61428 m
.13585 .61803 L
s
.1732 .61428 m
.1732 .61803 L
s
.2479 .61428 m
.2479 .61803 L
s
.28525 .61428 m
.28525 .61803 L
s
.3226 .61428 m
.3226 .61803 L
s
.35994 .61428 m
.35994 .61803 L
s
.43464 .61428 m
.43464 .61803 L
s
.47199 .61428 m
.47199 .61803 L
s
.50934 .61428 m
.50934 .61803 L
s
.54669 .61428 m
.54669 .61803 L
s
.62138 .61428 m
.62138 .61803 L
s
.65873 .61428 m
.65873 .61803 L
s
.69608 .61428 m
.69608 .61803 L
s
.73343 .61428 m
.73343 .61803 L
s
.80812 .61428 m
.80812 .61803 L
s
.84547 .61428 m
.84547 .61803 L
s
.88282 .61428 m
.88282 .61803 L
s
.92017 .61428 m
.92017 .61803 L
s
.99486 .61428 m
.99486 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.04248 .30902 m
.04248 .47354 L
s
.06116 .30902 m
.06116 .57522 L
s
.07983 .30902 m
.07983 .57522 L
s
.09851 .30902 m
.09851 .47354 L
s
.11718 .30902 m
.11718 .30902 L
s
.13585 .30902 m
.13585 .1445 L
s
.15453 .30902 m
.15453 .04282 L
s
.1732 .30902 m
.1732 .04282 L
s
.19188 .30902 m
.19188 .1445 L
s
.21055 .30902 m
.21055 .30902 L
s
.22923 .30902 m
.22923 .47354 L
s
.2479 .30902 m
.2479 .57522 L
s
.26657 .30902 m
.26657 .57522 L
s
.28525 .30902 m
.28525 .47354 L
s
.30392 .30902 m
.30392 .30902 L
s
.3226 .30902 m
.3226 .1445 L
s
.34127 .30902 m
.34127 .04282 L
s
.35994 .30902 m
.35994 .04282 L
s
.37862 .30902 m
.37862 .1445 L
s
.39729 .30902 m
.39729 .30902 L
s
.41597 .30902 m
.41597 .47354 L
s
.43464 .30902 m
.43464 .57522 L
s
.45331 .30902 m
.45331 .57522 L
s
.47199 .30902 m
.47199 .47354 L
s
.49066 .30902 m
.49066 .30902 L
s
.50934 .30902 m
.50934 .1445 L
s
.52801 .30902 m
.52801 .04282 L
s
.54669 .30902 m
.54669 .04282 L
s
.56536 .30902 m
.56536 .1445 L
s
.58403 .30902 m
.58403 .30902 L
s
.60271 .30902 m
.60271 .47354 L
s
.62138 .30902 m
.62138 .57522 L
s
.64006 .30902 m
.64006 .57522 L
s
.65873 .30902 m
.65873 .47354 L
s
.6774 .30902 m
.6774 .30902 L
s
.69608 .30902 m
.69608 .1445 L
s
.71475 .30902 m
.71475 .04282 L
s
.73343 .30902 m
.73343 .04282 L
s
.7521 .30902 m
.7521 .1445 L
s
.77077 .30902 m
.77077 .30902 L
s
.78945 .30902 m
.78945 .47354 L
s
.80812 .30902 m
.80812 .57522 L
s
.8268 .30902 m
.8268 .57522 L
s
.84547 .30902 m
.84547 .47354 L
s
.86415 .30902 m
.86415 .30902 L
s
.88282 .30902 m
.88282 .1445 L
s
.90149 .30902 m
.90149 .04282 L
s
.92017 .30902 m
.92017 .04282 L
s
.93884 .30902 m
.93884 .1445 L
s
.95752 .30902 m
.95752 .30902 L
s
.97619 .30902 m
.97619 .47354 L
s
.015 w
.04248 .47354 Mdot
.06116 .57522 Mdot
.07983 .57522 Mdot
.09851 .47354 Mdot
.11718 .30902 Mdot
.13585 .1445 Mdot
.15453 .04282 Mdot
.1732 .04282 Mdot
.19188 .1445 Mdot
.21055 .30902 Mdot
.22923 .47354 Mdot
.2479 .57522 Mdot
.26657 .57522 Mdot
.28525 .47354 Mdot
.30392 .30902 Mdot
.3226 .1445 Mdot
.34127 .04282 Mdot
.35994 .04282 Mdot
.37862 .1445 Mdot
.39729 .30902 Mdot
.41597 .47354 Mdot
.43464 .57522 Mdot
.45331 .57522 Mdot
.47199 .47354 Mdot
.49066 .30902 Mdot
.50934 .1445 Mdot
.52801 .04282 Mdot
.54669 .04282 Mdot
.56536 .1445 Mdot
.58403 .30902 Mdot
.60271 .47354 Mdot
.62138 .57522 Mdot
.64006 .57522 Mdot
.65873 .47354 Mdot
.6774 .30902 Mdot
.69608 .1445 Mdot
.71475 .04282 Mdot
.73343 .04282 Mdot
.7521 .1445 Mdot
.77077 .30902 Mdot
.78945 .47354 Mdot
.80812 .57522 Mdot
.8268 .57522 Mdot
.84547 .47354 Mdot
.86415 .30902 Mdot
.88282 .1445 Mdot
.90149 .04282 Mdot
.92017 .04282 Mdot
.93884 .1445 Mdot
.95752 .30902 Mdot
.97619 .47354 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 148.312},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0000U2000`400?l00000o`00003oo`3ooooi
0?ooo`00o`3ooooi0?ooo`00o`3ooooi0?ooo`00o`3ooooi0?ooo`00o`3ooooi0?ooo`00o`3ooooi
0?ooo`00:`3oool2o`0001l0oooo0ol000040?ooo`;o0000703oool5o`0000<0oooo0_l0000L0?oo
o`?o0000103oool2o`0001h0oooo0ol000030?ooo`;o0000703oool3o`0000@0oooo0_l0000j0?oo
o`;o00007`3oool3o`0000@0oooo0_l0000K0?ooo`Go00000`3oool2o`0001d0oooo0ol000040?oo
o`;o00007@3oool3o`0000<0oooo0_l0000M0?ooo`?o0000103oool2o`0001<0oooo000Z0?ooo`04
o`00003oool0ooooo`0001l0oooo00?o00000?ooo`3oool00P3oool01?l00000oooo0?ooool0000L
0?ooo`04o`00003oool0ooooo`000080oooo00Co00000?ooo`3ooooo00006P3oool01Ol00000oooo
0?ooo`3ooooo00000080oooo00Co00000?ooo`3ooooo00007P3oool01Ol00000oooo0?ooo`3ooooo
00000080oooo00?o00000?ooo`3oool0603oool01Ol00000oooo0?ooo`3ooooo00000080oooo00Co
00000?ooo`3ooooo0000>03oool01?l00000oooo0?ooool0000O0?ooo`03o`00003oool0oooo0080
oooo00Co00000?ooo`3ooooo00006`3oool01?l00000oooo0?ooool000020?ooo`04o`00003oool0
ooooo`0001/0oooo00Go00000?ooo`3oool0ooooo`0000020?ooo`04o`00003oool0ooooo`0001d0
oooo00Go00000?ooo`3oool0ooooo`0000020?ooo`03o`00003oool0oooo01T0oooo00Go00000?oo
o`3oool0ooooo`0000020?ooo`04o`00003oool0ooooo`000180oooo000Z0?ooo`04o`00003oool0
ooooo`0001l0oooo00?o00000?ooo`3oool00P3oool01?l00000oooo0?ooool0000M0?ooo`03o`00
003oool0oooo0080oooo00Co00000?ooo`3ooooo00007P3oool01?l00000oooo0?ooool000020?oo
o`03o`00003oool0oooo01T0oooo1Ol000020?ooo`04o`00003oool0ooooo`0001h0oooo00Co0000
0?ooo`3ooooo00000P3oool00ol00000oooo0?ooo`0f0?ooo`04o`00003oool0ooooo`0001l0oooo
00?o00000?ooo`3oool00P3oool01?l00000oooo0?ooool0000L0?ooo`03o`00003oool0oooo0080
oooo00Co00000?ooo`3ooooo00007`3oool01?l00000oooo0?ooool000020?ooo`03o`00003oool0
oooo01P0oooo1Ol000020?ooo`04o`00003oool0ooooo`0001l0oooo00Co00000?ooo`3ooooo0000
0P3oool00ol00000oooo0?ooo`0@0?ooo`00:P3oool01?l00000oooo0?ooool0000O0?ooo`03o`00
003oool0oooo0080oooo00Co00000?ooo`3ooooo00007P3oool01Ol00000oooo0?ooo`3ooooo0000
0080oooo00?o00000?ooo`3oool06P3oool2o`0000<0oooo00Co00000?ooo`3ooooo00006`3oool0
1?l00000oooo0?ooool000030?ooo`04o`00003oool0ooooo`0001h0oooo00Co00000?ooo`3ooooo
00000P3oool00ol00000oooo0?ooo`0f0?ooo`04o`00003oool0ooooo`0001l0oooo00?o00000?oo
o`3oool00P3oool01?l00000oooo0?ooool0000M0?ooo`05o`00003oool0oooo0?ooool000000P3o
ool00ol00000oooo0?ooo`0K0?ooo`;o00000`3oool01?l00000oooo0?ooool0000J0?ooo`04o`00
003oool0ooooo`0000<0oooo00Co00000?ooo`3ooooo00007`3oool01?l00000oooo0?ooool00002
0?ooo`03o`00003oool0oooo0100oooo000Z0?ooo`04o`00003oool0ooooo`0001l0oooo00?o0000
0?ooo`3oool00P3oool01?l00000oooo0?ooool0000K0?ooo`05o`00003oool0oooo0?ooool00000
0P3oool01?l00000oooo0?ooool0000N0?ooo`04o`00003oool0ooooo`000080oooo00?o00000?oo
o`3oool06P3oool00ol00000ooooo`0000030?ooo`04o`00003oool0ooooo`0001X0oooo1?l00003
0?ooo`04o`00003oool0ooooo`0003P0oooo00Co00000?ooo`3ooooo00007`3oool00ol00000oooo
0?ooo`020?ooo`04o`00003oool0ooooo`0001X0oooo00Go00000?ooo`3oool0ooooo`0000020?oo
o`04o`00003oool0ooooo`0001l0oooo00Co00000?ooo`3ooooo00000P3oool00ol00000oooo0?oo
o`0I0?ooo`03o`00003ooooo000000<0oooo00Co00000?ooo`3ooooo00006`3oool4o`0000<0oooo
00Co00000?ooo`3ooooo00004P3oool002X0oooo00Co00000?ooo`3ooooo00007P3oool2o`0000@0
oooo00Co00000?ooo`3ooooo00006`3oool01Ol00000oooo0?ooo`3ooooo00000080oooo00Co0000
0?ooo`3ooooo00006P3oool01Ol00000oooo0?ooo`3ooooo00000080oooo00Co00000?ooo`3ooooo
00007@3oool2o`0000<0oooo00Co00000?ooo`3ooooo00006P3oool00ol00000oooo0?ooo`040?oo
o`04o`00003oool0ooooo`0003P0oooo00Co00000?ooo`3ooooo00007P3oool2o`0000@0oooo00Co
00000?ooo`3ooooo00006P3oool01Ol00000oooo0?ooo`3ooooo00000080oooo00Co00000?ooo`3o
oooo00006`3oool01Ol00000oooo0?ooo`3ooooo00000080oooo00Co00000?ooo`3ooooo0000703o
ool2o`0000<0oooo00Co00000?ooo`3ooooo00006`3oool00ol00000oooo0?ooo`040?ooo`04o`00
003oool0ooooo`000180oooo000[0?ooo`;o0000803oool00ol00000oooo0?ooo`030?ooo`;o0000
7@3oool3o`0000@0oooo0_l0000L0?ooo`?o0000103oool2o`0001l0oooo00?o00000?ooo`3oool0
0P3oool2o`0001/0oooo1Ol000030?ooo`;o0000>P3oool2o`000200oooo00?o00000?ooo`3oool0
0`3oool2o`0001`0oooo0ol000040?ooo`;o00007@3oool3o`0000@0oooo0_l0000N0?ooo`03o`00
003oool0oooo0080oooo0_l0000L0?ooo`Go00000`3oool2o`0001<0oooo003o0?ooooT0oooo003o
0?ooooT0oooo003o0?ooooT0oooo003o0?ooooT0oooo000P0?ooo`?o0000103oooo:o`0002P0oooo
0ol000050?ooolWo00003P3oool00240oooo00?o00000?ooo`3oool00`3oool00ol00000oooo0?oo
o`020?ooo`03o`00003oool0oooo00@0oooo00?o00000?ooo`3oool01@3oool00ol00000oooo0?oo
o`040?ooo`03o`00003oool0oooo00D0oooo00?o00000?ooo`3oool0103oool00ol00000oooo0?oo
o`050?ooo`03o`00003oool0oooo00@0oooo00?o00000?ooo`3oool01@3oool00ol00000oooo0?oo
o`040?ooo`03o`00003oool0oooo00D0oooo00?o00000?ooo`3oool0103oool00ol00000oooo0?oo
o`050?ooo`03o`00003oool0oooo00@0oooo00?o00000?ooo`3oool01@3oool00ol00000oooo0?oo
o`040?ooo`03o`00003oool0oooo00D0oooo00?o00000?ooo`3oool0103oool00ol00000oooo0?oo
o`050?ooo`03o`00003oool0oooo00@0oooo00?o00000?ooo`3oool01@3oool00ol00000oooo0?oo
o`040?ooo`03o`00003oool0oooo00D0oooo00?o00000?ooo`3oool0103oool00ol00000oooo0?oo
o`050?ooo`03o`00003oool0oooo00@0oooo00?o00000?ooo`3oool0103oool00ol00000ooooo`00
000Y0?ooo`03o`00003oool0oooo00@0oooo00?o00000?ooo`3oool00P3oool00ol00000oooo0?oo
o`040?ooo`03o`00003oool0oooo00D0oooo00?o00000?ooo`3oool0103oool00ol00000oooo0?oo
o`050?ooo`03o`00003oool0oooo00@0oooo00?o00000?ooo`3oool0103oool00ol00000oooo0?oo
o`050?ooo`03o`00003oool0oooo00@0oooo00?o00000?ooo`3oool01@3oool00ol00000oooo0?oo
o`040?ooo`03o`00003oool0oooo00D0oooo00?o00000?ooo`3oool0103oool00ol00000oooo0?oo
o`050?ooo`03o`00003oool0oooo00@0oooo00?o00000?ooo`3oool01@3oool00ol00000oooo0?oo
o`040?ooo`03o`00003oool0oooo00D0oooo00?o00000?ooo`3oool0103oool00ol00000oooo0?oo
o`050?ooo`03o`00003oool0oooo00@0oooo00?o00000?ooo`3oool01@3oool00ol00000oooo0?oo
o`040?ooo`03o`00003oool0oooo00D0oooo00?o00000?ooo`3oool0103oool00ol00000oooo0?oo
o`050?ooo`03o`00003oool0oooo00@0oooo0_l0000>0?ooo`006@3oool5o`0000<0oooo00?o0000
0?ooo`3oool00`3oool00ol00000oooo0?ooo`0K0?ooo`?o003o8`3oool3o`00ob80oooo0ol00?lR
0?ooo`?o003o8`3oool3o`00oa80oooo00?o00000?ooo`3oool07`3oool5o`0000<0oooo00?o0000
0?ooo`3oool0103oool00ol00000oooo0?ooo`350?ooo`03o`00003oool0oooo00`0oooo000Q0?oo
o`03o`00003oool0oooo00<0oooo0_l0000L0?ooo`?o003o8`3oool3o`00ob80oooo0ol00?lR0?oo
o`?o003o8`3oool3o`00oa00oooo0ol0000Y0?ooo`03o`00003oool0oooo00@0oooo0_l000350?oo
o`;o00003P3oool00240oooo00?o00000?ooo`3oool00`3oool00ol00000oooo0?ooo`0K0?ooo`?o
003o8`3oool3o`00ob80oooo0ol00?lR0?ooo`?o003o8`3oool3o`00oa80oooo00?o00000?ooo`3o
ool09`3oool00ol00000oooo0?ooo`040?ooo`03o`00003oool0oooo0<D0oooo00?o00000?ooo`3o
ool0303oool00200oooo0_l000050?ooo`03o`00003oool0oooo01`0oooo00?o003o0?ooo`3oool0
8`3oool00ol00?l0oooo0?ooo`0R0?ooo`03o`00o`3oool0oooo0280oooo00?o003o0?ooo`3oool0
8`3oool00ol00?l0oooo0?ooo`0A0?ooo`03o`00003oool0oooo02H0oooo0_l000060?ooo`03o`00
003oool0oooo0<D0oooo00?o00000?ooo`3oool0303oool00240oooo00?o00000?ooo`3oool00`3o
ool00ol00000oooo0?ooo`0L0?ooo`03o`00o`3oool0oooo02<0oooo00?o003o0?ooo`3oool08P3o
ool00ol00?l0oooo0?ooo`0R0?ooo`03o`00o`3oool0oooo02<0oooo00?o003o0?ooo`3oool04@3o
ool00ol00000oooo0?ooo`0W0?ooo`03o`00003oool0oooo00@0oooo00?o00000?ooo`3oool0a@3o
ool00ol00000oooo0?ooo`0<0?ooo`009`3oool00ol00000oooo0?ooo`0L0?ooo`03o`00o`3oool0
oooo02<0oooo00?o003o0?ooo`3oool08P3oool00ol00?l0oooo0?ooo`0R0?ooo`03o`00o`3oool0
oooo02<0oooo00?o003o0?ooo`3oool04@3oool00ol00000oooo0?ooo`0^0?ooo`03o`00003oool0
oooo0<D0oooo00?o00000?ooo`3oool0303oool002L0oooo00?o00000?ooo`3oool0703oool00ol0
0?l0oooo0?ooo`0S0?ooo`03o`00o`3oool0oooo0280oooo00?o003o0?ooo`3oool08P3oool00ol0
0?l0oooo0?ooo`0S0?ooo`03o`00o`3oool0oooo0140oooo00?o00000?ooo`3oool0;P3oool00ol0
0000oooo0?ooo`0K0?ooo`?oo`0000@0ooooool00?oo003oo`007P3oool3ool000040?oooooo003o
o`00ool001l0oooo1_oo000O0?ooo`?oo`0000@0ooooool00?oo003oo`007P3oool3ool000040?oo
oooo003oo`00ool000h0oooo00?o00000?ooo`3oool0303oool002L0oooo0_l0000M0?ooo`03o`00
o`3oool0oooo02<0oooo00?o003o0?ooo`3oool08P3oool00ol00?l0oooo0?ooo`0R0?ooo`03o`00
o`3oool0oooo02<0oooo00?o003o0?ooo`3oool0403oool2o`000300oooo0_l0000L0?ooo`?oo`00
00@0ooooool00?oo003oo`007P3oool3ool000040?oooooo003oo`00ool001l0oooo1_oo000O0?oo
o`?oo`0000@0ooooool00?oo003oo`007P3oool3ool000040?oooooo003oo`00ool000d0oooo0_l0
000>0?ooo`009`3oool00ol00000oooo0?ooo`0L0?ooo`03o`00o`3oool0oooo02<0oooo00?o003o
0?ooo`3oool08P3oool00ol00?l0oooo0?ooo`0R0?ooo`03o`00o`3oool0oooo02<0oooo00?o003o
0?ooo`3oool04@3oool00ol00000oooo0?ooo`0^0?ooo`03o`00003oool0oooo01/0oooo0ooo0000
103oooooo`00ool00?oo000N0?ooo`?oo`0000@0ooooool00?oo003oo`007`3oool6ool001l0oooo
0ooo0000103oooooo`00ool00?oo000N0?ooo`?oo`0000@0ooooool00?oo003oo`003P3oool00ol0
0000oooo0?ooo`0<0?ooo`009`3oool00ol00000oooo0?ooo`0L0?ooo`03o`00o`3oool0oooo02<0
oooo00?o003o0?ooo`3oool08P3oool00ol00?l0oooo0?ooo`0R0?ooo`03o`00o`3oool0oooo02<0
oooo00?o003o0?ooo`3oool04@3oool00ol00000oooo0?ooo`0^0?ooo`03o`00003oool0oooo01`0
oooo00D0o`000?ooo`3oool0oooo0?l0000P0?ooo`050?l0003oool0oooo0?ooo`3o00008@3oool0
103o0000oooo0?ooo`3o000Q0?ooo`050?l0003oool0oooo0?ooo`3o0000803oool01@3o0000oooo
0?ooo`3oool0o`0000l0oooo00?o00000?ooo`3oool0303oool002L0oooo00?o00000?ooo`3oool0
703oool00ol00?l0oooo0?ooo`0S0?ooo`03o`00o`3oool0oooo0280oooo00?o003o0?ooo`3oool0
8P3oool00ol00?l0oooo0?ooo`0S0?ooo`03o`00o`3oool0oooo0140oooo00?o00000?ooo`3oool0
;P3oool00ol00000oooo0?ooo`0L0?ooo`050?l0003oool0oooo0?ooo`3o0000803oool01@3o0000
oooo0?ooo`3oool0o`000240oooo00@0o`000?ooo`3oool0o`008@3oool01@3o0000oooo0?ooo`3o
ool0o`000200oooo00D0o`000?ooo`3oool0oooo0?l0000?0?ooo`03o`00003oool0oooo00`0oooo
000W0?ooo`03o`00003oool0oooo01L0oooo0ol00?l20?ooo`03o`00o`3oool0oooo00?o003o6`3o
ool3o`00o`80oooo00?o003o0?ooool00?l00_l00?lK0?ooo`?o003o0P3oool00ol00?l0oooo0?oo
o`03o`00oa/0oooo0ol00?l0103ooooo003o0?ooo`3oool3o`00oa/0oooo0ol00?l20?ooo`03o`00
o`3oool0oooo00?o003o3P3oool00ol00000oooo0?ooo`0^0?ooo`03o`00003oool0oooo01`0oooo
00D0o`000?ooo`3oool0oooo0?l0000P0?ooo`050?l0003oool0oooo0?ooo`3o00008@3oool0103o
0000oooo0?ooo`3o000Q0?ooo`050?l0003oool0oooo0?ooo`3o0000803oool01@3o0000oooo0?oo
o`3oool0o`0000l0oooo00?o00000?ooo`3oool0303oool002L0oooo00?o00000?ooo`3oool05`3o
ool3o`00o`80oooo00?o003o0?ooo`3oool00ol00?lK0?ooo`?o003o0P3oool00ol00?l0ooooo`00
o`02o`00oa/0oooo0ol00?l20?ooo`03o`00o`3oool0oooo00?o003o6`3oool3o`00o`040?ooool0
0?l0oooo0?ooo`?o003o6`3oool3o`00o`80oooo00?o003o0?ooo`3oool00ol00?l>0?ooo`03o`00
003oool0oooo02h0oooo00?o00000?ooo`3oool0703oool01@3o0000oooo0?ooo`3oool0o`000200
oooo00D0o`000?ooo`3oool0oooo0?l0000Q0?ooo`040?l0003oool0oooo0?l00240oooo00D0o`00
0?ooo`3oool0oooo0?l0000P0?ooo`050?l0003oool0oooo0?ooo`3o00003`3oool00ol00000oooo
0?ooo`0<0?ooo`009`3oool2o`0001P0oooo0ol00?l20?ooo`03o`00o`3oool0oooo00?o003o6`3o
ool3o`00o`80oooo00?o003o0?ooool00?l00_l00?lK0?ooo`?o003o0P3oool00ol00?l0oooo0?oo
o`03o`00oa/0oooo0ol00?l0103ooooo003o0?ooo`3oool3o`00oa/0oooo0ol00?l20?ooo`03o`00
o`3oool0oooo00?o003o3@3oool2o`000300oooo0_l0000M0?ooo`050?l0003oool0oooo0?ooo`3o
0000803oool01@3o0000oooo0?ooo`3oool0o`000240oooo00@0o`000?ooo`3oool0o`008@3oool0
1@3o0000oooo0?ooo`3oool0o`000200oooo00D0o`000?ooo`3oool0oooo0?l0000>0?ooo`;o0000
3P3oool002L0oooo00?o00000?ooo`3oool0603oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo
00?o003o0?ooo`3oool06`3oool01Ol00?l0oooo0?ooo`3ooooo003o0080oooo00?o003o0?ooo`3o
ool06`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool06`3oool01?l0
0?l0oooo0?ooool00?l30?ooo`03o`00o`3oool0oooo01/0oooo00Go003o0?ooo`3oool0ooooo`00
o`030?ooo`03o`00o`3oool0oooo00d0oooo00?o00000?ooo`3oool0;P3oool00ol00000oooo0?oo
o`0L0?ooo`050?l0003oool0oooo0?ooo`3o0000803oool01@3o0000oooo0?ooo`3oool0o`000240
oooo00@0o`000?ooo`3oool0o`008@3oool01@3o0000oooo0?ooo`3oool0o`000200oooo00D0o`00
0?ooo`3oool0oooo0?l0000?0?ooo`03o`00003oool0oooo00`0oooo000W0?ooo`03o`00003oool0
oooo01P0oooo00Go003o0?ooo`3oool0ooooo`00o`030?ooo`03o`00o`3oool0oooo01/0oooo00Go
003o0?ooo`3oool0ooooo`00o`020?ooo`03o`00o`3oool0oooo01/0oooo00Go003o0?ooo`3oool0
ooooo`00o`030?ooo`03o`00o`3oool0oooo01/0oooo00Co003o0?ooo`3ooooo003o0`3oool00ol0
0?l0oooo0?ooo`0K0?ooo`05o`00o`3oool0oooo0?ooool00?l00`3oool00ol00?l0oooo0?ooo`0=
0?ooo`03o`00003oool0oooo02h0oooo00?o00000?ooo`3oool0703oool01@3o0000oooo0?ooo`3o
ool0o`000200oooo00D0o`000?ooo`3oool0oooo0?l0000Q0?ooo`040?l0003oool0oooo0?l00240
oooo00D0o`000?ooo`3oool0oooo0?l0000P0?ooo`050?l0003oool0oooo0?ooo`3o00003`3oool0
0ol00000oooo0?ooo`0<0?ooo`009`3oool00ol00000oooo0?ooo`0H0?ooo`05o`00o`3oool0oooo
0?ooool00?l00`3oool00ol00?l0oooo0?ooo`0K0?ooo`05o`00o`3oool0oooo0?ooool00?l00P3o
ool00ol00?l0oooo0?ooo`0K0?ooo`05o`00o`3oool0oooo0?ooool00?l00`3oool00ol00?l0oooo
0?ooo`0K0?ooo`04o`00o`3oool0ooooo`00o`<0oooo00?o003o0?ooo`3oool06`3oool01Ol00?l0
oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool03@3oool00ol00000oooo0?ooo`0^0?oo
o`03o`00003oool0oooo01`0oooo00D0o`000?ooo`3oool0oooo0?l0000P0?ooo`050?l0003oool0
oooo0?ooo`3o00008@3oool0103o0000oooo0?ooo`3o000Q0?ooo`050?l0003oool0oooo0?ooo`3o
0000803oool01@3o0000oooo0?ooo`3oool0o`0000l0oooo00?o00000?ooo`3oool0303oool002L0
oooo00?o00000?ooo`3oool0603oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?oo
o`3oool06`3oool01Ol00?l0oooo0?ooo`3ooooo003o0080oooo00?o003o0?ooo`3oool06`3oool0
1Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool06`3oool01?l00?l0oooo0?oo
ool00?l30?ooo`03o`00o`3oool0oooo01/0oooo00Go003o0?ooo`3oool0ooooo`00o`030?ooo`03
o`00o`3oool0oooo00d0oooo00?o00000?ooo`3oool0;P3oool00ol00000oooo0?ooo`0L0?ooo`05
0?l0003oool0oooo0?ooo`3o0000803oool01@3o0000oooo0?ooo`3oool0o`000240oooo00@0o`00
0?ooo`3oool0o`008@3oool01@3o0000oooo0?ooo`3oool0o`000200oooo00D0o`000?ooo`3oool0
oooo0?l0000?0?ooo`03o`00003oool0oooo00`0oooo000W0?ooo`03o`00003oool0oooo01P0oooo
00Go003o0?ooo`3oool0ooooo`00o`030?ooo`03o`00o`3oool0oooo01/0oooo00Go003o0?ooo`3o
ool0ooooo`00o`020?ooo`03o`00o`3oool0oooo01/0oooo00Go003o0?ooo`3oool0ooooo`00o`03
0?ooo`03o`00o`3oool0oooo01/0oooo00Co003o0?ooo`3ooooo003o0`3oool00ol00?l0oooo0?oo
o`0K0?ooo`05o`00o`3oool0oooo0?ooool00?l00`3oool00ol00?l0oooo0?ooo`0=0?ooo`03o`00
003oool0oooo02h0oooo00?o00000?ooo`3oool0703oool01@3o0000oooo0?ooo`3oool0o`000200
oooo00D0o`000?ooo`3oool0oooo0?l0000Q0?ooo`040?l0003oool0oooo0?l00240oooo00D0o`00
0?ooo`3oool0oooo0?l0000P0?ooo`050?l0003oool0oooo0?ooo`3o00003`3oool00ol00000oooo
0?ooo`0<0?ooo`009`3oool2o`0001T0oooo00Go003o0?ooo`3oool0ooooo`00o`030?ooo`03o`00
o`3oool0oooo01/0oooo00Go003o0?ooo`3oool0ooooo`00o`020?ooo`03o`00o`3oool0oooo01/0
oooo00Go003o0?ooo`3oool0ooooo`00o`030?ooo`03o`00o`3oool0oooo01/0oooo00Co003o0?oo
o`3ooooo003o0`3oool00ol00?l0oooo0?ooo`0K0?ooo`05o`00o`3oool0oooo0?ooool00?l00`3o
ool00ol00?l0oooo0?ooo`0<0?ooo`;o0000<03oool2o`0001d0oooo00D0o`000?ooo`3oool0oooo
0?l0000P0?ooo`050?l0003oool0oooo0?ooo`3o00008@3oool0103o0000oooo0?ooo`3o000Q0?oo
o`050?l0003oool0oooo0?ooo`3o0000803oool01@3o0000oooo0?ooo`3oool0o`0000h0oooo0_l0
000>0?ooo`009`3oool00ol00000oooo0?ooo`0H0?ooo`05o`00o`3oool0oooo0?ooool00?l00`3o
ool00ol00?l0oooo0?ooo`0K0?ooo`05o`00o`3oool0oooo0?ooool00?l00P3oool00ol00?l0oooo
0?ooo`0K0?ooo`05o`00o`3oool0oooo0?ooool00?l00`3oool00ol00?l0oooo0?ooo`0K0?ooo`04
o`00o`3oool0ooooo`00o`<0oooo00?o003o0?ooo`3oool06`3oool01Ol00?l0oooo0?ooo`3ooooo
003o00<0oooo00?o003o0?ooo`3oool03@3oool00ol00000oooo0?ooo`0^0?ooo`03o`00003oool0
oooo01`0oooo00D0o`000?ooo`3oool0oooo0?l0000P0?ooo`050?l0003oool0oooo0?ooo`3o0000
8@3oool0103o0000oooo0?ooo`3o000Q0?ooo`050?l0003oool0oooo0?ooo`3o0000803oool01@3o
0000oooo0?ooo`3oool0o`0000l0oooo00?o00000?ooo`3oool0303oool002L0oooo00?o00000?oo
o`3oool0603oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool06`3oool0
1Ol00?l0oooo0?ooo`3ooooo003o0080oooo00?o003o0?ooo`3oool06`3oool01Ol00?l0oooo0?oo
o`3ooooo003o00<0oooo00?o003o0?ooo`3oool06`3oool01?l00?l0oooo0?ooool00?l30?ooo`03
o`00o`3oool0oooo01/0oooo00Go003o0?ooo`3oool0ooooo`00o`030?ooo`03o`00o`3oool0oooo
00d0oooo00?o00000?ooo`3oool0;P3oool00ol00000oooo0?ooo`0L0?ooo`050?l0003oool0oooo
0?ooo`3o0000803oool01@3o0000oooo0?ooo`3oool0o`000240oooo00@0o`000?ooo`3oool0o`00
8@3oool01@3o0000oooo0?ooo`3oool0o`000200oooo00D0o`000?ooo`3oool0oooo0?l0000?0?oo
o`03o`00003oool0oooo00`0oooo000W0?ooo`03o`00003oool0oooo01P0oooo00Go003o0?ooo`3o
ool0ooooo`00o`030?ooo`03o`00o`3oool0oooo01/0oooo00Go003o0?ooo`3oool0ooooo`00o`02
0?ooo`03o`00o`3oool0oooo01/0oooo00Go003o0?ooo`3oool0ooooo`00o`030?ooo`03o`00o`3o
ool0oooo01/0oooo00Co003o0?ooo`3ooooo003o0`3oool00ol00?l0oooo0?ooo`0K0?ooo`05o`00
o`3oool0oooo0?ooool00?l00`3oool00ol00?l0oooo0?ooo`0=0?ooo`03o`00003oool0oooo02h0
oooo00?o00000?ooo`3oool0703oool01@3o0000oooo0?ooo`3oool0o`000200oooo00D0o`000?oo
o`3oool0oooo0?l0000Q0?ooo`040?l0003oool0oooo0?l00240oooo00D0o`000?ooo`3oool0oooo
0?l0000P0?ooo`050?l0003oool0oooo0?ooo`3o00003`3oool00ol00000oooo0?ooo`0<0?ooo`00
9`3oool00ol00000oooo0?ooo`0H0?ooo`05o`00o`3oool0oooo0?ooool00?l00`3oool00ol00?l0
oooo0?ooo`0K0?ooo`05o`00o`3oool0oooo0?ooool00?l00P3oool00ol00?l0oooo0?ooo`0K0?oo
o`05o`00o`3oool0oooo0?ooool00?l00`3oool00ol00?l0oooo0?ooo`0K0?ooo`04o`00o`3oool0
ooooo`00o`<0oooo00?o003o0?ooo`3oool06`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo
00?o003o0?ooo`3oool03@3oool00ol00000oooo0?ooo`0^0?ooo`03o`00003oool0oooo01`0oooo
00D0o`000?ooo`3oool0oooo0?l0000P0?ooo`050?l0003oool0oooo0?ooo`3o00008@3oool0103o
0000oooo0?ooo`3o000Q0?ooo`050?l0003oool0oooo0?ooo`3o0000803oool01@3o0000oooo0?oo
o`3oool0o`0000l0oooo00?o00000?ooo`3oool0303oool002L0oooo0_l0000I0?ooo`05o`00o`3o
ool0oooo0?ooool00?l00`3oool00ol00?l0oooo0?ooo`0K0?ooo`05o`00o`3oool0oooo0?ooool0
0?l00P3oool00ol00?l0oooo0?ooo`0K0?ooo`05o`00o`3oool0oooo0?ooool00?l00`3oool00ol0
0?l0oooo0?ooo`0K0?ooo`04o`00o`3oool0ooooo`00o`<0oooo00?o003o0?ooo`3oool06`3oool0
1Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool0303oool2o`000300oooo0_l0
000M0?ooo`050?l0003oool0oooo0?ooo`3o0000803oool01@3o0000oooo0?ooo`3oool0o`000240
oooo00@0o`000?ooo`3oool0o`008@3oool01@3o0000oooo0?ooo`3oool0o`000200oooo00D0o`00
0?ooo`3oool0oooo0?l0000>0?ooo`;o00003P3oool002L0oooo00?o00000?ooo`3oool0603oool0
1Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool06`3oool01Ol00?l0oooo0?oo
o`3ooooo003o0080oooo00?o003o0?ooo`3oool06`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0
oooo00?o003o0?ooo`3oool06`3oool01?l00?l0oooo0?ooool00?l30?ooo`03o`00o`3oool0oooo
01/0oooo00Go003o0?ooo`3oool0ooooo`00o`030?ooo`03o`00o`3oool0oooo00d0oooo00?o0000
0?ooo`3oool0;P3oool00ol00000oooo0?ooo`0L0?ooo`050?l0003oool0oooo0?ooo`3o0000803o
ool01@3o0000oooo0?ooo`3oool0o`000240oooo00@0o`000?ooo`3oool0o`008@3oool01@3o0000
oooo0?ooo`3oool0o`000200oooo00D0o`000?ooo`3oool0oooo0?l0000?0?ooo`03o`00003oool0
oooo00`0oooo000W0?ooo`03o`00003oool0oooo01P0oooo00Go003o0?ooo`3oool0ooooo`00o`03
0?ooo`03o`00o`3oool0oooo01/0oooo00Go003o0?ooo`3oool0ooooo`00o`020?ooo`03o`00o`3o
ool0oooo01/0oooo00Go003o0?ooo`3oool0ooooo`00o`030?ooo`03o`00o`3oool0oooo01/0oooo
00Co003o0?ooo`3ooooo003o0`3oool00ol00?l0oooo0?ooo`0K0?ooo`05o`00o`3oool0oooo0?oo
ool00?l00`3oool00ol00?l0oooo0?ooo`0=0?ooo`03o`00003oool0oooo02h0oooo00?o00000?oo
o`3oool05`3oool3ool00080oooo00H0o`000?ooo`3oool0oooo0?l0003oool3ool001L0oooo0ooo
00020?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool3ool001L0oooo0ooo00020?ooo`040?l0
003oool0oooo0?l00080oooo0ooo000G0?ooo`?oo`000P3oool01@3o0000oooo0?ooo`3oool0o`00
0080oooo0ooo000G0?ooo`?oo`0000<0oooo0?l0003oool00P3oool00`3o0000oooo0?ooo`03ool0
00X0oooo00?o00000?ooo`3oool0303oool002L0oooo00?o00000?ooo`3oool0603oool01Ol00?l0
oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool06`3oool01Ol00?l0oooo0?ooo`3ooooo
003o0080oooo00?o003o0?ooo`3oool06`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o
003o0?ooo`3oool06`3oool01?l00?l0oooo0?ooool00?l30?ooo`03o`00o`3oool0oooo01/0oooo
00Go003o0?ooo`3oool0ooooo`00o`030?ooo`03o`00o`3oool0oooo00d0oooo00?o00000?ooo`3o
ool0;P3oool00ol00000oooo0?ooo`0G0?ooo`?oo`000P3oool01P3o0000oooo0?ooo`3oool0o`00
0?ooo`?oo`005`3oool3ool00080oooo00D0o`000?ooo`3oool0oooo0?l000020?ooo`?oo`005`3o
ool3ool00080oooo00@0o`000?ooo`3oool0o`000P3oool3ool001L0oooo0ooo00020?ooo`050?l0
003oool0oooo0?ooo`3o00000P3oool3ool001L0oooo0ooo00000`3oool0o`000?ooo`020?ooo`03
0?l0003oool0oooo00?oo`002P3oool00ol00000oooo0?ooo`0<0?ooo`005@3oool2o`0000@0oooo
00?o00000?ooo`3oool00P3oool3o`0000@0oooo00?o00000?ooo`3oool0603oool01Ol00?l0oooo
0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool06`3oool01Ol00?l0oooo0?ooo`3ooooo003o
0080oooo00?o003o0?ooo`3oool06`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o
0?ooo`3oool06`3oool01?l00?l0oooo0?ooool00?l30?ooo`03o`00o`3oool0oooo01/0oooo00Go
003o0?ooo`3oool0ooooo`00o`030?ooo`03o`00o`3oool0oooo00d0oooo00?o00000?ooo`3oool0
6`3oool2o`0000@0oooo00?o00000?ooo`3oool00P3oool3o`0000D0oooo00?o00000?ooo`3oool0
5`3oool3ool00080oooo00H0o`000?ooo`3oool0oooo0?l0003oool3ool001L0oooo0ooo00020?oo
o`050?l0003oool0oooo0?ooo`3o00000P3oool3ool001L0oooo0ooo00020?ooo`040?l0003oool0
oooo0?l00080oooo0ooo000G0?ooo`?oo`000P3oool01@3o0000oooo0?ooo`3oool0o`000080oooo
0ooo000G0?ooo`?oo`0000<0oooo0?l0003oool00P3oool00`3o0000oooo0?ooo`03ool000X0oooo
00?o00000?ooo`3oool0303oool001@0oooo00Co00000?ooo`3ooooo00001`3oool01Ol00000oooo
0?ooo`3ooooo000000<0oooo00?o00000?ooo`3oool0603oool01Ol00?l0oooo0?ooo`3ooooo003o
00<0oooo00?o003o0?ooo`3oool06`3oool01Ol00?l0oooo0?ooo`3ooooo003o0080oooo00?o003o
0?ooo`3oool06`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool06`3o
ool01?l00?l0oooo0?ooool00?l30?ooo`03o`00o`3oool0oooo01/0oooo00Go003o0?ooo`3oool0
ooooo`00o`030?ooo`03o`00o`3oool0oooo00d0oooo00?o00000?ooo`3oool06P3oool01?l00000
oooo0?ooool000070?ooo`05o`00003oool0oooo0?ooool00000103oool00ol00000oooo0?ooo`0H
0?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool0103o0000oooo0?ooo`3o000I0?ooo`050?l0
003oool0oooo0?ooo`3o00000`3oool01@3o0000oooo0?ooo`3oool0o`0001T0oooo00D0o`000?oo
o`3oool0oooo0?l000020?ooo`050?l0003oool0oooo0?ooo`3o00006@3oool01@3o0000oooo0?oo
o`3oool0o`0000<0oooo00D0o`000?ooo`3oool0oooo0?l0000I0?ooo`040?l0003oool0oooo0?l0
00<0oooo00D0o`000?ooo`3oool0oooo0?l0000;0?ooo`03o`00003oool0oooo00`0oooo000=0?oo
o`Go00000P3oool01?l00000oooo0?ooool0000;0?ooo`04o`00003oool0oooo0?ooo`;o00006@3o
ool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool06`3oool01Ol00?l0oooo
0?ooo`3ooooo003o0080oooo00?o003o0?ooo`3oool06`3oool01Ol00?l0oooo0?ooo`3ooooo003o
00<0oooo00?o003o0?ooo`3oool06`3oool01?l00?l0oooo0?ooool00?l30?ooo`03o`00o`3oool0
oooo01/0oooo00Go003o0?ooo`3oool0ooooo`00o`030?ooo`03o`00o`3oool0oooo00/0oooo0ol0
000E0?ooo`Go00000P3oool01?l00000oooo0?ooool0000;0?ooo`03o`00003oool0oooo0080oooo
0_l0000I0?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool0103o0000oooo0?ooo`3o000I0?oo
o`050?l0003oool0oooo0?ooo`3o00000`3oool01@3o0000oooo0?ooo`3oool0o`0001T0oooo00D0
o`000?ooo`3oool0oooo0?l000020?ooo`050?l0003oool0oooo0?ooo`3o00006@3oool01@3o0000
oooo0?ooo`3oool0o`0000<0oooo00D0o`000?ooo`3oool0oooo0?l0000I0?ooo`040?l0003oool0
oooo0?l000<0oooo00D0o`000?ooo`3oool0oooo0?l0000:0?ooo`;o00003P3oool001@0oooo00Co
00000?ooo`3ooooo00002`3oool01Ol00000oooo0?ooo`3ooooo000001X0oooo00Go003o0?ooo`3o
ool0ooooo`00o`030?ooo`03o`00o`3oool0oooo01/0oooo00Go003o0?ooo`3oool0ooooo`00o`02
0?ooo`03o`00o`3oool0oooo01/0oooo00Go003o0?ooo`3oool0ooooo`00o`030?ooo`03o`00o`3o
ool0oooo01/0oooo00Co003o0?ooo`3ooooo003o0`3oool00ol00?l0oooo0?ooo`0K0?ooo`05o`00
o`3oool0oooo0?ooool00?l00`3oool00ol00?l0oooo0?ooo`0=0?ooo`03o`00003oool0oooo01X0
oooo00Co00000?ooo`3ooooo00002`3oool00ol00000oooo0?ooo`020?ooo`03o`00003oool0oooo
01P0oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`040?l0003oool0oooo0?l001T0oooo00D0
o`000?ooo`3oool0oooo0?l000030?ooo`050?l0003oool0oooo0?ooo`3o00006@3oool01@3o0000
oooo0?ooo`3oool0o`000080oooo00D0o`000?ooo`3oool0oooo0?l0000I0?ooo`050?l0003oool0
oooo0?ooo`3o00000`3oool01@3o0000oooo0?ooo`3oool0o`0001T0oooo00@0o`000?ooo`3oool0
o`000`3oool01@3o0000oooo0?ooo`3oool0o`0000/0oooo00?o00000?ooo`3oool0303oool001@0
oooo00Co00000?ooo`3ooooo00001`3oool4o`0000@0oooo00?o00000?ooo`3oool0603oool01Ol0
0?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool06`3oool01Ol00?l0oooo0?ooo`3o
oooo003o0080oooo00?o003o0?ooo`3oool06`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo
00?o003o0?ooo`3oool06`3oool01?l00?l0oooo0?ooool00?l30?ooo`03o`00o`3oool0oooo01/0
oooo00Go003o0?ooo`3oool0ooooo`00o`030?ooo`03o`00o`3oool0oooo00d0oooo00?o00000?oo
o`3oool06P3oool01?l00000oooo0?ooool000070?ooo`Co00001@3oool00ol00000oooo0?ooo`0H
0?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool0103o0000oooo0?ooo`3o000I0?ooo`050?l0
003oool0oooo0?ooo`3o00000`3oool01@3o0000oooo0?ooo`3oool0o`0001T0oooo00D0o`000?oo
o`3oool0oooo0?l000020?ooo`050?l0003oool0oooo0?ooo`3o00006@3oool01@3o0000oooo0?oo
o`3oool0o`0000<0oooo00D0o`000?ooo`3oool0oooo0?l0000I0?ooo`040?l0003oool0oooo0?l0
00<0oooo00D0o`000?ooo`3oool0oooo0?l0000;0?ooo`03o`00003oool0oooo00`0oooo000D0?oo
o`04o`00003oool0ooooo`0000L0oooo00?o00000?ooo`3oool01@3oool00ol00000oooo0?ooo`0H
0?ooo`05o`00o`3oool0oooo0?ooool00?l00`3oool00ol00?l0oooo0?ooo`0K0?ooo`05o`00o`3o
ool0oooo0?ooool00?l00P3oool00ol00?l0oooo0?ooo`0K0?ooo`05o`00o`3oool0oooo0?ooool0
0?l00`3oool00ol00?l0oooo0?ooo`0K0?ooo`04o`00o`3oool0ooooo`00o`<0oooo00?o003o0?oo
o`3oool06`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool03@3oool0
0ol00000oooo0?ooo`0J0?ooo`04o`00003oool0ooooo`0000L0oooo00?o00000?ooo`3oool01P3o
ool00ol00000oooo0?ooo`0H0?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool0103o0000oooo
0?ooo`3o000I0?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool01@3o0000oooo0?ooo`3oool0
o`0001T0oooo00D0o`000?ooo`3oool0oooo0?l000020?ooo`050?l0003oool0oooo0?ooo`3o0000
6@3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00D0o`000?ooo`3oool0oooo0?l0000I0?oo
o`040?l0003oool0oooo0?l000<0oooo00D0o`000?ooo`3oool0oooo0?l0000;0?ooo`03o`00003o
ool0oooo00`0oooo000E0?ooo`;o0000203oool5o`0000<0oooo00?o00000?ooo`3oool0603oool0
1Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool06`3oool01Ol00?l0oooo0?oo
o`3ooooo003o0080oooo00?o003o0?ooo`3oool06`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0
oooo00?o003o0?ooo`3oool06`3oool01?l00?l0oooo0?ooool00?l30?ooo`03o`00o`3oool0oooo
01/0oooo00Go003o0?ooo`3oool0ooooo`00o`030?ooo`03o`00o`3oool0oooo00d0oooo00?o0000
0?ooo`3oool06`3oool2o`0000P0oooo1Ol000040?ooo`03o`00003oool0oooo01P0oooo00D0o`00
0?ooo`3oool0oooo0?l000030?ooo`040?l0003oool0oooo0?l001T0oooo00D0o`000?ooo`3oool0
oooo0?l000030?ooo`050?l0003oool0oooo0?ooo`3o00006@3oool01@3o0000oooo0?ooo`3oool0
o`000080oooo00D0o`000?ooo`3oool0oooo0?l0000I0?ooo`050?l0003oool0oooo0?ooo`3o0000
0`3oool01@3o0000oooo0?ooo`3oool0o`0001T0oooo00@0o`000?ooo`3oool0o`000`3oool01@3o
0000oooo0?ooo`3oool0o`0000/0oooo00?o00000?ooo`3oool0303oool002L0oooo00?o00000?oo
o`3oool0603oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool06`3oool0
1Ol00?l0oooo0?ooo`3ooooo003o0080oooo00?o003o0?ooo`3oool06`3oool01Ol00?l0oooo0?oo
o`3ooooo003o00<0oooo00?o003o0?ooo`3oool06`3oool01?l00?l0oooo0?ooool00?l30?ooo`03
o`00o`3oool0oooo01/0oooo00Go003o0?ooo`3oool0ooooo`00o`030?ooo`03o`00o`3oool0oooo
00d0oooo00?o00000?ooo`3oool0;P3oool00ol00000oooo0?ooo`0H0?ooo`050?l0003oool0oooo
0?ooo`3o00000`3oool0103o0000oooo0?ooo`3o000I0?ooo`050?l0003oool0oooo0?ooo`3o0000
0`3oool01@3o0000oooo0?ooo`3oool0o`0001T0oooo00D0o`000?ooo`3oool0oooo0?l000020?oo
o`050?l0003oool0oooo0?ooo`3o00006@3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00D0
o`000?ooo`3oool0oooo0?l0000I0?ooo`040?l0003oool0oooo0?l000<0oooo00D0o`000?ooo`3o
ool0oooo0?l0000;0?ooo`03o`00003oool0oooo00`0oooo000W0?ooo`;o00006@3oool01Ol00?l0
oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool06`3oool01Ol00?l0oooo0?ooo`3ooooo
003o0080oooo00?o003o0?ooo`3oool06`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o
003o0?ooo`3oool06`3oool01?l00?l0oooo0?ooool00?l30?ooo`03o`00o`3oool0oooo01/0oooo
00Go003o0?ooo`3oool0ooooo`00o`030?ooo`03o`00o`3oool0oooo00`0oooo0_l0000`0?ooo`;o
00006@3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00@0o`000?ooo`3oool0o`006@3oool0
1@3o0000oooo0?ooo`3oool0o`0000<0oooo00D0o`000?ooo`3oool0oooo0?l0000I0?ooo`050?l0
003oool0oooo0?ooo`3o00000P3oool01@3o0000oooo0?ooo`3oool0o`0001T0oooo00D0o`000?oo
o`3oool0oooo0?l000030?ooo`050?l0003oool0oooo0?ooo`3o00006@3oool0103o0000oooo0?oo
o`3o00030?ooo`050?l0003oool0oooo0?ooo`3o00002P3oool2o`0000h0oooo000W0?ooo`03o`00
003oool0oooo01P0oooo00Go003o0?ooo`3oool0ooooo`00o`030?ooo`03o`00o`3oool0oooo01/0
oooo00Go003o0?ooo`3oool0ooooo`00o`020?ooo`03o`00o`3oool0oooo01/0oooo00Go003o0?oo
o`3oool0ooooo`00o`030?ooo`03o`00o`3oool0oooo01/0oooo00Co003o0?ooo`3ooooo003o0`3o
ool00ol00?l0oooo0?ooo`0K0?ooo`05o`00o`3oool0oooo0?ooool00?l00`3oool00ol00?l0oooo
0?ooo`0=0?ooo`03o`00003oool0oooo02h0oooo00?o00000?ooo`3oool0603oool01@3o0000oooo
0?ooo`3oool0o`0000<0oooo00@0o`000?ooo`3oool0o`006@3oool01@3o0000oooo0?ooo`3oool0
o`0000<0oooo00D0o`000?ooo`3oool0oooo0?l0000I0?ooo`050?l0003oool0oooo0?ooo`3o0000
0P3oool01@3o0000oooo0?ooo`3oool0o`0001T0oooo00D0o`000?ooo`3oool0oooo0?l000030?oo
o`050?l0003oool0oooo0?ooo`3o00006@3oool0103o0000oooo0?ooo`3o00030?ooo`050?l0003o
ool0oooo0?ooo`3o00002`3oool00ol00000oooo0?ooo`0<0?ooo`009`3oool00ol00000oooo0?oo
o`0H0?ooo`05o`00o`3oool0oooo0?ooool00?l00`3oool00ol00?l0oooo0?ooo`0K0?ooo`05o`00
o`3oool0oooo0?ooool00?l00P3oool00ol00?l0oooo0?ooo`0K0?ooo`05o`00o`3oool0oooo0?oo
ool00?l00`3oool00ol00?l0oooo0?ooo`0K0?ooo`04o`00o`3oool0ooooo`00o`<0oooo00?o003o
0?ooo`3oool06`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool03@3o
ool00ol00000oooo0?ooo`0^0?ooo`03o`00003oool0oooo01P0oooo00D0o`000?ooo`3oool0oooo
0?l000030?ooo`040?l0003oool0oooo0?l001T0oooo00D0o`000?ooo`3oool0oooo0?l000030?oo
o`050?l0003oool0oooo0?ooo`3o00006@3oool01@3o0000oooo0?ooo`3oool0o`000080oooo00D0
o`000?ooo`3oool0oooo0?l0000I0?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool01@3o0000
oooo0?ooo`3oool0o`0001T0oooo00@0o`000?ooo`3oool0o`000`3oool01@3o0000oooo0?ooo`3o
ool0o`0000/0oooo00?o00000?ooo`3oool0303oool002L0oooo00?o00000?ooo`3oool0603oool0
1Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool06`3oool01Ol00?l0oooo0?oo
o`3ooooo003o0080oooo00?o003o0?ooo`3oool06`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0
oooo00?o003o0?ooo`3oool06`3oool01?l00?l0oooo0?ooool00?l30?ooo`03o`00o`3oool0oooo
01/0oooo00Go003o0?ooo`3oool0ooooo`00o`030?ooo`03o`00o`3oool0oooo00d0oooo00?o0000
0?ooo`3oool0;P3oool00ol00000oooo0?ooo`0H0?ooo`050?l0003oool0oooo0?ooo`3o00000`3o
ool0103o0000oooo0?ooo`3o000I0?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool01@3o0000
oooo0?ooo`3oool0o`0001T0oooo00D0o`000?ooo`3oool0oooo0?l000020?ooo`050?l0003oool0
oooo0?ooo`3o00006@3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00D0o`000?ooo`3oool0
oooo0?l0000I0?ooo`040?l0003oool0oooo0?l000<0oooo00D0o`000?ooo`3oool0oooo0?l0000;
0?ooo`03o`00003oool0oooo00`0oooo000W0?ooo`03o`00003oool0oooo01P0oooo00Go003o0?oo
o`3oool0ooooo`00o`030?ooo`03o`00o`3oool0oooo01/0oooo00Go003o0?ooo`3oool0ooooo`00
o`020?ooo`03o`00o`3oool0oooo01/0oooo00Go003o0?ooo`3oool0ooooo`00o`030?ooo`03o`00
o`3oool0oooo01/0oooo00Co003o0?ooo`3ooooo003o0`3oool00ol00?l0oooo0?ooo`0K0?ooo`05
o`00o`3oool0oooo0?ooool00?l00`3oool00ol00?l0oooo0?ooo`0=0?ooo`03o`00003oool0oooo
02h0oooo00?o00000?ooo`3oool0603oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00@0o`00
0?ooo`3oool0o`006@3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00D0o`000?ooo`3oool0
oooo0?l0000I0?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool01@3o0000oooo0?ooo`3oool0
o`0001T0oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`050?l0003oool0oooo0?ooo`3o0000
6@3oool0103o0000oooo0?ooo`3o00030?ooo`050?l0003oool0oooo0?ooo`3o00002`3oool00ol0
0000oooo0?ooo`0<0?ooo`009`3oool00ol00000oooo0?ooo`0D0?ooo`?o003o00<0ooooo`00o`3o
ool00P3oool01Ol00?l0oooo0?ooo`3ooooo003o0080oooo0ol00?lC0?ooo`?o003o0P3oool01Ol0
0?l0oooo0?ooo`3ooooo003o0080oooo00?o003o0?ooo`3oool00ol00?lC0?ooo`?o003o0P3oool0
1Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooool00?l00_l00?lD0?ooo`?o003o0P3o
ool01?l00?l0oooo0?ooool00?l30?ooo`03o`00o`3oool0oooo00?o003o4`3oool3o`00o`80oooo
00Go003o0?ooo`3oool0ooooo`00o`030?ooo`03o`00o`3ooooo003o00;o003o2`3oool00ol00000
oooo0?ooo`0^0?ooo`03o`00003oool0oooo01P0oooo00D0o`000?ooo`3oool0oooo0?l000030?oo
o`040?l0003oool0oooo0?l001T0oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`050?l0003o
ool0oooo0?ooo`3o00006@3oool01@3o0000oooo0?ooo`3oool0o`000080oooo00D0o`000?ooo`3o
ool0oooo0?l0000I0?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool01@3o0000oooo0?ooo`3o
ool0o`0001T0oooo00@0o`000?ooo`3oool0o`000`3oool01@3o0000oooo0?ooo`3oool0o`0000/0
oooo00?o00000?ooo`3oool0303oool002L0oooo0_l0000E0?ooo`?o003o00<0ooooo`00o`3oool0
0P3oool01Ol00?l0oooo0?ooo`3ooooo003o0080oooo0ol00?lC0?ooo`?o003o0P3oool01Ol00?l0
oooo0?ooo`3ooooo003o0080oooo00?o003o0?ooo`3oool00ol00?lC0?ooo`?o003o0P3oool01Ol0
0?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooool00?l00_l00?lD0?ooo`?o003o0P3oool0
1?l00?l0oooo0?ooool00?l30?ooo`03o`00o`3oool0oooo00?o003o4`3oool3o`00o`80oooo00Go
003o0?ooo`3oool0ooooo`00o`030?ooo`03o`00o`3ooooo003o00;o003o2P3oool2o`000300oooo
0_l0000I0?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool0103o0000oooo0?ooo`3o000I0?oo
o`050?l0003oool0oooo0?ooo`3o00000`3oool01@3o0000oooo0?ooo`3oool0o`0001T0oooo00D0
o`000?ooo`3oool0oooo0?l000020?ooo`050?l0003oool0oooo0?ooo`3o00006@3oool01@3o0000
oooo0?ooo`3oool0o`0000<0oooo00D0o`000?ooo`3oool0oooo0?l0000I0?ooo`040?l0003oool0
oooo0?l000<0oooo00D0o`000?ooo`3oool0oooo0?l0000:0?ooo`;o00003P3oool002L0oooo00?o
00000?ooo`3oool0503oool3o`00o`030?ooool00?l0oooo0080oooo00Go003o0?ooo`3oool0oooo
o`00o`020?ooo`?o003o4`3oool3o`00o`80oooo00Go003o0?ooo`3oool0ooooo`00o`020?ooo`03
o`00o`3oool0oooo00?o003o4`3oool3o`00o`80oooo00Go003o0?ooo`3oool0ooooo`00o`030?oo
o`03o`00o`3ooooo003o00;o003o503oool3o`00o`80oooo00Co003o0?ooo`3ooooo003o0`3oool0
0ol00?l0oooo0?ooo`03o`00oa<0oooo0ol00?l20?ooo`05o`00o`3oool0oooo0?ooool00?l00`3o
ool00ol00?l0ooooo`00o`02o`00o`/0oooo00?o00000?ooo`3oool0;P3oool00ol00000oooo0?oo
o`0H0?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool0103o0000oooo0?ooo`3o000I0?ooo`05
0?l0003oool0oooo0?ooo`3o00000`3oool01@3o0000oooo0?ooo`3oool0o`0001T0oooo00D0o`00
0?ooo`3oool0oooo0?l000020?ooo`050?l0003oool0oooo0?ooo`3o00006@3oool01@3o0000oooo
0?ooo`3oool0o`0000<0oooo00D0o`000?ooo`3oool0oooo0?l0000I0?ooo`040?l0003oool0oooo
0?l000<0oooo00D0o`000?ooo`3oool0oooo0?l0000;0?ooo`03o`00003oool0oooo00`0oooo000W
0?ooo`03o`00003oool0oooo01D0oooo00Co003o0?ooo`3ooooo003o0`3oool01Ol00?l0oooo0?oo
o`3ooooo003o00<0oooo00?o003o0?ooo`3oool04`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0
oooo00Co003o0?ooo`3ooooo003o0`3oool00ol00?l0oooo0?ooo`0C0?ooo`05o`00o`3oool0oooo
0?ooool00?l00`3oool01Ol00?l0oooo0?ooo`3ooooo003o0080oooo00?o003o0?ooo`3oool0503o
ool01Ol00?l0oooo0?ooo`3ooooo003o0080oooo00Go003o0?ooo`3oool0ooooo`00o`030?ooo`03
o`00o`3oool0oooo01<0oooo00Go003o0?ooo`3oool0ooooo`00o`030?ooo`05o`00o`3oool0oooo
0?ooool00?l00P3oool00ol00?l0oooo0?ooo`0:0?ooo`03o`00003oool0oooo02h0oooo00?o0000
0?ooo`3oool0603oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00@0o`000?ooo`3oool0o`00
6@3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00D0o`000?ooo`3oool0oooo0?l0000I0?oo
o`050?l0003oool0oooo0?ooo`3o00000P3oool01@3o0000oooo0?ooo`3oool0o`0001T0oooo00D0
o`000?ooo`3oool0oooo0?l000030?ooo`050?l0003oool0oooo0?ooo`3o00006@3oool0103o0000
oooo0?ooo`3o00030?ooo`050?l0003oool0oooo0?ooo`3o00002`3oool00ol00000oooo0?ooo`0<
0?ooo`009`3oool00ol00000oooo0?ooo`0E0?ooo`04o`00o`3oool0ooooo`00o`<0oooo00Go003o
0?ooo`3oool0ooooo`00o`030?ooo`03o`00o`3oool0oooo01<0oooo00Go003o0?ooo`3oool0oooo
o`00o`030?ooo`04o`00o`3oool0ooooo`00o`<0oooo00?o003o0?ooo`3oool04`3oool01Ol00?l0
oooo0?ooo`3ooooo003o00<0oooo00Go003o0?ooo`3oool0ooooo`00o`020?ooo`03o`00o`3oool0
oooo01@0oooo00Go003o0?ooo`3oool0ooooo`00o`020?ooo`05o`00o`3oool0oooo0?ooool00?l0
0`3oool00ol00?l0oooo0?ooo`0C0?ooo`05o`00o`3oool0oooo0?ooool00?l00`3oool01Ol00?l0
oooo0?ooo`3ooooo003o0080oooo00?o003o0?ooo`3oool02P3oool00ol00000oooo0?ooo`0^0?oo
o`03o`00003oool0oooo01P0oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`040?l0003oool0
oooo0?l001T0oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`050?l0003oool0oooo0?ooo`3o
00006@3oool01@3o0000oooo0?ooo`3oool0o`000080oooo00D0o`000?ooo`3oool0oooo0?l0000I
0?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool01@3o0000oooo0?ooo`3oool0o`0001T0oooo
00@0o`000?ooo`3oool0o`000`3oool01@3o0000oooo0?ooo`3oool0o`0000/0oooo00?o00000?oo
o`3oool0303oool002L0oooo00?o00000?ooo`3oool05@3oool01?l00?l0oooo0?ooool00?l30?oo
o`05o`00o`3oool0oooo0?ooool00?l00`3oool00ol00?l0oooo0?ooo`0C0?ooo`05o`00o`3oool0
oooo0?ooool00?l00`3oool01?l00?l0oooo0?ooool00?l30?ooo`03o`00o`3oool0oooo01<0oooo
00Go003o0?ooo`3oool0ooooo`00o`030?ooo`05o`00o`3oool0oooo0?ooool00?l00P3oool00ol0
0?l0oooo0?ooo`0D0?ooo`05o`00o`3oool0oooo0?ooool00?l00P3oool01Ol00?l0oooo0?ooo`3o
oooo003o00<0oooo00?o003o0?ooo`3oool04`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo
00Go003o0?ooo`3oool0ooooo`00o`020?ooo`03o`00o`3oool0oooo00X0oooo00?o00000?ooo`3o
ool0;P3oool00ol00000oooo0?ooo`0H0?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool0103o
0000oooo0?ooo`3o000I0?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool01@3o0000oooo0?oo
o`3oool0o`0001T0oooo00D0o`000?ooo`3oool0oooo0?l000020?ooo`050?l0003oool0oooo0?oo
o`3o00006@3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00D0o`000?ooo`3oool0oooo0?l0
000I0?ooo`040?l0003oool0oooo0?l000<0oooo00D0o`000?ooo`3oool0oooo0?l0000;0?ooo`03
o`00003oool0oooo00`0oooo000W0?ooo`03o`00003oool0oooo01D0oooo00Co003o0?ooo`3ooooo
003o0`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool04`3oool01Ol0
0?l0oooo0?ooo`3ooooo003o00<0oooo00Co003o0?ooo`3ooooo003o0`3oool00ol00?l0oooo0?oo
o`0C0?ooo`05o`00o`3oool0oooo0?ooool00?l00`3oool01Ol00?l0oooo0?ooo`3ooooo003o0080
oooo00?o003o0?ooo`3oool0503oool01Ol00?l0oooo0?ooo`3ooooo003o0080oooo00Go003o0?oo
o`3oool0ooooo`00o`030?ooo`03o`00o`3oool0oooo01<0oooo00Go003o0?ooo`3oool0ooooo`00
o`030?ooo`05o`00o`3oool0oooo0?ooool00?l00P3oool00ol00?l0oooo0?ooo`0:0?ooo`03o`00
003oool0oooo02h0oooo00?o00000?ooo`3oool0603oool01@3o0000oooo0?ooo`3oool0o`0000<0
oooo00@0o`000?ooo`3oool0o`006@3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00D0o`00
0?ooo`3oool0oooo0?l0000I0?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool01@3o0000oooo
0?ooo`3oool0o`0001T0oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`050?l0003oool0oooo
0?ooo`3o00006@3oool0103o0000oooo0?ooo`3o00030?ooo`050?l0003oool0oooo0?ooo`3o0000
2`3oool00ol00000oooo0?ooo`0<0?ooo`009`3oool2o`0001H0oooo00Co003o0?ooo`3ooooo003o
0`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool04`3oool01Ol00?l0
oooo0?ooo`3ooooo003o00<0oooo00Co003o0?ooo`3ooooo003o0`3oool00ol00?l0oooo0?ooo`0C
0?ooo`05o`00o`3oool0oooo0?ooool00?l00`3oool01Ol00?l0oooo0?ooo`3ooooo003o0080oooo
00?o003o0?ooo`3oool0503oool01Ol00?l0oooo0?ooo`3ooooo003o0080oooo00Go003o0?ooo`3o
ool0ooooo`00o`030?ooo`03o`00o`3oool0oooo01<0oooo00Go003o0?ooo`3oool0ooooo`00o`03
0?ooo`05o`00o`3oool0oooo0?ooool00?l00P3oool00ol00?l0oooo0?ooo`090?ooo`;o0000<03o
ool2o`0001T0oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`040?l0003oool0oooo0?l001T0
oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`050?l0003oool0oooo0?ooo`3o00006@3oool0
1@3o0000oooo0?ooo`3oool0o`000080oooo00D0o`000?ooo`3oool0oooo0?l0000I0?ooo`050?l0
003oool0oooo0?ooo`3o00000`3oool01@3o0000oooo0?ooo`3oool0o`0001T0oooo00@0o`000?oo
o`3oool0o`000`3oool01@3o0000oooo0?ooo`3oool0o`0000X0oooo0_l0000>0?ooo`009`3oool0
0ol00000oooo0?ooo`0E0?ooo`04o`00o`3oool0ooooo`00o`<0oooo00Go003o0?ooo`3oool0oooo
o`00o`030?ooo`03o`00o`3oool0oooo01<0oooo00Go003o0?ooo`3oool0ooooo`00o`030?ooo`04
o`00o`3oool0ooooo`00o`<0oooo00?o003o0?ooo`3oool04`3oool01Ol00?l0oooo0?ooo`3ooooo
003o00<0oooo00Go003o0?ooo`3oool0ooooo`00o`020?ooo`03o`00o`3oool0oooo01@0oooo00Go
003o0?ooo`3oool0ooooo`00o`020?ooo`05o`00o`3oool0oooo0?ooool00?l00`3oool00ol00?l0
oooo0?ooo`0C0?ooo`05o`00o`3oool0oooo0?ooool00?l00`3oool01Ol00?l0oooo0?ooo`3ooooo
003o0080oooo00?o003o0?ooo`3oool02P3oool00ol00000oooo0?ooo`0^0?ooo`03o`00003oool0
oooo01P0oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`040?l0003oool0oooo0?l001T0oooo
00D0o`000?ooo`3oool0oooo0?l000030?ooo`050?l0003oool0oooo0?ooo`3o00006@3oool01@3o
0000oooo0?ooo`3oool0o`000080oooo00D0o`000?ooo`3oool0oooo0?l0000I0?ooo`050?l0003o
ool0oooo0?ooo`3o00000`3oool01@3o0000oooo0?ooo`3oool0o`0001T0oooo00@0o`000?ooo`3o
ool0o`000`3oool01@3o0000oooo0?ooo`3oool0o`0000/0oooo00?o00000?ooo`3oool0303oool0
02L0oooo00?o00000?ooo`3oool05@3oool01?l00?l0oooo0?ooool00?l30?ooo`05o`00o`3oool0
oooo0?ooool00?l00`3oool00ol00?l0oooo0?ooo`0C0?ooo`05o`00o`3oool0oooo0?ooool00?l0
0`3oool01?l00?l0oooo0?ooool00?l30?ooo`03o`00o`3oool0oooo01<0oooo00Go003o0?ooo`3o
ool0ooooo`00o`030?ooo`05o`00o`3oool0oooo0?ooool00?l00P3oool00ol00?l0oooo0?ooo`0D
0?ooo`05o`00o`3oool0oooo0?ooool00?l00P3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo
00?o003o0?ooo`3oool04`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00Go003o0?ooo`3o
ool0ooooo`00o`020?ooo`03o`00o`3oool0oooo00X0oooo00?o00000?ooo`3oool0;P3oool00ol0
0000oooo0?ooo`0H0?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool0103o0000oooo0?ooo`3o
000I0?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool01@3o0000oooo0?ooo`3oool0o`0001T0
oooo00D0o`000?ooo`3oool0oooo0?l000020?ooo`050?l0003oool0oooo0?ooo`3o00006@3oool0
1@3o0000oooo0?ooo`3oool0o`0000<0oooo00D0o`000?ooo`3oool0oooo0?l0000I0?ooo`040?l0
003oool0oooo0?l000<0oooo00D0o`000?ooo`3oool0oooo0?l0000;0?ooo`03o`00003oool0oooo
00`0oooo000W0?ooo`03o`00003oool0oooo01D0oooo00Co003o0?ooo`3ooooo003o0`3oool01Ol0
0?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool04`3oool01Ol00?l0oooo0?ooo`3o
oooo003o00<0oooo00Co003o0?ooo`3ooooo003o0`3oool00ol00?l0oooo0?ooo`0C0?ooo`05o`00
o`3oool0oooo0?ooool00?l00`3oool01Ol00?l0oooo0?ooo`3ooooo003o0080oooo00?o003o0?oo
o`3oool0503oool01Ol00?l0oooo0?ooo`3ooooo003o0080oooo00Go003o0?ooo`3oool0ooooo`00
o`030?ooo`03o`00o`3oool0oooo01<0oooo00Go003o0?ooo`3oool0ooooo`00o`030?ooo`05o`00
o`3oool0oooo0?ooool00?l00P3oool00ol00?l0oooo0?ooo`0:0?ooo`03o`00003oool0oooo02h0
oooo00?o00000?ooo`3oool0603oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00@0o`000?oo
o`3oool0o`006@3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00D0o`000?ooo`3oool0oooo
0?l0000I0?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool01@3o0000oooo0?ooo`3oool0o`00
01T0oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`050?l0003oool0oooo0?ooo`3o00006@3o
ool0103o0000oooo0?ooo`3o00030?ooo`050?l0003oool0oooo0?ooo`3o00002`3oool00ol00000
oooo0?ooo`0<0?ooo`009`3oool00ol00000oooo0?ooo`0E0?ooo`04o`00o`3oool0ooooo`00o`<0
oooo00Go003o0?ooo`3oool0ooooo`00o`030?ooo`03o`00o`3oool0oooo01<0oooo00Go003o0?oo
o`3oool0ooooo`00o`030?ooo`04o`00o`3oool0ooooo`00o`<0oooo00?o003o0?ooo`3oool04`3o
ool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00Go003o0?ooo`3oool0ooooo`00o`020?ooo`03
o`00o`3oool0oooo01@0oooo00Go003o0?ooo`3oool0ooooo`00o`020?ooo`05o`00o`3oool0oooo
0?ooool00?l00`3oool00ol00?l0oooo0?ooo`0C0?ooo`05o`00o`3oool0oooo0?ooool00?l00`3o
ool01Ol00?l0oooo0?ooo`3ooooo003o0080oooo00?o003o0?ooo`3oool02P3oool00ol00000oooo
0?ooo`0^0?ooo`03o`00003oool0oooo01P0oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`04
0?l0003oool0oooo0?l001T0oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`050?l0003oool0
oooo0?ooo`3o00006@3oool01@3o0000oooo0?ooo`3oool0o`000080oooo00D0o`000?ooo`3oool0
oooo0?l0000I0?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool01@3o0000oooo0?ooo`3oool0
o`0001T0oooo00@0o`000?ooo`3oool0o`000`3oool01@3o0000oooo0?ooo`3oool0o`0000/0oooo
00?o00000?ooo`3oool0303oool002L0oooo00?o00000?ooo`3oool05@3oool01?l00?l0oooo0?oo
ool00?l30?ooo`05o`00o`3oool0oooo0?ooool00?l00`3oool00ol00?l0oooo0?ooo`0C0?ooo`05
o`00o`3oool0oooo0?ooool00?l00`3oool01?l00?l0oooo0?ooool00?l30?ooo`03o`00o`3oool0
oooo01<0oooo00Go003o0?ooo`3oool0ooooo`00o`030?ooo`05o`00o`3oool0oooo0?ooool00?l0
0P3oool00ol00?l0oooo0?ooo`0D0?ooo`05o`00o`3oool0oooo0?ooool00?l00P3oool01Ol00?l0
oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool04`3oool01Ol00?l0oooo0?ooo`3ooooo
003o00<0oooo00Go003o0?ooo`3oool0ooooo`00o`020?ooo`03o`00o`3oool0oooo00X0oooo00?o
00000?ooo`3oool0;P3oool00ol00000oooo0?ooo`0H0?ooo`050?l0003oool0oooo0?ooo`3o0000
0`3oool0103o0000oooo0?ooo`3o000I0?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool01@3o
0000oooo0?ooo`3oool0o`0001T0oooo00D0o`000?ooo`3oool0oooo0?l000020?ooo`050?l0003o
ool0oooo0?ooo`3o00006@3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00D0o`000?ooo`3o
ool0oooo0?l0000I0?ooo`040?l0003oool0oooo0?l000<0oooo00D0o`000?ooo`3oool0oooo0?l0
000;0?ooo`03o`00003oool0oooo00`0oooo000W0?ooo`;o00005P3oool01?l00?l0oooo0?ooool0
0?l30?ooo`05o`00o`3oool0oooo0?ooool00?l00`3oool00ol00?l0oooo0?ooo`0C0?ooo`05o`00
o`3oool0oooo0?ooool00?l00`3oool01?l00?l0oooo0?ooool00?l30?ooo`03o`00o`3oool0oooo
01<0oooo00Go003o0?ooo`3oool0ooooo`00o`030?ooo`05o`00o`3oool0oooo0?ooool00?l00P3o
ool00ol00?l0oooo0?ooo`0D0?ooo`05o`00o`3oool0oooo0?ooool00?l00P3oool01Ol00?l0oooo
0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool04`3oool01Ol00?l0oooo0?ooo`3ooooo003o
00<0oooo00Go003o0?ooo`3oool0ooooo`00o`020?ooo`03o`00o`3oool0oooo00T0oooo0_l0000`
0?ooo`;o00006@3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00@0o`000?ooo`3oool0o`00
6@3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00D0o`000?ooo`3oool0oooo0?l0000I0?oo
o`050?l0003oool0oooo0?ooo`3o00000P3oool01@3o0000oooo0?ooo`3oool0o`0001T0oooo00D0
o`000?ooo`3oool0oooo0?l000030?ooo`050?l0003oool0oooo0?ooo`3o00006@3oool0103o0000
oooo0?ooo`3o00030?ooo`050?l0003oool0oooo0?ooo`3o00002P3oool2o`0000h0oooo000W0?oo
o`03o`00003oool0oooo01D0oooo00Co003o0?ooo`3ooooo003o0`3oool01Ol00?l0oooo0?ooo`3o
oooo003o00<0oooo00?o003o0?ooo`3oool04`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo
00Co003o0?ooo`3ooooo003o0`3oool00ol00?l0oooo0?ooo`0C0?ooo`05o`00o`3oool0oooo0?oo
ool00?l00`3oool01Ol00?l0oooo0?ooo`3ooooo003o0080oooo00?o003o0?ooo`3oool0503oool0
1Ol00?l0oooo0?ooo`3ooooo003o0080oooo00Go003o0?ooo`3oool0ooooo`00o`030?ooo`03o`00
o`3oool0oooo01<0oooo00Go003o0?ooo`3oool0ooooo`00o`030?ooo`05o`00o`3oool0oooo0?oo
ool00?l00P3oool00ol00?l0oooo0?ooo`0:0?ooo`03o`00003oool0oooo02h0oooo00?o00000?oo
o`3oool0603oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00@0o`000?ooo`3oool0o`006@3o
ool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00D0o`000?ooo`3oool0oooo0?l0000I0?ooo`05
0?l0003oool0oooo0?ooo`3o00000P3oool01@3o0000oooo0?ooo`3oool0o`0001T0oooo00D0o`00
0?ooo`3oool0oooo0?l000030?ooo`050?l0003oool0oooo0?ooo`3o00006@3oool0103o0000oooo
0?ooo`3o00030?ooo`050?l0003oool0oooo0?ooo`3o00002`3oool00ol00000oooo0?ooo`0<0?oo
o`009`3oool00ol00000oooo0?ooo`0E0?ooo`04o`00o`3oool0ooooo`00o`<0oooo00Go003o0?oo
o`3oool0ooooo`00o`030?ooo`03o`00o`3oool0oooo01<0oooo00Go003o0?ooo`3oool0ooooo`00
o`030?ooo`04o`00o`3oool0ooooo`00o`<0oooo00?o003o0?ooo`3oool04`3oool01Ol00?l0oooo
0?ooo`3ooooo003o00<0oooo00Go003o0?ooo`3oool0ooooo`00o`020?ooo`03o`00o`3oool0oooo
01@0oooo00Go003o0?ooo`3oool0ooooo`00o`020?ooo`05o`00o`3oool0oooo0?ooool00?l00`3o
ool00ol00?l0oooo0?ooo`0C0?ooo`05o`00o`3oool0oooo0?ooool00?l00`3oool01Ol00?l0oooo
0?ooo`3ooooo003o0080oooo00?o003o0?ooo`3oool02P3oool00ol00000oooo0?ooo`0^0?ooo`03
o`00003oool0oooo01P0oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`040?l0003oool0oooo
0?l001T0oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`050?l0003oool0oooo0?ooo`3o0000
6@3oool01@3o0000oooo0?ooo`3oool0o`000080oooo00D0o`000?ooo`3oool0oooo0?l0000I0?oo
o`050?l0003oool0oooo0?ooo`3o00000`3oool01@3o0000oooo0?ooo`3oool0o`0001T0oooo00@0
o`000?ooo`3oool0o`000`3oool01@3o0000oooo0?ooo`3oool0o`0000/0oooo00?o00000?ooo`3o
ool0303oool00240oooo0_l000040?ooo`03o`00003oool0oooo01D0oooo00Co003o0?ooo`3ooooo
003o0`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool04`3oool01Ol0
0?l0oooo0?ooo`3ooooo003o00<0oooo00Co003o0?ooo`3ooooo003o0`3oool00ol00?l0oooo0?oo
o`0C0?ooo`05o`00o`3oool0oooo0?ooool00?l00`3oool01Ol00?l0oooo0?ooo`3ooooo003o0080
oooo00?o003o0?ooo`3oool0503oool01Ol00?l0oooo0?ooo`3ooooo003o0080oooo00Go003o0?oo
o`3oool0ooooo`00o`030?ooo`03o`00o`3oool0oooo01<0oooo00Go003o0?ooo`3oool0ooooo`00
o`030?ooo`05o`00o`3oool0oooo0?ooool00?l00P3oool00ol00?l0oooo0?ooo`0:0?ooo`03o`00
003oool0oooo02L0oooo0_l000050?ooo`03o`00003oool0oooo01P0oooo00D0o`000?ooo`3oool0
oooo0?l000030?ooo`040?l0003oool0oooo0?l001T0oooo00D0o`000?ooo`3oool0oooo0?l00003
0?ooo`050?l0003oool0oooo0?ooo`3o00006@3oool01@3o0000oooo0?ooo`3oool0o`000080oooo
00D0o`000?ooo`3oool0oooo0?l0000I0?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool01@3o
0000oooo0?ooo`3oool0o`0001T0oooo00@0o`000?ooo`3oool0o`000`3oool01@3o0000oooo0?oo
o`3oool0o`0000/0oooo00?o00000?ooo`3oool0303oool00200oooo00Co00000?ooo`3ooooo0000
0`3oool00ol00000oooo0?ooo`0E0?ooo`04o`00o`3oool0ooooo`00o`<0oooo00Go003o0?ooo`3o
ool0ooooo`00o`030?ooo`03o`00o`3oool0oooo01<0oooo00Go003o0?ooo`3oool0ooooo`00o`03
0?ooo`04o`00o`3oool0ooooo`00o`<0oooo00?o003o0?ooo`3oool04`3oool01Ol00?l0oooo0?oo
o`3ooooo003o00<0oooo00Go003o0?ooo`3oool0ooooo`00o`020?ooo`03o`00o`3oool0oooo01@0
oooo00Go003o0?ooo`3oool0ooooo`00o`020?ooo`05o`00o`3oool0oooo0?ooool00?l00`3oool0
0ol00?l0oooo0?ooo`0C0?ooo`05o`00o`3oool0oooo0?ooool00?l00`3oool01Ol00?l0oooo0?oo
o`3ooooo003o0080oooo00?o003o0?ooo`3oool02P3oool00ol00000oooo0?ooo`0V0?ooo`04o`00
003oool0ooooo`0000@0oooo00?o00000?ooo`3oool0603oool01@3o0000oooo0?ooo`3oool0o`00
00<0oooo00@0o`000?ooo`3oool0o`006@3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00D0
o`000?ooo`3oool0oooo0?l0000I0?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool01@3o0000
oooo0?ooo`3oool0o`0001T0oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`050?l0003oool0
oooo0?ooo`3o00006@3oool0103o0000oooo0?ooo`3o00030?ooo`050?l0003oool0oooo0?ooo`3o
00002`3oool00ol00000oooo0?ooo`0<0?ooo`00803oool01?l00000oooo0?ooool000030?ooo`03
o`00003oool0oooo01D0oooo00Co003o0?ooo`3ooooo003o0`3oool01Ol00?l0oooo0?ooo`3ooooo
003o00<0oooo00?o003o0?ooo`3oool04`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00Co
003o0?ooo`3ooooo003o0`3oool00ol00?l0oooo0?ooo`0C0?ooo`05o`00o`3oool0oooo0?ooool0
0?l00`3oool01Ol00?l0oooo0?ooo`3ooooo003o0080oooo00?o003o0?ooo`3oool0503oool01Ol0
0?l0oooo0?ooo`3ooooo003o0080oooo00Go003o0?ooo`3oool0ooooo`00o`030?ooo`03o`00o`3o
ool0oooo01<0oooo00Go003o0?ooo`3oool0ooooo`00o`030?ooo`05o`00o`3oool0oooo0?ooool0
0?l00P3oool00ol00?l0oooo0?ooo`0:0?ooo`03o`00003oool0oooo02H0oooo00Co00000?ooo`3o
oooo0000103oool00ol00000oooo0?ooo`0C0?ooo`?oo`000P3oool01@3o0000oooo0?ooo`3oool0
o`0000<0oooo00@0o`000?ooo`3oool0o`000P3oool3ool00100oooo0ooo00000`3oool0o`000?oo
o`020?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool00`3o0000ooooool00002ool00100oooo
0ooo00020?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool01@3o0000oooo0?ooo`3oool0o`00
0080oooo0ooo000@0?ooo`?oo`0000<0oooo0?l0003oool00P3oool01@3o0000oooo0?ooo`3oool0
o`0000<0oooo00<0o`000?oooooo00000_oo000@0?ooo`?oo`000P3oool0103o0000oooo0?ooo`3o
00030?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool3ool000H0oooo00?o00000?ooo`3oool0
303oool00200oooo00Co00000?ooo`3ooooo00000`3oool2o`0000L0oooo00Co003o0?ooo`3ooooo
003o0`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00Co003o0?ooo`3ooooo003o0`3oool0
1Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00Co003o0?ooo`3ooooo003o0`3oool01Ol00?l0oooo
0?ooo`3ooooo003o00<0oooo00Co003o0?ooo`3ooooo003o0`3oool01Ol00?l0oooo0?ooo`3ooooo
003o00<0oooo00Co003o0?ooo`3ooooo003o0`3oool01Ol00?l0oooo0?ooo`3ooooo003o0080oooo
00Go003o0?ooo`3oool0ooooo`00o`030?ooo`05o`00o`3oool0oooo0?ooool00?l00P3oool01Ol0
0?l0oooo0?ooo`3ooooo003o00<0oooo00Go003o0?ooo`3oool0ooooo`00o`020?ooo`05o`00o`3o
ool0oooo0?ooool00?l00`3oool01Ol00?l0oooo0?ooo`3ooooo003o0080oooo00Go003o0?ooo`3o
ool0ooooo`00o`030?ooo`05o`00o`3oool0oooo0?ooool00?l00P3oool01Ol00?l0oooo0?ooo`3o
oooo003o00<0oooo00Go003o0?ooo`3oool0ooooo`00o`020?ooo`05o`00o`3oool0oooo0?ooool0
0?l00`3oool01Ol00?l0oooo0?ooo`3ooooo003o0080oooo00Go003o0?ooo`3oool0ooooo`00o`03
0?ooo`05o`00o`3oool0oooo0?ooool00?l00P3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo
00?o003o0?ooo`3oool00ol0000X0?ooo`04o`00003oool0ooooo`0000@0oooo0_l000060?ooo`05
ool0003oool0oooo0?oooooo00000`3oool01_oo0000oooo0?ooo`3oooooo`000?ooo`?oo`000P3o
ool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00@0o`000?ooo`3oool0o`000P3oool3ool00080
oooo00@0o`000?ooo`3oool0o`000`3oool01@3o0000oooo0?ooo`3oool0o`000080oooo0ooo0000
0`3oool0o`000?ooo`020?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool00`3o0000ooooool0
0002ool00080oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`040?l0003oool0oooo0?l00080
oooo0ooo00020?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool01@3o0000oooo0?ooo`3oool0
o`000080oooo0ooo00020?ooo`040?l0003oool0oooo0?l000<0oooo00D0o`000?ooo`3oool0oooo
0?l000020?ooo`?oo`0000<0oooo0?l0003oool00P3oool01@3o0000oooo0?ooo`3oool0o`0000<0
oooo00<0o`000?oooooo00000_oo00020?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool01@3o
0000oooo0?ooo`3oool0o`000080oooo0ooo00020?ooo`040?l0003oool0oooo0?l000<0oooo00D0
o`000?ooo`3oool0oooo0?l000020?ooo`?oo`0000<0oooo0?l0003oool00P3oool2o`0000h0oooo
000P0?ooo`04o`00003oool0ooooo`0000<0oooo00?o00000?ooo`3oool01P3oool01?l00?l0oooo
0?ooool00?l30?ooo`05o`00o`3oool0oooo0?ooool00?l05@3oool01Ol00?l0oooo0?ooo`3ooooo
003o00<0oooo00Go003o0?ooo`3oool0ooooo`00o`020?ooo`03o`00o`3oool0oooo01@0oooo00Co
003o0?ooo`3ooooo003o0`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3o
ool04`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00Co003o0?ooo`3ooooo003o0`3oool0
0ol00?l0oooo0?ooo`0D0?ooo`04o`00o`3oool0ooooo`00o`<0oooo00Go003o0?ooo`3oool0oooo
o`00o`030?ooo`03o`00o`3oool0oooo01<0oooo00Go003o0?ooo`3oool0ooooo`00o`040?ooo`03
o`00003oool0oooo02H0oooo00Co00000?ooo`3ooooo0000103oool00ol00000oooo0?ooo`050?oo
o`05ool0003oool0oooo0?oooooo00000`3oool01_oo0000oooo0?ooo`3oooooo`000?ooo`?oo`00
403oool3ool00080oooo00@0o`000?ooo`3oool0o`000`3oool01@3o0000oooo0?ooo`3oool0o`00
0080oooo0ooo000?0?ooo`?oo`000P3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00@0o`00
0?ooo`3oool0o`000P3oool3ool00100oooo0ooo00020?ooo`040?l0003oool0oooo0?l000<0oooo
00D0o`000?ooo`3oool0oooo0?l000020?ooo`?oo`003`3oool3ool00080oooo00D0o`000?ooo`3o
ool0oooo0?l000020?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool3ool00100oooo0ooo0000
0`3oool0o`000?ooo`030?ooo`03o`00003oool0oooo00`0oooo000P0?ooo`04o`00003oool0oooo
o`0000<0oooo00?o00000?ooo`3oool01P3oool01?l00?l0oooo0?ooool00?l30?ooo`05o`00o`3o
ool0oooo0?ooool00?l05@3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00Go003o0?ooo`3o
ool0ooooo`00o`020?ooo`03o`00o`3oool0oooo01@0oooo00Co003o0?ooo`3ooooo003o0`3oool0
1Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool04`3oool01Ol00?l0oooo0?oo
o`3ooooo003o00<0oooo00Co003o0?ooo`3ooooo003o0`3oool00ol00?l0oooo0?ooo`0D0?ooo`04
o`00o`3oool0ooooo`00o`<0oooo00Go003o0?ooo`3oool0ooooo`00o`030?ooo`03o`00o`3oool0
oooo01<0oooo00Go003o0?ooo`3oool0ooooo`00o`040?ooo`03o`00003oool0oooo02H0oooo00Co
00000?ooo`3ooooo0000103oool00ol00000oooo0?ooo`050?ooo`05ool0003oool0oooo0?oooooo
00000`3oool01Ooo0000oooo0?ooo`3oooooo`0001T0oooo00@0o`000?ooo`3oool0o`000`3oool0
1@3o0000oooo0?ooo`3oool0o`0001T0oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`040?l0
003oool0oooo0?l001X0oooo00@0o`000?ooo`3oool0o`000`3oool01@3o0000oooo0?ooo`3oool0
o`0001T0oooo00D0o`000?ooo`3oool0oooo0?l000020?ooo`050?l0003oool0oooo0?ooo`3o0000
6@3oool00`3o0000oooo0?ooo`020?ooo`03o`00003oool0oooo00`0oooo000Q0?ooo`;o0000103o
ool00ol00000oooo0?ooo`060?ooo`04o`00o`3oool0ooooo`00o`<0oooo00Go003o0?ooo`3oool0
ooooo`00o`0E0?ooo`05o`00o`3oool0oooo0?ooool00?l00`3oool01Ol00?l0oooo0?ooo`3ooooo
003o0080oooo00?o003o0?ooo`3oool0503oool01?l00?l0oooo0?ooool00?l30?ooo`05o`00o`3o
ool0oooo0?ooool00?l00`3oool00ol00?l0oooo0?ooo`0C0?ooo`05o`00o`3oool0oooo0?ooool0
0?l00`3oool01?l00?l0oooo0?ooool00?l30?ooo`03o`00o`3oool0oooo01@0oooo00Co003o0?oo
o`3ooooo003o0`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool04`3o
ool01Ol00?l0oooo0?ooo`3ooooo003o00@0oooo00?o00000?ooo`3oool09`3oool2o`0000D0oooo
00?o00000?ooo`3oool01@3oool01Ooo0000oooo0?ooo`3oooooo`0000<0oooo00Goo`000?ooo`3o
ool0ooooool0000I0?ooo`040?l0003oool0oooo0?l000<0oooo00D0o`000?ooo`3oool0oooo0?l0
000I0?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool0103o0000oooo0?ooo`3o000J0?ooo`04
0?l0003oool0oooo0?l000<0oooo00D0o`000?ooo`3oool0oooo0?l0000I0?ooo`050?l0003oool0
oooo0?ooo`3o00000P3oool01@3o0000oooo0?ooo`3oool0o`0001T0oooo00<0o`000?ooo`3oool0
0P3oool00ol00000oooo0?ooo`0<0?ooo`009`3oool00ol00000oooo0?ooo`060?ooo`04o`00o`3o
ool0ooooo`00o`<0oooo00Go003o0?ooo`3oool0ooooo`00o`0E0?ooo`05o`00o`3oool0oooo0?oo
ool00?l00`3oool01Ol00?l0oooo0?ooo`3ooooo003o0080oooo00?o003o0?ooo`3oool0503oool0
1?l00?l0oooo0?ooool00?l30?ooo`05o`00o`3oool0oooo0?ooool00?l00`3oool00ol00?l0oooo
0?ooo`0C0?ooo`05o`00o`3oool0oooo0?ooool00?l00`3oool01?l00?l0oooo0?ooool00?l30?oo
o`03o`00o`3oool0oooo01@0oooo00Co003o0?ooo`3ooooo003o0`3oool01Ol00?l0oooo0?ooo`3o
oooo003o00<0oooo00?o003o0?ooo`3oool04`3oool01Ol00?l0oooo0?ooo`3ooooo003o00@0oooo
00?o00000?ooo`3oool0;P3oool00ol00000oooo0?ooo`050?ooo`05ool0003oool0oooo0?oooooo
00000`3oool01Ooo0000oooo0?ooo`3oooooo`0001T0oooo00@0o`000?ooo`3oool0o`000`3oool0
1@3o0000oooo0?ooo`3oool0o`0001T0oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`040?l0
003oool0oooo0?l001X0oooo00@0o`000?ooo`3oool0o`000`3oool01@3o0000oooo0?ooo`3oool0
o`0001T0oooo00D0o`000?ooo`3oool0oooo0?l000020?ooo`050?l0003oool0oooo0?ooo`3o0000
6@3oool00`3o0000oooo0?ooo`020?ooo`03o`00003oool0oooo00`0oooo000W0?ooo`03o`00003o
ool0oooo00H0oooo00Co003o0?ooo`3ooooo003o0`3oool01Ol00?l0oooo0?ooo`3ooooo003o01D0
oooo00Go003o0?ooo`3oool0ooooo`00o`030?ooo`05o`00o`3oool0oooo0?ooool00?l00P3oool0
0ol00?l0oooo0?ooo`0D0?ooo`04o`00o`3oool0ooooo`00o`<0oooo00Go003o0?ooo`3oool0oooo
o`00o`030?ooo`03o`00o`3oool0oooo01<0oooo00Go003o0?ooo`3oool0ooooo`00o`030?ooo`04
o`00o`3oool0ooooo`00o`<0oooo00?o003o0?ooo`3oool0503oool01?l00?l0oooo0?ooool00?l3
0?ooo`05o`00o`3oool0oooo0?ooool00?l00`3oool00ol00?l0oooo0?ooo`0C0?ooo`05o`00o`3o
ool0oooo0?ooool00?l0103oool00ol00000oooo0?ooo`0^0?ooo`03o`00003oool0oooo00D0oooo
00Goo`000?ooo`3oool0ooooool000030?ooo`05ool0003oool0oooo0?oooooo00006@3oool0103o
0000oooo0?ooo`3o00030?ooo`050?l0003oool0oooo0?ooo`3o00006@3oool01@3o0000oooo0?oo
o`3oool0o`0000<0oooo00@0o`000?ooo`3oool0o`006P3oool0103o0000oooo0?ooo`3o00030?oo
o`050?l0003oool0oooo0?ooo`3o00006@3oool01@3o0000oooo0?ooo`3oool0o`000080oooo00D0
o`000?ooo`3oool0oooo0?l0000I0?ooo`030?l0003oool0oooo0080oooo00?o00000?ooo`3oool0
303oool002L0oooo0_l000070?ooo`04o`00o`3oool0ooooo`00o`<0oooo00Go003o0?ooo`3oool0
ooooo`00o`0E0?ooo`05o`00o`3oool0oooo0?ooool00?l00`3oool01Ol00?l0oooo0?ooo`3ooooo
003o0080oooo00?o003o0?ooo`3oool0503oool01?l00?l0oooo0?ooool00?l30?ooo`05o`00o`3o
ool0oooo0?ooool00?l00`3oool00ol00?l0oooo0?ooo`0C0?ooo`05o`00o`3oool0oooo0?ooool0
0?l00`3oool01?l00?l0oooo0?ooool00?l30?ooo`03o`00o`3oool0oooo01@0oooo00Co003o0?oo
o`3ooooo003o0`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool04`3o
ool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo0_l0000`0?ooo`;o00001P3oool01Ooo0000oooo
0?ooo`3oooooo`0000<0oooo00Goo`000?ooo`3oool0ooooool0000I0?ooo`040?l0003oool0oooo
0?l000<0oooo00D0o`000?ooo`3oool0oooo0?l0000I0?ooo`050?l0003oool0oooo0?ooo`3o0000
0`3oool0103o0000oooo0?ooo`3o000J0?ooo`040?l0003oool0oooo0?l000<0oooo00D0o`000?oo
o`3oool0oooo0?l0000I0?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool01@3o0000oooo0?oo
o`3oool0o`0001T0oooo00@0o`000?ooo`3oool0oooo0_l0000>0?ooo`009`3oool00ol00000oooo
0?ooo`060?ooo`04o`00o`3oool0ooooo`00o`<0oooo00Go003o0?ooo`3oool0ooooo`00o`0E0?oo
o`05o`00o`3oool0oooo0?ooool00?l00`3oool01Ol00?l0oooo0?ooo`3ooooo003o0080oooo00?o
003o0?ooo`3oool0503oool01?l00?l0oooo0?ooool00?l30?ooo`05o`00o`3oool0oooo0?ooool0
0?l00`3oool00ol00?l0oooo0?ooo`0C0?ooo`05o`00o`3oool0oooo0?ooool00?l00`3oool01?l0
0?l0oooo0?ooool00?l30?ooo`03o`00o`3oool0oooo01@0oooo00Co003o0?ooo`3ooooo003o0`3o
ool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool04`3oool01Ol00?l0oooo
0?ooo`3ooooo003o00@0oooo00?o00000?ooo`3oool0;P3oool00ol00000oooo0?ooo`050?ooo`05
ool0003oool0oooo0?oooooo00000`3oool01Ooo0000oooo0?ooo`3oooooo`0001T0oooo00@0o`00
0?ooo`3oool0o`000`3oool01@3o0000oooo0?ooo`3oool0o`0001T0oooo00D0o`000?ooo`3oool0
oooo0?l000030?ooo`040?l0003oool0oooo0?l001X0oooo00@0o`000?ooo`3oool0o`000`3oool0
1@3o0000oooo0?ooo`3oool0o`0001T0oooo00D0o`000?ooo`3oool0oooo0?l000020?ooo`050?l0
003oool0oooo0?ooo`3o00006@3oool00`3o0000oooo0?ooo`020?ooo`03o`00003oool0oooo00`0
oooo000W0?ooo`03o`00003oool0oooo00H0oooo00Co003o0?ooo`3ooooo003o0`3oool01Ol00?l0
oooo0?ooo`3ooooo003o01D0oooo00Go003o0?ooo`3oool0ooooo`00o`030?ooo`05o`00o`3oool0
oooo0?ooool00?l00P3oool00ol00?l0oooo0?ooo`0D0?ooo`04o`00o`3oool0ooooo`00o`<0oooo
00Go003o0?ooo`3oool0ooooo`00o`030?ooo`03o`00o`3oool0oooo01<0oooo00Go003o0?ooo`3o
ool0ooooo`00o`030?ooo`04o`00o`3oool0ooooo`00o`<0oooo00?o003o0?ooo`3oool0503oool0
1?l00?l0oooo0?ooool00?l30?ooo`05o`00o`3oool0oooo0?ooool00?l00`3oool00ol00?l0oooo
0?ooo`0C0?ooo`05o`00o`3oool0oooo0?ooool00?l0103oool00ol00000oooo0?ooo`0^0?ooo`03
o`00003oool0oooo00D0oooo00Goo`000?ooo`3oool0ooooool000030?ooo`05ool0003oool0oooo
0?oooooo00006@3oool0103o0000oooo0?ooo`3o00030?ooo`050?l0003oool0oooo0?ooo`3o0000
6@3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00@0o`000?ooo`3oool0o`006P3oool0103o
0000oooo0?ooo`3o00030?ooo`050?l0003oool0oooo0?ooo`3o00006@3oool01@3o0000oooo0?oo
o`3oool0o`000080oooo00D0o`000?ooo`3oool0oooo0?l0000I0?ooo`030?l0003oool0oooo0080
oooo00?o00000?ooo`3oool0303oool002L0oooo00?o00000?ooo`3oool01P3oool01?l00?l0oooo
0?ooool00?l30?ooo`05o`00o`3oool0oooo0?ooool00?l05@3oool01Ol00?l0oooo0?ooo`3ooooo
003o00<0oooo00Go003o0?ooo`3oool0ooooo`00o`020?ooo`03o`00o`3oool0oooo01@0oooo00Co
003o0?ooo`3ooooo003o0`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3o
ool04`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00Co003o0?ooo`3ooooo003o0`3oool0
0ol00?l0oooo0?ooo`0D0?ooo`04o`00o`3oool0ooooo`00o`<0oooo00Go003o0?ooo`3oool0oooo
o`00o`030?ooo`03o`00o`3oool0oooo01<0oooo00Go003o0?ooo`3oool0ooooo`00o`040?ooo`03
o`00003oool0oooo02h0oooo00?o00000?ooo`3oool01@3oool01Ooo0000oooo0?ooo`3oooooo`00
00<0oooo00Goo`000?ooo`3oool0ooooool0000I0?ooo`040?l0003oool0oooo0?l000<0oooo00D0
o`000?ooo`3oool0oooo0?l0000I0?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool0103o0000
oooo0?ooo`3o000J0?ooo`040?l0003oool0oooo0?l000<0oooo00D0o`000?ooo`3oool0oooo0?l0
000I0?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool01@3o0000oooo0?ooo`3oool0o`0001T0
oooo00<0o`000?ooo`3oool00P3oool00ol00000oooo0?ooo`0<0?ooo`009`3oool00ol00000oooo
0?ooo`060?ooo`04o`00o`3oool0ooooo`00o`<0oooo00Go003o0?ooo`3oool0ooooo`00o`0E0?oo
o`05o`00o`3oool0oooo0?ooool00?l00`3oool01Ol00?l0oooo0?ooo`3ooooo003o0080oooo00?o
003o0?ooo`3oool0503oool01?l00?l0oooo0?ooool00?l30?ooo`05o`00o`3oool0oooo0?ooool0
0?l00`3oool00ol00?l0oooo0?ooo`0C0?ooo`05o`00o`3oool0oooo0?ooool00?l00`3oool01?l0
0?l0oooo0?ooool00?l30?ooo`03o`00o`3oool0oooo01@0oooo00Co003o0?ooo`3ooooo003o0`3o
ool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool04`3oool01Ol00?l0oooo
0?ooo`3ooooo003o00@0oooo00?o00000?ooo`3oool0;P3oool00ol00000oooo0?ooo`050?ooo`05
ool0003oool0oooo0?oooooo00000`3oool01Ooo0000oooo0?ooo`3oooooo`0001T0oooo00@0o`00
0?ooo`3oool0o`000`3oool01@3o0000oooo0?ooo`3oool0o`0001T0oooo00D0o`000?ooo`3oool0
oooo0?l000030?ooo`040?l0003oool0oooo0?l001X0oooo00@0o`000?ooo`3oool0o`000`3oool0
1@3o0000oooo0?ooo`3oool0o`0001T0oooo00D0o`000?ooo`3oool0oooo0?l000020?ooo`050?l0
003oool0oooo0?ooo`3o00006@3oool00`3o0000oooo0?ooo`020?ooo`03o`00003oool0oooo00`0
oooo000W0?ooo`03o`00003oool0oooo00H0oooo00Co003o0?ooo`3ooooo003o0`3oool01Ol00?l0
oooo0?ooo`3ooooo003o01D0oooo00Go003o0?ooo`3oool0ooooo`00o`030?ooo`05o`00o`3oool0
oooo0?ooool00?l00P3oool00ol00?l0oooo0?ooo`0D0?ooo`04o`00o`3oool0ooooo`00o`<0oooo
00Go003o0?ooo`3oool0ooooo`00o`030?ooo`03o`00o`3oool0oooo01<0oooo00Go003o0?ooo`3o
ool0ooooo`00o`030?ooo`04o`00o`3oool0ooooo`00o`<0oooo00?o003o0?ooo`3oool0503oool0
1?l00?l0oooo0?ooool00?l30?ooo`05o`00o`3oool0oooo0?ooool00?l00`3oool00ol00?l0oooo
0?ooo`0C0?ooo`05o`00o`3oool0oooo0?ooool00?l0103oool00ol00000oooo0?ooo`0^0?ooo`03
o`00003oool0oooo00D0oooo00Goo`000?ooo`3oool0ooooool000030?ooo`05ool0003oool0oooo
0?oooooo00006@3oool0103o0000oooo0?ooo`3o00030?ooo`050?l0003oool0oooo0?ooo`3o0000
6@3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00@0o`000?ooo`3oool0o`006P3oool0103o
0000oooo0?ooo`3o00030?ooo`050?l0003oool0oooo0?ooo`3o00006@3oool01@3o0000oooo0?oo
o`3oool0o`000080oooo00D0o`000?ooo`3oool0oooo0?l0000I0?ooo`030?l0003oool0oooo0080
oooo00?o00000?ooo`3oool0303oool002L0oooo0_l000070?ooo`04o`00o`3oool0ooooo`00o`<0
oooo00Go003o0?ooo`3oool0ooooo`00o`0E0?ooo`05o`00o`3oool0oooo0?ooool00?l00`3oool0
1Ol00?l0oooo0?ooo`3ooooo003o0080oooo00?o003o0?ooo`3oool0503oool01?l00?l0oooo0?oo
ool00?l30?ooo`05o`00o`3oool0oooo0?ooool00?l00`3oool00ol00?l0oooo0?ooo`0C0?ooo`05
o`00o`3oool0oooo0?ooool00?l00`3oool01?l00?l0oooo0?ooool00?l30?ooo`03o`00o`3oool0
oooo01@0oooo00Co003o0?ooo`3ooooo003o0`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo
00?o003o0?ooo`3oool04`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo0_l0000`0?ooo`;o
00001P3oool01Ooo0000oooo0?ooo`3oooooo`0000<0oooo00Goo`000?ooo`3oool0ooooool0000I
0?ooo`040?l0003oool0oooo0?l000<0oooo00D0o`000?ooo`3oool0oooo0?l0000I0?ooo`050?l0
003oool0oooo0?ooo`3o00000`3oool0103o0000oooo0?ooo`3o000J0?ooo`040?l0003oool0oooo
0?l000<0oooo00D0o`000?ooo`3oool0oooo0?l0000I0?ooo`050?l0003oool0oooo0?ooo`3o0000
0P3oool01@3o0000oooo0?ooo`3oool0o`0001T0oooo00@0o`000?ooo`3oool0oooo0_l0000>0?oo
o`009`3oool00ol00000oooo0?ooo`060?ooo`04o`00o`3oool0ooooo`00o`<0oooo00Go003o0?oo
o`3oool0ooooo`00o`0E0?ooo`05o`00o`3oool0oooo0?ooool00?l00`3oool01Ol00?l0oooo0?oo
o`3ooooo003o0080oooo00?o003o0?ooo`3oool0503oool01?l00?l0oooo0?ooool00?l30?ooo`05
o`00o`3oool0oooo0?ooool00?l00`3oool00ol00?l0oooo0?ooo`0C0?ooo`05o`00o`3oool0oooo
0?ooool00?l00`3oool01?l00?l0oooo0?ooool00?l30?ooo`03o`00o`3oool0oooo01@0oooo00Co
003o0?ooo`3ooooo003o0`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3o
ool04`3oool01Ol00?l0oooo0?ooo`3ooooo003o00@0oooo00?o00000?ooo`3oool0;P3oool00ol0
0000oooo0?ooo`050?ooo`05ool0003oool0oooo0?oooooo00000`3oool01Ooo0000oooo0?ooo`3o
ooooo`0001T0oooo00@0o`000?ooo`3oool0o`000`3oool01@3o0000oooo0?ooo`3oool0o`0001T0
oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`040?l0003oool0oooo0?l001X0oooo00@0o`00
0?ooo`3oool0o`000`3oool01@3o0000oooo0?ooo`3oool0o`0001T0oooo00D0o`000?ooo`3oool0
oooo0?l000020?ooo`050?l0003oool0oooo0?ooo`3o00006@3oool00`3o0000oooo0?ooo`020?oo
o`03o`00003oool0oooo00`0oooo000W0?ooo`03o`00003oool0oooo00H0oooo00Co003o0?ooo`3o
oooo003o0`3oool01Ol00?l0oooo0?ooo`3ooooo003o01D0oooo00Go003o0?ooo`3oool0ooooo`00
o`030?ooo`05o`00o`3oool0oooo0?ooool00?l00P3oool00ol00?l0oooo0?ooo`0D0?ooo`04o`00
o`3oool0ooooo`00o`<0oooo00Go003o0?ooo`3oool0ooooo`00o`030?ooo`03o`00o`3oool0oooo
01<0oooo00Go003o0?ooo`3oool0ooooo`00o`030?ooo`04o`00o`3oool0ooooo`00o`<0oooo00?o
003o0?ooo`3oool0503oool01?l00?l0oooo0?ooool00?l30?ooo`05o`00o`3oool0oooo0?ooool0
0?l00`3oool00ol00?l0oooo0?ooo`0C0?ooo`05o`00o`3oool0oooo0?ooool00?l0103oool00ol0
0000oooo0?ooo`0^0?ooo`03o`00003oool0oooo00D0oooo00Goo`000?ooo`3oool0ooooool00003
0?ooo`05ool0003oool0oooo0?oooooo00006@3oool0103o0000oooo0?ooo`3o00030?ooo`050?l0
003oool0oooo0?ooo`3o00006@3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00@0o`000?oo
o`3oool0o`006P3oool0103o0000oooo0?ooo`3o00030?ooo`050?l0003oool0oooo0?ooo`3o0000
6@3oool01@3o0000oooo0?ooo`3oool0o`000080oooo00D0o`000?ooo`3oool0oooo0?l0000I0?oo
o`030?l0003oool0oooo0080oooo00?o00000?ooo`3oool0303oool002L0oooo00?o00000?ooo`3o
ool01P3oool01?l00?l0oooo0?ooool00?l30?ooo`05o`00o`3oool0oooo0?ooool00?l05@3oool0
1Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00Go003o0?ooo`3oool0ooooo`00o`020?ooo`03o`00
o`3oool0oooo01@0oooo00Co003o0?ooo`3ooooo003o0`3oool01Ol00?l0oooo0?ooo`3ooooo003o
00<0oooo00?o003o0?ooo`3oool04`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00Co003o
0?ooo`3ooooo003o0`3oool00ol00?l0oooo0?ooo`0D0?ooo`04o`00o`3oool0ooooo`00o`<0oooo
00Go003o0?ooo`3oool0ooooo`00o`030?ooo`03o`00o`3oool0oooo01<0oooo00Go003o0?ooo`3o
ool0ooooo`00o`040?ooo`03o`00003oool0oooo02h0oooo00?o00000?ooo`3oool01@3oool01Ooo
0000oooo0?ooo`3oooooo`0000<0oooo00Goo`000?ooo`3oool0ooooool0000I0?ooo`040?l0003o
ool0oooo0?l000<0oooo00D0o`000?ooo`3oool0oooo0?l0000I0?ooo`050?l0003oool0oooo0?oo
o`3o00000`3oool0103o0000oooo0?ooo`3o000J0?ooo`040?l0003oool0oooo0?l000<0oooo00D0
o`000?ooo`3oool0oooo0?l0000I0?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool01@3o0000
oooo0?ooo`3oool0o`0001T0oooo00<0o`000?ooo`3oool00P3oool00ol00000oooo0?ooo`0<0?oo
o`009`3oool00ol00000oooo0?ooo`060?ooo`04o`00o`3oool0ooooo`00o`<0oooo00Go003o0?oo
o`3oool0ooooo`00o`0E0?ooo`05o`00o`3oool0oooo0?ooool00?l00`3oool01Ol00?l0oooo0?oo
o`3ooooo003o0080oooo00?o003o0?ooo`3oool0503oool01?l00?l0oooo0?ooool00?l30?ooo`05
o`00o`3oool0oooo0?ooool00?l00`3oool00ol00?l0oooo0?ooo`0C0?ooo`05o`00o`3oool0oooo
0?ooool00?l00`3oool01?l00?l0oooo0?ooool00?l30?ooo`03o`00o`3oool0oooo01@0oooo00Co
003o0?ooo`3ooooo003o0`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3o
ool04`3oool01Ol00?l0oooo0?ooo`3ooooo003o00@0oooo00?o00000?ooo`3oool0;P3oool00ol0
0000oooo0?ooo`050?ooo`05ool0003oool0oooo0?oooooo00000`3oool01Ooo0000oooo0?ooo`3o
ooooo`0001T0oooo00@0o`000?ooo`3oool0o`000`3oool01@3o0000oooo0?ooo`3oool0o`0001T0
oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`040?l0003oool0oooo0?l001X0oooo00@0o`00
0?ooo`3oool0o`000`3oool01@3o0000oooo0?ooo`3oool0o`0001T0oooo00D0o`000?ooo`3oool0
oooo0?l000020?ooo`050?l0003oool0oooo0?ooo`3o00006@3oool00`3o0000oooo0?ooo`020?oo
o`03o`00003oool0oooo00`0oooo000W0?ooo`03o`00003oool0oooo00H0oooo00Co003o0?ooo`3o
oooo003o0`3oool00ol00?l0oooo0?ooo`03o`00oa<0oooo0ol00?l20?ooo`05o`00o`3oool0oooo
0?ooool00?l00`3oool00ol00?l0ooooo`00o`02o`00oa@0oooo0ol00?l00`3ooooo003o0?ooo`02
0?ooo`05o`00o`3oool0oooo0?ooool00?l00P3oool3o`00oa<0oooo0ol00?l20?ooo`05o`00o`3o
ool0oooo0?ooool00?l00P3oool00ol00?l0oooo0?ooo`03o`00oa@0oooo0ol00?l00`3ooooo003o
0?ooo`020?ooo`05o`00o`3oool0oooo0?ooool00?l00P3oool3o`00oa<0oooo0ol00?l20?ooo`03
o`00o`3oool0oooo0080oooo00?o00000?ooo`3oool0;P3oool00ol00000oooo0?ooo`050?ooo`05
ool0003oool0oooo0?oooooo00000`3oool01Ooo0000oooo0?ooo`3oooooo`0001T0oooo00@0o`00
0?ooo`3oool0o`000`3oool01@3o0000oooo0?ooo`3oool0o`0001T0oooo00D0o`000?ooo`3oool0
oooo0?l000030?ooo`040?l0003oool0oooo0?l001X0oooo00@0o`000?ooo`3oool0o`000`3oool0
1@3o0000oooo0?ooo`3oool0o`0001T0oooo00D0o`000?ooo`3oool0oooo0?l000020?ooo`050?l0
003oool0oooo0?ooo`3o00006@3oool00`3o0000oooo0?ooo`020?ooo`03o`00003oool0oooo00`0
oooo000W0?ooo`;o00001`3oool01?l00?l0oooo0?ooool00?l30?ooo`03o`00o`3oool0oooo00?o
003o4`3oool3o`00o`80oooo00Go003o0?ooo`3oool0ooooo`00o`030?ooo`03o`00o`3ooooo003o
00;o003o503oool3o`00o`030?ooool00?l0oooo0080oooo00Go003o0?ooo`3oool0ooooo`00o`02
0?ooo`?o003o4`3oool3o`00o`80oooo00Go003o0?ooo`3oool0ooooo`00o`020?ooo`03o`00o`3o
ool0oooo00?o003o503oool3o`00o`030?ooool00?l0oooo0080oooo00Go003o0?ooo`3oool0oooo
o`00o`020?ooo`?o003o4`3oool3o`00o`80oooo00Co003o0?ooo`3oool0oooo0_l0000`0?ooo`;o
00001P3oool01Ooo0000oooo0?ooo`3oooooo`0000<0oooo00Goo`000?ooo`3oool0ooooool0000I
0?ooo`040?l0003oool0oooo0?l000<0oooo00D0o`000?ooo`3oool0oooo0?l0000I0?ooo`050?l0
003oool0oooo0?ooo`3o00000`3oool0103o0000oooo0?ooo`3o000J0?ooo`040?l0003oool0oooo
0?l000<0oooo00D0o`000?ooo`3oool0oooo0?l0000I0?ooo`050?l0003oool0oooo0?ooo`3o0000
0P3oool01@3o0000oooo0?ooo`3oool0o`0001T0oooo00@0o`000?ooo`3oool0oooo0_l0000>0?oo
o`009`3oool00ol00000oooo0?ooo`060?ooo`04o`00o`3oool0ooooo`00o`<0oooo00?o003o0?oo
o`3oool00ol00?lC0?ooo`?o003o0P3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o
0?ooool00?l00_l00?lD0?ooo`?o003o00<0ooooo`00o`3oool00P3oool01Ol00?l0oooo0?ooo`3o
oooo003o0080oooo0ol00?lC0?ooo`?o003o0P3oool01Ol00?l0oooo0?ooo`3ooooo003o0080oooo
00?o003o0?ooo`3oool00ol00?lD0?ooo`?o003o00<0ooooo`00o`3oool00P3oool01Ol00?l0oooo
0?ooo`3ooooo003o0080oooo0ol00?lC0?ooo`?o003o0P3oool00ol00?l0oooo0?ooo`020?ooo`03
o`00003oool0oooo02h0oooo00?o00000?ooo`3oool01@3oool01Ooo0000oooo0?ooo`3oooooo`00
00<0oooo00Goo`000?ooo`3oool0ooooool0000I0?ooo`040?l0003oool0oooo0?l000<0oooo00D0
o`000?ooo`3oool0oooo0?l0000I0?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool0103o0000
oooo0?ooo`3o000J0?ooo`040?l0003oool0oooo0?l000<0oooo00D0o`000?ooo`3oool0oooo0?l0
000I0?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool01@3o0000oooo0?ooo`3oool0o`0001T0
oooo00<0o`000?ooo`3oool00P3oool00ol00000oooo0?ooo`0<0?ooo`009`3oool00ol00000oooo
0?ooo`060?ooo`04o`00o`3oool0ooooo`00o`<0oooo00?o003o0?ooo`3oool06`3oool01Ol00?l0
oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool06P3oool01Ol00?l0oooo0?ooo`3ooooo
003o00<0oooo00?o003o0?ooo`3oool06`3oool01Ol00?l0oooo0?ooo`3ooooo003o0080oooo00?o
003o0?ooo`3oool06`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool0
6`3oool00ol00?l0oooo0?ooo`020?ooo`03o`00003oool0oooo02h0oooo00?o00000?ooo`3oool0
1@3oool01Ooo0000oooo0?ooo`3oooooo`0000<0oooo00Goo`000?ooo`3oool0ooooool0000I0?oo
o`040?l0003oool0oooo0?l000<0oooo00D0o`000?ooo`3oool0oooo0?l0000I0?ooo`050?l0003o
ool0oooo0?ooo`3o00000`3oool0103o0000oooo0?ooo`3o000J0?ooo`040?l0003oool0oooo0?l0
00<0oooo00D0o`000?ooo`3oool0oooo0?l0000I0?ooo`050?l0003oool0oooo0?ooo`3o00000P3o
ool01@3o0000oooo0?ooo`3oool0o`0001T0oooo00<0o`000?ooo`3oool00P3oool00ol00000oooo
0?ooo`0<0?ooo`009`3oool00ol00000oooo0?ooo`060?ooo`04o`00o`3oool0ooooo`00o`<0oooo
00?o003o0?ooo`3oool06`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3o
ool06P3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool06`3oool01Ol0
0?l0oooo0?ooo`3ooooo003o0080oooo00?o003o0?ooo`3oool06`3oool01Ol00?l0oooo0?ooo`3o
oooo003o00<0oooo00?o003o0?ooo`3oool06`3oool00ol00?l0oooo0?ooo`020?ooo`03o`00003o
ool0oooo02h0oooo00?o00000?ooo`3oool01@3oool01Ooo0000oooo0?ooo`3oooooo`0000<0oooo
00Goo`000?ooo`3oool0ooooool0000I0?ooo`040?l0003oool0oooo0?l000<0oooo00D0o`000?oo
o`3oool0oooo0?l0000I0?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool0103o0000oooo0?oo
o`3o000J0?ooo`040?l0003oool0oooo0?l000<0oooo00D0o`000?ooo`3oool0oooo0?l0000I0?oo
o`050?l0003oool0oooo0?ooo`3o00000P3oool01@3o0000oooo0?ooo`3oool0o`0001T0oooo00<0
o`000?ooo`3oool00P3oool00ol00000oooo0?ooo`0<0?ooo`009`3oool00ol00000oooo0?ooo`06
0?ooo`04o`00o`3oool0ooooo`00o`<0oooo00?o003o0?ooo`3oool06`3oool01Ol00?l0oooo0?oo
o`3ooooo003o00<0oooo00?o003o0?ooo`3oool06P3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0
oooo00?o003o0?ooo`3oool06`3oool01Ol00?l0oooo0?ooo`3ooooo003o0080oooo00?o003o0?oo
o`3oool06`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool06`3oool0
0ol00?l0oooo0?ooo`020?ooo`03o`00003oool0oooo02h0oooo00?o00000?ooo`3oool01@3oool0
1Ooo0000oooo0?ooo`3oooooo`0000<0oooo00Goo`000?ooo`3oool0ooooool0000I0?ooo`040?l0
003oool0oooo0?l000<0oooo00D0o`000?ooo`3oool0oooo0?l0000I0?ooo`050?l0003oool0oooo
0?ooo`3o00000`3oool0103o0000oooo0?ooo`3o000J0?ooo`040?l0003oool0oooo0?l000<0oooo
00D0o`000?ooo`3oool0oooo0?l0000I0?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool01@3o
0000oooo0?ooo`3oool0o`0001T0oooo00<0o`000?ooo`3oool00P3oool00ol00000oooo0?ooo`0<
0?ooo`009`3oool2o`0000L0oooo00Co003o0?ooo`3ooooo003o0`3oool00ol00?l0oooo0?ooo`0K
0?ooo`05o`00o`3oool0oooo0?ooool00?l00`3oool00ol00?l0oooo0?ooo`0J0?ooo`05o`00o`3o
ool0oooo0?ooool00?l00`3oool00ol00?l0oooo0?ooo`0K0?ooo`05o`00o`3oool0oooo0?ooool0
0?l00P3oool00ol00?l0oooo0?ooo`0K0?ooo`05o`00o`3oool0oooo0?ooool00?l00`3oool00ol0
0?l0oooo0?ooo`0K0?ooo`04o`00o`3oool0oooo0?ooo`;o0000<03oool2o`0000H0oooo00Goo`00
0?ooo`3oool0ooooool000030?ooo`05ool0003oool0oooo0?oooooo00006@3oool0103o0000oooo
0?ooo`3o00030?ooo`050?l0003oool0oooo0?ooo`3o00006@3oool01@3o0000oooo0?ooo`3oool0
o`0000<0oooo00@0o`000?ooo`3oool0o`006P3oool0103o0000oooo0?ooo`3o00030?ooo`050?l0
003oool0oooo0?ooo`3o00006@3oool01@3o0000oooo0?ooo`3oool0o`000080oooo00D0o`000?oo
o`3oool0oooo0?l0000I0?ooo`040?l0003oool0oooo0?ooo`;o00003P3oool002L0oooo00?o0000
0?ooo`3oool01P3oool01?l00?l0oooo0?ooool00?l30?ooo`03o`00o`3oool0oooo01/0oooo00Go
003o0?ooo`3oool0ooooo`00o`030?ooo`03o`00o`3oool0oooo01X0oooo00Go003o0?ooo`3oool0
ooooo`00o`030?ooo`03o`00o`3oool0oooo01/0oooo00Go003o0?ooo`3oool0ooooo`00o`020?oo
o`03o`00o`3oool0oooo01/0oooo00Go003o0?ooo`3oool0ooooo`00o`030?ooo`03o`00o`3oool0
oooo01/0oooo00?o003o0?ooo`3oool00P3oool00ol00000oooo0?ooo`0^0?ooo`03o`00003oool0
oooo00D0oooo00Goo`000?ooo`3oool0ooooool000030?ooo`05ool0003oool0oooo0?oooooo0000
6@3oool0103o0000oooo0?ooo`3o00030?ooo`050?l0003oool0oooo0?ooo`3o00006@3oool01@3o
0000oooo0?ooo`3oool0o`0000<0oooo00@0o`000?ooo`3oool0o`006P3oool0103o0000oooo0?oo
o`3o00030?ooo`050?l0003oool0oooo0?ooo`3o00006@3oool01@3o0000oooo0?ooo`3oool0o`00
0080oooo00D0o`000?ooo`3oool0oooo0?l0000I0?ooo`030?l0003oool0oooo0080oooo00?o0000
0?ooo`3oool0303oool002L0oooo00?o00000?ooo`3oool01P3oool01?l00?l0oooo0?ooool00?l3
0?ooo`03o`00o`3oool0oooo01/0oooo00Go003o0?ooo`3oool0ooooo`00o`030?ooo`03o`00o`3o
ool0oooo01X0oooo00Go003o0?ooo`3oool0ooooo`00o`030?ooo`03o`00o`3oool0oooo01/0oooo
00Go003o0?ooo`3oool0ooooo`00o`020?ooo`03o`00o`3oool0oooo01/0oooo00Go003o0?ooo`3o
ool0ooooo`00o`030?ooo`03o`00o`3oool0oooo01/0oooo00?o003o0?ooo`3oool00P3oool00ol0
0000oooo0?ooo`0^0?ooo`03o`00003oool0oooo00D0oooo00Goo`000?ooo`3oool0ooooool00003
0?ooo`05ool0003oool0oooo0?oooooo00006@3oool0103o0000oooo0?ooo`3o00030?ooo`050?l0
003oool0oooo0?ooo`3o00006@3oool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00@0o`000?oo
o`3oool0o`006P3oool0103o0000oooo0?ooo`3o00030?ooo`050?l0003oool0oooo0?ooo`3o0000
6@3oool01@3o0000oooo0?ooo`3oool0o`000080oooo00D0o`000?ooo`3oool0oooo0?l0000I0?oo
o`030?l0003oool0oooo0080oooo00?o00000?ooo`3oool0303oool002L0oooo00?o00000?ooo`3o
ool01P3oool01?l00?l0oooo0?ooool00?l30?ooo`03o`00o`3oool0oooo01/0oooo00Go003o0?oo
o`3oool0ooooo`00o`030?ooo`03o`00o`3oool0oooo01X0oooo00Go003o0?ooo`3oool0ooooo`00
o`030?ooo`03o`00o`3oool0oooo01/0oooo00Go003o0?ooo`3oool0ooooo`00o`020?ooo`03o`00
o`3oool0oooo01/0oooo00Go003o0?ooo`3oool0ooooo`00o`030?ooo`03o`00o`3oool0oooo01/0
oooo00?o003o0?ooo`3oool00P3oool00ol00000oooo0?ooo`0^0?ooo`03o`00003oool0oooo00D0
oooo00Goo`000?ooo`3oool0ooooool000030?ooo`05ool0003oool0oooo0?oooooo00006@3oool0
103o0000oooo0?ooo`3o00030?ooo`050?l0003oool0oooo0?ooo`3o00006@3oool01@3o0000oooo
0?ooo`3oool0o`0000<0oooo00@0o`000?ooo`3oool0o`006P3oool0103o0000oooo0?ooo`3o0003
0?ooo`050?l0003oool0oooo0?ooo`3o00006@3oool01@3o0000oooo0?ooo`3oool0o`000080oooo
00D0o`000?ooo`3oool0oooo0?l0000I0?ooo`030?l0003oool0oooo0080oooo00?o00000?ooo`3o
ool0303oool001D0oooo0_l000040?ooo`03o`00003oool0oooo0080oooo0ol000040?ooo`03o`00
003oool0oooo00H0oooo00Co003o0?ooo`3ooooo003o0`3oool00ol00?l0oooo0?ooo`0K0?ooo`05
o`00o`3oool0oooo0?ooool00?l00`3oool00ol00?l0oooo0?ooo`0J0?ooo`05o`00o`3oool0oooo
0?ooool00?l00`3oool00ol00?l0oooo0?ooo`0K0?ooo`05o`00o`3oool0oooo0?ooool00?l00P3o
ool00ol00?l0oooo0?ooo`0K0?ooo`05o`00o`3oool0oooo0?ooool00?l00`3oool00ol00?l0oooo
0?ooo`0K0?ooo`03o`00o`3oool0oooo0080oooo00?o00000?ooo`3oool06`3oool2o`0000@0oooo
00?o00000?ooo`3oool00P3oool3o`0000D0oooo00?o00000?ooo`3oool01@3oool01Ooo0000oooo
0?ooo`3oooooo`0000<0oooo00Goo`000?ooo`3oool0ooooool0000I0?ooo`040?l0003oool0oooo
0?l000<0oooo00D0o`000?ooo`3oool0oooo0?l0000I0?ooo`050?l0003oool0oooo0?ooo`3o0000
0`3oool0103o0000oooo0?ooo`3o000J0?ooo`040?l0003oool0oooo0?l000<0oooo00D0o`000?oo
o`3oool0oooo0?l0000I0?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool01@3o0000oooo0?oo
o`3oool0o`0001T0oooo00<0o`000?ooo`3oool00P3oool00ol00000oooo0?ooo`0<0?ooo`00503o
ool01?l00000oooo0?ooool000070?ooo`05o`00003oool0oooo0?ooool000000`3oool00ol00000
oooo0?ooo`060?ooo`04o`00o`3oool0ooooo`00o`<0oooo00?o003o0?ooo`3oool06`3oool01Ol0
0?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool06P3oool01Ol00?l0oooo0?ooo`3o
oooo003o00<0oooo00?o003o0?ooo`3oool06`3oool01Ol00?l0oooo0?ooo`3ooooo003o0080oooo
00?o003o0?ooo`3oool06`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3o
ool06`3oool00ol00?l0oooo0?ooo`020?ooo`03o`00003oool0oooo01X0oooo00Co00000?ooo`3o
oooo00001`3oool01Ol00000oooo0?ooo`3ooooo000000@0oooo00?o00000?ooo`3oool01@3oool0
1Ooo0000oooo0?ooo`3oooooo`0000<0oooo00Goo`000?ooo`3oool0ooooool0000I0?ooo`040?l0
003oool0oooo0?l000<0oooo00D0o`000?ooo`3oool0oooo0?l0000I0?ooo`050?l0003oool0oooo
0?ooo`3o00000`3oool0103o0000oooo0?ooo`3o000J0?ooo`040?l0003oool0oooo0?l000<0oooo
00D0o`000?ooo`3oool0oooo0?l0000I0?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool01@3o
0000oooo0?ooo`3oool0o`0001T0oooo00<0o`000?ooo`3oool00P3oool00ol00000oooo0?ooo`0<
0?ooo`00503oool01?l00000oooo0?ooool0000;0?ooo`04o`00003oool0oooo0?ooo`;o00001`3o
ool01?l00?l0oooo0?ooool00?l30?ooo`03o`00o`3oool0oooo01/0oooo00Go003o0?ooo`3oool0
ooooo`00o`030?ooo`03o`00o`3oool0oooo01X0oooo00Go003o0?ooo`3oool0ooooo`00o`030?oo
o`03o`00o`3oool0oooo01/0oooo00Go003o0?ooo`3oool0ooooo`00o`020?ooo`03o`00o`3oool0
oooo01/0oooo00Go003o0?ooo`3oool0ooooo`00o`030?ooo`03o`00o`3oool0oooo01/0oooo00?o
003o0?ooo`3oool00ol0000L0?ooo`04o`00003oool0ooooo`0000/0oooo00?o00000?ooo`3oool0
0P3oool2o`0000H0oooo00Goo`000?ooo`3oool0ooooool000030?ooo`05ool0003oool0oooo0?oo
oooo00006@3oool0103o0000oooo0?ooo`3o00030?ooo`050?l0003oool0oooo0?ooo`3o00006@3o
ool01@3o0000oooo0?ooo`3oool0o`0000<0oooo00@0o`000?ooo`3oool0o`006P3oool0103o0000
oooo0?ooo`3o00030?ooo`050?l0003oool0oooo0?ooo`3o00006@3oool01@3o0000oooo0?ooo`3o
ool0o`000080oooo00D0o`000?ooo`3oool0oooo0?l0000I0?ooo`040?l0003oool0oooo0?ooo`;o
00003P3oool001@0oooo00Co00000?ooo`3ooooo00002`3oool01Ol00000oooo0?ooo`3ooooo0000
00P0oooo00Co003o0?ooo`3ooooo003o0`3oool00ol00?l0oooo0?ooo`0K0?ooo`05o`00o`3oool0
oooo0?ooool00?l00`3oool00ol00?l0oooo0?ooo`0J0?ooo`05o`00o`3oool0oooo0?ooool00?l0
0`3oool00ol00?l0oooo0?ooo`0K0?ooo`05o`00o`3oool0oooo0?ooool00?l00P3oool00ol00?l0
oooo0?ooo`0K0?ooo`05o`00o`3oool0oooo0?ooool00?l00`3oool00ol00?l0oooo0?ooo`0K0?oo
o`03o`00o`3oool0oooo0080oooo00?o00000?ooo`3oool06P3oool01?l00000oooo0?ooool0000;
0?ooo`03o`00003oool0oooo0080oooo00?o00000?ooo`3oool01@3oool01Ooo0000oooo0?ooo`3o
ooooo`0000<0oooo00Goo`000?ooo`3oool0ooooool0000I0?ooo`040?l0003oool0oooo0?l000<0
oooo00D0o`000?ooo`3oool0oooo0?l0000I0?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool0
103o0000oooo0?ooo`3o000J0?ooo`040?l0003oool0oooo0?l000<0oooo00D0o`000?ooo`3oool0
oooo0?l0000I0?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool01@3o0000oooo0?ooo`3oool0
o`0001T0oooo00<0o`000?ooo`3oool00P3oool00ol00000oooo0?ooo`0<0?ooo`00503oool01?l0
0000oooo0?ooool000070?ooo`Co0000103oool00ol00000oooo0?ooo`060?ooo`04o`00o`3oool0
ooooo`00o`<0oooo00?o003o0?ooo`3oool06`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo
00?o003o0?ooo`3oool06P3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3o
ool06`3oool01Ol00?l0oooo0?ooo`3ooooo003o0080oooo00?o003o0?ooo`3oool06`3oool01Ol0
0?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool06`3oool00ol00?l0oooo0?ooo`02
0?ooo`03o`00003oool0oooo01X0oooo00Co00000?ooo`3ooooo00001`3oool4o`0000D0oooo00?o
00000?ooo`3oool01@3oool01Ooo0000oooo0?ooo`3oooooo`0000<0oooo00Goo`000?ooo`3oool0
ooooool0000I0?ooo`040?l0003oool0oooo0?l000<0oooo00D0o`000?ooo`3oool0oooo0?l0000I
0?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool0103o0000oooo0?ooo`3o000J0?ooo`040?l0
003oool0oooo0?l000<0oooo00D0o`000?ooo`3oool0oooo0?l0000I0?ooo`050?l0003oool0oooo
0?ooo`3o00000P3oool01@3o0000oooo0?ooo`3oool0o`0001T0oooo00<0o`000?ooo`3oool00P3o
ool00ol00000oooo0?ooo`0<0?ooo`00503oool01?l00000oooo0?ooool000070?ooo`03o`00003o
ool0oooo00D0oooo00?o00000?ooo`3oool01P3oool01?l00?l0oooo0?ooool00?l30?ooo`03o`00
o`3oool0oooo01/0oooo00Go003o0?ooo`3oool0ooooo`00o`030?ooo`03o`00o`3oool0oooo01X0
oooo00Go003o0?ooo`3oool0ooooo`00o`030?ooo`03o`00o`3oool0oooo01/0oooo00Go003o0?oo
o`3oool0ooooo`00o`020?ooo`03o`00o`3oool0oooo01/0oooo00Go003o0?ooo`3oool0ooooo`00
o`030?ooo`03o`00o`3oool0oooo01/0oooo00?o003o0?ooo`3oool00P3oool00ol00000oooo0?oo
o`0J0?ooo`04o`00003oool0ooooo`0000L0oooo00?o00000?ooo`3oool01P3oool00ol00000oooo
0?ooo`040?ooo`?oo`000P3oool01Ooo0000oooo0?ooo`3oooooo`000080oooo0ooo000G0?ooo`?o
o`0000<0oooo0?l0003oool00P3oool00`3o0000oooo0?ooo`03ool001L0oooo0ooo00020?ooo`06
0?l0003oool0oooo0?ooo`3o0000oooo0ooo000H0?ooo`?oo`0000<0oooo0?l0003oool00P3oool0
0`3o0000oooo0?ooo`03ool001L0oooo0ooo00020?ooo`040?l0003oool0oooo0?l00080oooo0ooo
000G0?ooo`?oo`000`3oool00ol00000oooo0?ooo`0<0?ooo`005@3oool2o`0000P0oooo1Ol00003
0?ooo`03o`00003oool0oooo00H0oooo00Co003o0?ooo`3ooooo003o0`3oool00ol00?l0oooo0?oo
o`0K0?ooo`05o`00o`3oool0oooo0?ooool00?l00`3oool00ol00?l0oooo0?ooo`0J0?ooo`05o`00
o`3oool0oooo0?ooool00?l00`3oool00ol00?l0oooo0?ooo`0K0?ooo`05o`00o`3oool0oooo0?oo
ool00?l00P3oool00ol00?l0oooo0?ooo`0K0?ooo`05o`00o`3oool0oooo0?ooool00?l00`3oool0
0ol00?l0oooo0?ooo`0K0?ooo`03o`00o`3oool0oooo0080oooo00?o00000?ooo`3oool06`3oool2
o`0000P0oooo1Ol000040?ooo`03o`00003oool0oooo00@0oooo0ooo00020?ooo`05ool0003oool0
oooo0?oooooo00000P3oool3ool001L0oooo0ooo00000`3oool0o`000?ooo`020?ooo`030?l0003o
ool0oooo00?oo`005`3oool3ool00080oooo00H0o`000?ooo`3oool0oooo0?l0003oool3ool001P0
oooo0ooo00000`3oool0o`000?ooo`020?ooo`030?l0003oool0oooo00?oo`005`3oool3ool00080
oooo00@0o`000?ooo`3oool0o`000P3oool3ool001L0oooo0ooo00030?ooo`03o`00003oool0oooo
00`0oooo000W0?ooo`03o`00003oool0oooo00H0oooo00Co003o0?ooo`3ooooo003o0`3oool00ol0
0?l0oooo0?ooo`0K0?ooo`05o`00o`3oool0oooo0?ooool00?l00`3oool00ol00?l0oooo0?ooo`0J
0?ooo`05o`00o`3oool0oooo0?ooool00?l00`3oool00ol00?l0oooo0?ooo`0K0?ooo`05o`00o`3o
ool0oooo0?ooool00?l00P3oool00ol00?l0oooo0?ooo`0K0?ooo`05o`00o`3oool0oooo0?ooool0
0?l00`3oool00ol00?l0oooo0?ooo`0K0?ooo`03o`00o`3oool0oooo0080oooo00?o00000?ooo`3o
ool0;P3oool00ol00000oooo0?ooo`040?ooo`?oo`000P3oool01Ooo0000oooo0?ooo`3oooooo`00
0080oooo0ooo000G0?ooo`?oo`0000<0oooo0?l0003oool00P3oool00`3o0000oooo0?ooo`03ool0
01L0oooo0ooo00020?ooo`060?l0003oool0oooo0?ooo`3o0000oooo0ooo000H0?ooo`?oo`0000<0
oooo0?l0003oool00P3oool00`3o0000oooo0?ooo`03ool001L0oooo0ooo00020?ooo`040?l0003o
ool0oooo0?l00080oooo0ooo000G0?ooo`?oo`000`3oool00ol00000oooo0?ooo`0<0?ooo`009`3o
ool2o`0000L0oooo00Co003o0?ooo`3ooooo003o0`3oool00ol00?l0oooo0?ooo`0K0?ooo`05o`00
o`3oool0oooo0?ooool00?l00`3oool00ol00?l0oooo0?ooo`0J0?ooo`05o`00o`3oool0oooo0?oo
ool00?l00`3oool00ol00?l0oooo0?ooo`0K0?ooo`05o`00o`3oool0oooo0?ooool00?l00P3oool0
0ol00?l0oooo0?ooo`0K0?ooo`05o`00o`3oool0oooo0?ooool00?l00`3oool00ol00?l0oooo0?oo
o`0K0?ooo`04o`00o`3oool0oooo0?ooo`;o0000<03oool2o`0000X0oooo00Goo`000?ooo`3oool0
ooooool0000P0?ooo`050?l0003oool0oooo0?ooo`3o00008@3oool01@3o0000oooo0?ooo`3oool0
o`000200oooo00D0o`000?ooo`3oool0oooo0?l0000Q0?ooo`040?l0003oool0oooo0?l00240oooo
0_l0000>0?ooo`009`3oool00ol00000oooo0?ooo`060?ooo`04o`00o`3oool0ooooo`00o`<0oooo
00?o003o0?ooo`3oool06`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3o
ool06P3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool06`3oool01Ol0
0?l0oooo0?ooo`3ooooo003o0080oooo00?o003o0?ooo`3oool06`3oool01Ol00?l0oooo0?ooo`3o
oooo003o00<0oooo00?o003o0?ooo`3oool06`3oool00ol00?l0oooo0?ooo`020?ooo`03o`00003o
ool0oooo02h0oooo00?o00000?ooo`3oool02@3oool01Ooo0000oooo0?ooo`3oooooo`000200oooo
00D0o`000?ooo`3oool0oooo0?l0000Q0?ooo`050?l0003oool0oooo0?ooo`3o0000803oool01@3o
0000oooo0?ooo`3oool0o`000240oooo00@0o`000?ooo`3oool0o`008P3oool00ol00000oooo0?oo
o`0<0?ooo`009`3oool00ol00000oooo0?ooo`060?ooo`04o`00o`3oool0ooooo`00o`<0oooo00?o
003o0?ooo`3oool06`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool0
6P3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool06`3oool01Ol00?l0
oooo0?ooo`3ooooo003o0080oooo00?o003o0?ooo`3oool06`3oool01Ol00?l0oooo0?ooo`3ooooo
003o00<0oooo00?o003o0?ooo`3oool06`3oool00ol00?l0oooo0?ooo`020?ooo`03o`00003oool0
oooo02h0oooo00?o00000?ooo`3oool02@3oool01Ooo0000oooo0?ooo`3oooooo`000200oooo00D0
o`000?ooo`3oool0oooo0?l0000Q0?ooo`050?l0003oool0oooo0?ooo`3o0000803oool01@3o0000
oooo0?ooo`3oool0o`000240oooo00@0o`000?ooo`3oool0o`008P3oool00ol00000oooo0?ooo`0<
0?ooo`009`3oool00ol00000oooo0?ooo`060?ooo`04o`00o`3oool0ooooo`00o`<0oooo00?o003o
0?ooo`3oool06`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool06P3o
ool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool06`3oool01Ol00?l0oooo
0?ooo`3ooooo003o0080oooo00?o003o0?ooo`3oool06`3oool01Ol00?l0oooo0?ooo`3ooooo003o
00<0oooo00?o003o0?ooo`3oool06`3oool00ol00?l0oooo0?ooo`020?ooo`03o`00003oool0oooo
02h0oooo00?o00000?ooo`3oool02@3oool01Ooo0000oooo0?ooo`3oooooo`000200oooo00D0o`00
0?ooo`3oool0oooo0?l0000Q0?ooo`050?l0003oool0oooo0?ooo`3o0000803oool01@3o0000oooo
0?ooo`3oool0o`000240oooo00@0o`000?ooo`3oool0o`008P3oool00ol00000oooo0?ooo`0<0?oo
o`009`3oool00ol00000oooo0?ooo`060?ooo`04o`00o`3oool0ooooo`00o`<0oooo00?o003o0?oo
o`3oool06`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool06P3oool0
1Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool06`3oool01Ol00?l0oooo0?oo
o`3ooooo003o0080oooo00?o003o0?ooo`3oool06`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0
oooo00?o003o0?ooo`3oool06`3oool00ol00?l0oooo0?ooo`020?ooo`03o`00003oool0oooo02h0
oooo00?o00000?ooo`3oool02@3oool01Ooo0000oooo0?ooo`3oooooo`000200oooo00D0o`000?oo
o`3oool0oooo0?l0000Q0?ooo`050?l0003oool0oooo0?ooo`3o0000803oool01@3o0000oooo0?oo
o`3oool0o`000240oooo00@0o`000?ooo`3oool0o`008P3oool00ol00000oooo0?ooo`0<0?ooo`00
9`3oool00ol00000oooo0?ooo`060?ooo`04o`00o`3oool0ooooo`00o`<0oooo00?o003o0?ooo`3o
ool06`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool06P3oool01Ol0
0?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool06`3oool01Ol00?l0oooo0?ooo`3o
oooo003o0080oooo00?o003o0?ooo`3oool06`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo
00?o003o0?ooo`3oool06`3oool00ol00?l0oooo0?ooo`020?ooo`03o`00003oool0oooo02h0oooo
00?o00000?ooo`3oool02@3oool01Ooo0000oooo0?ooo`3oooooo`000200oooo00D0o`000?ooo`3o
ool0oooo0?l0000Q0?ooo`050?l0003oool0oooo0?ooo`3o0000803oool01@3o0000oooo0?ooo`3o
ool0o`000240oooo00@0o`000?ooo`3oool0o`008P3oool00ol00000oooo0?ooo`0<0?ooo`009`3o
ool2o`0000L0oooo00Co003o0?ooo`3ooooo003o0`3oool00ol00?l0oooo0?ooo`0K0?ooo`05o`00
o`3oool0oooo0?ooool00?l00`3oool00ol00?l0oooo0?ooo`0J0?ooo`05o`00o`3oool0oooo0?oo
ool00?l00`3oool00ol00?l0oooo0?ooo`0K0?ooo`05o`00o`3oool0oooo0?ooool00?l00P3oool0
0ol00?l0oooo0?ooo`0K0?ooo`05o`00o`3oool0oooo0?ooool00?l00`3oool00ol00?l0oooo0?oo
o`0K0?ooo`04o`00o`3oool0oooo0?ooo`;o0000<03oool2o`0000X0oooo00Goo`000?ooo`3oool0
ooooool0000P0?ooo`050?l0003oool0oooo0?ooo`3o00008@3oool01@3o0000oooo0?ooo`3oool0
o`000200oooo00D0o`000?ooo`3oool0oooo0?l0000Q0?ooo`040?l0003oool0oooo0?l00240oooo
0_l0000>0?ooo`009`3oool00ol00000oooo0?ooo`060?ooo`04o`00o`3oool0ooooo`00o`<0oooo
00?o003o0?ooo`3oool06`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3o
ool06P3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool06`3oool01Ol0
0?l0oooo0?ooo`3ooooo003o0080oooo00?o003o0?ooo`3oool06`3oool01Ol00?l0oooo0?ooo`3o
oooo003o00<0oooo00?o003o0?ooo`3oool06`3oool00ol00?l0oooo0?ooo`020?ooo`03o`00003o
ool0oooo02h0oooo00?o00000?ooo`3oool02@3oool01Ooo0000oooo0?ooo`3oooooo`000200oooo
00D0o`000?ooo`3oool0oooo0?l0000Q0?ooo`050?l0003oool0oooo0?ooo`3o0000803oool01@3o
0000oooo0?ooo`3oool0o`000240oooo00@0o`000?ooo`3oool0o`008P3oool00ol00000oooo0?oo
o`0<0?ooo`009`3oool00ol00000oooo0?ooo`060?ooo`04o`00o`3oool0ooooo`00o`<0oooo00?o
003o0?ooo`3oool06`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool0
6P3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool06`3oool01Ol00?l0
oooo0?ooo`3ooooo003o0080oooo00?o003o0?ooo`3oool06`3oool01Ol00?l0oooo0?ooo`3ooooo
003o00<0oooo00?o003o0?ooo`3oool06`3oool00ol00?l0oooo0?ooo`020?ooo`03o`00003oool0
oooo02h0oooo00?o00000?ooo`3oool02@3oool01Ooo0000oooo0?ooo`3oooooo`000200oooo00D0
o`000?ooo`3oool0oooo0?l0000Q0?ooo`050?l0003oool0oooo0?ooo`3o0000803oool01@3o0000
oooo0?ooo`3oool0o`000240oooo00@0o`000?ooo`3oool0o`008P3oool00ol00000oooo0?ooo`0<
0?ooo`009`3oool00ol00000oooo0?ooo`060?ooo`04o`00o`3oool0ooooo`00o`<0oooo00?o003o
0?ooo`3oool06`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool06P3o
ool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool06`3oool01Ol00?l0oooo
0?ooo`3ooooo003o0080oooo00?o003o0?ooo`3oool06`3oool01Ol00?l0oooo0?ooo`3ooooo003o
00<0oooo00?o003o0?ooo`3oool06`3oool00ol00?l0oooo0?ooo`020?ooo`03o`00003oool0oooo
02h0oooo00?o00000?ooo`3oool02@3oool01Ooo0000oooo0?ooo`3oooooo`000200oooo00D0o`00
0?ooo`3oool0oooo0?l0000Q0?ooo`050?l0003oool0oooo0?ooo`3o0000803oool01@3o0000oooo
0?ooo`3oool0o`000240oooo00@0o`000?ooo`3oool0o`008P3oool00ol00000oooo0?ooo`0<0?oo
o`009`3oool00ol00000oooo0?ooo`060?ooo`04o`00o`3oool0ooooo`00o`<0oooo00?o003o0?oo
o`3oool06`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool06P3oool0
1Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool06`3oool01Ol00?l0oooo0?oo
o`3ooooo003o0080oooo00?o003o0?ooo`3oool06`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0
oooo00?o003o0?ooo`3oool06`3oool00ol00?l0oooo0?ooo`020?ooo`03o`00003oool0oooo02h0
oooo00?o00000?ooo`3oool02@3oool01Ooo0000oooo0?ooo`3oooooo`000200oooo00D0o`000?oo
o`3oool0oooo0?l0000Q0?ooo`050?l0003oool0oooo0?ooo`3o0000803oool01@3o0000oooo0?oo
o`3oool0o`000240oooo00@0o`000?ooo`3oool0o`008P3oool00ol00000oooo0?ooo`0<0?ooo`00
9`3oool00ol00000oooo0?ooo`060?ooo`04o`00o`3oool0ooooo`00o`<0oooo00?o003o0?ooo`3o
ool06`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool06P3oool01Ol0
0?l0oooo0?ooo`3ooooo003o00<0oooo00?o003o0?ooo`3oool06`3oool01Ol00?l0oooo0?ooo`3o
oooo003o0080oooo00?o003o0?ooo`3oool06`3oool01Ol00?l0oooo0?ooo`3ooooo003o00<0oooo
00?o003o0?ooo`3oool06`3oool00ol00?l0oooo0?ooo`020?ooo`03o`00003oool0oooo02h0oooo
00?o00000?ooo`3oool02@3oool01Ooo0000oooo0?ooo`3oooooo`000200oooo00D0o`000?ooo`3o
ool0oooo0?l0000Q0?ooo`050?l0003oool0oooo0?ooo`3o0000803oool01@3o0000oooo0?ooo`3o
ool0o`000240oooo00@0o`000?ooo`3oool0o`008P3oool00ol00000oooo0?ooo`0<0?ooo`009`3o
ool2o`0000H0oooo0ol00?l0103ooooo003o0?ooo`3oool3o`00oa/0oooo0ol00?l20?ooo`03o`00
o`3oool0oooo00?o003o6P3oool3o`00o`80oooo00?o003o0?ooo`3oool00ol00?lK0?ooo`?o003o
0P3oool00ol00?l0ooooo`00o`02o`00oa/0oooo0ol00?l20?ooo`03o`00o`3oool0oooo00?o003o
6`3oool3o`00o`80oooo0_l0000`0?ooo`;o00002P3oool01Ooo0000oooo0?ooo`3oooooo`000200
oooo00D0o`000?ooo`3oool0oooo0?l0000Q0?ooo`050?l0003oool0oooo0?ooo`3o0000803oool0
1@3o0000oooo0?ooo`3oool0o`000240oooo00@0o`000?ooo`3oool0o`008@3oool2o`0000h0oooo
000W0?ooo`03o`00003oool0oooo00D0oooo0ol00?l0103ooooo003o0?ooo`3oool3o`00oa/0oooo
0ol00?l20?ooo`03o`00o`3oool0oooo00?o003o6P3oool3o`00o`80oooo00?o003o0?ooo`3oool0
0ol00?lK0?ooo`?o003o0P3oool00ol00?l0ooooo`00o`02o`00oa/0oooo0ol00?l20?ooo`03o`00
o`3oool0oooo00?o003o6`3oool3o`00o`<0oooo00?o00000?ooo`3oool0;P3oool00ol00000oooo
0?ooo`090?ooo`05ool0003oool0oooo0?oooooo0000803oool01@3o0000oooo0?ooo`3oool0o`00
0240oooo00D0o`000?ooo`3oool0oooo0?l0000P0?ooo`050?l0003oool0oooo0?ooo`3o00008@3o
ool0103o0000oooo0?ooo`3o000R0?ooo`03o`00003oool0oooo00`0oooo000W0?ooo`03o`00003o
ool0oooo00D0oooo0ol00?l0103ooooo003o0?ooo`3oool3o`00oa/0oooo0ol00?l20?ooo`03o`00
o`3oool0oooo00?o003o6P3oool3o`00o`80oooo00?o003o0?ooo`3oool00ol00?lK0?ooo`?o003o
0P3oool00ol00?l0ooooo`00o`02o`00oa/0oooo0ol00?l20?ooo`03o`00o`3oool0oooo00?o003o
6`3oool3o`00o`<0oooo00?o00000?ooo`3oool0;P3oool00ol00000oooo0?ooo`090?ooo`05ool0
003oool0oooo0?oooooo0000803oool01@3o0000oooo0?ooo`3oool0o`000240oooo00D0o`000?oo
o`3oool0oooo0?l0000P0?ooo`050?l0003oool0oooo0?ooo`3o00008@3oool0103o0000oooo0?oo
o`3o000R0?ooo`03o`00003oool0oooo00`0oooo000W0?ooo`03o`00003oool0oooo00T0oooo00?o
003o0?ooo`3oool08`3oool00ol00?l0oooo0?ooo`0R0?ooo`03o`00o`3oool0oooo02<0oooo00?o
003o0?ooo`3oool08P3oool00ol00?l0oooo0?ooo`0T0?ooo`03o`00003oool0oooo02h0oooo00?o
00000?ooo`3oool02@3oool01Ooo0000oooo0?ooo`3oooooo`000200oooo00D0o`000?ooo`3oool0
oooo0?l0000Q0?ooo`050?l0003oool0oooo0?ooo`3o0000803oool01@3o0000oooo0?ooo`3oool0
o`000240oooo00@0o`000?ooo`3oool0o`008P3oool00ol00000oooo0?ooo`0<0?ooo`009`3oool0
0ol00000oooo0?ooo`090?ooo`03o`00o`3oool0oooo02<0oooo00?o003o0?ooo`3oool08P3oool0
0ol00?l0oooo0?ooo`0S0?ooo`03o`00o`3oool0oooo0280oooo00?o003o0?ooo`3oool0903oool0
0ol00000oooo0?ooo`0^0?ooo`03o`00003oool0oooo00T0oooo00Goo`000?ooo`3oool0ooooool0
000P0?ooo`050?l0003oool0oooo0?ooo`3o00008@3oool01@3o0000oooo0?ooo`3oool0o`000200
oooo00D0o`000?ooo`3oool0oooo0?l0000Q0?ooo`040?l0003oool0oooo0?l00280oooo00?o0000
0?ooo`3oool0303oool002L0oooo00?o00000?ooo`3oool02@3oool00ol00?l0oooo0?ooo`0S0?oo
o`03o`00o`3oool0oooo0280oooo00?o003o0?ooo`3oool08`3oool00ol00?l0oooo0?ooo`0R0?oo
o`03o`00o`3oool0oooo02@0oooo00?o00000?ooo`3oool0;P3oool00ol00000oooo0?ooo`080?oo
o`?oo`0000@0ooooool00?oo003oo`007P3oool3ool000040?oooooo003oo`00ool001l0oooo0ooo
0000103oooooo`00ool00?oo000N0?ooo`?oo`0000@0ooooool00?oo003oo`007`3oool6ool00240
oooo00?o00000?ooo`3oool0303oool002L0oooo0_l0000:0?ooo`03o`00o`3oool0oooo02<0oooo
00?o003o0?ooo`3oool08P3oool00ol00?l0oooo0?ooo`0S0?ooo`03o`00o`3oool0oooo0280oooo
00?o003o0?ooo`3oool08`3oool2o`000300oooo0_l000090?ooo`?oo`0000@0ooooool00?oo003o
o`007P3oool3ool000040?oooooo003oo`00ool001l0oooo0ooo0000103oooooo`00ool00?oo000N
0?ooo`?oo`0000@0ooooool00?oo003oo`007`3oool6ool00200oooo0_l0000>0?ooo`009`3oool0
0ol00000oooo0?ooo`090?ooo`03o`00o`3oool0oooo02<0oooo00?o003o0?ooo`3oool08P3oool0
0ol00?l0oooo0?ooo`0S0?ooo`03o`00o`3oool0oooo0280oooo00?o003o0?ooo`3oool0903oool0
0ol00000oooo0?ooo`0^0?ooo`03o`00003oool0oooo00P0oooo0ooo0000103oooooo`00ool00?oo
000N0?ooo`?oo`0000@0ooooool00?oo003oo`007`3oool3ool000040?oooooo003oo`00ool001h0
oooo0ooo0000103oooooo`00ool00?oo000O0?ooo`Koo`008@3oool00ol00000oooo0?ooo`0<0?oo
o`009`3oool00ol00000oooo0?ooo`090?ooo`03o`00o`3oool0oooo02<0oooo00?o003o0?ooo`3o
ool08P3oool00ol00?l0oooo0?ooo`0S0?ooo`03o`00o`3oool0oooo0280oooo00?o003o0?ooo`3o
ool0903oool00ol00000oooo0?ooo`0^0?ooo`03o`00003oool0oooo0<D0oooo00?o00000?ooo`3o
ool0303oool00200oooo0ol000040?ooo`03o`00003oool0oooo00T0oooo00?o003o0?ooo`3oool0
8`3oool00ol00?l0oooo0?ooo`0R0?ooo`03o`00o`3oool0oooo02<0oooo00?o003o0?ooo`3oool0
8P3oool00ol00?l0oooo0?ooo`0T0?ooo`03o`00003oool0oooo02H0oooo0ol000050?ooo`03o`00
003oool0oooo0<D0oooo00?o00000?ooo`3oool0303oool00240oooo00?o00000?ooo`3oool00`3o
ool00ol00000oooo0?ooo`090?ooo`03o`00o`3oool0oooo02<0oooo00?o003o0?ooo`3oool08P3o
ool00ol00?l0oooo0?ooo`0S0?ooo`03o`00o`3oool0oooo0280oooo00?o003o0?ooo`3oool0903o
ool00ol00000oooo0?ooo`0W0?ooo`03o`00003oool0oooo00@0oooo00?o00000?ooo`3oool0a@3o
ool00ol00000oooo0?ooo`0<0?ooo`008@3oool00ol00000oooo0?ooo`030?ooo`03o`00003oool0
oooo00P0oooo0ol00?lS0?ooo`?o003o8P3oool3o`00ob<0oooo0ol00?lR0?ooo`?o003o9@3oool0
0ol00000oooo0?ooo`0W0?ooo`03o`00003oool0oooo00@0oooo00?o00000?ooo`3oool0a@3oool0
0ol00000oooo0?ooo`0<0?ooo`008@3oool00ol00000oooo0?ooo`030?ooo`;o00002@3oool3o`00
ob<0oooo0ol00?lR0?ooo`?o003o8`3oool3o`00ob80oooo0ol00?lS0?ooo`?o0000:@3oool00ol0
0000oooo0?ooo`040?ooo`;o0000a@3oool2o`0000h0oooo000Q0?ooo`03o`00003oool0oooo00<0
oooo00?o00000?ooo`3oool0203oool3o`00ob<0oooo0ol00?lR0?ooo`?o003o8`3oool3o`00ob80
oooo0ol00?lU0?ooo`03o`00003oool0oooo02L0oooo00?o00000?ooo`3oool0103oool00ol00000
oooo0?ooo`350?ooo`03o`00003oool0oooo00`0oooo000P0?ooo`;o00001@3oool00ol00000oooo
0?ooo`020?ooo`03o`00003oool0oooo00@0oooo00?o00000?ooo`3oool01@3oool00ol00000oooo
0?ooo`040?ooo`03o`00003oool0oooo00D0oooo00?o00000?ooo`3oool0103oool00ol00000oooo
0?ooo`050?ooo`03o`00003oool0oooo00@0oooo00?o00000?ooo`3oool01@3oool00ol00000oooo
0?ooo`040?ooo`03o`00003oool0oooo00D0oooo00?o00000?ooo`3oool0103oool00ol00000oooo
0?ooo`050?ooo`03o`00003oool0oooo00@0oooo00?o00000?ooo`3oool01@3oool00ol00000oooo
0?ooo`040?ooo`03o`00003oool0oooo00D0oooo00?o00000?ooo`3oool0103oool00ol00000oooo
0?ooo`050?ooo`03o`00003oool0oooo00@0oooo00?o00000?ooo`3oool01@3oool00ol00000oooo
0?ooo`040?ooo`03o`00003oool0oooo00D0oooo00?o00000?ooo`3oool0103oool00ol00000oooo
0?ooo`050?ooo`03o`00003oool0oooo00@0oooo00?o00000?ooo`3oool0103oool00ol00000oooo
o`00000X0?ooo`;o00001P3oool00ol00000oooo0?ooo`020?ooo`03o`00003oool0oooo00@0oooo
00?o00000?ooo`3oool01@3oool00ol00000oooo0?ooo`040?ooo`03o`00003oool0oooo00D0oooo
00?o00000?ooo`3oool0103oool00ol00000oooo0?ooo`040?ooo`03o`00003oool0oooo00D0oooo
00?o00000?ooo`3oool0103oool00ol00000oooo0?ooo`050?ooo`03o`00003oool0oooo00@0oooo
00?o00000?ooo`3oool01@3oool00ol00000oooo0?ooo`040?ooo`03o`00003oool0oooo00D0oooo
00?o00000?ooo`3oool0103oool00ol00000oooo0?ooo`050?ooo`03o`00003oool0oooo00@0oooo
00?o00000?ooo`3oool01@3oool00ol00000oooo0?ooo`040?ooo`03o`00003oool0oooo00D0oooo
00?o00000?ooo`3oool0103oool00ol00000oooo0?ooo`050?ooo`03o`00003oool0oooo00@0oooo
00?o00000?ooo`3oool01@3oool00ol00000oooo0?ooo`040?ooo`03o`00003oool0oooo00D0oooo
00?o00000?ooo`3oool0103oool2o`0000h0oooo000Q0?ooo`03o`00003oool0oooo00<0oooob_l0
000Y0?ooo`03o`00003oool0oooo00@0oooobOl0000>0?ooo`00o`3ooooi0?ooo`00o`3ooooi0?oo
o`00o`3ooooi0?ooo`00o`3ooooi0?ooo`00o`3ooooi0?ooo`00o`3ooooi0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 503}, {147.312, 0}} -> {-0.0551454, -0.0147182, \
0.00419541, 0.00419541}, {{13.125, 240.125}, {143.75, 3.5}} -> {-11.8666, \
-1.33399, 0.267258, 0.0169581}, {{262.812, 489.812}, {143.75, 3.5}} -> \
{-78.5977, -1.33399, 0.267258, 0.0169581}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Output of system for simple cosine input: use frequency-response \
function\
\>", "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  "Value ",
  Cell[BoxData[
      \(TraditionalForm\`H(e\^j\[Theta])\)]],
  "at 50Hz (\[Theta] = 2\[Pi] 50/",
  Cell[BoxData[
      \(TraditionalForm\`f\_s\)]],
  "= 0.2\[Pi])"
}], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(H50\  = \ 
      H\[Theta]\  /. \ \[Theta] \[Rule] \((2  \[Pi]\ 50/fs)\)\)], "Input"],

Cell[BoxData[
    \(1\/2 + 
      1\/2\ \[ExponentialE]\^\(-\(\(\[ImaginaryI]\ \[Pi]\)\/5\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({Abs[H50], \ Arg[H50]}\)], "Input"],

Cell[BoxData[
    \({\@\(1\/32\ \((5 - \@5)\) + \((1\/2 + 1\/8\ \((1 + \@5)\))\)\^2\), \
\(-ArcTan[\@\(1\/2\ \((5 - \@5)\)\)\/\(4\ \((1\/2 + 1\/8\ \((1 + \@5)\))\)\)]\
\)}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`y[
        n] = \(\(|\)\(H(
          e\^j\[Theta])\)\(|\)\(cos[\(\(0.2  \[Pi]\ n\)\(+\)\)\  \
\[LeftVector] H(e\^j\[Theta])]\)\)\)]]], "Subsubsection"],

Cell[BoxData[
    \(\(yn = 
        Table[{n - 99, Abs[H50]\ Cos[2  \[Pi]\ n\ 50/fs\  + \ Arg[H50]]}, {n, 
            0, 499}];\)\)], "Input",
  Background->RGBColor[0, 1, 0]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(g3 = 
        DiscreteListPlot[Take[yn, {100, 150}], \ Green, \ 
          DisplayFunction \[Rule] Identity, \ Frame \[Rule] True, \ 
          Evaluate[\(AbsoluteOptions[g1, 
                PlotRange]\)[\([1]\)]]];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{{g1, g2}, {g1, g3}}], \ 
        ImageSize \[Rule] 504];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 504 311.489 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0186741 0.309017 0.294302 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21055 -0.0125 -6 -9 ]
[.21055 -0.0125 6 0 ]
[.39729 -0.0125 -6 -9 ]
[.39729 -0.0125 6 0 ]
[.58403 -0.0125 -6 -9 ]
[.58403 -0.0125 6 0 ]
[.77077 -0.0125 -6 -9 ]
[.77077 -0.0125 6 0 ]
[.95752 -0.0125 -6 -9 ]
[.95752 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -12 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -24 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -18 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21055 0 m
.21055 .00625 L
s
[(10)] .21055 -0.0125 0 1 Mshowa
.39729 0 m
.39729 .00625 L
s
[(20)] .39729 -0.0125 0 1 Mshowa
.58403 0 m
.58403 .00625 L
s
[(30)] .58403 -0.0125 0 1 Mshowa
.77077 0 m
.77077 .00625 L
s
[(40)] .77077 -0.0125 0 1 Mshowa
.95752 0 m
.95752 .00625 L
s
[(50)] .95752 -0.0125 0 1 Mshowa
.125 Mabswid
.06116 0 m
.06116 .00375 L
s
.09851 0 m
.09851 .00375 L
s
.13585 0 m
.13585 .00375 L
s
.1732 0 m
.1732 .00375 L
s
.2479 0 m
.2479 .00375 L
s
.28525 0 m
.28525 .00375 L
s
.3226 0 m
.3226 .00375 L
s
.35994 0 m
.35994 .00375 L
s
.43464 0 m
.43464 .00375 L
s
.47199 0 m
.47199 .00375 L
s
.50934 0 m
.50934 .00375 L
s
.54669 0 m
.54669 .00375 L
s
.62138 0 m
.62138 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.69608 0 m
.69608 .00375 L
s
.73343 0 m
.73343 .00375 L
s
.80812 0 m
.80812 .00375 L
s
.84547 0 m
.84547 .00375 L
s
.88282 0 m
.88282 .00375 L
s
.92017 0 m
.92017 .00375 L
s
.99486 0 m
.99486 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(-1)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(-0.5)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(0.5)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(1)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21055 .61178 m
.21055 .61803 L
s
.39729 .61178 m
.39729 .61803 L
s
.58403 .61178 m
.58403 .61803 L
s
.77077 .61178 m
.77077 .61803 L
s
.95752 .61178 m
.95752 .61803 L
s
.125 Mabswid
.06116 .61428 m
.06116 .61803 L
s
.09851 .61428 m
.09851 .61803 L
s
.13585 .61428 m
.13585 .61803 L
s
.1732 .61428 m
.1732 .61803 L
s
.2479 .61428 m
.2479 .61803 L
s
.28525 .61428 m
.28525 .61803 L
s
.3226 .61428 m
.3226 .61803 L
s
.35994 .61428 m
.35994 .61803 L
s
.43464 .61428 m
.43464 .61803 L
s
.47199 .61428 m
.47199 .61803 L
s
.50934 .61428 m
.50934 .61803 L
s
.54669 .61428 m
.54669 .61803 L
s
.62138 .61428 m
.62138 .61803 L
s
.65873 .61428 m
.65873 .61803 L
s
.69608 .61428 m
.69608 .61803 L
s
.73343 .61428 m
.73343 .61803 L
s
.80812 .61428 m
.80812 .61803 L
s
.84547 .61428 m
.84547 .61803 L
s
.88282 .61428 m
.88282 .61803 L
s
.92017 .61428 m
.92017 .61803 L
s
.99486 .61428 m
.99486 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.04248 .30902 m
.04248 .54711 L
s
.06116 .30902 m
.06116 .60332 L
s
.07983 .30902 m
.07983 .54711 L
s
.09851 .30902 m
.09851 .39996 L
s
.11718 .30902 m
.11718 .21807 L
s
.13585 .30902 m
.13585 .07092 L
s
.15453 .30902 m
.15453 .01472 L
s
.1732 .30902 m
.1732 .07092 L
s
.19188 .30902 m
.19188 .21807 L
s
.21055 .30902 m
.21055 .39996 L
s
.22923 .30902 m
.22923 .54711 L
s
.2479 .30902 m
.2479 .60332 L
s
.26657 .30902 m
.26657 .54711 L
s
.28525 .30902 m
.28525 .39996 L
s
.30392 .30902 m
.30392 .21807 L
s
.3226 .30902 m
.3226 .07092 L
s
.34127 .30902 m
.34127 .01472 L
s
.35994 .30902 m
.35994 .07092 L
s
.37862 .30902 m
.37862 .21807 L
s
.39729 .30902 m
.39729 .39996 L
s
.41597 .30902 m
.41597 .54711 L
s
.43464 .30902 m
.43464 .60332 L
s
.45331 .30902 m
.45331 .54711 L
s
.47199 .30902 m
.47199 .39996 L
s
.49066 .30902 m
.49066 .21807 L
s
.50934 .30902 m
.50934 .07092 L
s
.52801 .30902 m
.52801 .01472 L
s
.54669 .30902 m
.54669 .07092 L
s
.56536 .30902 m
.56536 .21807 L
s
.58403 .30902 m
.58403 .39996 L
s
.60271 .30902 m
.60271 .54711 L
s
.62138 .30902 m
.62138 .60332 L
s
.64006 .30902 m
.64006 .54711 L
s
.65873 .30902 m
.65873 .39996 L
s
.6774 .30902 m
.6774 .21807 L
s
.69608 .30902 m
.69608 .07092 L
s
.71475 .30902 m
.71475 .01472 L
s
.73343 .30902 m
.73343 .07092 L
s
.7521 .30902 m
.7521 .21807 L
s
.77077 .30902 m
.77077 .39996 L
s
.78945 .30902 m
.78945 .54711 L
s
.80812 .30902 m
.80812 .60332 L
s
.8268 .30902 m
.8268 .54711 L
s
.84547 .30902 m
.84547 .39996 L
s
.86415 .30902 m
.86415 .21807 L
s
.88282 .30902 m
.88282 .07092 L
s
.90149 .30902 m
.90149 .01472 L
s
.92017 .30902 m
.92017 .07092 L
s
.93884 .30902 m
.93884 .21807 L
s
.95752 .30902 m
.95752 .39996 L
s
.97619 .30902 m
.97619 .54711 L
s
.015 w
.04248 .54711 Mdot
.06116 .60332 Mdot
.07983 .54711 Mdot
.09851 .39996 Mdot
.11718 .21807 Mdot
.13585 .07092 Mdot
.15453 .01472 Mdot
.1732 .07092 Mdot
.19188 .21807 Mdot
.21055 .39996 Mdot
.22923 .54711 Mdot
.2479 .60332 Mdot
.26657 .54711 Mdot
.28525 .39996 Mdot
.30392 .21807 Mdot
.3226 .07092 Mdot
.34127 .01472 Mdot
.35994 .07092 Mdot
.37862 .21807 Mdot
.39729 .39996 Mdot
.41597 .54711 Mdot
.43464 .60332 Mdot
.45331 .54711 Mdot
.47199 .39996 Mdot
.49066 .21807 Mdot
.50934 .07092 Mdot
.52801 .01472 Mdot
.54669 .07092 Mdot
.56536 .21807 Mdot
.58403 .39996 Mdot
.60271 .54711 Mdot
.62138 .60332 Mdot
.64006 .54711 Mdot
.65873 .39996 Mdot
.6774 .21807 Mdot
.69608 .07092 Mdot
.71475 .01472 Mdot
.73343 .07092 Mdot
.7521 .21807 Mdot
.77077 .39996 Mdot
.78945 .54711 Mdot
.80812 .60332 Mdot
.8268 .54711 Mdot
.84547 .39996 Mdot
.86415 .21807 Mdot
.88282 .07092 Mdot
.90149 .01472 Mdot
.92017 .07092 Mdot
.93884 .21807 Mdot
.95752 .39996 Mdot
.97619 .54711 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0186741 0.309017 0.294302 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21055 -0.0125 -6 -9 ]
[.21055 -0.0125 6 0 ]
[.39729 -0.0125 -6 -9 ]
[.39729 -0.0125 6 0 ]
[.58403 -0.0125 -6 -9 ]
[.58403 -0.0125 6 0 ]
[.77077 -0.0125 -6 -9 ]
[.77077 -0.0125 6 0 ]
[.95752 -0.0125 -6 -9 ]
[.95752 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -12 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -24 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -18 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21055 0 m
.21055 .00625 L
s
[(10)] .21055 -0.0125 0 1 Mshowa
.39729 0 m
.39729 .00625 L
s
[(20)] .39729 -0.0125 0 1 Mshowa
.58403 0 m
.58403 .00625 L
s
[(30)] .58403 -0.0125 0 1 Mshowa
.77077 0 m
.77077 .00625 L
s
[(40)] .77077 -0.0125 0 1 Mshowa
.95752 0 m
.95752 .00625 L
s
[(50)] .95752 -0.0125 0 1 Mshowa
.125 Mabswid
.06116 0 m
.06116 .00375 L
s
.09851 0 m
.09851 .00375 L
s
.13585 0 m
.13585 .00375 L
s
.1732 0 m
.1732 .00375 L
s
.2479 0 m
.2479 .00375 L
s
.28525 0 m
.28525 .00375 L
s
.3226 0 m
.3226 .00375 L
s
.35994 0 m
.35994 .00375 L
s
.43464 0 m
.43464 .00375 L
s
.47199 0 m
.47199 .00375 L
s
.50934 0 m
.50934 .00375 L
s
.54669 0 m
.54669 .00375 L
s
.62138 0 m
.62138 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.69608 0 m
.69608 .00375 L
s
.73343 0 m
.73343 .00375 L
s
.80812 0 m
.80812 .00375 L
s
.84547 0 m
.84547 .00375 L
s
.88282 0 m
.88282 .00375 L
s
.92017 0 m
.92017 .00375 L
s
.99486 0 m
.99486 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(-1)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(-0.5)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(0.5)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(1)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21055 .61178 m
.21055 .61803 L
s
.39729 .61178 m
.39729 .61803 L
s
.58403 .61178 m
.58403 .61803 L
s
.77077 .61178 m
.77077 .61803 L
s
.95752 .61178 m
.95752 .61803 L
s
.125 Mabswid
.06116 .61428 m
.06116 .61803 L
s
.09851 .61428 m
.09851 .61803 L
s
.13585 .61428 m
.13585 .61803 L
s
.1732 .61428 m
.1732 .61803 L
s
.2479 .61428 m
.2479 .61803 L
s
.28525 .61428 m
.28525 .61803 L
s
.3226 .61428 m
.3226 .61803 L
s
.35994 .61428 m
.35994 .61803 L
s
.43464 .61428 m
.43464 .61803 L
s
.47199 .61428 m
.47199 .61803 L
s
.50934 .61428 m
.50934 .61803 L
s
.54669 .61428 m
.54669 .61803 L
s
.62138 .61428 m
.62138 .61803 L
s
.65873 .61428 m
.65873 .61803 L
s
.69608 .61428 m
.69608 .61803 L
s
.73343 .61428 m
.73343 .61803 L
s
.80812 .61428 m
.80812 .61803 L
s
.84547 .61428 m
.84547 .61803 L
s
.88282 .61428 m
.88282 .61803 L
s
.92017 .61428 m
.92017 .61803 L
s
.99486 .61428 m
.99486 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
.5 Mabswid
.02381 .30902 m
.02381 .47354 L
s
.04248 .30902 m
.04248 .57522 L
s
.06116 .30902 m
.06116 .57522 L
s
.07983 .30902 m
.07983 .47354 L
s
.09851 .30902 m
.09851 .30902 L
s
.11718 .30902 m
.11718 .1445 L
s
.13585 .30902 m
.13585 .04282 L
s
.15453 .30902 m
.15453 .04282 L
s
.1732 .30902 m
.1732 .1445 L
s
.19188 .30902 m
.19188 .30902 L
s
.21055 .30902 m
.21055 .47354 L
s
.22923 .30902 m
.22923 .57522 L
s
.2479 .30902 m
.2479 .57522 L
s
.26657 .30902 m
.26657 .47354 L
s
.28525 .30902 m
.28525 .30902 L
s
.30392 .30902 m
.30392 .1445 L
s
.3226 .30902 m
.3226 .04282 L
s
.34127 .30902 m
.34127 .04282 L
s
.35994 .30902 m
.35994 .1445 L
s
.37862 .30902 m
.37862 .30902 L
s
.39729 .30902 m
.39729 .47354 L
s
.41597 .30902 m
.41597 .57522 L
s
.43464 .30902 m
.43464 .57522 L
s
.45331 .30902 m
.45331 .47354 L
s
.47199 .30902 m
.47199 .30902 L
s
.49066 .30902 m
.49066 .1445 L
s
.50934 .30902 m
.50934 .04282 L
s
.52801 .30902 m
.52801 .04282 L
s
.54669 .30902 m
.54669 .1445 L
s
.56536 .30902 m
.56536 .30902 L
s
.58403 .30902 m
.58403 .47354 L
s
.60271 .30902 m
.60271 .57522 L
s
.62138 .30902 m
.62138 .57522 L
s
.64006 .30902 m
.64006 .47354 L
s
.65873 .30902 m
.65873 .30902 L
s
.6774 .30902 m
.6774 .1445 L
s
.69608 .30902 m
.69608 .04282 L
s
.71475 .30902 m
.71475 .04282 L
s
.73343 .30902 m
.73343 .1445 L
s
.7521 .30902 m
.7521 .30902 L
s
.77077 .30902 m
.77077 .47354 L
s
.78945 .30902 m
.78945 .57522 L
s
.80812 .30902 m
.80812 .57522 L
s
.8268 .30902 m
.8268 .47354 L
s
.84547 .30902 m
.84547 .30902 L
s
.86415 .30902 m
.86415 .1445 L
s
.88282 .30902 m
.88282 .04282 L
s
.90149 .30902 m
.90149 .04282 L
s
.92017 .30902 m
.92017 .1445 L
s
.93884 .30902 m
.93884 .30902 L
s
.95752 .30902 m
.95752 .47354 L
s
.015 w
.02381 .47354 Mdot
.04248 .57522 Mdot
.06116 .57522 Mdot
.07983 .47354 Mdot
.09851 .30902 Mdot
.11718 .1445 Mdot
.13585 .04282 Mdot
.15453 .04282 Mdot
.1732 .1445 Mdot
.19188 .30902 Mdot
.21055 .47354 Mdot
.22923 .57522 Mdot
.2479 .57522 Mdot
.26657 .47354 Mdot
.28525 .30902 Mdot
.30392 .1445 Mdot
.3226 .04282 Mdot
.34127 .04282 Mdot
.35994 .1445 Mdot
.37862 .30902 Mdot
.39729 .47354 Mdot
.41597 .57522 Mdot
.43464 .57522 Mdot
.45331 .47354 Mdot
.47199 .30902 Mdot
.49066 .1445 Mdot
.50934 .04282 Mdot
.52801 .04282 Mdot
.54669 .1445 Mdot
.56536 .30902 Mdot
.58403 .47354 Mdot
.60271 .57522 Mdot
.62138 .57522 Mdot
.64006 .47354 Mdot
.65873 .30902 Mdot
.6774 .1445 Mdot
.69608 .04282 Mdot
.71475 .04282 Mdot
.73343 .1445 Mdot
.7521 .30902 Mdot
.77077 .47354 Mdot
.78945 .57522 Mdot
.80812 .57522 Mdot
.8268 .47354 Mdot
.84547 .30902 Mdot
.86415 .1445 Mdot
.88282 .04282 Mdot
.90149 .04282 Mdot
.92017 .1445 Mdot
.93884 .30902 Mdot
.95752 .47354 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0186741 0.309017 0.294302 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21055 -0.0125 -6 -9 ]
[.21055 -0.0125 6 0 ]
[.39729 -0.0125 -6 -9 ]
[.39729 -0.0125 6 0 ]
[.58403 -0.0125 -6 -9 ]
[.58403 -0.0125 6 0 ]
[.77077 -0.0125 -6 -9 ]
[.77077 -0.0125 6 0 ]
[.95752 -0.0125 -6 -9 ]
[.95752 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -12 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -24 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -18 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21055 0 m
.21055 .00625 L
s
[(10)] .21055 -0.0125 0 1 Mshowa
.39729 0 m
.39729 .00625 L
s
[(20)] .39729 -0.0125 0 1 Mshowa
.58403 0 m
.58403 .00625 L
s
[(30)] .58403 -0.0125 0 1 Mshowa
.77077 0 m
.77077 .00625 L
s
[(40)] .77077 -0.0125 0 1 Mshowa
.95752 0 m
.95752 .00625 L
s
[(50)] .95752 -0.0125 0 1 Mshowa
.125 Mabswid
.06116 0 m
.06116 .00375 L
s
.09851 0 m
.09851 .00375 L
s
.13585 0 m
.13585 .00375 L
s
.1732 0 m
.1732 .00375 L
s
.2479 0 m
.2479 .00375 L
s
.28525 0 m
.28525 .00375 L
s
.3226 0 m
.3226 .00375 L
s
.35994 0 m
.35994 .00375 L
s
.43464 0 m
.43464 .00375 L
s
.47199 0 m
.47199 .00375 L
s
.50934 0 m
.50934 .00375 L
s
.54669 0 m
.54669 .00375 L
s
.62138 0 m
.62138 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.69608 0 m
.69608 .00375 L
s
.73343 0 m
.73343 .00375 L
s
.80812 0 m
.80812 .00375 L
s
.84547 0 m
.84547 .00375 L
s
.88282 0 m
.88282 .00375 L
s
.92017 0 m
.92017 .00375 L
s
.99486 0 m
.99486 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(-1)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(-0.5)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(0.5)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(1)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21055 .61178 m
.21055 .61803 L
s
.39729 .61178 m
.39729 .61803 L
s
.58403 .61178 m
.58403 .61803 L
s
.77077 .61178 m
.77077 .61803 L
s
.95752 .61178 m
.95752 .61803 L
s
.125 Mabswid
.06116 .61428 m
.06116 .61803 L
s
.09851 .61428 m
.09851 .61803 L
s
.13585 .61428 m
.13585 .61803 L
s
.1732 .61428 m
.1732 .61803 L
s
.2479 .61428 m
.2479 .61803 L
s
.28525 .61428 m
.28525 .61803 L
s
.3226 .61428 m
.3226 .61803 L
s
.35994 .61428 m
.35994 .61803 L
s
.43464 .61428 m
.43464 .61803 L
s
.47199 .61428 m
.47199 .61803 L
s
.50934 .61428 m
.50934 .61803 L
s
.54669 .61428 m
.54669 .61803 L
s
.62138 .61428 m
.62138 .61803 L
s
.65873 .61428 m
.65873 .61803 L
s
.69608 .61428 m
.69608 .61803 L
s
.73343 .61428 m
.73343 .61803 L
s
.80812 .61428 m
.80812 .61803 L
s
.84547 .61428 m
.84547 .61803 L
s
.88282 .61428 m
.88282 .61803 L
s
.92017 .61428 m
.92017 .61803 L
s
.99486 .61428 m
.99486 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.04248 .30902 m
.04248 .54711 L
s
.06116 .30902 m
.06116 .60332 L
s
.07983 .30902 m
.07983 .54711 L
s
.09851 .30902 m
.09851 .39996 L
s
.11718 .30902 m
.11718 .21807 L
s
.13585 .30902 m
.13585 .07092 L
s
.15453 .30902 m
.15453 .01472 L
s
.1732 .30902 m
.1732 .07092 L
s
.19188 .30902 m
.19188 .21807 L
s
.21055 .30902 m
.21055 .39996 L
s
.22923 .30902 m
.22923 .54711 L
s
.2479 .30902 m
.2479 .60332 L
s
.26657 .30902 m
.26657 .54711 L
s
.28525 .30902 m
.28525 .39996 L
s
.30392 .30902 m
.30392 .21807 L
s
.3226 .30902 m
.3226 .07092 L
s
.34127 .30902 m
.34127 .01472 L
s
.35994 .30902 m
.35994 .07092 L
s
.37862 .30902 m
.37862 .21807 L
s
.39729 .30902 m
.39729 .39996 L
s
.41597 .30902 m
.41597 .54711 L
s
.43464 .30902 m
.43464 .60332 L
s
.45331 .30902 m
.45331 .54711 L
s
.47199 .30902 m
.47199 .39996 L
s
.49066 .30902 m
.49066 .21807 L
s
.50934 .30902 m
.50934 .07092 L
s
.52801 .30902 m
.52801 .01472 L
s
.54669 .30902 m
.54669 .07092 L
s
.56536 .30902 m
.56536 .21807 L
s
.58403 .30902 m
.58403 .39996 L
s
.60271 .30902 m
.60271 .54711 L
s
.62138 .30902 m
.62138 .60332 L
s
.64006 .30902 m
.64006 .54711 L
s
.65873 .30902 m
.65873 .39996 L
s
.6774 .30902 m
.6774 .21807 L
s
.69608 .30902 m
.69608 .07092 L
s
.71475 .30902 m
.71475 .01472 L
s
.73343 .30902 m
.73343 .07092 L
s
.7521 .30902 m
.7521 .21807 L
s
.77077 .30902 m
.77077 .39996 L
s
.78945 .30902 m
.78945 .54711 L
s
.80812 .30902 m
.80812 .60332 L
s
.8268 .30902 m
.8268 .54711 L
s
.84547 .30902 m
.84547 .39996 L
s
.86415 .30902 m
.86415 .21807 L
s
.88282 .30902 m
.88282 .07092 L
s
.90149 .30902 m
.90149 .01472 L
s
.92017 .30902 m
.92017 .07092 L
s
.93884 .30902 m
.93884 .21807 L
s
.95752 .30902 m
.95752 .39996 L
s
.97619 .30902 m
.97619 .54711 L
s
.015 w
.04248 .54711 Mdot
.06116 .60332 Mdot
.07983 .54711 Mdot
.09851 .39996 Mdot
.11718 .21807 Mdot
.13585 .07092 Mdot
.15453 .01472 Mdot
.1732 .07092 Mdot
.19188 .21807 Mdot
.21055 .39996 Mdot
.22923 .54711 Mdot
.2479 .60332 Mdot
.26657 .54711 Mdot
.28525 .39996 Mdot
.30392 .21807 Mdot
.3226 .07092 Mdot
.34127 .01472 Mdot
.35994 .07092 Mdot
.37862 .21807 Mdot
.39729 .39996 Mdot
.41597 .54711 Mdot
.43464 .60332 Mdot
.45331 .54711 Mdot
.47199 .39996 Mdot
.49066 .21807 Mdot
.50934 .07092 Mdot
.52801 .01472 Mdot
.54669 .07092 Mdot
.56536 .21807 Mdot
.58403 .39996 Mdot
.60271 .54711 Mdot
.62138 .60332 Mdot
.64006 .54711 Mdot
.65873 .39996 Mdot
.6774 .21807 Mdot
.69608 .07092 Mdot
.71475 .01472 Mdot
.73343 .07092 Mdot
.7521 .21807 Mdot
.77077 .39996 Mdot
.78945 .54711 Mdot
.80812 .60332 Mdot
.8268 .54711 Mdot
.84547 .39996 Mdot
.86415 .21807 Mdot
.88282 .07092 Mdot
.90149 .01472 Mdot
.92017 .07092 Mdot
.93884 .21807 Mdot
.95752 .39996 Mdot
.97619 .54711 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0186741 0.309017 0.294302 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21055 -0.0125 -6 -9 ]
[.21055 -0.0125 6 0 ]
[.39729 -0.0125 -6 -9 ]
[.39729 -0.0125 6 0 ]
[.58403 -0.0125 -6 -9 ]
[.58403 -0.0125 6 0 ]
[.77077 -0.0125 -6 -9 ]
[.77077 -0.0125 6 0 ]
[.95752 -0.0125 -6 -9 ]
[.95752 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -12 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -24 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -18 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21055 0 m
.21055 .00625 L
s
[(10)] .21055 -0.0125 0 1 Mshowa
.39729 0 m
.39729 .00625 L
s
[(20)] .39729 -0.0125 0 1 Mshowa
.58403 0 m
.58403 .00625 L
s
[(30)] .58403 -0.0125 0 1 Mshowa
.77077 0 m
.77077 .00625 L
s
[(40)] .77077 -0.0125 0 1 Mshowa
.95752 0 m
.95752 .00625 L
s
[(50)] .95752 -0.0125 0 1 Mshowa
.125 Mabswid
.06116 0 m
.06116 .00375 L
s
.09851 0 m
.09851 .00375 L
s
.13585 0 m
.13585 .00375 L
s
.1732 0 m
.1732 .00375 L
s
.2479 0 m
.2479 .00375 L
s
.28525 0 m
.28525 .00375 L
s
.3226 0 m
.3226 .00375 L
s
.35994 0 m
.35994 .00375 L
s
.43464 0 m
.43464 .00375 L
s
.47199 0 m
.47199 .00375 L
s
.50934 0 m
.50934 .00375 L
s
.54669 0 m
.54669 .00375 L
s
.62138 0 m
.62138 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.69608 0 m
.69608 .00375 L
s
.73343 0 m
.73343 .00375 L
s
.80812 0 m
.80812 .00375 L
s
.84547 0 m
.84547 .00375 L
s
.88282 0 m
.88282 .00375 L
s
.92017 0 m
.92017 .00375 L
s
.99486 0 m
.99486 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(-1)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(-0.5)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(0.5)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(1)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .13244 m
.00375 .13244 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .25016 m
.00375 .25016 L
s
0 .27959 m
.00375 .27959 L
s
0 .33845 m
.00375 .33845 L
s
0 .36788 m
.00375 .36788 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .4856 m
.00375 .4856 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21055 .61178 m
.21055 .61803 L
s
.39729 .61178 m
.39729 .61803 L
s
.58403 .61178 m
.58403 .61803 L
s
.77077 .61178 m
.77077 .61803 L
s
.95752 .61178 m
.95752 .61803 L
s
.125 Mabswid
.06116 .61428 m
.06116 .61803 L
s
.09851 .61428 m
.09851 .61803 L
s
.13585 .61428 m
.13585 .61803 L
s
.1732 .61428 m
.1732 .61803 L
s
.2479 .61428 m
.2479 .61803 L
s
.28525 .61428 m
.28525 .61803 L
s
.3226 .61428 m
.3226 .61803 L
s
.35994 .61428 m
.35994 .61803 L
s
.43464 .61428 m
.43464 .61803 L
s
.47199 .61428 m
.47199 .61803 L
s
.50934 .61428 m
.50934 .61803 L
s
.54669 .61428 m
.54669 .61803 L
s
.62138 .61428 m
.62138 .61803 L
s
.65873 .61428 m
.65873 .61803 L
s
.69608 .61428 m
.69608 .61803 L
s
.73343 .61428 m
.73343 .61803 L
s
.80812 .61428 m
.80812 .61803 L
s
.84547 .61428 m
.84547 .61803 L
s
.88282 .61428 m
.88282 .61803 L
s
.92017 .61428 m
.92017 .61803 L
s
.99486 .61428 m
.99486 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .13244 m
1 .13244 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .25016 m
1 .25016 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .36788 m
1 .36788 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .4856 m
1 .4856 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.04248 .30902 m
.04248 .47354 L
s
.06116 .30902 m
.06116 .57522 L
s
.07983 .30902 m
.07983 .57522 L
s
.09851 .30902 m
.09851 .47354 L
s
.11718 .30902 m
.11718 .30902 L
s
.13585 .30902 m
.13585 .1445 L
s
.15453 .30902 m
.15453 .04282 L
s
.1732 .30902 m
.1732 .04282 L
s
.19188 .30902 m
.19188 .1445 L
s
.21055 .30902 m
.21055 .30902 L
s
.22923 .30902 m
.22923 .47354 L
s
.2479 .30902 m
.2479 .57522 L
s
.26657 .30902 m
.26657 .57522 L
s
.28525 .30902 m
.28525 .47354 L
s
.30392 .30902 m
.30392 .30902 L
s
.3226 .30902 m
.3226 .1445 L
s
.34127 .30902 m
.34127 .04282 L
s
.35994 .30902 m
.35994 .04282 L
s
.37862 .30902 m
.37862 .1445 L
s
.39729 .30902 m
.39729 .30902 L
s
.41597 .30902 m
.41597 .47354 L
s
.43464 .30902 m
.43464 .57522 L
s
.45331 .30902 m
.45331 .57522 L
s
.47199 .30902 m
.47199 .47354 L
s
.49066 .30902 m
.49066 .30902 L
s
.50934 .30902 m
.50934 .1445 L
s
.52801 .30902 m
.52801 .04282 L
s
.54669 .30902 m
.54669 .04282 L
s
.56536 .30902 m
.56536 .1445 L
s
.58403 .30902 m
.58403 .30902 L
s
.60271 .30902 m
.60271 .47354 L
s
.62138 .30902 m
.62138 .57522 L
s
.64006 .30902 m
.64006 .57522 L
s
.65873 .30902 m
.65873 .47354 L
s
.6774 .30902 m
.6774 .30902 L
s
.69608 .30902 m
.69608 .1445 L
s
.71475 .30902 m
.71475 .04282 L
s
.73343 .30902 m
.73343 .04282 L
s
.7521 .30902 m
.7521 .1445 L
s
.77077 .30902 m
.77077 .30902 L
s
.78945 .30902 m
.78945 .47354 L
s
.80812 .30902 m
.80812 .57522 L
s
.8268 .30902 m
.8268 .57522 L
s
.84547 .30902 m
.84547 .47354 L
s
.86415 .30902 m
.86415 .30902 L
s
.88282 .30902 m
.88282 .1445 L
s
.90149 .30902 m
.90149 .04282 L
s
.92017 .30902 m
.92017 .04282 L
s
.93884 .30902 m
.93884 .1445 L
s
.95752 .30902 m
.95752 .30902 L
s
.97619 .30902 m
.97619 .47354 L
s
.015 w
.04248 .47354 Mdot
.06116 .57522 Mdot
.07983 .57522 Mdot
.09851 .47354 Mdot
.11718 .30902 Mdot
.13585 .1445 Mdot
.15453 .04282 Mdot
.1732 .04282 Mdot
.19188 .1445 Mdot
.21055 .30902 Mdot
.22923 .47354 Mdot
.2479 .57522 Mdot
.26657 .57522 Mdot
.28525 .47354 Mdot
.30392 .30902 Mdot
.3226 .1445 Mdot
.34127 .04282 Mdot
.35994 .04282 Mdot
.37862 .1445 Mdot
.39729 .30902 Mdot
.41597 .47354 Mdot
.43464 .57522 Mdot
.45331 .57522 Mdot
.47199 .47354 Mdot
.49066 .30902 Mdot
.50934 .1445 Mdot
.52801 .04282 Mdot
.54669 .04282 Mdot
.56536 .1445 Mdot
.58403 .30902 Mdot
.60271 .47354 Mdot
.62138 .57522 Mdot
.64006 .57522 Mdot
.65873 .47354 Mdot
.6774 .30902 Mdot
.69608 .1445 Mdot
.71475 .04282 Mdot
.73343 .04282 Mdot
.7521 .1445 Mdot
.77077 .30902 Mdot
.78945 .47354 Mdot
.80812 .57522 Mdot
.8268 .57522 Mdot
.84547 .47354 Mdot
.86415 .30902 Mdot
.88282 .1445 Mdot
.90149 .04282 Mdot
.92017 .04282 Mdot
.93884 .1445 Mdot
.95752 .30902 Mdot
.97619 .47354 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 311.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0001=b000`400?l00000o`00003ooooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00:_ooool2
o`00023ooooo0ol00004ooooo`;o00006oooool5o`0000?ooooo0_l0000Mooooo`?o00001?ooool2
o`0001gooooo0ol00003ooooo`;o00007Oooool3o`0000Cooooo0_l0000jooooo`;o00007oooool3
o`0000Cooooo0_l0000Looooo`Go00000oooool2o`0001cooooo0ol00004ooooo`;o00007_ooool3
o`0000?ooooo0_l0000Mooooo`?o00001?ooool2o`0001;ooooo000Yooooo`04o`000?oooooooooo
o`00023ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Kooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00006oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00007Oooool01Ol0003ooooooooooooooooo000000;ooooo00?o
0000ooooooooool06Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
0000>?ooool01?l0003oooooooooool0000Oooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00007?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001[ooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001kooooo00Go0000oooo
ooooooooooooo`000002ooooo`03o`000?oooooooooo01Wooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`00017ooooo000Yooooo`04o`000?ooooooooooo`00023ooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Looooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00007oooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo01Sooooo1Ol00002ooooo`04o`000?ooooooooooo`0001oooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`0fooooo`04o`000?ooooooooooo`0001oooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool0000Mooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00007_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo01Wooooo1Ol0
0002ooooo`04o`000?ooooooooooo`0001oooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0?ooooo`00:Oooool01?l0003oooooooooool0000Pooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00007Oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000
ooooooooool06oooool2o`0000?ooooo00Co0000oooooooooooo00006_ooool01?l0003ooooooooo
ool00003ooooo`04o`000?ooooooooooo`0001oooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`0fooooo`04o`000?ooooooooooo`0001oooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000Nooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooo
ooooo`0Jooooo`;o00000oooool01?l0003oooooooooool0000Kooooo`04o`000?ooooooooooo`00
00?ooooo00Co0000oooooooooooo00007oooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00oooooo000Yooooo`04o`000?ooooooooooo`00023ooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool0000Jooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool0000Oooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool06Oooool0
0ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0001_ooooo1?l00003ooooo`04o`000?oo
ooooooooo`0003Sooooo00Co0000oooooooooooo00007oooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0001_ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0001kooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooo000000?ooooo00Co0000oooooooooooo00006oooool4o`0000?ooooo00Co0000oooooooo
oooo00004Oooool002Wooooo00Co0000oooooooooooo00007oooool2o`0000Cooooo00Co0000oooo
oooooooo00006_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
6oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00007?ooool2o`00
00?ooooo00Co0000oooooooooooo00006oooool00ol0003oooooooooo`04ooooo`04o`000?oooooo
ooooo`0003Sooooo00Co0000oooooooooooo00007_ooool2o`0000Cooooo00Co0000oooooooooooo
00006oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00006_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00007Oooool2o`0000?ooooo
00Co0000oooooooooooo00006oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`00
017ooooo000Zooooo`;o00008Oooool00ol0003oooooooooo`03ooooo`;o00007?ooool3o`0000Co
oooo0_l0000Mooooo`?o00001?ooool2o`0001kooooo00?o0000ooooooooool00_ooool2o`0001co
oooo1Ol00003ooooo`;o0000>_ooool2o`00023ooooo00?o0000ooooooooool00oooool2o`0001go
oooo0ol00004ooooo`;o00007?ooool3o`0000Cooooo0_l0000Oooooo`03o`000?oooooooooo00;o
oooo0_l0000Looooo`Go00000oooool2o`0001;ooooo003oooooooWooooo003oooooooWooooo003o
ooooooWooooo003oooooooWooooo000Oooooo`?o00001?ooooo:o`0002Wooooo0ol00005oooool[o
00003Oooool0023ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00_ooooo000Hooooo`Go00000oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo01_ooooo0ol00?lSooooo`?o003o8oooool3o`00ob;ooooo0ol00?lSooooo`?o003o4Ooo
ool00ol0003oooooooooo`0Pooooo`Go00000oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0<Kooooo00?o0000ooooooooool02oooool0023ooooo00?o0000ooooooooool00oooool3
o`0001_ooooo0ol00?lSooooo`?o003o8oooool3o`00ob;ooooo0ol00?lSooooo`?o003o4?ooool2
o`0002[ooooo00?o0000ooooooooool01?ooool2o`000<Kooooo0_l0000=ooooo`008?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo0ol00?lSooooo`?o003o8oooool3o`00
ob;ooooo0ol00?lSooooo`?o003o4Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0a_ooool00ol0003oooooooooo`0;ooooo`007oooool2o`0000Go
oooo00?o0000ooooooooool07?ooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo02?o
oooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo013o
oooo00?o0000ooooooooool09oooool2o`0000Kooooo00?o0000ooooooooool0a_ooool00ol0003o
ooooooooo`0;ooooo`008?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01cooooo
00?o003oooooooooool08oooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo02;ooooo
00?o003oooooooooool08oooool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`36ooooo`03o`000?oooooooooo00_ooooo
000Vooooo`03o`000?oooooooooo01cooooo00?o003oooooooooool08oooool00ol00?oooooooooo
o`0Sooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool08oooool00ol00?oooooooooo
o`0@ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool05oooool3o`3o0004ooooool0
o`3o0?l0o`3o01oooooo0ol0o`001?oooooo0?l0o`3o0?l0o`0Nooooo`?o0?l000Coooooo`3o0?l0
o`3o0?l07oooool3o`3o0004ooooool0o`3o0?l0o`3o01kooooo0ol0o`001?oooooo0?l0o`3o0?l0
o`0Booooo`03o`000?oooooooooo00_ooooo000Vooooo`03o`000?oooooooooo01cooooo00?o003o
ooooooooool08oooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo02;ooooo00?o003o
ooooooooool08oooool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool05oooool3o`3o0004ooooool0o`3o0?l0o`3o01oooooo0ol0o`001?oooooo0?l0o`3o
0?l0o`0Nooooo`?o0?l000Coooooo`3o0?l0o`3o0?l07oooool3o`3o0004ooooool0o`3o0?l0o`3o
01kooooo0ol0o`001?oooooo0?l0o`3o0?l0o`0Booooo`03o`000?oooooooooo00_ooooo000Voooo
o`;o00007Oooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo02?ooooo00?o003ooooo
ooooool08_ooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo013ooooo00?o0000oooo
ooooool0;oooool2o`0001Sooooo0ol0o`001?oooooo0?l0o`3o0?l0o`0Oooooo`?o0?l000Cooooo
o`3o0?l0o`3o0?l07_ooool3o`3o0004ooooool0o`3o0?l0o`3o01oooooo0ol0o`001?oooooo0?l0
o`3o0?l0o`0Nooooo`?o0?l000Coooooo`3o0?l0o`3o0?l04Oooool2o`0000gooooo000Vooooo`03
o`000?oooooooooo01cooooo00?o003oooooooooool08oooool00ol00?ooooooooooo`0Sooooo`03
o`00oooooooooooo02;ooooo00?o003oooooooooool08oooool00ol00?ooooooooooo`0@ooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool06?ooool01@00o`3oooooooooooooool00?l0
027ooooo00D00?l0oooooooooooooooo003o000Pooooo`05003o0?ooooooooooooooo`00o`008Ooo
ool01@00o`3oooooooooooooool00?l0023ooooo00D00?l0oooooooooooooooo003o000Cooooo`03
o`000?oooooooooo00_ooooo000Vooooo`03o`000?oooooooooo01cooooo00?o003oooooooooool0
8oooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool0
8oooool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
6?ooool01@00o`3oooooooooooooool00?l0027ooooo00D00?l0oooooooooooooooo003o000Poooo
o`05003o0?ooooooooooooooo`00o`008Oooool01@00o`3oooooooooooooool00?l0023ooooo00D0
0?l0oooooooooooooooo003o000Cooooo`03o`000?oooooooooo00_ooooo000Vooooo`03o`000?oo
oooooooo01cooooo00?o003oooooooooool08oooool00ol00?ooooooooooo`0Sooooo`03o`00oooo
oooooooo02;ooooo00?o003oooooooooool08oooool00ol00?ooooooooooo`0@ooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool06?ooool01@00o`3oooooooooooooool00?l0027ooooo
00D00?l0oooooooooooooooo003o000Pooooo`05003o0?ooooooooooooooo`00o`008Oooool01@00
o`3oooooooooooooool00?l0023ooooo00D00?l0oooooooooooooooo003o000Cooooo`03o`000?oo
oooooooo00_ooooo000Vooooo`03o`000?oooooooooo01Sooooo0ol00?l01?oooooo003ooooooooo
ool3o`00oa_ooooo0ol00?l2ooooo`03o`00oooooooooooo00?o003o6oooool3o`00o`;ooooo00?o
003oooooool00?l00_l00?lKooooo`?o003o0_ooool00ol00?ooooooooooo`03o`00oa_ooooo0ol0
0?l2ooooo`03o`00oooooooo003o00;o003o3_ooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo01Sooooo00D00?l0oooooooooooooooo003o000Qooooo`05003o0?ooooooooooooooo`00
o`008?ooool01@00o`3oooooooooooooool00?l0027ooooo00D00?l0oooooooooooooooo003o000P
ooooo`05003o0?ooooooooooooooo`00o`004oooool00ol0003oooooooooo`0;ooooo`009_ooool0
0ol0003oooooooooo`0Hooooo`?o003o00Coooooo`00oooooooooooo0ol00?lKooooo`?o003o0_oo
ool00ol00?ooooooooooo`03o`00oa_ooooo0ol00?l2ooooo`03o`00oooooooo003o00;o003o6ooo
ool3o`00o`;ooooo00?o003oooooooooool00ol00?lKooooo`?o003o0_ooool00ol00?ooooooo`00
o`02o`00o`kooooo00?o0000ooooooooool0;oooool2o`0001Wooooo00D00?l0oooooooooooooooo
003o000Qooooo`05003o0?ooooooooooooooo`00o`008?ooool01@00o`3oooooooooooooool00?l0
027ooooo00D00?l0oooooooooooooooo003o000Pooooo`05003o0?ooooooooooooooo`00o`004_oo
ool2o`0000gooooo000Vooooo`;o00006Oooool3o`00o`04ooooool00?ooooooooooo`?o003o6ooo
ool3o`00o`;ooooo00?o003oooooooooool00ol00?lKooooo`?o003o0_ooool00ol00?ooooooo`00
o`02o`00oa_ooooo0ol00?l2ooooo`03o`00oooooooooooo00?o003o6oooool3o`00o`;ooooo00?o
003oooooool00?l00_l00?l>ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool06?oo
ool01@00o`3oooooooooooooool00?l0027ooooo00D00?l0oooooooooooooooo003o000Pooooo`05
003o0?ooooooooooooooo`00o`008Oooool01@00o`3oooooooooooooool00?l0023ooooo00D00?l0
oooooooooooooooo003o000Cooooo`03o`000?oooooooooo00_ooooo000Vooooo`03o`000?oooooo
oooo01Wooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`0Kooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool0
0?l00_ooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0=
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool06?ooool01@00o`3ooooooooooooo
ool00?l0027ooooo00D00?l0oooooooooooooooo003o000Pooooo`05003o0?ooooooooooooooo`00
o`008Oooool01@00o`3oooooooooooooool00?l0023ooooo00D00?l0oooooooooooooooo003o000C
ooooo`03o`000?oooooooooo00_ooooo000Vooooo`03o`000?oooooooooo01Wooooo00Co003ooooo
oooooooo003o0oooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?oooooo
ooooo`0Kooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`05
o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0=ooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool06?ooool01@00o`3oooooooooooooool00?l0027ooooo00D00?l0
oooooooooooooooo003o000Pooooo`05003o0?ooooooooooooooo`00o`008Oooool01@00o`3ooooo
ooooooooool00?l0023ooooo00D00?l0oooooooooooooooo003o000Cooooo`03o`000?oooooooooo
00_ooooo000Vooooo`03o`000?oooooooooo01Wooooo00Co003ooooooooooooo003o0oooool00ol0
0?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0K
ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0Kooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool0
0?l00_ooool00ol00?ooooooooooo`0=ooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool06?ooool01@00o`3oooooooooooooool00?l0027ooooo00D00?l0oooooooooooooooo003o000P
ooooo`05003o0?ooooooooooooooo`00o`008Oooool01@00o`3oooooooooooooool00?l0023ooooo
00D00?l0oooooooooooooooo003o000Cooooo`03o`000?oooooooooo00_ooooo000Vooooo`03o`00
0?oooooooooo01Wooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`0Kooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`05o`00oooooooooooo
ooooool00?l00_ooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?oooooo
ooooo`0=ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool06?ooool01@00o`3ooooo
ooooooooool00?l0027ooooo00D00?l0oooooooooooooooo003o000Pooooo`05003o0?oooooooooo
ooooo`00o`008Oooool01@00o`3oooooooooooooool00?l0023ooooo00D00?l0oooooooooooooooo
003o000Cooooo`03o`000?oooooooooo00_ooooo000Vooooo`;o00006_ooool01?l00?oooooooooo
ool00?l3ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo
01_ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01_ooooo00Go003o
ooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo00gooooo00?o0000ooooooooool0;ooo
ool2o`0001Wooooo00D00?l0oooooooooooooooo003o000Qooooo`05003o0?ooooooooooooooo`00
o`008?ooool01@00o`3oooooooooooooool00?l0027ooooo00D00?l0oooooooooooooooo003o000P
ooooo`05003o0?ooooooooooooooo`00o`004_ooool2o`0000gooooo000Vooooo`03o`000?oooooo
oooo01Wooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`0Kooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool0
0?l00_ooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0=
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool06?ooool01@00o`3ooooooooooooo
ool00?l0027ooooo00D00?l0oooooooooooooooo003o000Pooooo`05003o0?ooooooooooooooo`00
o`008Oooool01@00o`3oooooooooooooool00?l0023ooooo00D00?l0oooooooooooooooo003o000C
ooooo`03o`000?oooooooooo00_ooooo000Vooooo`03o`000?oooooooooo01Wooooo00Co003ooooo
oooooooo003o0oooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?oooooo
ooooo`0Kooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`05
o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0=ooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool06?ooool01@00o`3oooooooooooooool00?l0027ooooo00D00?l0
oooooooooooooooo003o000Pooooo`05003o0?ooooooooooooooo`00o`008Oooool01@00o`3ooooo
ooooooooool00?l0023ooooo00D00?l0oooooooooooooooo003o000Cooooo`03o`000?oooooooooo
00_ooooo000Vooooo`03o`000?oooooooooo01Wooooo00Co003ooooooooooooo003o0oooool00ol0
0?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0K
ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0Kooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool0
0?l00_ooool00ol00?ooooooooooo`0=ooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool06?ooool01@00o`3oooooooooooooool00?l0027ooooo00D00?l0oooooooooooooooo003o000P
ooooo`05003o0?ooooooooooooooo`00o`008Oooool01@00o`3oooooooooooooool00?l0023ooooo
00D00?l0oooooooooooooooo003o000Cooooo`03o`000?oooooooooo00_ooooo000Vooooo`03o`00
0?oooooooooo01Wooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`0Kooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`05o`00oooooooooooo
ooooool00?l00_ooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?oooooo
ooooo`0=ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool06?ooool01@00o`3ooooo
ooooooooool00?l0027ooooo00D00?l0oooooooooooooooo003o000Pooooo`05003o0?oooooooooo
ooooo`00o`008Oooool01@00o`3oooooooooooooool00?l0023ooooo00D00?l0oooooooooooooooo
003o000Cooooo`03o`000?oooooooooo00_ooooo000Vooooo`03o`000?oooooooooo01Wooooo00Co
003ooooooooooooo003o0oooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00_ooool00ol0
0?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0K
ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0=ooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool06?ooool01@00o`3oooooooooooooool00?l0027ooooo
00D00?l0oooooooooooooooo003o000Pooooo`05003o0?ooooooooooooooo`00o`008Oooool01@00
o`3oooooooooooooool00?l0023ooooo00D00?l0oooooooooooooooo003o000Cooooo`03o`000?oo
oooooooo00_ooooo000Vooooo`;o00006_ooool01?l00?ooooooooooool00?l3ooooo`03o`00oooo
oooooooo01_ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01_ooooo
00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo01_ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`02
ooooo`03o`00oooooooooooo00gooooo00?o0000ooooooooool0;oooool2o`0001Wooooo00D00?l0
oooooooooooooooo003o000Qooooo`05003o0?ooooooooooooooo`00o`008?ooool01@00o`3ooooo
ooooooooool00?l0027ooooo00D00?l0oooooooooooooooo003o000Pooooo`05003o0?oooooooooo
ooooo`00o`004_ooool2o`0000gooooo000Vooooo`03o`000?oooooooooo01Wooooo00Co003ooooo
oooooooo003o0oooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?oooooo
ooooo`0Kooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`05
o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0=ooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool06?ooool01@00o`3oooooooooooooool00?l0027ooooo00D00?l0
oooooooooooooooo003o000Pooooo`05003o0?ooooooooooooooo`00o`008Oooool01@00o`3ooooo
ooooooooool00?l0023ooooo00D00?l0oooooooooooooooo003o000Cooooo`03o`000?oooooooooo
00_ooooo000Vooooo`03o`000?oooooooooo01Wooooo00Co003ooooooooooooo003o0oooool00ol0
0?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0K
ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0Kooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool0
0?l00_ooool00ol00?ooooooooooo`0=ooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool04oooool3o`3o00;ooooo00D00?l0oooooooooooooooo003o0002ooooo`?o0?l05oooool3o`3o
00;ooooo00H00?l0oooooooooooooooo003o0?ooool3o`3o01Sooooo0ol0o`000oooool00?l0oooo
o`02ooooo`03003o0?oooooooooo00?o0?l05oooool3o`3o00;ooooo00H00?l0oooooooooooooooo
003o0?ooool3o`3o01Sooooo0ol0o`000oooool00?l0ooooo`02ooooo`03003o0?oooooooooo00?o
0?l03_ooool00ol0003oooooooooo`0;ooooo`009_ooool00ol0003oooooooooo`0Iooooo`04o`00
ooooooooooooo`00o`?ooooo00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003o
ooooooooool06oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06ooo
ool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool03Oooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo01?ooooo0ol0o`02ooooo`05003o0?ooooooooooooooo`00
o`000_ooool3o`3o01Oooooo0ol0o`02ooooo`06003o0?ooooooooooooooo`00o`3ooooo0ol0o`0H
ooooo`?o0?l000?ooooo003o0?ooool00_ooool00`00o`3oooooooooo`03o`3o01Oooooo0ol0o`02
ooooo`06003o0?ooooooooooooooo`00o`3ooooo0ol0o`0Hooooo`?o0?l000?ooooo003o0?ooool0
0_ooool00`00o`3oooooooooo`03o`3o00kooooo00?o0000ooooooooool02oooool001Cooooo0_l0
0004ooooo`03o`000?oooooooooo00;ooooo0ol00004ooooo`03o`000?oooooooooo01Wooooo00Co
003ooooooooooooo003o0oooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00_ooool00ol0
0?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0K
ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0=ooooo`03o`000?oo
oooooooo01cooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oo
oooooooo01?ooooo0ol0o`02ooooo`05003o0?ooooooooooooooo`00o`000_ooool3o`3o01Oooooo
0ol0o`02ooooo`06003o0?ooooooooooooooo`00o`3ooooo0ol0o`0Hooooo`?o0?l000?ooooo003o
0?ooool00_ooool00`00o`3oooooooooo`03o`3o01Oooooo0ol0o`02ooooo`06003o0?oooooooooo
ooooo`00o`3ooooo0ol0o`0Hooooo`?o0?l000?ooooo003o0?ooool00_ooool00`00o`3ooooooooo
o`03o`3o00kooooo00?o0000ooooooooool02oooool001?ooooo00Co0000oooooooooooo00001ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool06Oooool01?l00?oooooo
ooooool00?l3ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooo
oooo01_ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01_ooooo00Go
003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo00gooooo00?o0000ooooooooool0
6oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`0Dooooo`05003o0?ooooooooooooooo`00o`000oooool01@00o`3ooooooooooooo
ool00?l001Wooooo00D00?l0oooooooooooooooo003o0003ooooo`04003o0?oooooooooo003o01[o
oooo00@00?l0ooooooooool00?l00oooool01@00o`3oooooooooooooool00?l001Wooooo00D00?l0
oooooooooooooooo003o0003ooooo`04003o0?oooooooooo003o01[ooooo00@00?l0ooooooooool0
0?l00oooool01@00o`3oooooooooooooool00?l000oooooo00?o0000ooooooooool02oooool000co
oooo1Ol00002ooooo`04o`000?ooooooooooo`0000_ooooo00Co0000oooooooooooooooo0ol0000I
ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool06oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo003o00;o
oooo00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool06oooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool03?ooool2
o`0001Kooooo1Ol00002ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool00_oo
ool2o`0001Gooooo00D00?l0oooooooooooooooo003o0003ooooo`05003o0?ooooooooooooooo`00
o`006Oooool01@00o`3oooooooooooooool00?l000?ooooo00@00?l0ooooooooool00?l06_ooool0
1000o`3oooooooooo`00o`03ooooo`05003o0?ooooooooooooooo`00o`006Oooool01@00o`3ooooo
ooooooooool00?l000?ooooo00@00?l0ooooooooool00?l06_ooool01000o`3oooooooooo`00o`03
ooooo`05003o0?ooooooooooooooo`00o`003_ooool2o`0000gooooo000Cooooo`04o`000?oooooo
ooooo`0000_ooooo00Go0000ooooooooooooooooo`00000Kooooo`04o`00ooooooooooooo`00o`?o
oooo00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool06oooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool06oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06oooool01Ol00?oooooooooo
oooooooo003o00;ooooo00?o003oooooooooool03Oooool00ol0003oooooooooo`0Kooooo`04o`00
0?ooooooooooo`0000_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Dooooo`05
003o0?ooooooooooooooo`00o`000oooool01@00o`3oooooooooooooool00?l001Wooooo00D00?l0
oooooooooooooooo003o0003ooooo`04003o0?oooooooooo003o01[ooooo00@00?l0ooooooooool0
0?l00oooool01@00o`3oooooooooooooool00?l001Wooooo00D00?l0oooooooooooooooo003o0003
ooooo`04003o0?oooooooooo003o01[ooooo00@00?l0ooooooooool00?l00oooool01@00o`3ooooo
ooooooooool00?l000oooooo00?o0000ooooooooool02oooool001?ooooo00Co0000oooooooooooo
00001oooool4o`0000Cooooo00?o0000ooooooooool06Oooool01?l00?ooooooooooool00?l3oooo
o`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo01_ooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo01_ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01_ooooo00Go003ooooooooooooo
ooooo`00o`02ooooo`03o`00oooooooooooo00gooooo00?o0000ooooooooool06oooool01?l0003o
ooooooooool00007ooooo`Co00001Oooool00ol0003oooooooooo`0Dooooo`05003o0?oooooooooo
ooooo`00o`000oooool01@00o`3oooooooooooooool00?l001Wooooo00D00?l0oooooooooooooooo
003o0003ooooo`04003o0?oooooooooo003o01[ooooo00@00?l0ooooooooool00?l00oooool01@00
o`3oooooooooooooool00?l001Wooooo00D00?l0oooooooooooooooo003o0003ooooo`04003o0?oo
oooooooo003o01[ooooo00@00?l0ooooooooool00?l00oooool01@00o`3oooooooooooooool00?l0
00oooooo00?o0000ooooooooool02oooool001?ooooo00Co0000oooooooooooo00001oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo01Wooooo00Co003ooooooooooooo003o0oooool0
0ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`0Kooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0Kooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`05o`00oooooooooooooooo
ool00?l00_ooool00ol00?ooooooooooo`0=ooooo`03o`000?oooooooooo01_ooooo00Co0000oooo
oooooooo00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Cooooo00D00?l0
oooooooooooooooo003o0003ooooo`05003o0?ooooooooooooooo`00o`006Oooool01@00o`3ooooo
ooooooooool00?l000?ooooo00@00?l0ooooooooool00?l06_ooool01000o`3oooooooooo`00o`03
ooooo`05003o0?ooooooooooooooo`00o`006Oooool01@00o`3oooooooooooooool00?l000?ooooo
00@00?l0ooooooooool00?l06_ooool01000o`3oooooooooo`00o`03ooooo`05003o0?oooooooooo
ooooo`00o`003oooool00ol0003oooooooooo`0;ooooo`005?ooool2o`0000Sooooo1Ol00003oooo
o`03o`000?oooooooooo01Wooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`0K
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`05o`00oooo
ooooooooooooool00?l00_ooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00_ooool00ol0
0?ooooooooooo`0=ooooo`03o`000?oooooooooo01cooooo0_l00008ooooo`Go00001?ooool00ol0
003oooooooooo`0Dooooo`05003o0?ooooooooooooooo`00o`000oooool01@00o`3ooooooooooooo
ool00?l001Wooooo00D00?l0oooooooooooooooo003o0003ooooo`04003o0?oooooooooo003o01[o
oooo00@00?l0ooooooooool00?l00oooool01@00o`3oooooooooooooool00?l001Wooooo00D00?l0
oooooooooooooooo003o0003ooooo`04003o0?oooooooooo003o01[ooooo00@00?l0ooooooooool0
0?l00oooool01@00o`3oooooooooooooool00?l000oooooo00?o0000ooooooooool02oooool002Ko
oooo00?o0000ooooooooool06Oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo
01_ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01_ooooo00Go003o
ooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo01_ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`02ooooo`03
o`00oooooooooooo00gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Dooooo`05
003o0?ooooooooooooooo`00o`000oooool01@00o`3oooooooooooooool00?l001Wooooo00D00?l0
oooooooooooooooo003o0003ooooo`04003o0?oooooooooo003o01[ooooo00@00?l0ooooooooool0
0?l00oooool01@00o`3oooooooooooooool00?l001Wooooo00D00?l0oooooooooooooooo003o0003
ooooo`04003o0?oooooooooo003o01[ooooo00@00?l0ooooooooool00?l00oooool01@00o`3ooooo
ooooooooool00?l000oooooo00?o0000ooooooooool02oooool002Kooooo0_l0000Jooooo`04o`00
ooooooooooooo`00o`?ooooo00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003o
ooooooooool06oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06ooo
ool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool03Oooool00ol0003ooooo
ooooo`0_ooooo`;o00005Oooool01@00o`3oooooooooooooool00?l000?ooooo00D00?l0oooooooo
oooooooo003o000Iooooo`05003o0?ooooooooooooooo`00o`000oooool01000o`3oooooooooo`00
o`0Jooooo`04003o0?oooooooooo003o00?ooooo00D00?l0oooooooooooooooo003o000Iooooo`05
003o0?ooooooooooooooo`00o`000oooool01000o`3oooooooooo`00o`0Jooooo`04003o0?oooooo
oooo003o00?ooooo00D00?l0oooooooooooooooo003o000>ooooo`;o00003Oooool002Kooooo00?o
0000ooooooooool06Oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo01_ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01_ooooo00Go003ooooooooo
ooooooooo`00o`02ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooo
oooooooo00gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Dooooo`05003o0?oo
ooooooooooooo`00o`000oooool01@00o`3oooooooooooooool00?l001Wooooo00D00?l0oooooooo
oooooooo003o0003ooooo`04003o0?oooooooooo003o01[ooooo00@00?l0ooooooooool00?l00ooo
ool01@00o`3oooooooooooooool00?l001Wooooo00D00?l0oooooooooooooooo003o0003ooooo`04
003o0?oooooooooo003o01[ooooo00@00?l0ooooooooool00?l00oooool01@00o`3ooooooooooooo
ool00?l000oooooo00?o0000ooooooooool02oooool002Kooooo00?o0000ooooooooool06Oooool0
1?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo01_ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`02ooooo`03
o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
01_ooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo00gooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0Dooooo`05003o0?ooooooooooooooo`00o`000ooo
ool01@00o`3oooooooooooooool00?l001Wooooo00D00?l0oooooooooooooooo003o0003ooooo`04
003o0?oooooooooo003o01[ooooo00@00?l0ooooooooool00?l00oooool01@00o`3ooooooooooooo
ool00?l001Wooooo00D00?l0oooooooooooooooo003o0003ooooo`04003o0?oooooooooo003o01[o
oooo00@00?l0ooooooooool00?l00oooool01@00o`3oooooooooooooool00?l000oooooo00?o0000
ooooooooool02oooool002Kooooo00?o0000ooooooooool06Oooool01?l00?ooooooooooool00?l3
ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo01_ooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo01_ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01_ooooo00Go003ooooooooo
ooooooooo`00o`02ooooo`03o`00oooooooooooo00gooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`0Dooooo`05003o0?ooooooooooooooo`00o`000oooool01@00o`3ooooooooooooo
ool00?l001Wooooo00D00?l0oooooooooooooooo003o0003ooooo`04003o0?oooooooooo003o01[o
oooo00@00?l0ooooooooool00?l00oooool01@00o`3oooooooooooooool00?l001Wooooo00D00?l0
oooooooooooooooo003o0003ooooo`04003o0?oooooooooo003o01[ooooo00@00?l0ooooooooool0
0?l00oooool01@00o`3oooooooooooooool00?l000oooooo00?o0000ooooooooool02oooool002Ko
oooo00?o0000ooooooooool06Oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo
01_ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01_ooooo00Go003o
ooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo01_ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`02ooooo`03
o`00oooooooooooo00gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Dooooo`05
003o0?ooooooooooooooo`00o`000oooool01@00o`3oooooooooooooool00?l001Wooooo00D00?l0
oooooooooooooooo003o0003ooooo`04003o0?oooooooooo003o01[ooooo00@00?l0ooooooooool0
0?l00oooool01@00o`3oooooooooooooool00?l001Wooooo00D00?l0oooooooooooooooo003o0003
ooooo`04003o0?oooooooooo003o01[ooooo00@00?l0ooooooooool00?l00oooool01@00o`3ooooo
ooooooooool00?l000oooooo00?o0000ooooooooool02oooool002Kooooo00?o0000ooooooooool0
5?ooool3o`00o`;ooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`03o`00oa?o
oooo0ol00?l2ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooo`00o`02o`00
oaCooooo0ol00?l2ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`03
o`00oaCooooo0ol00?l00ooooooo003oooooo`02ooooo`05o`00ooooooooooooooooool00?l00_oo
ool3o`00oa?ooooo0ol00?l2ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?oooooo
ooooo`03o`00o`[ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Dooooo`05003o
0?ooooooooooooooo`00o`000oooool01@00o`3oooooooooooooool00?l001Wooooo00D00?l0oooo
oooooooooooo003o0003ooooo`04003o0?oooooooooo003o01[ooooo00@00?l0ooooooooool00?l0
0oooool01@00o`3oooooooooooooool00?l001Wooooo00D00?l0oooooooooooooooo003o0003oooo
o`04003o0?oooooooooo003o01[ooooo00@00?l0ooooooooool00?l00oooool01@00o`3ooooooooo
ooooool00?l000oooooo00?o0000ooooooooool02oooool002Kooooo0_l0000Eooooo`?o003o0_oo
ool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo00?o003o4oooool3o`00o`;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo003o00;o003o5?ooool3o`00o`;o
oooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo00?o003o5?ooool3o`00
o`03ooooool00?oooooo00;ooooo00Go003oooooooooooooooooo`00o`02ooooo`?o003o4oooool3
o`00o`;ooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo00?o003o2_oo
ool00ol0003oooooooooo`0_ooooo`;o00005Oooool01@00o`3oooooooooooooool00?l000?ooooo
00D00?l0oooooooooooooooo003o000Iooooo`05003o0?ooooooooooooooo`00o`000oooool01000
o`3oooooooooo`00o`0Jooooo`04003o0?oooooooooo003o00?ooooo00D00?l0oooooooooooooooo
003o000Iooooo`05003o0?ooooooooooooooo`00o`000oooool01000o`3oooooooooo`00o`0Joooo
o`04003o0?oooooooooo003o00?ooooo00D00?l0oooooooooooooooo003o000>ooooo`;o00003Ooo
ool002Kooooo00?o0000ooooooooool05?ooool3o`00o`;ooooo00Co003ooooooooooooo003o0ooo
ool00ol00?ooooooooooo`03o`00oa?ooooo0ol00?l2ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooo`00o`02o`00oaCooooo0ol00?l2ooooo`05o`00ooooooooooooooooool0
0?l00_ooool00ol00?ooooooooooo`03o`00oaCooooo0ol00?l00ooooooo003oooooo`02ooooo`05
o`00ooooooooooooooooool00?l00_ooool3o`00oa?ooooo0ol00?l2ooooo`05o`00oooooooooooo
ooooool00?l00_ooool00ol00?ooooooooooo`03o`00o`[ooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`0Dooooo`05003o0?ooooooooooooooo`00o`000oooool01@00o`3ooooooooo
ooooool00?l001Wooooo00D00?l0oooooooooooooooo003o0003ooooo`04003o0?oooooooooo003o
01[ooooo00@00?l0ooooooooool00?l00oooool01@00o`3oooooooooooooool00?l001Wooooo00D0
0?l0oooooooooooooooo003o0003ooooo`04003o0?oooooooooo003o01[ooooo00@00?l0oooooooo
ool00?l00oooool01@00o`3oooooooooooooool00?l000oooooo00?o0000ooooooooool02oooool0
02Kooooo00?o0000ooooooooool05Oooool01Ol00?oooooooooooooooooo003o00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0Dooooo`05
o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooo
oooo01Cooooo00Co003ooooooooooooo003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool04oooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooo
oooo003o0oooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo02oooooo00?o0000oooo
ooooool05?ooool01@00o`3oooooooooooooool00?l000?ooooo00D00?l0oooooooooooooooo003o
000Iooooo`05003o0?ooooooooooooooo`00o`000oooool01000o`3oooooooooo`00o`0Jooooo`04
003o0?oooooooooo003o00?ooooo00D00?l0oooooooooooooooo003o000Iooooo`05003o0?oooooo
ooooooooo`00o`000oooool01000o`3oooooooooo`00o`0Jooooo`04003o0?oooooooooo003o00?o
oooo00D00?l0oooooooooooooooo003o000?ooooo`03o`000?oooooooooo00_ooooo000Vooooo`03
o`000?oooooooooo01Gooooo00Go003oooooooooooooooooo`00o`02ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`0Cooooo`05o`00ooooooooooooooooool00?l00ooo
ool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool05?ooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`0Doooo
o`04o`00ooooooooooooo`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo01?ooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`?o
oooo00?o003oooooooooool02Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Co
oooo00D00?l0oooooooooooooooo003o0003ooooo`05003o0?ooooooooooooooo`00o`006Oooool0
1@00o`3oooooooooooooool00?l000?ooooo00@00?l0ooooooooool00?l06_ooool01000o`3ooooo
ooooo`00o`03ooooo`05003o0?ooooooooooooooo`00o`006Oooool01@00o`3oooooooooooooool0
0?l000?ooooo00@00?l0ooooooooool00?l06_ooool01000o`3oooooooooo`00o`03ooooo`05003o
0?ooooooooooooooo`00o`003oooool00ol0003oooooooooo`0;ooooo`009_ooool00ol0003ooooo
ooooo`0Eooooo`05o`00ooooooooooooooooool00?l00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool04oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003o
ooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo01Cooooo00Go003ooooooooooooooooo
o`00o`03ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool05?ooool01?l00?oo
ooooooooool00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0C
ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`03o`00
oooooooooooo00Wooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Dooooo`05003o
0?ooooooooooooooo`00o`000oooool01@00o`3oooooooooooooool00?l001Wooooo00D00?l0oooo
oooooooooooo003o0003ooooo`04003o0?oooooooooo003o01[ooooo00@00?l0ooooooooool00?l0
0oooool01@00o`3oooooooooooooool00?l001Wooooo00D00?l0oooooooooooooooo003o0003oooo
o`04003o0?oooooooooo003o01[ooooo00@00?l0ooooooooool00?l00oooool01@00o`3ooooooooo
ooooool00?l000oooooo00?o0000ooooooooool02oooool002Kooooo00?o0000ooooooooool05Ooo
ool01Ol00?oooooooooooooooooo003o00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo01?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l00_ooool00ol00?ooooooooooo`0Dooooo`05o`00ooooooooooooooooool00?l00ooo
ool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo01Cooooo00Co003ooooooooooooo
003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool04oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooo003o0oooool00ol00?oooooooooo
o`09ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool05?ooool01@00o`3ooooooooo
ooooool00?l000?ooooo00D00?l0oooooooooooooooo003o000Iooooo`05003o0?oooooooooooooo
o`00o`000oooool01000o`3oooooooooo`00o`0Jooooo`04003o0?oooooooooo003o00?ooooo00D0
0?l0oooooooooooooooo003o000Iooooo`05003o0?ooooooooooooooo`00o`000oooool01000o`3o
ooooooooo`00o`0Jooooo`04003o0?oooooooooo003o00?ooooo00D00?l0oooooooooooooooo003o
000?ooooo`03o`000?oooooooooo00_ooooo000Vooooo`;o00005_ooool01Ol00?oooooooooooooo
oooo003o00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol0
0?ooooooooooo`0Dooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooool0
0?l3ooooo`03o`00oooooooooooo01Cooooo00Co003ooooooooooooo003o0oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool04oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`09ooooo`03o`000?oooooo
oooo02oooooo0_l0000Eooooo`05003o0?ooooooooooooooo`00o`000oooool01@00o`3ooooooooo
ooooool00?l001Wooooo00D00?l0oooooooooooooooo003o0003ooooo`04003o0?oooooooooo003o
01[ooooo00@00?l0ooooooooool00?l00oooool01@00o`3oooooooooooooool00?l001Wooooo00D0
0?l0oooooooooooooooo003o0003ooooo`04003o0?oooooooooo003o01[ooooo00@00?l0oooooooo
ool00?l00oooool01@00o`3oooooooooooooool00?l000kooooo0_l0000=ooooo`009_ooool00ol0
003oooooooooo`0Eooooo`05o`00ooooooooooooooooool00?l00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool04oooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo01Cooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool05?ooool0
1?l00?ooooooooooool00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`0Cooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooool00?l3oooo
o`03o`00oooooooooooo00Wooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Doooo
o`05003o0?ooooooooooooooo`00o`000oooool01@00o`3oooooooooooooool00?l001Wooooo00D0
0?l0oooooooooooooooo003o0003ooooo`04003o0?oooooooooo003o01[ooooo00@00?l0oooooooo
ool00?l00oooool01@00o`3oooooooooooooool00?l001Wooooo00D00?l0oooooooooooooooo003o
0003ooooo`04003o0?oooooooooo003o01[ooooo00@00?l0ooooooooool00?l00oooool01@00o`3o
ooooooooooooool00?l000oooooo00?o0000ooooooooool02oooool002Kooooo00?o0000oooooooo
ool05Oooool01Ol00?oooooooooooooooooo003o00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo01?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00_ooool00ol00?ooooooooooo`0Dooooo`05o`00ooooooooooooooooool0
0?l00oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo01Cooooo00Co003ooooo
oooooooo003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool04ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooo003o0oooool00ol00?oo
ooooooooo`09ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool05?ooool01@00o`3o
ooooooooooooool00?l000?ooooo00D00?l0oooooooooooooooo003o000Iooooo`05003o0?oooooo
ooooooooo`00o`000oooool01000o`3oooooooooo`00o`0Jooooo`04003o0?oooooooooo003o00?o
oooo00D00?l0oooooooooooooooo003o000Iooooo`05003o0?ooooooooooooooo`00o`000oooool0
1000o`3oooooooooo`00o`0Jooooo`04003o0?oooooooooo003o00?ooooo00D00?l0oooooooooooo
oooo003o000?ooooo`03o`000?oooooooooo00_ooooo000Vooooo`03o`000?oooooooooo01Gooooo
00Go003oooooooooooooooooo`00o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`0Cooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooo
oooo003o00;ooooo00?o003oooooooooool05?ooool01Ol00?oooooooooooooooooo003o00?ooooo
00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`0Dooooo`04o`00ooooooooooooo`00
o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool0
2Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Cooooo00D00?l0oooooooooooo
oooo003o0003ooooo`05003o0?ooooooooooooooo`00o`006Oooool01@00o`3oooooooooooooool0
0?l000?ooooo00@00?l0ooooooooool00?l06_ooool01000o`3oooooooooo`00o`03ooooo`05003o
0?ooooooooooooooo`00o`006Oooool01@00o`3oooooooooooooool00?l000?ooooo00@00?l0oooo
ooooool00?l06_ooool01000o`3oooooooooo`00o`03ooooo`05003o0?ooooooooooooooo`00o`00
3oooool00ol0003oooooooooo`0;ooooo`009_ooool00ol0003oooooooooo`0Eooooo`05o`00oooo
ooooooooooooool00?l00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool04oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`02
ooooo`03o`00oooooooooooo01Cooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00oooo
ooooooooo`00o`?ooooo00?o003oooooooooool05?ooool01?l00?ooooooooooool00?l3ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Cooooo`05o`00oooooooooooo
ooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo00Wooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`0Dooooo`05003o0?ooooooooooooooo`00o`00
0oooool01@00o`3oooooooooooooool00?l001Wooooo00D00?l0oooooooooooooooo003o0003oooo
o`04003o0?oooooooooo003o01[ooooo00@00?l0ooooooooool00?l00oooool01@00o`3ooooooooo
ooooool00?l001Wooooo00D00?l0oooooooooooooooo003o0003ooooo`04003o0?oooooooooo003o
01[ooooo00@00?l0ooooooooool00?l00oooool01@00o`3oooooooooooooool00?l000oooooo00?o
0000ooooooooool02oooool002Kooooo00?o0000ooooooooool05Oooool01Ol00?oooooooooooooo
oooo003o00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol0
0?ooooooooooo`0Dooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooool0
0?l3ooooo`03o`00oooooooooooo01Cooooo00Co003ooooooooooooo003o0oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool04oooool01Ol00?oooooooooooooooooo003o
00?ooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`09ooooo`03o`000?oooooo
oooo02oooooo00?o0000ooooooooool05?ooool01@00o`3oooooooooooooool00?l000?ooooo00D0
0?l0oooooooooooooooo003o000Iooooo`05003o0?ooooooooooooooo`00o`000oooool01000o`3o
ooooooooo`00o`0Jooooo`04003o0?oooooooooo003o00?ooooo00D00?l0oooooooooooooooo003o
000Iooooo`05003o0?ooooooooooooooo`00o`000oooool01000o`3oooooooooo`00o`0Jooooo`04
003o0?oooooooooo003o00?ooooo00D00?l0oooooooooooooooo003o000?ooooo`03o`000?oooooo
oooo00_ooooo000Vooooo`;o00005_ooool01Ol00?oooooooooooooooooo003o00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0Dooooo`05
o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooo
oooo01Cooooo00Co003ooooooooooooo003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool04oooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooo
oooo003o0oooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo02oooooo0_l0000Eoooo
o`05003o0?ooooooooooooooo`00o`000oooool01@00o`3oooooooooooooool00?l001Wooooo00D0
0?l0oooooooooooooooo003o0003ooooo`04003o0?oooooooooo003o01[ooooo00@00?l0oooooooo
ool00?l00oooool01@00o`3oooooooooooooool00?l001Wooooo00D00?l0oooooooooooooooo003o
0003ooooo`04003o0?oooooooooo003o01[ooooo00@00?l0ooooooooool00?l00oooool01@00o`3o
ooooooooooooool00?l000kooooo0_l0000=ooooo`009_ooool00ol0003oooooooooo`0Eooooo`05
o`00ooooooooooooooooool00?l00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool04oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooooooo
o`00o`02ooooo`03o`00oooooooooooo01Cooooo00Go003oooooooooooooooooo`00o`03ooooo`04
o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool05?ooool01?l00?ooooooooooool00?l3
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Cooooo`05o`00oooo
ooooooooooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo00Wo
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Dooooo`05003o0?oooooooooooooo
o`00o`000oooool01@00o`3oooooooooooooool00?l001Wooooo00D00?l0oooooooooooooooo003o
0003ooooo`04003o0?oooooooooo003o01[ooooo00@00?l0ooooooooool00?l00oooool01@00o`3o
ooooooooooooool00?l001Wooooo00D00?l0oooooooooooooooo003o0003ooooo`04003o0?oooooo
oooo003o01[ooooo00@00?l0ooooooooool00?l00oooool01@00o`3oooooooooooooool00?l000oo
oooo00?o0000ooooooooool02oooool002Kooooo00?o0000ooooooooool05Oooool01Ol00?oooooo
oooooooooooo003o00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
01?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00_oo
ool00ol00?ooooooooooo`0Dooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?oooooo
ooooool00?l3ooooo`03o`00oooooooooooo01Cooooo00Co003ooooooooooooo003o0oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool04oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`09ooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool05?ooool01@00o`3oooooooooooooool00?l000?o
oooo00D00?l0oooooooooooooooo003o000Iooooo`05003o0?ooooooooooooooo`00o`000oooool0
1000o`3oooooooooo`00o`0Jooooo`04003o0?oooooooooo003o00?ooooo00D00?l0oooooooooooo
oooo003o000Iooooo`05003o0?ooooooooooooooo`00o`000oooool01000o`3oooooooooo`00o`0J
ooooo`04003o0?oooooooooo003o00?ooooo00D00?l0oooooooooooooooo003o000?ooooo`03o`00
0?oooooooooo00_ooooo000Pooooo`;o00001?ooool00ol0003oooooooooo`0Eooooo`05o`00oooo
ooooooooooooool00?l00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool04oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`02
ooooo`03o`00oooooooooooo01Cooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00oooo
ooooooooo`00o`?ooooo00?o003oooooooooool05?ooool01?l00?ooooooooooool00?l3ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Cooooo`05o`00oooooooooooo
ooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo00Wooooo00?o
0000ooooooooool0:?ooool2o`0000Gooooo00?o0000ooooooooool05?ooool01@00o`3ooooooooo
ooooool00?l000?ooooo00D00?l0oooooooooooooooo003o000Iooooo`05003o0?oooooooooooooo
o`00o`000oooool01000o`3oooooooooo`00o`0Jooooo`04003o0?oooooooooo003o00?ooooo00D0
0?l0oooooooooooooooo003o000Iooooo`05003o0?ooooooooooooooo`00o`000oooool01000o`3o
ooooooooo`00o`0Jooooo`04003o0?oooooooooo003o00?ooooo00D00?l0oooooooooooooooo003o
000?ooooo`03o`000?oooooooooo00_ooooo000Oooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooooooool05Oooool01Ol00?oooooooooooooooooo003o00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo01?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0Dooooo`05o`00oooooooo
ooooooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo01Cooooo
00Co003ooooooooooooo003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool04oooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooo003o0ooo
ool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo02Oooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`0Dooooo`05003o0?ooooooooooooooo`00o`000oooool01@00o`3o
ooooooooooooool00?l001Wooooo00D00?l0oooooooooooooooo003o0003ooooo`04003o0?oooooo
oooo003o01[ooooo00@00?l0ooooooooool00?l00oooool01@00o`3oooooooooooooool00?l001Wo
oooo00D00?l0oooooooooooooooo003o0003ooooo`04003o0?oooooooooo003o01[ooooo00@00?l0
ooooooooool00?l00oooool01@00o`3oooooooooooooool00?l000oooooo00?o0000ooooooooool0
2oooool001oooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0Eooooo`05o`00
ooooooooooooooooool00?l00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool04oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`02ooooo`03o`00oooooooooooo01Cooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00
ooooooooooooo`00o`?ooooo00?o003oooooooooool05?ooool01?l00?ooooooooooool00?l3oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Cooooo`05o`00oooooooo
ooooooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo00Wooooo
00?o0000ooooooooool09oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo013o
oooo0ol0o`000oooool00?l0ooooo`02ooooo`05003o0?ooooooooooooooo`00o`000oooool00`00
o`3oooooo`3o0002o`3o013ooooo0ol0o`02ooooo`05003o0?ooooooooooooooo`00o`000oooool0
1000o`3oooooooooo`00o`02ooooo`?o0?l04?ooool3o`3o00;ooooo00@00?l0ooooooooool00?l0
0oooool01@00o`3oooooooooooooool00?l000;ooooo0ol0o`0?ooooo`?o0?l00_ooool01@00o`3o
ooooooooooooool00?l000?ooooo00@00?l0ooooooooool00?l00_ooool3o`3o013ooooo0ol0o`02
ooooo`04003o0?oooooooooo003o00?ooooo00D00?l0oooooooooooooooo003o0002ooooo`?o0?l0
2_ooool00ol0003oooooooooo`0;ooooo`007oooool01?l0003oooooooooool00003ooooo`03o`00
00000000000000Kooooo00Go003oooooooooooooooooo`00o`02ooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`02ooooo`05o`00ooooooooooooooooool00?l00oooool0
1Ol00?oooooooooooooooooo003o00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`04o`00ooooooooooooo`00o`?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`04o`00ooooooooooooo`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00oooo
ooooooooo`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooo`00
o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo00;o0000:Oooool01?l0003ooooo
ooooool00004ooooo`;o00000oooool01?l0o`3oooooooooool0o`03ooooo`05o`3o0?oooooooooo
ooooool0o`000_ooool3o`3o0003ooooo`00o`3ooooo00;ooooo00D00?l0oooooooooooooooo003o
0003ooooo`03003o0?oooooo0?l000;o0?l00_ooool01@00o`3oooooooooooooool00?l000?ooooo
00H00?l0oooooooooooooooo003o0?ooool3o`3o00;ooooo00D00?l0oooooooooooooooo003o0003
ooooo`04003o0?oooooooooo003o00;ooooo0ol0o`02ooooo`05003o0?ooooooooooooooo`00o`00
0_ooool01@00o`3oooooooooooooool00?l000;ooooo0ol0o`02ooooo`04003o0?oooooooooo003o
00?ooooo00D00?l0oooooooooooooooo003o0002ooooo`?o0?l000?ooooo003o0?ooool00_ooool0
1@00o`3oooooooooooooool00?l000?ooooo00<00?l0ooooool0o`000_l0o`02ooooo`05003o0?oo
ooooooooooooo`00o`000oooool01000o`3oooooooooo`00o`02ooooo`?o0?l00_ooool01@00o`3o
ooooooooooooool00?l000;ooooo00D00?l0oooooooooooooooo003o0002ooooo`?o0?l00_ooool0
1000o`3oooooooooo`00o`03ooooo`05003o0?ooooooooooooooo`00o`000_ooool3o`3o00;ooooo
00<00?l0ooooooooool01?ooool2o`0000gooooo000Oooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool01_ooool01Ol00?oooooooooooooooooo003o00;ooooo00Go003ooooooooo
ooooooooo`00o`0Fooooo`04o`00ooooooooooooo`00o`?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo01?ooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00
ooooooooooooo`00o`?ooooo00?o003oooooooooool05?ooool01Ol00?oooooooooooooooooo003o
00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?oooooo
ooooo`0Dooooo`05o`00ooooooooooooooooool00?l00oooool00ol0003oooooooooo`0Wooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_ooool01?l0o`3oooooooooool0o`03
ooooo`05o`3o0?ooooooooooooooool0o`000_ooool3o`3o00oooooo0ol0o`02ooooo`05003o0?oo
ooooooooooooo`00o`000oooool01P00o`3oooooooooooooool00?l0ooooo`?o0?l04?ooool3o`3o
00;ooooo00D00?l0oooooooooooooooo003o0002ooooo`05003o0?ooooooooooooooo`00o`000_oo
ool3o`3o013ooooo0ol0o`000oooool00?l0ooooo`02ooooo`05003o0?ooooooooooooooo`00o`00
0oooool00`00o`3oooooo`3o0002o`3o013ooooo0ol0o`02ooooo`05003o0?ooooooooooooooo`00
o`000_ooool01@00o`3oooooooooooooool00?l000;ooooo0ol0o`0@ooooo`?o0?l00_ooool00`00
o`3oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo000Oooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool01_ooool01Ol00?oooooooooooooooooo003o00;ooooo00Go003o
ooooooooooooooooo`00o`0Fooooo`04o`00ooooooooooooo`00o`?ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo01?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool05?ooool01Ol00?oooooooooooooo
oooo003o00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol0
0?ooooooooooo`0Dooooo`05o`00ooooooooooooooooool00?l00oooool00ol0003oooooooooo`0W
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_ooool01?l0o`3ooooooooo
ool0o`03ooooo`05o`3o0?ooooooooooooooool0o`006Oooool01@00o`3oooooooooooooool00?l0
00?ooooo00D00?l0oooooooooooooooo003o000Iooooo`05003o0?ooooooooooooooo`00o`000_oo
ool01@00o`3oooooooooooooool00?l001Wooooo00D00?l0oooooooooooooooo003o0003ooooo`05
003o0?ooooooooooooooo`00o`006Oooool01@00o`3oooooooooooooool00?l000;ooooo00D00?l0
oooooooooooooooo003o000Jooooo`03003o0?oooooooooo00Gooooo00?o0000ooooooooool02ooo
ool0023ooooo0_l00004ooooo`03o`000?oooooooooo00Kooooo00Go003oooooooooooooooooo`00
o`02ooooo`05o`00ooooooooooooooooool00?l05_ooool01?l00?ooooooooooool00?l3ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Cooooo`05o`00oooooooooooo
ooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo01Cooooo00Go
003oooooooooooooooooo`00o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`0Cooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00;ooooo00?o003oooooooooool05?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
0000ooooooooool0:?ooool2o`0000Gooooo00?o0000ooooooooool00_ooool01?l0o`3ooooooooo
ool0o`03ooooo`05o`3o0?ooooooooooooooool0o`006Oooool01@00o`3oooooooooooooool00?l0
00?ooooo00D00?l0oooooooooooooooo003o000Iooooo`05003o0?ooooooooooooooo`00o`000_oo
ool01@00o`3oooooooooooooool00?l001Wooooo00D00?l0oooooooooooooooo003o0003ooooo`05
003o0?ooooooooooooooo`00o`006Oooool01@00o`3oooooooooooooool00?l000;ooooo00D00?l0
oooooooooooooooo003o000Jooooo`03003o0?oooooooooo00Gooooo00?o0000ooooooooool02ooo
ool002Kooooo00?o0000ooooooooool01_ooool01Ol00?oooooooooooooooooo003o00;ooooo00Go
003oooooooooooooooooo`00o`0Fooooo`04o`00ooooooooooooo`00o`?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo01?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool05?ooool01Ol00?oooooooooo
oooooooo003o00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00_ooool0
0ol00?ooooooooooo`0Dooooo`05o`00ooooooooooooooooool00?l00oooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo00;ooooo00Co0?l0oooooooooooo0?l00oooool01Ol0o`3ooooo
oooooooooooo0?l001Wooooo00D00?l0oooooooooooooooo003o0003ooooo`05003o0?oooooooooo
ooooo`00o`006Oooool01@00o`3oooooooooooooool00?l000;ooooo00D00?l0oooooooooooooooo
003o000Iooooo`05003o0?ooooooooooooooo`00o`000oooool01@00o`3oooooooooooooool00?l0
01Wooooo00D00?l0oooooooooooooooo003o0002ooooo`05003o0?ooooooooooooooo`00o`006_oo
ool00`00o`3oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo000Vooooo`03o`000?oooooo
oooo00Kooooo00Go003oooooooooooooooooo`00o`02ooooo`05o`00ooooooooooooooooool00?l0
5_ooool01?l00?ooooooooooool00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`0Cooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooool0
0?l3ooooo`03o`00oooooooooooo01Cooooo00Go003oooooooooooooooooo`00o`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Cooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool05?ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o0000ooooooooool0;oooool00ol0003ooooooooo
o`02ooooo`04o`3o0?ooooooooooo`3o00?ooooo00Go0?l0ooooooooooooooooo`3o000Iooooo`05
003o0?ooooooooooooooo`00o`000oooool01@00o`3oooooooooooooool00?l001Wooooo00D00?l0
oooooooooooooooo003o0002ooooo`05003o0?ooooooooooooooo`00o`006Oooool01@00o`3ooooo
ooooooooool00?l000?ooooo00D00?l0oooooooooooooooo003o000Iooooo`05003o0?oooooooooo
ooooo`00o`000_ooool01@00o`3oooooooooooooool00?l001[ooooo00<00?l0ooooooooool01Ooo
ool00ol0003oooooooooo`0;ooooo`009_ooool2o`0000Oooooo00Go003oooooooooooooooooo`00
o`02ooooo`05o`00ooooooooooooooooool00?l05_ooool01?l00?ooooooooooool00?l3ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Cooooo`05o`00oooooooooooo
ooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo01Cooooo00Go
003oooooooooooooooooo`00o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`0Cooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00;ooooo00?o003oooooooooool05?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
0000ooooooooool0;oooool2o`0000?ooooo00Co0?l0oooooooooooo0?l00oooool01Ol0o`3ooooo
oooooooooooo0?l001Wooooo00D00?l0oooooooooooooooo003o0003ooooo`05003o0?oooooooooo
ooooo`00o`006Oooool01@00o`3oooooooooooooool00?l000;ooooo00D00?l0oooooooooooooooo
003o000Iooooo`05003o0?ooooooooooooooo`00o`000oooool01@00o`3oooooooooooooool00?l0
01Wooooo00D00?l0oooooooooooooooo003o0002ooooo`05003o0?ooooooooooooooo`00o`006_oo
ool00`00o`3oooooooooo`04ooooo`;o00003Oooool002Kooooo00?o0000ooooooooool01_ooool0
1Ol00?oooooooooooooooooo003o00;ooooo00Go003oooooooooooooooooo`00o`0Fooooo`04o`00
ooooooooooooo`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
01?ooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`?ooooo00?o
003oooooooooool05?ooool01Ol00?oooooooooooooooooo003o00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo01?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0Dooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00;ooooo00Co
0?l0oooooooooooo0?l00oooool01Ol0o`3ooooooooooooooooo0?l001Wooooo00D00?l0oooooooo
oooooooo003o0003ooooo`05003o0?ooooooooooooooo`00o`006Oooool01@00o`3ooooooooooooo
ool00?l000;ooooo00D00?l0oooooooooooooooo003o000Iooooo`05003o0?ooooooooooooooo`00
o`000oooool01@00o`3oooooooooooooool00?l001Wooooo00D00?l0oooooooooooooooo003o0002
ooooo`05003o0?ooooooooooooooo`00o`006_ooool00`00o`3oooooooooo`05ooooo`03o`000?oo
oooooooo00_ooooo000Vooooo`03o`000?oooooooooo00Kooooo00Go003oooooooooooooooooo`00
o`02ooooo`05o`00ooooooooooooooooool00?l05_ooool01?l00?ooooooooooool00?l3ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Cooooo`05o`00oooooooooooo
ooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo01Cooooo00Go
003oooooooooooooooooo`00o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`0Cooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00;ooooo00?o003oooooooooool05?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`02ooooo`04o`3o0?ooooooooooo`3o00?ooooo
00Go0?l0ooooooooooooooooo`3o000Iooooo`05003o0?ooooooooooooooo`00o`000oooool01@00
o`3oooooooooooooool00?l001Wooooo00D00?l0oooooooooooooooo003o0002ooooo`05003o0?oo
ooooooooooooo`00o`006Oooool01@00o`3oooooooooooooool00?l000?ooooo00D00?l0oooooooo
oooooooo003o000Iooooo`05003o0?ooooooooooooooo`00o`000_ooool01@00o`3ooooooooooooo
ool00?l001[ooooo00<00?l0ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`009_ooool0
0ol0003oooooooooo`06ooooo`05o`00ooooooooooooooooool00?l00_ooool01Ol00?oooooooooo
oooooooo003o01Kooooo00Co003ooooooooooooo003o0oooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool04oooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003o
oooooooooooo003o0oooool00ol00?ooooooooooo`0Dooooo`05o`00ooooooooooooooooool00?l0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool04oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooo
oooo01Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool00_ooool01?l0o`3oooooooooool0o`03ooooo`05o`3o0?ooooooooooooooool0
o`006Oooool01@00o`3oooooooooooooool00?l000?ooooo00D00?l0oooooooooooooooo003o000I
ooooo`05003o0?ooooooooooooooo`00o`000_ooool01@00o`3oooooooooooooool00?l001Wooooo
00D00?l0oooooooooooooooo003o0003ooooo`05003o0?ooooooooooooooo`00o`006Oooool01@00
o`3oooooooooooooool00?l000;ooooo00D00?l0oooooooooooooooo003o000Jooooo`03003o0?oo
oooooooo00Gooooo00?o0000ooooooooool02oooool002Kooooo00?o0000ooooooooool01_ooool0
1Ol00?oooooooooooooooooo003o00;ooooo00Go003oooooooooooooooooo`00o`0Fooooo`04o`00
ooooooooooooo`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo
01?ooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`?ooooo00?o
003oooooooooool05?ooool01Ol00?oooooooooooooooooo003o00;ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo01?ooooo00Go003oooooooooooooooooo`00o`03oooo
o`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0Dooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00;ooooo00Co
0?l0oooooooooooo0?l00oooool01Ol0o`3ooooooooooooooooo0?l001Wooooo00D00?l0oooooooo
oooooooo003o0003ooooo`05003o0?ooooooooooooooo`00o`006Oooool01@00o`3ooooooooooooo
ool00?l000;ooooo00D00?l0oooooooooooooooo003o000Iooooo`05003o0?ooooooooooooooo`00
o`000oooool01@00o`3oooooooooooooool00?l001Wooooo00D00?l0oooooooooooooooo003o0002
ooooo`05003o0?ooooooooooooooo`00o`006_ooool00`00o`3oooooooooo`05ooooo`03o`000?oo
oooooooo00_ooooo000Vooooo`03o`000?oooooooooo00Kooooo00Go003oooooooooooooooooo`00
o`02ooooo`05o`00ooooooooooooooooool00?l05_ooool01?l00?ooooooooooool00?l3ooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Cooooo`05o`00oooooooooooo
ooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo01Cooooo00Go
003oooooooooooooooooo`00o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`0Cooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00;ooooo00?o003oooooooooool05?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`02ooooo`04o`3o0?ooooooooooo`3o00?ooooo
00Go0?l0ooooooooooooooooo`3o000Iooooo`05003o0?ooooooooooooooo`00o`000oooool01@00
o`3oooooooooooooool00?l001Wooooo00D00?l0oooooooooooooooo003o0002ooooo`05003o0?oo
ooooooooooooo`00o`006Oooool01@00o`3oooooooooooooool00?l000?ooooo00D00?l0oooooooo
oooooooo003o000Iooooo`05003o0?ooooooooooooooo`00o`000_ooool01@00o`3ooooooooooooo
ool00?l001[ooooo00<00?l0ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`009_ooool2
o`0000Oooooo00Go003oooooooooooooooooo`00o`02ooooo`05o`00ooooooooooooooooool00?l0
5_ooool01?l00?ooooooooooool00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`0Cooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooool0
0?l3ooooo`03o`00oooooooooooo01Cooooo00Go003oooooooooooooooooo`00o`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Cooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool05?ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o0000ooooooooool0;oooool2o`0000?ooooo00Co
0?l0oooooooooooo0?l00oooool01Ol0o`3ooooooooooooooooo0?l001Wooooo00D00?l0oooooooo
oooooooo003o0003ooooo`05003o0?ooooooooooooooo`00o`006Oooool01@00o`3ooooooooooooo
ool00?l000;ooooo00D00?l0oooooooooooooooo003o000Iooooo`05003o0?ooooooooooooooo`00
o`000oooool01@00o`3oooooooooooooool00?l001Wooooo00D00?l0oooooooooooooooo003o0002
ooooo`05003o0?ooooooooooooooo`00o`006_ooool00`00o`3oooooooooo`04ooooo`;o00003Ooo
ool002Kooooo00?o0000ooooooooool01_ooool01Ol00?oooooooooooooooooo003o00;ooooo00Go
003oooooooooooooooooo`00o`0Fooooo`04o`00ooooooooooooo`00o`?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo01?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool05?ooool01Ol00?oooooooooo
oooooooo003o00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00_ooool0
0ol00?ooooooooooo`0Dooooo`05o`00ooooooooooooooooool00?l00oooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo00;ooooo00Co0?l0oooooooooooo0?l00oooool01Ol0o`3ooooo
oooooooooooo0?l001Wooooo00D00?l0oooooooooooooooo003o0003ooooo`05003o0?oooooooooo
ooooo`00o`006Oooool01@00o`3oooooooooooooool00?l000;ooooo00D00?l0oooooooooooooooo
003o000Iooooo`05003o0?ooooooooooooooo`00o`000oooool01@00o`3oooooooooooooool00?l0
01Wooooo00D00?l0oooooooooooooooo003o0002ooooo`05003o0?ooooooooooooooo`00o`006_oo
ool00`00o`3oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo000Vooooo`03o`000?oooooo
oooo00Kooooo00Go003oooooooooooooooooo`00o`02ooooo`05o`00ooooooooooooooooool00?l0
5_ooool01?l00?ooooooooooool00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`0Cooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooool0
0?l3ooooo`03o`00oooooooooooo01Cooooo00Go003oooooooooooooooooo`00o`02ooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Cooooo`05o`00oooooooooooooooo
ool00?l00oooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool05?ooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o0000ooooooooool0;oooool00ol0003ooooooooo
o`02ooooo`04o`3o0?ooooooooooo`3o00?ooooo00Go0?l0ooooooooooooooooo`3o000Iooooo`05
003o0?ooooooooooooooo`00o`000oooool01@00o`3oooooooooooooool00?l001Wooooo00D00?l0
oooooooooooooooo003o0002ooooo`05003o0?ooooooooooooooo`00o`006Oooool01@00o`3ooooo
ooooooooool00?l000?ooooo00D00?l0oooooooooooooooo003o000Iooooo`05003o0?oooooooooo
ooooo`00o`000_ooool01@00o`3oooooooooooooool00?l001[ooooo00<00?l0ooooooooool01Ooo
ool00ol0003oooooooooo`0;ooooo`009_ooool00ol0003oooooooooo`06ooooo`05o`00oooooooo
ooooooooool00?l00_ooool01Ol00?oooooooooooooooooo003o01Kooooo00Co003ooooooooooooo
003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool04oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooo003o0oooool00ol00?oooooooooo
o`0Dooooo`05o`00ooooooooooooooooool00?l00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool04oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`02ooooo`03o`00oooooooooooo01Cooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool00_ooool01?l0o`3ooooooooo
ool0o`03ooooo`05o`3o0?ooooooooooooooool0o`006Oooool01@00o`3oooooooooooooool00?l0
00?ooooo00D00?l0oooooooooooooooo003o000Iooooo`05003o0?ooooooooooooooo`00o`000_oo
ool01@00o`3oooooooooooooool00?l001Wooooo00D00?l0oooooooooooooooo003o0003ooooo`05
003o0?ooooooooooooooo`00o`006Oooool01@00o`3oooooooooooooool00?l000;ooooo00D00?l0
oooooooooooooooo003o000Jooooo`03003o0?oooooooooo00Gooooo00?o0000ooooooooool02ooo
ool002Kooooo00?o0000ooooooooool01_ooool01Ol00?oooooooooooooooooo003o00;ooooo00Go
003oooooooooooooooooo`00o`0Fooooo`04o`00ooooooooooooo`00o`?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo01?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool05?ooool01Ol00?oooooooooo
oooooooo003o00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00_ooool0
0ol00?ooooooooooo`0Dooooo`05o`00ooooooooooooooooool00?l00oooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo00;ooooo00Co0?l0oooooooooooo0?l00oooool01Ol0o`3ooooo
oooooooooooo0?l001Wooooo00D00?l0oooooooooooooooo003o0003ooooo`05003o0?oooooooooo
ooooo`00o`006Oooool01@00o`3oooooooooooooool00?l000;ooooo00D00?l0oooooooooooooooo
003o000Iooooo`05003o0?ooooooooooooooo`00o`000oooool01@00o`3oooooooooooooool00?l0
01Wooooo00D00?l0oooooooooooooooo003o0002ooooo`05003o0?ooooooooooooooo`00o`006_oo
ool00`00o`3oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo000Vooooo`03o`000?oooooo
oooo00Kooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo00?o003o5?oo
ool3o`00o`03ooooool00?oooooo00;ooooo00Go003oooooooooooooooooo`00o`02ooooo`?o003o
4oooool3o`00o`;ooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo00?o
003o5?ooool3o`00o`;ooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`03o`00
oa?ooooo0ol00?l2ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooo`00o`02
o`00oaCooooo0ol00?l2ooooo`05o`00ooooooooooooooooool00000<Oooool00ol0003ooooooooo
o`02ooooo`04o`3o0?ooooooooooo`3o00?ooooo00Go0?l0ooooooooooooooooo`3o000Iooooo`05
003o0?ooooooooooooooo`00o`000oooool01@00o`3oooooooooooooool00?l001Wooooo00D00?l0
oooooooooooooooo003o0002ooooo`05003o0?ooooooooooooooo`00o`006Oooool01@00o`3ooooo
ooooooooool00?l000?ooooo00D00?l0oooooooooooooooo003o000Iooooo`05003o0?oooooooooo
ooooo`00o`000_ooool01@00o`3oooooooooooooool00?l001[ooooo00<00?l0ooooooooool01Ooo
ool00ol0003oooooooooo`0;ooooo`009_ooool2o`0000Oooooo00Go003oooooooooooooooooo`00
o`02ooooo`03o`00oooooooooooo00?o003o5?ooool3o`00o`03ooooool00?oooooo00;ooooo00Go
003oooooooooooooooooo`00o`02ooooo`?o003o4oooool3o`00o`;ooooo00Go003ooooooooooooo
ooooo`00o`02ooooo`03o`00oooooooooooo00?o003o5?ooool3o`00o`;ooooo00Co003ooooooooo
oooo003o0oooool00ol00?ooooooooooo`03o`00oa?ooooo0ol00?l2ooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooo`00o`02o`00oaCooooo0ol00?l2ooooo`05o`00oooooooo
ooooooooool00000<Oooool2o`0000?ooooo00Co0?l0oooooooooooo0?l00oooool01Ol0o`3ooooo
oooooooooooo0?l001Wooooo00D00?l0oooooooooooooooo003o0003ooooo`05003o0?oooooooooo
ooooo`00o`006Oooool01@00o`3oooooooooooooool00?l000;ooooo00D00?l0oooooooooooooooo
003o000Iooooo`05003o0?ooooooooooooooo`00o`000oooool01@00o`3oooooooooooooool00?l0
01Wooooo00D00?l0oooooooooooooooo003o0002ooooo`05003o0?ooooooooooooooo`00o`006_oo
ool00`00o`3oooooooooo`04ooooo`;o00003Oooool002Kooooo00?o0000ooooooooool01_ooool0
1Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool00ol00?lDooooo`?o003o00?o
ooooo`00ooooool00_ooool01Ol00?oooooooooooooooooo003o00;ooooo0ol00?lCooooo`?o003o
0_ooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool00ol00?lDooooo`?o
003o0_ooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo00?o003o4oooool3o`00
o`;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo003o00;o003o5?ooool3
o`00o`;ooooo00Go003oooooooooooooooooo`00000aooooo`03o`000?oooooooooo00;ooooo00Co
0?l0oooooooooooo0?l00oooool01Ol0o`3ooooooooooooooooo0?l001Wooooo00D00?l0oooooooo
oooooooo003o0003ooooo`05003o0?ooooooooooooooo`00o`006Oooool01@00o`3ooooooooooooo
ool00?l000;ooooo00D00?l0oooooooooooooooo003o000Iooooo`05003o0?ooooooooooooooo`00
o`000oooool01@00o`3oooooooooooooool00?l001Wooooo00D00?l0oooooooooooooooo003o0002
ooooo`05003o0?ooooooooooooooo`00o`006_ooool00`00o`3oooooooooo`05ooooo`03o`000?oo
oooooooo00_ooooo000Vooooo`03o`000?oooooooooo00Kooooo00Go003oooooooooooooooooo`00
o`02ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo01co
oooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`0Kooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00000<Ooo
ool00ol0003oooooooooo`02ooooo`04o`3o0?ooooooooooo`3o00?ooooo00Go0?l0oooooooooooo
ooooo`3o000Iooooo`05003o0?ooooooooooooooo`00o`000oooool01@00o`3oooooooooooooool0
0?l001Wooooo00D00?l0oooooooooooooooo003o0002ooooo`05003o0?ooooooooooooooo`00o`00
6Oooool01@00o`3oooooooooooooool00?l000?ooooo00D00?l0oooooooooooooooo003o000Ioooo
o`05003o0?ooooooooooooooo`00o`000_ooool01@00o`3oooooooooooooool00?l001[ooooo00<0
0?l0ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`009_ooool00ol0003oooooooooo`06
ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0Kooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool0
0?l00_ooool00ol00?ooooooooooo`0Looooo`04o`00ooooooooooooo`00o`?ooooo00?o003ooooo
ooooool06oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06oooool0
1Ol00?oooooooooooooooooo0000037ooooo00?o0000ooooooooool00_ooool01?l0o`3ooooooooo
ool0o`03ooooo`05o`3o0?ooooooooooooooool0o`006Oooool01@00o`3oooooooooooooool00?l0
00?ooooo00D00?l0oooooooooooooooo003o000Iooooo`05003o0?ooooooooooooooo`00o`000_oo
ool01@00o`3oooooooooooooool00?l001Wooooo00D00?l0oooooooooooooooo003o0003ooooo`05
003o0?ooooooooooooooo`00o`006Oooool01@00o`3oooooooooooooool00?l000;ooooo00D00?l0
oooooooooooooooo003o000Jooooo`03003o0?oooooooooo00Gooooo00?o0000ooooooooool02ooo
ool002Kooooo00?o0000ooooooooool01_ooool01Ol00?oooooooooooooooooo003o00;ooooo00?o
003oooooooooool06oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
6oooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool07?ooool01?l00?oo
ooooooooool00?l3ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00000aooooo`03o`000?oo
oooooooo00;ooooo00Co0?l0oooooooooooo0?l00oooool01Ol0o`3ooooooooooooooooo0?l001Wo
oooo00D00?l0oooooooooooooooo003o0003ooooo`05003o0?ooooooooooooooo`00o`006Oooool0
1@00o`3oooooooooooooool00?l000;ooooo00D00?l0oooooooooooooooo003o000Iooooo`05003o
0?ooooooooooooooo`00o`000oooool01@00o`3oooooooooooooool00?l001Wooooo00D00?l0oooo
oooooooooooo003o0002ooooo`05003o0?ooooooooooooooo`00o`006_ooool00`00o`3ooooooooo
o`05ooooo`03o`000?oooooooooo00_ooooo000Vooooo`03o`000?oooooooooo00Kooooo00Go003o
ooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo01_ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`02ooooo`03
o`00oooooooooooo01cooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`0Koooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`05o`00oooooooo
ooooooooool00000<Oooool00ol0003oooooooooo`02ooooo`04o`3o0?ooooooooooo`3o00?ooooo
00Go0?l0ooooooooooooooooo`3o000Iooooo`05003o0?ooooooooooooooo`00o`000oooool01@00
o`3oooooooooooooool00?l001Wooooo00D00?l0oooooooooooooooo003o0002ooooo`05003o0?oo
ooooooooooooo`00o`006Oooool01@00o`3oooooooooooooool00?l000?ooooo00D00?l0oooooooo
oooooooo003o000Iooooo`05003o0?ooooooooooooooo`00o`000_ooool01@00o`3ooooooooooooo
ool00?l001[ooooo00<00?l0ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`009_ooool2
o`0000Oooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo01_ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01_ooooo00Go003ooooooooooooo
ooooo`00o`02ooooo`03o`00oooooooooooo01cooooo00Co003ooooooooooooo003o0oooool00ol0
0?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0K
ooooo`05o`00ooooooooooooooooool00000<Oooool2o`0000?ooooo00Co0?l0oooooooooooo0?l0
0oooool01Ol0o`3ooooooooooooooooo0?l001Wooooo00D00?l0oooooooooooooooo003o0003oooo
o`05003o0?ooooooooooooooo`00o`006Oooool01@00o`3oooooooooooooool00?l000;ooooo00D0
0?l0oooooooooooooooo003o000Iooooo`05003o0?ooooooooooooooo`00o`000oooool01@00o`3o
ooooooooooooool00?l001Wooooo00D00?l0oooooooooooooooo003o0002ooooo`05003o0?oooooo
ooooooooo`00o`006_ooool00`00o`3oooooooooo`04ooooo`;o00003Oooool002Kooooo00?o0000
ooooooooool01_ooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool06ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06oooool01Ol00?oooooo
oooooooooooo003o00;ooooo00?o003oooooooooool07?ooool01?l00?ooooooooooool00?l3oooo
o`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo01_ooooo00Go003oooooooooooooooooo`00000aooooo`03o`000?oooooooooo00;ooooo00Co
0?l0oooooooooooo0?l00oooool01Ol0o`3ooooooooooooooooo0?l001Wooooo00D00?l0oooooooo
oooooooo003o0003ooooo`05003o0?ooooooooooooooo`00o`006Oooool01@00o`3ooooooooooooo
ool00?l000;ooooo00D00?l0oooooooooooooooo003o000Iooooo`05003o0?ooooooooooooooo`00
o`000oooool01@00o`3oooooooooooooool00?l001Wooooo00D00?l0oooooooooooooooo003o0002
ooooo`05003o0?ooooooooooooooo`00o`006_ooool00`00o`3oooooooooo`05ooooo`03o`000?oo
oooooooo00_ooooo000Vooooo`03o`000?oooooooooo00Kooooo00Go003oooooooooooooooooo`00
o`02ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo01co
oooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`0Kooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00000<Ooo
ool00ol0003oooooooooo`02ooooo`04o`3o0?ooooooooooo`3o00?ooooo00Go0?l0oooooooooooo
ooooo`3o000Iooooo`05003o0?ooooooooooooooo`00o`000oooool01@00o`3oooooooooooooool0
0?l001Wooooo00D00?l0oooooooooooooooo003o0002ooooo`05003o0?ooooooooooooooo`00o`00
6Oooool01@00o`3oooooooooooooool00?l000?ooooo00D00?l0oooooooooooooooo003o000Ioooo
o`05003o0?ooooooooooooooo`00o`000_ooool01@00o`3oooooooooooooool00?l001[ooooo00<0
0?l0ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`005?ooool2o`0000Cooooo00?o0000
ooooooooool00_ooool3o`0000Cooooo00?o0000ooooooooool01_ooool01Ol00?oooooooooooooo
oooo003o00;ooooo00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003ooooooooo
ool07?ooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo01_ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00
000Nooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003ooooooooo
o`02ooooo`04o`3o0?ooooooooooo`3o00?ooooo00Go0?l0ooooooooooooooooo`3o000Iooooo`05
003o0?ooooooooooooooo`00o`000oooool01@00o`3oooooooooooooool00?l001Wooooo00D00?l0
oooooooooooooooo003o0002ooooo`05003o0?ooooooooooooooo`00o`006Oooool01@00o`3ooooo
ooooooooool00?l000?ooooo00D00?l0oooooooooooooooo003o000Iooooo`05003o0?oooooooooo
ooooo`00o`000_ooool01@00o`3oooooooooooooool00?l001[ooooo00<00?l0ooooooooool01Ooo
ool00ol0003oooooooooo`0;ooooo`004oooool01?l0003oooooooooool00007ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`06ooooo`05o`00ooooooooooooooooool0
0?l00_ooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0L
ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool06oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo000001go
oooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000
ooooooooool00_ooool01?l0o`3oooooooooool0o`03ooooo`05o`3o0?ooooooooooooooool0o`00
6Oooool01@00o`3oooooooooooooool00?l000?ooooo00D00?l0oooooooooooooooo003o000Ioooo
o`05003o0?ooooooooooooooo`00o`000_ooool01@00o`3oooooooooooooool00?l001Wooooo00D0
0?l0oooooooooooooooo003o0003ooooo`05003o0?ooooooooooooooo`00o`006Oooool01@00o`3o
ooooooooooooool00?l000;ooooo00D00?l0oooooooooooooooo003o000Jooooo`03003o0?oooooo
oooo00Gooooo00?o0000ooooooooool02oooool001?ooooo00Co0000oooooooooooo00002oooool0
1?l0003oooooooooooooool3o`0000Kooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00
oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01_o
oooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo01cooooo00Co003ooooo
oooooooo003o0oooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00;o00007Oooool01?l0003ooooooooo
ool0000;ooooo`03o`000?oooooooooo00;ooooo0_l00003ooooo`04o`3o0?ooooooooooo`3o00?o
oooo00Go0?l0ooooooooooooooooo`3o000Iooooo`05003o0?ooooooooooooooo`00o`000oooool0
1@00o`3oooooooooooooool00?l001Wooooo00D00?l0oooooooooooooooo003o0002ooooo`05003o
0?ooooooooooooooo`00o`006Oooool01@00o`3oooooooooooooool00?l000?ooooo00D00?l0oooo
oooooooooooo003o000Iooooo`05003o0?ooooooooooooooo`00o`000_ooool01@00o`3ooooooooo
ooooool00?l001[ooooo00<00?l0ooooooooool01?ooool2o`0000gooooo000Cooooo`04o`000?oo
ooooooooo`0000_ooooo00Go0000ooooooooooooooooo`000008ooooo`05o`00oooooooooooooooo
ool00?l00_ooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?oooooooooo
o`0Looooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool06oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo0000
01gooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00Co0?l0oooooooooooo0?l00oooool01Ol0o`3ooooooooooooooooo0?l001Wooooo
00D00?l0oooooooooooooooo003o0003ooooo`05003o0?ooooooooooooooo`00o`006Oooool01@00
o`3oooooooooooooool00?l000;ooooo00D00?l0oooooooooooooooo003o000Iooooo`05003o0?oo
ooooooooooooo`00o`000oooool01@00o`3oooooooooooooool00?l001Wooooo00D00?l0oooooooo
oooooooo003o0002ooooo`05003o0?ooooooooooooooo`00o`006_ooool00`00o`3oooooooooo`05
ooooo`03o`000?oooooooooo00_ooooo000Cooooo`04o`000?ooooooooooo`0000Oooooo1?l00004
ooooo`03o`000?oooooooooo00Kooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooo
oooooooo01_ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01_ooooo
00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo01cooooo00Co003ooooooooo
oooo003o0oooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool000007Oooool01?l0003ooooooooo
ool00007ooooo`Co00001Oooool00ol0003oooooooooo`02ooooo`04o`3o0?ooooooooooo`3o00?o
oooo00Go0?l0ooooooooooooooooo`3o000Iooooo`05003o0?ooooooooooooooo`00o`000oooool0
1@00o`3oooooooooooooool00?l001Wooooo00D00?l0oooooooooooooooo003o0002ooooo`05003o
0?ooooooooooooooo`00o`006Oooool01@00o`3oooooooooooooool00?l000?ooooo00D00?l0oooo
oooooooooooo003o000Iooooo`05003o0?ooooooooooooooo`00o`000_ooool01@00o`3ooooooooo
ooooool00?l001[ooooo00<00?l0ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`004ooo
ool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool06oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo
003o00;ooooo00?o003oooooooooool07?ooool01?l00?ooooooooooool00?l3ooooo`03o`00oooo
oooooooo01_ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01_ooooo
00Go003oooooooooooooooooo`00000Mooooo`04o`000?ooooooooooo`0000Oooooo00?o0000oooo
ooooool01_ooool01?l0003oooooooooooooool3o`3o0003ooooool0o`3ooooo00;ooooo00?o0?l0
ooooooooool00ol0o`0Gooooo`?o0?l00_ooool01@00o`3oooooooooooooool00?l000;ooooo0ol0
o`0Gooooo`?o0?l00_ooool01000o`3oooooooooo`00o`02ooooo`?o0?l05oooool3o`3o00;ooooo
00D00?l0oooooooooooooooo003o0002ooooo`?o0?l05oooool3o`3o00;ooooo00@00?l0oooooooo
ool00?l00_ooool3o`3o01Sooooo0ol0o`06ooooo`03o`000?oooooooooo00_ooooo000Dooooo`;o
00002?ooool5o`0000?ooooo00?o0000ooooooooool01_ooool01Ol00?oooooooooooooooooo003o
00;ooooo00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool06oooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool07?oo
ool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo01_ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00000Noooo
o`;o00002?ooool5o`0000Cooooo00Co0000oooooooooooooooo0ol0o`000ooooooo0?l0ooooo`02
ooooo`03o`3o0?oooooooooo00?o0?l05oooool3o`3o00;ooooo00D00?l0oooooooooooooooo003o
0002ooooo`?o0?l05oooool3o`3o00;ooooo00@00?l0ooooooooool00?l00_ooool3o`3o01Oooooo
0ol0o`02ooooo`05003o0?ooooooooooooooo`00o`000_ooool3o`3o01Oooooo0ol0o`02ooooo`04
003o0?oooooooooo003o00;ooooo0ol0o`0Hooooo`?o0?l01_ooool00ol0003oooooooooo`0;oooo
o`009_ooool00ol0003oooooooooo`06ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol0
0?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0K
ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0Looooo`04o`00oooo
ooooooooo`00o`?ooooo00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo0000037ooooo00Co0000oooo
oooooooooooo0ol0o`000ooooooo0?l0ooooo`02ooooo`03o`3o0?oooooooooo00?o0?l05oooool3
o`3o00;ooooo00D00?l0oooooooooooooooo003o0002ooooo`?o0?l05oooool3o`3o00;ooooo00@0
0?l0ooooooooool00?l00_ooool3o`3o01Oooooo0ol0o`02ooooo`05003o0?ooooooooooooooo`00
o`000_ooool3o`3o01Oooooo0ol0o`02ooooo`04003o0?oooooooooo003o00;ooooo0ol0o`0Hoooo
o`?o0?l01_ooool00ol0003oooooooooo`0;ooooo`009_ooool2o`0000Oooooo00Go003ooooooooo
ooooooooo`00o`02ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooo
oooooooo01cooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`0Kooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`05o`00oooooooooooooooo
ool00000<Oooool2o`0000Kooooo00Go0?l0ooooooooooooooooo`3o000Qooooo`05003o0?oooooo
ooooooooo`00o`008Oooool01000o`3oooooooooo`00o`0Qooooo`05003o0?ooooooooooooooo`00
o`008Oooool01000o`3oooooooooo`00o`0Uooooo`;o00003Oooool002Kooooo00?o0000oooooooo
ool01_ooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool06oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06oooool01Ol00?oooooooooooooo
oooo003o00;ooooo00?o003oooooooooool07?ooool01?l00?ooooooooooool00?l3ooooo`03o`00
oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01_o
oooo00Go003oooooooooooooooooo`00000aooooo`03o`000?oooooooooo00Gooooo00Go0?l0oooo
ooooooooooooo`3o000Qooooo`05003o0?ooooooooooooooo`00o`008Oooool01000o`3ooooooooo
o`00o`0Qooooo`05003o0?ooooooooooooooo`00o`008Oooool01000o`3oooooooooo`00o`0Voooo
o`03o`000?oooooooooo00_ooooo000Vooooo`03o`000?oooooooooo00Kooooo00Go003ooooooooo
ooooooooo`00o`02ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooo
oooooooo01cooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`0Kooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`05o`00oooooooooooooooo
ool00000<Oooool00ol0003oooooooooo`05ooooo`05o`3o0?ooooooooooooooool0o`008Oooool0
1@00o`3oooooooooooooool00?l0027ooooo00@00?l0ooooooooool00?l08Oooool01@00o`3ooooo
ooooooooool00?l0027ooooo00@00?l0ooooooooool00?l09_ooool00ol0003oooooooooo`0;oooo
o`009_ooool00ol0003oooooooooo`06ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol0
0?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0K
ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0Looooo`04o`00oooo
ooooooooo`00o`?ooooo00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo0000037ooooo00?o0000oooo
ooooool01Oooool01Ol0o`3ooooooooooooooooo0?l0027ooooo00D00?l0oooooooooooooooo003o
000Qooooo`04003o0?oooooooooo003o027ooooo00D00?l0oooooooooooooooo003o000Qooooo`04
003o0?oooooooooo003o02Kooooo00?o0000ooooooooool02oooool002Kooooo00?o0000oooooooo
ool01_ooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool06oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06oooool01Ol00?oooooooooooooo
oooo003o00;ooooo00?o003oooooooooool07?ooool01?l00?ooooooooooool00?l3ooooo`03o`00
oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01_o
oooo00Go003oooooooooooooooooo`00000aooooo`03o`000?oooooooooo00Gooooo00Go0?l0oooo
ooooooooooooo`3o000Qooooo`05003o0?ooooooooooooooo`00o`008Oooool01000o`3ooooooooo
o`00o`0Qooooo`05003o0?ooooooooooooooo`00o`008Oooool01000o`3oooooooooo`00o`0Voooo
o`03o`000?oooooooooo00_ooooo000Vooooo`03o`000?oooooooooo00Kooooo00Go003ooooooooo
ooooooooo`00o`02ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooo
oooooooo01cooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`0Kooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`05o`00oooooooooooooooo
ool00000<Oooool00ol0003oooooooooo`05ooooo`05o`3o0?ooooooooooooooool0o`008Oooool0
1@00o`3oooooooooooooool00?l0027ooooo00@00?l0ooooooooool00?l08Oooool01@00o`3ooooo
ooooooooool00?l0027ooooo00@00?l0ooooooooool00?l09_ooool00ol0003oooooooooo`0;oooo
o`009_ooool2o`0000Oooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo
01_ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01_ooooo00Go003o
ooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo01cooooo00Co003ooooooooooooo003o
0oooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`0Kooooo`05o`00ooooooooooooooooool00000<Oooool2o`0000Kooooo00Go0?l0oooo
ooooooooooooo`3o000Qooooo`05003o0?ooooooooooooooo`00o`008Oooool01000o`3ooooooooo
o`00o`0Qooooo`05003o0?ooooooooooooooo`00o`008Oooool01000o`3oooooooooo`00o`0Uoooo
o`;o00003Oooool002Kooooo00?o0000ooooooooool01_ooool01Ol00?oooooooooooooooooo003o
00;ooooo00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool06oooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool07?oo
ool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo01_ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00000aoooo
o`03o`000?oooooooooo00Gooooo00Go0?l0ooooooooooooooooo`3o000Qooooo`05003o0?oooooo
ooooooooo`00o`008Oooool01000o`3oooooooooo`00o`0Qooooo`05003o0?ooooooooooooooo`00
o`008Oooool01000o`3oooooooooo`00o`0Vooooo`03o`000?oooooooooo00_ooooo000Vooooo`03
o`000?oooooooooo00Kooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo
01_ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01_ooooo00Go003o
ooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo01cooooo00Co003ooooooooooooo003o
0oooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`0Kooooo`05o`00ooooooooooooooooool00000<Oooool00ol0003oooooooooo`05oooo
o`05o`3o0?ooooooooooooooool0o`008Oooool01@00o`3oooooooooooooool00?l0027ooooo00@0
0?l0ooooooooool00?l08Oooool01@00o`3oooooooooooooool00?l0027ooooo00@00?l0oooooooo
ool00?l09_ooool00ol0003oooooooooo`0;ooooo`009_ooool00ol0003oooooooooo`06ooooo`05
o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0Kooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00_oo
ool00ol00?ooooooooooo`0Looooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool0
6oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06oooool01Ol00?oo
oooooooooooooooo0000037ooooo00?o0000ooooooooool01Oooool01Ol0o`3ooooooooooooooooo
0?l0027ooooo00D00?l0oooooooooooooooo003o000Qooooo`04003o0?oooooooooo003o027ooooo
00D00?l0oooooooooooooooo003o000Qooooo`04003o0?oooooooooo003o02Kooooo00?o0000oooo
ooooool02oooool002Kooooo00?o0000ooooooooool01_ooool01Ol00?oooooooooooooooooo003o
00;ooooo00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool06oooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool07?oo
ool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo01_ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00000aoooo
o`03o`000?oooooooooo00Gooooo00Go0?l0ooooooooooooooooo`3o000Qooooo`05003o0?oooooo
ooooooooo`00o`008Oooool01000o`3oooooooooo`00o`0Qooooo`05003o0?ooooooooooooooo`00
o`008Oooool01000o`3oooooooooo`00o`0Vooooo`03o`000?oooooooooo00_ooooo000Vooooo`03
o`000?oooooooooo00Kooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo
01_ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01_ooooo00Go003o
ooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo01cooooo00Co003ooooooooooooo003o
0oooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`0Kooooo`05o`00ooooooooooooooooool00000<Oooool00ol0003oooooooooo`05oooo
o`05o`3o0?ooooooooooooooool0o`008Oooool01@00o`3oooooooooooooool00?l0027ooooo00@0
0?l0ooooooooool00?l08Oooool01@00o`3oooooooooooooool00?l0027ooooo00@00?l0oooooooo
ool00?l09_ooool00ol0003oooooooooo`0;ooooo`009_ooool2o`0000Kooooo0ol00?l2ooooo`03
o`00oooooooo003o00;o003o6oooool3o`00o`;ooooo00?o003oooooooooool00ol00?lKooooo`?o
003o0_ooool00ol00?ooooooo`00o`02o`00oacooooo0ol00?l01?oooooo003oooooooooool3o`00
oa_ooooo0ol00?l2ooooo`03o`00oooooooooooo00?o003o6oooool3o`00o`;ooooo00?o0000oooo
ooooool0;oooool2o`0000Kooooo00Go0?l0ooooooooooooooooo`3o000Qooooo`05003o0?oooooo
ooooooooo`00o`008Oooool01000o`3oooooooooo`00o`0Qooooo`05003o0?ooooooooooooooo`00
o`008Oooool01000o`3oooooooooo`00o`0Uooooo`;o00003Oooool002Kooooo00?o0000oooooooo
ool01Oooool3o`00o`;ooooo00?o003oooooool00?l00_l00?lKooooo`?o003o0_ooool00ol00?oo
ooooooooo`03o`00oa_ooooo0ol00?l2ooooo`03o`00oooooooo003o00;o003o7?ooool3o`00o`04
ooooool00?ooooooooooo`?o003o6oooool3o`00o`;ooooo00?o003oooooooooool00ol00?lKoooo
o`?o003o0_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Gooooo00Go0?l0oooo
ooooooooooooo`3o000Qooooo`05003o0?ooooooooooooooo`00o`008Oooool01000o`3ooooooooo
o`00o`0Qooooo`05003o0?ooooooooooooooo`00o`008Oooool01000o`3oooooooooo`00o`0Voooo
o`03o`000?oooooooooo00_ooooo000Vooooo`03o`000?oooooooooo00Gooooo0ol00?l2ooooo`03
o`00oooooooo003o00;o003o6oooool3o`00o`;ooooo00?o003oooooooooool00ol00?lKooooo`?o
003o0_ooool00ol00?ooooooo`00o`02o`00oacooooo0ol00?l01?oooooo003oooooooooool3o`00
oa_ooooo0ol00?l2ooooo`03o`00oooooooooooo00?o003o6oooool3o`00o`;ooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`05ooooo`05o`3o0?ooooooooooooooool0o`008Oooool0
1@00o`3oooooooooooooool00?l0027ooooo00@00?l0ooooooooool00?l08Oooool01@00o`3ooooo
ooooooooool00?l0027ooooo00@00?l0ooooooooool00?l09_ooool00ol0003oooooooooo`0;oooo
o`009_ooool00ol0003oooooooooo`0:ooooo`03o`00oooooooooooo02;ooooo00?o003ooooooooo
ool08oooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo02?ooooo00?o003ooooooooo
ool08oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Gooooo00Go0?l0oooooooo
ooooooooo`3o000Qooooo`05003o0?ooooooooooooooo`00o`008Oooool01000o`3oooooooooo`00
o`0Qooooo`05003o0?ooooooooooooooo`00o`008Oooool01000o`3oooooooooo`00o`0Vooooo`03
o`000?oooooooooo00_ooooo000Vooooo`03o`000?oooooooooo00[ooooo00?o003oooooooooool0
8_ooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool0
8oooool00ol00?ooooooooooo`0Sooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
1Oooool01Ol0o`3ooooooooooooooooo0?l0027ooooo00D00?l0oooooooooooooooo003o000Qoooo
o`04003o0?oooooooooo003o027ooooo00D00?l0oooooooooooooooo003o000Qooooo`04003o0?oo
oooooooo003o02Kooooo00?o0000ooooooooool02oooool002Kooooo00?o0000ooooooooool02_oo
ool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo02?ooooo00?o003oooooooooool08_oo
ool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo02?ooooo00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`04ooooo`?o0?l000Coooooo`3o0?l0o`3o0?l07oooool3o`3o0004oooo
ool0o`3o0?l0o`3o01oooooo1_l0o`0Oooooo`?o0?l000Coooooo`3o0?l0o`3o0?l07oooool6o`3o
02Gooooo00?o0000ooooooooool02oooool002Kooooo0_l0000;ooooo`03o`00oooooooooooo02;o
oooo00?o003oooooooooool08oooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo02?o
oooo00?o003oooooooooool08oooool00ol0003oooooooooo`0_ooooo`;o00001Oooool3o`3o0004
ooooool0o`3o0?l0o`3o01oooooo0ol0o`001?oooooo0?l0o`3o0?l0o`0Oooooo`Ko0?l07oooool3
o`3o0004ooooool0o`3o0?l0o`3o01oooooo1_l0o`0Tooooo`;o00003Oooool002Kooooo00?o0000
ooooooooool02_ooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo02?ooooo00?o003o
ooooooooool08_ooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo02?ooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`04ooooo`?o0?l000Coooooo`3o0?l0o`3o0?l07ooo
ool3o`3o0004ooooool0o`3o0?l0o`3o01oooooo1_l0o`0Oooooo`?o0?l000Coooooo`3o0?l0o`3o
0?l07oooool6o`3o02Gooooo00?o0000ooooooooool02oooool002Kooooo00?o0000ooooooooool0
2_ooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo02?ooooo00?o003oooooooooool0
8_ooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo02?ooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`36ooooo`03o`000?oooooooooo00_ooooo000Vooooo`03o`000?oo
oooooooo00[ooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`0Sooooo`03o`00oooo
oooooooo02;ooooo00?o003oooooooooool08oooool00ol00?ooooooooooo`0Sooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool0a_ooool00ol0003oooooooooo`0;ooooo`007oooool3
o`0000Cooooo00?o0000ooooooooool02_ooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooo
oooo02?ooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooo
oooo02?ooooo00?o0000ooooooooool09oooool3o`0000Gooooo00?o0000ooooooooool0a_ooool0
0ol0003oooooooooo`0;ooooo`008?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Wooooo0ol00?lRooooo`?o003o8oooool3o`00ob;ooooo0ol00?lSooooo`?o003o9?ooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0a_ooool00ol0
003oooooooooo`0;ooooo`008?ooool00ol0003oooooooooo`03ooooo`03o`0000000000000000Wo
oooo0ol00?lRooooo`?o003o8oooool3o`00ob;ooooo0ol00?lSooooo`?o003o8oooool2o`0002[o
oooo00?o0000ooooooooool01?ooool2o`000<Kooooo0_l0000=ooooo`008?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Wooooo0ol00?lRooooo`?o003o8oooool3o`00ob;ooooo
0ol00?lSooooo`?o003o9?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0a_ooool00ol0003oooooooooo`0;ooooo`008?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`04ooooo`;o0000:_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`;o00003Oooool001oooooo0_l00005
oooool[o0000:Oooool2o`0000Kooooob_l0000=ooooo`008?ooool00ol0003oooooooooo`3goooo
o`03o`000?oooooooooo0=_ooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003o
ooooooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003o
ooooooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003o
ooooooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo000Z
ooooo`;o00008?ooool3o`0000Cooooo0_l0000Kooooo`Go00000oooool2o`0001gooooo0ol00004
ooooo`;o00007Oooool3o`0000?ooooo0_l0000Mooooo`?o00001?ooool2o`0003[ooooo0_l0000O
ooooo`?o00001?ooool2o`0001cooooo1Ol00003ooooo`;o00007?ooool3o`0000Cooooo0_l0000N
ooooo`?o00000oooool2o`0001gooooo0ol00004ooooo`;o00004_ooool002Wooooo00Co0000oooo
oooooooo00008?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001_ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool0000Kooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool0000Mooooo`05o`000?ooooooooooooooool000000_oo
ool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool0000hooooo`04o`000?ooooooooooo`0001oooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Looooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
6_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00007_ooool01Ol0
003ooooooooooooooooo000000;ooooo00?o0000ooooooooool06Oooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00004Oooool002Wooooo00Co0000oooooooooooo0000
8?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001cooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool0000Oooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool06?ooool5o`0000;ooooo00Co0000oooooooooooo00007oooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo03Kooooo00Co0000oooooooooooo00007oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0001gooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Nooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool06Ooo
ool5o`0000;ooooo00Co0000oooooooooooo00007oooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo00oooooo000Yooooo`04o`000?ooooooooooo`00023ooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool0000Mooooo`05o`000?ooooooooooooooool000000_ooool0
0ol0003oooooooooo`0Kooooo`;o00000oooool01?l0003oooooooooool0000Jooooo`04o`000?oo
ooooooooo`0000?ooooo00Co0000oooooooooooo00007oooool01?l0003oooooooooool00002oooo
o`03o`000?oooooooooo03Kooooo00Co0000oooooooooooo00007oooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0001kooooo00Go0000ooooooooooooooooo`000002ooooo`03o`00
0?oooooooooo01[ooooo0_l00003ooooo`04o`000?ooooooooooo`0001_ooooo00Co0000oooooooo
oooo00000oooool01?l0003oooooooooool0000Oooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool03oooool002Wooooo00Co0000oooooooooooo00008?ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0001[ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0001oooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00006oooool4o`0000?ooooo00Co
0000oooooooooooo0000>?ooool01?l0003oooooooooool0000Oooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00006oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00007_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooool000000oooool01?l0003oooooooooool0000Kooooo`Co00000oooool01?l0003o
ooooooooool0000Aooooo`00:Oooool01?l0003oooooooooool0000Oooooo`;o00001?ooool01?l0
003oooooooooool0000Jooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool0000Kooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Loooo
o`;o00000oooool01?l0003oooooooooool0000Kooooo`03o`000?oooooooooo00Cooooo00Co0000
oooooooooooo0000>?ooool01?l0003oooooooooool0000Nooooo`;o00001?ooool01?l0003ooooo
ooooool0000Kooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000J
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Mooooo`;o0000
0oooool01?l0003oooooooooool0000Kooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooo
oooo00004Oooool002[ooooo0_l0000Qooooo`03o`000?oooooooooo00?ooooo0_l0000Looooo`?o
00001?ooool2o`0001gooooo0ol00004ooooo`;o00007_ooool00ol0003oooooooooo`02ooooo`;o
00007?ooool5o`0000?ooooo0_l0000jooooo`;o00008?ooool00ol0003oooooooooo`03ooooo`;o
00007Oooool3o`0000Cooooo0_l0000Looooo`?o00001?ooool2o`0001oooooo00?o0000oooooooo
ool00_ooool2o`0001cooooo1Ol00003ooooo`;o00004_ooool00?oooooonOooool00?oooooonOoo
ool00?oooooonOooool00?oooooonOooool001oooooo0ol00004oooool[o0000:Oooool3o`0000Go
oooob_l0000=ooooo`008?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool02oooool001Sooooo1Ol00003ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool06oooool3o`00ob?ooooo0ol00?lSooooo`?o003o8_ooool3o`00ob?ooooo0ol0
0?lAooooo`03o`000?oooooooooo023ooooo1Ol00003ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0a_ooool00ol0003oooooooooo`0;ooooo`008?ooool00ol0003oooooooooo`03
ooooo`?o00006oooool3o`00ob?ooooo0ol00?lSooooo`?o003o8_ooool3o`00ob?ooooo0ol00?l@
ooooo`;o0000:_ooool00ol0003oooooooooo`04ooooo`;o0000a_ooool2o`0000gooooo000Poooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06oooool3o`00ob?ooooo0ol00?lSoooo
o`?o003o8_ooool3o`00ob?ooooo0ol00?lAooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`36ooooo`03o`000?oooooooooo00_ooooo000Oooooo`;o
00001Oooool00ol0003oooooooooo`0Looooo`03o`00oooooooooooo02?ooooo00?o003ooooooooo
ool08oooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo02?ooooo00?o003ooooooooo
ool04?ooool00ol0003oooooooooo`0Wooooo`;o00001_ooool00ol0003oooooooooo`36ooooo`03
o`000?oooooooooo00_ooooo000Pooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
7?ooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo02?ooooo00?o003oooooooooool0
8_ooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo013ooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0<Kooooo00?o0000ooooooooool0
2oooool002Kooooo00?o0000ooooooooool07?ooool00ol00?ooooooooooo`0Sooooo`03o`00oooo
oooooooo02?ooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`0Sooooo`03o`00oooo
oooooooo013ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Kooooo`?oo`0000Co
ooooool00?oo003oo`007oooool6ool001oooooo0ooo00001?ooooooo`00ool00?oo000Oooooo`Ko
o`007oooool3ool00004oooooooo003oo`00ool000kooooo00?o0000ooooooooool02oooool002Ko
oooo0_l0000Mooooo`03o`00oooooooooooo02?ooooo00?o003oooooooooool08oooool00ol00?oo
ooooooooo`0Rooooo`03o`00oooooooooooo02?ooooo00?o003oooooooooool04?ooool00ol0003o
ooooooooo`0_ooooo`;o00007?ooool3ool00004oooooooo003oo`00ool001oooooo1_oo000Ooooo
o`?oo`0000Coooooool00?oo003oo`007oooool6ool001oooooo0ooo00001?ooooooo`00ool00?oo
000=ooooo`;o00003Oooool002Kooooo00?o0000ooooooooool07?ooool00ol00?ooooooooooo`0S
ooooo`03o`00oooooooooooo02?ooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`0S
ooooo`03o`00oooooooooooo013ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0K
ooooo`?oo`0000Coooooool00?oo003oo`007oooool6ool001oooooo0ooo00001?ooooooo`00ool0
0?oo000Oooooo`Koo`007oooool3ool00004oooooooo003oo`00ool000kooooo00?o0000oooooooo
ool02oooool002Kooooo00?o0000ooooooooool07?ooool00ol00?ooooooooooo`0Sooooo`03o`00
oooooooooooo02?ooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`0Sooooo`03o`00
oooooooooooo013ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Looooo`050?l0
0?ooooooooooooooo`3o00008Oooool0103o003oooooooooo`3o000Qooooo`050?l00?oooooooooo
ooooo`3o00008Oooool0103o003oooooooooo`3o000Qooooo`050?l00?ooooooooooooooo`3o0000
3oooool00ol0003oooooooooo`0;ooooo`009_ooool00ol0003oooooooooo`0Looooo`03o`00oooo
oooooooo02?ooooo00?o003oooooooooool08oooool00ol00?ooooooooooo`0Rooooo`03o`00oooo
oooooooo02?ooooo00?o003oooooooooool04?ooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo01cooooo00D0o`00oooooooooooooooo0?l0000Qooooo`040?l00?oooooooooo0?l0027o
oooo00D0o`00oooooooooooooooo0?l0000Qooooo`040?l00?oooooooooo0?l0027ooooo00D0o`00
oooooooooooooooo0?l0000?ooooo`03o`000?oooooooooo00_ooooo000Vooooo`03o`000?oooooo
oooo01cooooo00?o003oooooooooool08oooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooo
oooo02;ooooo00?o003oooooooooool08oooool00ol00?ooooooooooo`0@ooooo`03o`000?oooooo
oooo02oooooo00?o0000ooooooooool07?ooool01@3o003oooooooooooooool0o`00027ooooo00@0
o`00ooooooooool0o`008Oooool01@3o003oooooooooooooool0o`00027ooooo00@0o`00oooooooo
ool0o`008Oooool01@3o003oooooooooooooool0o`0000oooooo00?o0000ooooooooool02oooool0
02Kooooo00?o0000ooooooooool06?ooool3o`00o`04ooooool00?ooooooooooo`?o003o6oooool3
o`00o`;ooooo00?o003oooooooooool00ol00?lKooooo`?o003o0_ooool00ol00?ooooooo`00o`02
o`00oa_ooooo0ol00?l2ooooo`03o`00oooooooooooo00?o003o6oooool3o`00o`;ooooo00?o003o
ooooool00?l00_l00?l>ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool07?ooool0
1@3o003oooooooooooooool0o`00027ooooo00@0o`00ooooooooool0o`008Oooool01@3o003ooooo
ooooooooool0o`00027ooooo00@0o`00ooooooooool0o`008Oooool01@3o003oooooooooooooool0
o`0000oooooo00?o0000ooooooooool02oooool002Kooooo0_l0000Iooooo`?o003o00Coooooo`00
oooooooooooo0ol00?lKooooo`?o003o0_ooool00ol00?ooooooooooo`03o`00oa_ooooo0ol00?l2
ooooo`03o`00oooooooo003o00;o003o6oooool3o`00o`;ooooo00?o003oooooooooool00ol00?lK
ooooo`?o003o0_ooool00ol00?ooooooo`00o`02o`00o`kooooo00?o0000ooooooooool0;oooool2
o`0001gooooo00D0o`00oooooooooooooooo0?l0000Qooooo`040?l00?oooooooooo0?l0027ooooo
00D0o`00oooooooooooooooo0?l0000Qooooo`040?l00?oooooooooo0?l0027ooooo00D0o`00oooo
oooooooooooo0?l0000>ooooo`;o00003Oooool002Kooooo00?o0000ooooooooool06?ooool3o`00
o`04ooooool00?ooooooooooo`?o003o6oooool3o`00o`;ooooo00?o003oooooooooool00ol00?lK
ooooo`?o003o0_ooool00ol00?ooooooo`00o`02o`00oa_ooooo0ol00?l2ooooo`03o`00oooooooo
oooo00?o003o6oooool3o`00o`;ooooo00?o003oooooool00?l00_l00?l>ooooo`03o`000?oooooo
oooo02oooooo00?o0000ooooooooool07?ooool01@3o003oooooooooooooool0o`00027ooooo00@0
o`00ooooooooool0o`008Oooool01@3o003oooooooooooooool0o`00027ooooo00@0o`00oooooooo
ool0o`008Oooool01@3o003oooooooooooooool0o`0000oooooo00?o0000ooooooooool02oooool0
02Kooooo00?o0000ooooooooool06Oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooo
oooo01_ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01_ooooo00Go
003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo01_ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`02oooo
o`03o`00oooooooooooo00gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Loooo
o`050?l00?ooooooooooooooo`3o00008Oooool0103o003oooooooooo`3o000Qooooo`050?l00?oo
ooooooooooooo`3o00008Oooool0103o003oooooooooo`3o000Qooooo`050?l00?oooooooooooooo
o`3o00003oooool00ol0003oooooooooo`0;ooooo`009_ooool00ol0003oooooooooo`0Iooooo`04
o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo003o00;ooooo00?o
003oooooooooool06oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
6oooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool03Oooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo01cooooo00D0o`00oooooooooooooooo0?l0000Qoooo
o`040?l00?oooooooooo0?l0027ooooo00D0o`00oooooooooooooooo0?l0000Qooooo`040?l00?oo
oooooooo0?l0027ooooo00D0o`00oooooooooooooooo0?l0000?ooooo`03o`000?oooooooooo00_o
oooo000Vooooo`03o`000?oooooooooo01Wooooo00Co003ooooooooooooo003o0oooool00ol00?oo
ooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Koooo
o`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0Kooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l0
0_ooool00ol00?ooooooooooo`0=ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
7?ooool01@3o003oooooooooooooool0o`00027ooooo00@0o`00ooooooooool0o`008Oooool01@3o
003oooooooooooooool0o`00027ooooo00@0o`00ooooooooool0o`008Oooool01@3o003ooooooooo
ooooool0o`0000oooooo00?o0000ooooooooool02oooool002Kooooo00?o0000ooooooooool06Ooo
ool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo01_ooooo00Go003ooooooooooooo
ooooo`00o`03ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`02oooo
o`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo01_ooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo00gooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`0Looooo`050?l00?ooooooooooooooo`3o0000
8Oooool0103o003oooooooooo`3o000Qooooo`050?l00?ooooooooooooooo`3o00008Oooool0103o
003oooooooooo`3o000Qooooo`050?l00?ooooooooooooooo`3o00003oooool00ol0003ooooooooo
o`0;ooooo`009_ooool2o`0001[ooooo00Co003ooooooooooooo003o0oooool00ol00?oooooooooo
o`0Kooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`05o`00
ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0Kooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00_ooool0
0ol00?ooooooooooo`0=ooooo`03o`000?oooooooooo02oooooo0_l0000Mooooo`050?l00?oooooo
ooooooooo`3o00008Oooool0103o003oooooooooo`3o000Qooooo`050?l00?ooooooooooooooo`3o
00008Oooool0103o003oooooooooo`3o000Qooooo`050?l00?ooooooooooooooo`3o00003_ooool2
o`0000gooooo000Vooooo`03o`000?oooooooooo01Wooooo00Co003ooooooooooooo003o0oooool0
0ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`0Kooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0Kooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`05o`00oooooooooooooooo
ool00?l00_ooool00ol00?ooooooooooo`0=ooooo`03o`000?oooooooooo02oooooo00?o0000oooo
ooooool07?ooool01@3o003oooooooooooooool0o`00027ooooo00@0o`00ooooooooool0o`008Ooo
ool01@3o003oooooooooooooool0o`00027ooooo00@0o`00ooooooooool0o`008Oooool01@3o003o
ooooooooooooool0o`0000oooooo00?o0000ooooooooool02oooool002Kooooo00?o0000oooooooo
ool06Oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo01_ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00
o`02ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo00go
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Looooo`050?l00?oooooooooooooo
o`3o00008Oooool0103o003oooooooooo`3o000Qooooo`050?l00?ooooooooooooooo`3o00008Ooo
ool0103o003oooooooooo`3o000Qooooo`050?l00?ooooooooooooooo`3o00003oooool00ol0003o
ooooooooo`0;ooooo`009_ooool00ol0003oooooooooo`0Iooooo`04o`00ooooooooooooo`00o`?o
oooo00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool06oooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool06oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06oooool01Ol00?oooooooooo
oooooooo003o00;ooooo00?o003oooooooooool03Oooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo01cooooo00D0o`00oooooooooooooooo0?l0000Qooooo`040?l00?oooooooooo0?l0
027ooooo00D0o`00oooooooooooooooo0?l0000Qooooo`040?l00?oooooooooo0?l0027ooooo00D0
o`00oooooooooooooooo0?l0000?ooooo`03o`000?oooooooooo00_ooooo000Vooooo`03o`000?oo
oooooooo01Wooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`0Kooooo`05o`00
ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`05o`00oooooooooooooooo
ool00?l00_ooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?oooooooooo
o`0=ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool07?ooool01@3o003ooooooooo
ooooool0o`00027ooooo00@0o`00ooooooooool0o`008Oooool01@3o003oooooooooooooool0o`00
027ooooo00@0o`00ooooooooool0o`008Oooool01@3o003oooooooooooooool0o`0000oooooo00?o
0000ooooooooool02oooool002Kooooo00?o0000ooooooooool06Oooool01?l00?ooooooooooool0
0?l3ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo01_o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01_ooooo00Go003ooooo
ooooooooooooo`00o`02ooooo`03o`00oooooooooooo00gooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`0Looooo`050?l00?ooooooooooooooo`3o00008Oooool0103o003ooooooooo
o`3o000Qooooo`050?l00?ooooooooooooooo`3o00008Oooool0103o003oooooooooo`3o000Qoooo
o`050?l00?ooooooooooooooo`3o00003oooool00ol0003oooooooooo`0;ooooo`009_ooool2o`00
01[ooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`0Kooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l0
0_ooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0=oooo
o`03o`000?oooooooooo02oooooo0_l0000Mooooo`050?l00?ooooooooooooooo`3o00008Oooool0
103o003oooooooooo`3o000Qooooo`050?l00?ooooooooooooooo`3o00008Oooool0103o003ooooo
ooooo`3o000Qooooo`050?l00?ooooooooooooooo`3o00003_ooool2o`0000gooooo000Vooooo`03
o`000?oooooooooo01Wooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`0Koooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`05o`00oooooooo
ooooooooool00?l00_ooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?oo
ooooooooo`0=ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool07?ooool01@3o003o
ooooooooooooool0o`00027ooooo00@0o`00ooooooooool0o`008Oooool01@3o003ooooooooooooo
ool0o`00027ooooo00@0o`00ooooooooool0o`008Oooool01@3o003oooooooooooooool0o`0000oo
oooo00?o0000ooooooooool02oooool002Kooooo00?o0000ooooooooool06Oooool01?l00?oooooo
ooooool00?l3ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooo
oooo01_ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01_ooooo00Go
003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo00gooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`0Gooooo`?oo`000_ooool01P3o003oooooooooooooool0o`00oooo
o`?oo`006?ooool3ool000;ooooo00@0o`00ooooooooool0o`000_ooool3ool001Oooooo0ooo0002
ooooo`050?l00?ooooooooooooooo`3o00000_ooool3ool001Oooooo0ooo0002ooooo`040?l00?oo
oooooooo0?l000;ooooo0ooo000Gooooo`?oo`000_ooool01@3o003oooooooooooooool0o`0000;o
oooo0ooo000:ooooo`03o`000?oooooooooo00_ooooo000Vooooo`03o`000?oooooooooo01Wooooo
00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`0Kooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00_ooool0
0ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`0Kooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0=ooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool05oooool3ool000;ooooo00H0o`00oooooooooooo
oooo0?l00?ooool3ool001Sooooo0ooo0002ooooo`040?l00?oooooooooo0?l000;ooooo0ooo000G
ooooo`?oo`000_ooool01@3o003oooooooooooooool0o`0000;ooooo0ooo000Gooooo`?oo`000_oo
ool0103o003oooooooooo`3o0002ooooo`?oo`005oooool3ool000;ooooo00D0o`00oooooooooooo
oooo0?l00002ooooo`?oo`002_ooool00ol0003oooooooooo`0;ooooo`005?ooool2o`0000Cooooo
00?o0000ooooooooool00_ooool3o`0000Cooooo00?o0000ooooooooool06Oooool01?l00?oooooo
ooooool00?l3ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooo
oooo01_ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01_ooooo00Go
003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo00gooooo00?o0000ooooooooool0
7?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0
5oooool3ool000;ooooo00H0o`00oooooooooooooooo0?l00?ooool3ool001Sooooo0ooo0002oooo
o`040?l00?oooooooooo0?l000;ooooo0ooo000Gooooo`?oo`000_ooool01@3o003ooooooooooooo
ool0o`0000;ooooo0ooo000Gooooo`?oo`000_ooool0103o003oooooooooo`3o0002ooooo`?oo`00
5oooool3ool000;ooooo00D0o`00oooooooooooooooo0?l00002ooooo`?oo`002_ooool00ol0003o
ooooooooo`0;ooooo`004oooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`0Iooooo`04o`00ooooooooooooo`00o`?ooooo00?o003o
ooooooooool06oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06ooo
ool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool06oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo003o
00;ooooo00?o003oooooooooool03Oooool00ol0003oooooooooo`0Kooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo01Sooooo00D0
o`00oooooooooooooooo0?l00003ooooo`040?l00?oooooooooo0?l001[ooooo00D0o`00oooooooo
oooooooo0?l00002ooooo`050?l00?ooooooooooooooo`3o00006Oooool01@3o003ooooooooooooo
ool0o`0000?ooooo00D0o`00oooooooooooooooo0?l0000Iooooo`050?l00?ooooooooooooooo`3o
00000_ooool01@3o003oooooooooooooool0o`0001Wooooo00D0o`00oooooooooooooooo0?l00003
ooooo`050?l00?ooooooooooooooo`3o00002oooool00ol0003oooooooooo`0;ooooo`003?ooool5
o`0000;ooooo00Co0000oooooooooooo00002oooool01?l0003oooooooooooooool3o`0001Wooooo
00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`0Kooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00_ooool0
0ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`0Kooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0<ooooo`;o0000
5_ooool5o`0000;ooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`02ooooo`;o
00006Oooool01@3o003oooooooooooooool0o`0000?ooooo00@0o`00ooooooooool0o`006_ooool0
1@3o003oooooooooooooool0o`0000;ooooo00D0o`00oooooooooooooooo0?l0000Iooooo`050?l0
0?ooooooooooooooo`3o00000oooool01@3o003oooooooooooooool0o`0001Wooooo00D0o`00oooo
oooooooooooo0?l00002ooooo`050?l00?ooooooooooooooo`3o00006Oooool01@3o003ooooooooo
ooooool0o`0000?ooooo00D0o`00oooooooooooooooo0?l0000:ooooo`;o00003Oooool001?ooooo
00Co0000oooooooooooo00002oooool01Ol0003ooooooooooooooooo000001_ooooo00Co003ooooo
oooooooo003o0oooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?oooooo
ooooo`0Kooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`05
o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0=ooooo`03o`000?oooooooooo
01_ooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo01Sooooo00D0o`00oooooooooooooooo0?l00003ooooo`040?l00?oooooooooo0?l001[ooooo
00D0o`00oooooooooooooooo0?l00002ooooo`050?l00?ooooooooooooooo`3o00006Oooool01@3o
003oooooooooooooool0o`0000?ooooo00D0o`00oooooooooooooooo0?l0000Iooooo`050?l00?oo
ooooooooooooo`3o00000_ooool01@3o003oooooooooooooool0o`0001Wooooo00D0o`00oooooooo
oooooooo0?l00003ooooo`050?l00?ooooooooooooooo`3o00002oooool00ol0003oooooooooo`0;
ooooo`004oooool01?l0003oooooooooool00007ooooo`Co00001?ooool00ol0003oooooooooo`0I
ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool06oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo003o00;o
oooo00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool06oooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool03Oooool0
0ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0000Oooooo1?l00005ooooo`03o`000?oo
oooooooo01Sooooo00D0o`00oooooooooooooooo0?l00003ooooo`040?l00?oooooooooo0?l001[o
oooo00D0o`00oooooooooooooooo0?l00002ooooo`050?l00?ooooooooooooooo`3o00006Oooool0
1@3o003oooooooooooooool0o`0000?ooooo00D0o`00oooooooooooooooo0?l0000Iooooo`050?l0
0?ooooooooooooooo`3o00000_ooool01@3o003oooooooooooooool0o`0001Wooooo00D0o`00oooo
oooooooooooo0?l00003ooooo`050?l00?ooooooooooooooo`3o00002oooool00ol0003ooooooooo
o`0;ooooo`004oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool06Oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo01_ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01_ooooo00Go003ooooooooo
ooooooooo`00o`02ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooo
oooooooo00gooooo00?o0000ooooooooool06oooool01?l0003oooooooooool00007ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool06?ooool01@3o003oooooooooooooool0o`0000?o
oooo00@0o`00ooooooooool0o`006_ooool01@3o003oooooooooooooool0o`0000;ooooo00D0o`00
oooooooooooooooo0?l0000Iooooo`050?l00?ooooooooooooooo`3o00000oooool01@3o003ooooo
ooooooooool0o`0001Wooooo00D0o`00oooooooooooooooo0?l00002ooooo`050?l00?oooooooooo
ooooo`3o00006Oooool01@3o003oooooooooooooool0o`0000?ooooo00D0o`00oooooooooooooooo
0?l0000;ooooo`03o`000?oooooooooo00_ooooo000Dooooo`;o00002?ooool5o`0000?ooooo00?o
0000ooooooooool06Oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo01_ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01_ooooo00Go003ooooooooo
ooooooooo`00o`02ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooo
oooooooo00gooooo00?o0000ooooooooool07?ooool2o`0000Sooooo1Ol00004ooooo`03o`000?oo
oooooooo01Sooooo00D0o`00oooooooooooooooo0?l00003ooooo`040?l00?oooooooooo0?l001[o
oooo00D0o`00oooooooooooooooo0?l00002ooooo`050?l00?ooooooooooooooo`3o00006Oooool0
1@3o003oooooooooooooool0o`0000?ooooo00D0o`00oooooooooooooooo0?l0000Iooooo`050?l0
0?ooooooooooooooo`3o00000_ooool01@3o003oooooooooooooool0o`0001Wooooo00D0o`00oooo
oooooooooooo0?l00003ooooo`050?l00?ooooooooooooooo`3o00002oooool00ol0003ooooooooo
o`0;ooooo`009_ooool00ol0003oooooooooo`0Iooooo`04o`00ooooooooooooo`00o`?ooooo00?o
003oooooooooool06oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
6oooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool06oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo
003o00;ooooo00?o003oooooooooool03Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo01Sooooo00D0o`00oooooooooooooooo0?l00003ooooo`040?l00?oooooooooo0?l001[ooooo
00D0o`00oooooooooooooooo0?l00002ooooo`050?l00?ooooooooooooooo`3o00006Oooool01@3o
003oooooooooooooool0o`0000?ooooo00D0o`00oooooooooooooooo0?l0000Iooooo`050?l00?oo
ooooooooooooo`3o00000_ooool01@3o003oooooooooooooool0o`0001Wooooo00D0o`00oooooooo
oooooooo0?l00003ooooo`050?l00?ooooooooooooooo`3o00002oooool00ol0003oooooooooo`0;
ooooo`009_ooool2o`0001[ooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`0K
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`05o`00oooo
ooooooooooooool00?l00_ooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00_ooool00ol0
0?ooooooooooo`0=ooooo`03o`000?oooooooooo02oooooo0_l0000Iooooo`050?l00?oooooooooo
ooooo`3o00000oooool0103o003oooooooooo`3o000Jooooo`050?l00?ooooooooooooooo`3o0000
0_ooool01@3o003oooooooooooooool0o`0001Wooooo00D0o`00oooooooooooooooo0?l00003oooo
o`050?l00?ooooooooooooooo`3o00006Oooool01@3o003oooooooooooooool0o`0000;ooooo00D0
o`00oooooooooooooooo0?l0000Iooooo`050?l00?ooooooooooooooo`3o00000oooool01@3o003o
ooooooooooooool0o`0000[ooooo0_l0000=ooooo`009_ooool00ol0003oooooooooo`0Iooooo`04
o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo003o00;ooooo00?o
003oooooooooool06oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
6oooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool03Oooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo01Sooooo00D0o`00oooooooooooooooo0?l00003oooo
o`040?l00?oooooooooo0?l001[ooooo00D0o`00oooooooooooooooo0?l00002ooooo`050?l00?oo
ooooooooooooo`3o00006Oooool01@3o003oooooooooooooool0o`0000?ooooo00D0o`00oooooooo
oooooooo0?l0000Iooooo`050?l00?ooooooooooooooo`3o00000_ooool01@3o003ooooooooooooo
ool0o`0001Wooooo00D0o`00oooooooooooooooo0?l00003ooooo`050?l00?ooooooooooooooo`3o
00002oooool00ol0003oooooooooo`0;ooooo`009_ooool00ol0003oooooooooo`0Iooooo`04o`00
ooooooooooooo`00o`?ooooo00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003o
ooooooooool06oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06ooo
ool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool03Oooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo01Sooooo00D0o`00oooooooooooooooo0?l00003ooooo`04
0?l00?oooooooooo0?l001[ooooo00D0o`00oooooooooooooooo0?l00002ooooo`050?l00?oooooo
ooooooooo`3o00006Oooool01@3o003oooooooooooooool0o`0000?ooooo00D0o`00oooooooooooo
oooo0?l0000Iooooo`050?l00?ooooooooooooooo`3o00000_ooool01@3o003oooooooooooooool0
o`0001Wooooo00D0o`00oooooooooooooooo0?l00003ooooo`050?l00?ooooooooooooooo`3o0000
2oooool00ol0003oooooooooo`0;ooooo`009_ooool00ol0003oooooooooo`0Iooooo`04o`00oooo
ooooooooo`00o`?ooooo00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003ooooo
ooooool06oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06oooool0
1Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool03Oooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo01Sooooo00D0o`00oooooooooooooooo0?l00003ooooo`040?l0
0?oooooooooo0?l001[ooooo00D0o`00oooooooooooooooo0?l00002ooooo`050?l00?oooooooooo
ooooo`3o00006Oooool01@3o003oooooooooooooool0o`0000?ooooo00D0o`00oooooooooooooooo
0?l0000Iooooo`050?l00?ooooooooooooooo`3o00000_ooool01@3o003oooooooooooooool0o`00
01Wooooo00D0o`00oooooooooooooooo0?l00003ooooo`050?l00?ooooooooooooooo`3o00002ooo
ool00ol0003oooooooooo`0;ooooo`009_ooool00ol0003oooooooooo`0Dooooo`?o003o0_ooool0
1?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo00?o003o4oooool3o`00o`;ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo003o00;o003o5?ooool3o`00o`;ooooo
00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo00?o003o5?ooool3o`00o`03
ooooool00?oooooo00;ooooo00Go003oooooooooooooooooo`00o`02ooooo`?o003o4oooool3o`00
o`;ooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo00?o003o2_ooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Sooooo00D0o`00oooooooooooooooo0?l0
0003ooooo`040?l00?oooooooooo0?l001[ooooo00D0o`00oooooooooooooooo0?l00002ooooo`05
0?l00?ooooooooooooooo`3o00006Oooool01@3o003oooooooooooooool0o`0000?ooooo00D0o`00
oooooooooooooooo0?l0000Iooooo`050?l00?ooooooooooooooo`3o00000_ooool01@3o003ooooo
ooooooooool0o`0001Wooooo00D0o`00oooooooooooooooo0?l00003ooooo`050?l00?oooooooooo
ooooo`3o00002oooool00ol0003oooooooooo`0;ooooo`009_ooool00ol0003oooooooooo`0Doooo
o`?o003o0_ooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo00?o003o4oooool3
o`00o`;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo003o00;o003o5?oo
ool3o`00o`;ooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo00?o003o
5?ooool3o`00o`03ooooool00?oooooo00;ooooo00Go003oooooooooooooooooo`00o`02ooooo`?o
003o4oooool3o`00o`;ooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo
00?o003o2_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Sooooo00D0o`00oooo
oooooooooooo0?l00003ooooo`040?l00?oooooooooo0?l001[ooooo00D0o`00oooooooooooooooo
0?l00002ooooo`050?l00?ooooooooooooooo`3o00006Oooool01@3o003oooooooooooooool0o`00
00?ooooo00D0o`00oooooooooooooooo0?l0000Iooooo`050?l00?ooooooooooooooo`3o00000_oo
ool01@3o003oooooooooooooool0o`0001Wooooo00D0o`00oooooooooooooooo0?l00003ooooo`05
0?l00?ooooooooooooooo`3o00002oooool00ol0003oooooooooo`0;ooooo`009_ooool2o`0001Go
oooo0ol00?l2ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool00ol00?lCoooo
o`?o003o0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooool00?l00_l00?lD
ooooo`?o003o0_ooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool00ol0
0?lDooooo`?o003o00?oooooo`00ooooool00_ooool01Ol00?oooooooooooooooooo003o00;ooooo
0ol00?lCooooo`?o003o0_ooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003ooooooooo
ool00ol00?l:ooooo`03o`000?oooooooooo02oooooo0_l0000Iooooo`050?l00?oooooooooooooo
o`3o00000oooool0103o003oooooooooo`3o000Jooooo`050?l00?ooooooooooooooo`3o00000_oo
ool01@3o003oooooooooooooool0o`0001Wooooo00D0o`00oooooooooooooooo0?l00003ooooo`05
0?l00?ooooooooooooooo`3o00006Oooool01@3o003oooooooooooooool0o`0000;ooooo00D0o`00
oooooooooooooooo0?l0000Iooooo`050?l00?ooooooooooooooo`3o00000oooool01@3o003ooooo
ooooooooool0o`0000[ooooo0_l0000=ooooo`009_ooool00ol0003oooooooooo`0Eooooo`05o`00
ooooooooooooooooool00?l00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool04oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`02ooooo`03o`00oooooooooooo01Cooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00
ooooooooooooo`00o`?ooooo00?o003oooooooooool05?ooool01?l00?ooooooooooool00?l3oooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Cooooo`05o`00oooooooo
ooooooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo00Wooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Hooooo`050?l00?ooooooooooooooo`3o
00000oooool0103o003oooooooooo`3o000Jooooo`050?l00?ooooooooooooooo`3o00000_ooool0
1@3o003oooooooooooooool0o`0001Wooooo00D0o`00oooooooooooooooo0?l00003ooooo`050?l0
0?ooooooooooooooo`3o00006Oooool01@3o003oooooooooooooool0o`0000;ooooo00D0o`00oooo
oooooooooooo0?l0000Iooooo`050?l00?ooooooooooooooo`3o00000oooool01@3o003ooooooooo
ooooool0o`0000_ooooo00?o0000ooooooooool02oooool002Kooooo00?o0000ooooooooool05Ooo
ool01Ol00?oooooooooooooooooo003o00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo01?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooo
ooooool00?l00_ooool00ol00?ooooooooooo`0Dooooo`05o`00ooooooooooooooooool00?l00ooo
ool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo01Cooooo00Co003ooooooooooooo
003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool04oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooo003o0oooool00ol00?oooooooooo
o`09ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool06?ooool01@3o003ooooooooo
ooooool0o`0000?ooooo00@0o`00ooooooooool0o`006_ooool01@3o003oooooooooooooool0o`00
00;ooooo00D0o`00oooooooooooooooo0?l0000Iooooo`050?l00?ooooooooooooooo`3o00000ooo
ool01@3o003oooooooooooooool0o`0001Wooooo00D0o`00oooooooooooooooo0?l00002ooooo`05
0?l00?ooooooooooooooo`3o00006Oooool01@3o003oooooooooooooool0o`0000?ooooo00D0o`00
oooooooooooooooo0?l0000;ooooo`03o`000?oooooooooo00_ooooo000Vooooo`03o`000?oooooo
oooo01Gooooo00Go003oooooooooooooooooo`00o`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`0Cooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00;ooooo00?o003oooooooooool05?ooool01Ol00?oooooooooooooooooo
003o00?ooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`0Dooooo`04o`00oooo
ooooooooo`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01?o
oooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003o
ooooooooool02Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Sooooo00D0o`00
oooooooooooooooo0?l00003ooooo`040?l00?oooooooooo0?l001[ooooo00D0o`00oooooooooooo
oooo0?l00002ooooo`050?l00?ooooooooooooooo`3o00006Oooool01@3o003oooooooooooooool0
o`0000?ooooo00D0o`00oooooooooooooooo0?l0000Iooooo`050?l00?ooooooooooooooo`3o0000
0_ooool01@3o003oooooooooooooool0o`0001Wooooo00D0o`00oooooooooooooooo0?l00003oooo
o`050?l00?ooooooooooooooo`3o00002oooool00ol0003oooooooooo`0;ooooo`009_ooool00ol0
003oooooooooo`0Eooooo`05o`00ooooooooooooooooool00?l00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool04oooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo01Cooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool05?ooool0
1?l00?ooooooooooool00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`0Cooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooool00?l3oooo
o`03o`00oooooooooooo00Wooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Hoooo
o`050?l00?ooooooooooooooo`3o00000oooool0103o003oooooooooo`3o000Jooooo`050?l00?oo
ooooooooooooo`3o00000_ooool01@3o003oooooooooooooool0o`0001Wooooo00D0o`00oooooooo
oooooooo0?l00003ooooo`050?l00?ooooooooooooooo`3o00006Oooool01@3o003ooooooooooooo
ool0o`0000;ooooo00D0o`00oooooooooooooooo0?l0000Iooooo`050?l00?ooooooooooooooo`3o
00000oooool01@3o003oooooooooooooool0o`0000_ooooo00?o0000ooooooooool02oooool002Ko
oooo00?o0000ooooooooool05Oooool01Ol00?oooooooooooooooooo003o00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo01?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0Dooooo`05o`00
ooooooooooooooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo
01Cooooo00Co003ooooooooooooo003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool04oooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooo
003o0oooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool06?ooool01@3o003oooooooooooooool0o`0000?ooooo00@0o`00ooooooooool0o`006_ooool0
1@3o003oooooooooooooool0o`0000;ooooo00D0o`00oooooooooooooooo0?l0000Iooooo`050?l0
0?ooooooooooooooo`3o00000oooool01@3o003oooooooooooooool0o`0001Wooooo00D0o`00oooo
oooooooooooo0?l00002ooooo`050?l00?ooooooooooooooo`3o00006Oooool01@3o003ooooooooo
ooooool0o`0000?ooooo00D0o`00oooooooooooooooo0?l0000;ooooo`03o`000?oooooooooo00_o
oooo000Vooooo`;o00005_ooool01Ol00?oooooooooooooooooo003o00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo01?ooooo00Go003oooooooooooooooooo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0Dooooo`05o`00oooo
ooooooooooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo01Co
oooo00Co003ooooooooooooo003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool04oooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooo003o
0oooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo02oooooo0_l0000Iooooo`050?l0
0?ooooooooooooooo`3o00000oooool0103o003oooooooooo`3o000Jooooo`050?l00?oooooooooo
ooooo`3o00000_ooool01@3o003oooooooooooooool0o`0001Wooooo00D0o`00oooooooooooooooo
0?l00003ooooo`050?l00?ooooooooooooooo`3o00006Oooool01@3o003oooooooooooooool0o`00
00;ooooo00D0o`00oooooooooooooooo0?l0000Iooooo`050?l00?ooooooooooooooo`3o00000ooo
ool01@3o003oooooooooooooool0o`0000[ooooo0_l0000=ooooo`009_ooool00ol0003ooooooooo
o`0Eooooo`05o`00ooooooooooooooooool00?l00_ooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool04oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooo
ooooooooooooo`00o`02ooooo`03o`00oooooooooooo01Cooooo00Go003oooooooooooooooooo`00
o`03ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool05?ooool01?l00?oooooo
ooooool00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Coooo
o`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooo
oooooooo00Wooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Hooooo`050?l00?oo
ooooooooooooo`3o00000oooool0103o003oooooooooo`3o000Jooooo`050?l00?oooooooooooooo
o`3o00000_ooool01@3o003oooooooooooooool0o`0001Wooooo00D0o`00oooooooooooooooo0?l0
0003ooooo`050?l00?ooooooooooooooo`3o00006Oooool01@3o003oooooooooooooool0o`0000;o
oooo00D0o`00oooooooooooooooo0?l0000Iooooo`050?l00?ooooooooooooooo`3o00000oooool0
1@3o003oooooooooooooool0o`0000_ooooo00?o0000ooooooooool02oooool002Kooooo00?o0000
ooooooooool05Oooool01Ol00?oooooooooooooooooo003o00;ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`03o`00oooooooooooo01?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05
o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0Dooooo`05o`00oooooooooooo
ooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo01Cooooo00Co
003ooooooooooooo003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool04oooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooo003o0oooool0
0ol00?ooooooooooo`09ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool06?ooool0
1@3o003oooooooooooooool0o`0000?ooooo00@0o`00ooooooooool0o`006_ooool01@3o003ooooo
ooooooooool0o`0000;ooooo00D0o`00oooooooooooooooo0?l0000Iooooo`050?l00?oooooooooo
ooooo`3o00000oooool01@3o003oooooooooooooool0o`0001Wooooo00D0o`00oooooooooooooooo
0?l00002ooooo`050?l00?ooooooooooooooo`3o00006Oooool01@3o003oooooooooooooool0o`00
00?ooooo00D0o`00oooooooooooooooo0?l0000;ooooo`03o`000?oooooooooo00_ooooo000Voooo
o`03o`000?oooooooooo01Gooooo00Go003oooooooooooooooooo`00o`02ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`0Cooooo`05o`00ooooooooooooooooool00?l0
0oooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool05?ooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`0D
ooooo`04o`00ooooooooooooo`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo01?ooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooo`00
o`?ooooo00?o003oooooooooool02Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
01Sooooo00D0o`00oooooooooooooooo0?l00003ooooo`040?l00?oooooooooo0?l001[ooooo00D0
o`00oooooooooooooooo0?l00002ooooo`050?l00?ooooooooooooooo`3o00006Oooool01@3o003o
ooooooooooooool0o`0000?ooooo00D0o`00oooooooooooooooo0?l0000Iooooo`050?l00?oooooo
ooooooooo`3o00000_ooool01@3o003oooooooooooooool0o`0001Wooooo00D0o`00oooooooooooo
oooo0?l00003ooooo`050?l00?ooooooooooooooo`3o00002oooool00ol0003oooooooooo`0;oooo
o`009_ooool00ol0003oooooooooo`0Eooooo`05o`00ooooooooooooooooool00?l00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool04oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo01Cooooo
00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003ooooo
ooooool05?ooool01?l00?ooooooooooool00?l3ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`0Cooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?oooooo
ooooool00?l3ooooo`03o`00oooooooooooo00Wooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`0Hooooo`050?l00?ooooooooooooooo`3o00000oooool0103o003oooooooooo`3o000J
ooooo`050?l00?ooooooooooooooo`3o00000_ooool01@3o003oooooooooooooool0o`0001Wooooo
00D0o`00oooooooooooooooo0?l00003ooooo`050?l00?ooooooooooooooo`3o00006Oooool01@3o
003oooooooooooooool0o`0000;ooooo00D0o`00oooooooooooooooo0?l0000Iooooo`050?l00?oo
ooooooooooooo`3o00000oooool01@3o003oooooooooooooool0o`0000_ooooo00?o0000oooooooo
ool02oooool002Kooooo00?o0000ooooooooool05Oooool01Ol00?oooooooooooooooooo003o00;o
oooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01?ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?oooooooooo
o`0Dooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`03
o`00oooooooooooo01Cooooo00Co003ooooooooooooo003o0oooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool04oooool01Ol00?oooooooooooooooooo003o00?ooooo00Co
003ooooooooooooo003o0oooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo02oooooo
00?o0000ooooooooool06?ooool01@3o003oooooooooooooool0o`0000?ooooo00@0o`00oooooooo
ool0o`006_ooool01@3o003oooooooooooooool0o`0000;ooooo00D0o`00oooooooooooooooo0?l0
000Iooooo`050?l00?ooooooooooooooo`3o00000oooool01@3o003oooooooooooooool0o`0001Wo
oooo00D0o`00oooooooooooooooo0?l00002ooooo`050?l00?ooooooooooooooo`3o00006Oooool0
1@3o003oooooooooooooool0o`0000?ooooo00D0o`00oooooooooooooooo0?l0000;ooooo`03o`00
0?oooooooooo00_ooooo000Vooooo`;o00005_ooool01Ol00?oooooooooooooooooo003o00;ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0D
ooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`03o`00
oooooooooooo01Cooooo00Co003ooooooooooooo003o0oooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool04oooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003o
oooooooooooo003o0oooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo02oooooo0_l0
000Iooooo`050?l00?ooooooooooooooo`3o00000oooool0103o003oooooooooo`3o000Jooooo`05
0?l00?ooooooooooooooo`3o00000_ooool01@3o003oooooooooooooool0o`0001Wooooo00D0o`00
oooooooooooooooo0?l00003ooooo`050?l00?ooooooooooooooo`3o00006Oooool01@3o003ooooo
ooooooooool0o`0000;ooooo00D0o`00oooooooooooooooo0?l0000Iooooo`050?l00?oooooooooo
ooooo`3o00000oooool01@3o003oooooooooooooool0o`0000[ooooo0_l0000=ooooo`009_ooool0
0ol0003oooooooooo`0Eooooo`05o`00ooooooooooooooooool00?l00_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool04oooool01Ol00?oooooooooooooooooo003o00?o
oooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo01Cooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool05?oo
ool01?l00?ooooooooooool00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`0Cooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooool00?l3
ooooo`03o`00oooooooooooo00Wooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0H
ooooo`050?l00?ooooooooooooooo`3o00000oooool0103o003oooooooooo`3o000Jooooo`050?l0
0?ooooooooooooooo`3o00000_ooool01@3o003oooooooooooooool0o`0001Wooooo00D0o`00oooo
oooooooooooo0?l00003ooooo`050?l00?ooooooooooooooo`3o00006Oooool01@3o003ooooooooo
ooooool0o`0000;ooooo00D0o`00oooooooooooooooo0?l0000Iooooo`050?l00?oooooooooooooo
o`3o00000oooool01@3o003oooooooooooooool0o`0000_ooooo00?o0000ooooooooool02oooool0
02Kooooo00?o0000ooooooooool05Oooool01Ol00?oooooooooooooooooo003o00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0Dooooo`05
o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooo
oooo01Cooooo00Co003ooooooooooooo003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool04oooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooo
oooo003o0oooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo02oooooo00?o0000oooo
ooooool06?ooool01@3o003oooooooooooooool0o`0000?ooooo00@0o`00ooooooooool0o`006_oo
ool01@3o003oooooooooooooool0o`0000;ooooo00D0o`00oooooooooooooooo0?l0000Iooooo`05
0?l00?ooooooooooooooo`3o00000oooool01@3o003oooooooooooooool0o`0001Wooooo00D0o`00
oooooooooooooooo0?l00002ooooo`050?l00?ooooooooooooooo`3o00006Oooool01@3o003ooooo
ooooooooool0o`0000?ooooo00D0o`00oooooooooooooooo0?l0000;ooooo`03o`000?oooooooooo
00_ooooo000Pooooo`;o00001?ooool00ol0003oooooooooo`0Eooooo`05o`00oooooooooooooooo
ool00?l00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool04oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00
oooooooooooo01Cooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooo`00
o`?ooooo00?o003oooooooooool05?ooool01?l00?ooooooooooool00?l3ooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`0Cooooo`05o`00ooooooooooooooooool00?l0
0oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo00Wooooo00?o0000oooooooo
ool0:?ooool2o`0000Gooooo00?o0000ooooooooool06?ooool01@3o003oooooooooooooool0o`00
00?ooooo00@0o`00ooooooooool0o`006_ooool01@3o003oooooooooooooool0o`0000;ooooo00D0
o`00oooooooooooooooo0?l0000Iooooo`050?l00?ooooooooooooooo`3o00000oooool01@3o003o
ooooooooooooool0o`0001Wooooo00D0o`00oooooooooooooooo0?l00002ooooo`050?l00?oooooo
ooooooooo`3o00006Oooool01@3o003oooooooooooooool0o`0000?ooooo00D0o`00oooooooooooo
oooo0?l0000;ooooo`03o`000?oooooooooo00_ooooo000Oooooo`04o`000?ooooooooooo`0000?o
oooo00?o0000ooooooooool05Oooool01Ol00?oooooooooooooooooo003o00;ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo01?ooooo00Go003oooooooooooooooooo`00
o`03ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0Dooooo`05o`00
ooooooooooooooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo
01Cooooo00Co003ooooooooooooo003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool04oooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooo
003o0oooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo02Oooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`0Hooooo`050?l00?ooooooooooooooo`3o00000oooool0
103o003oooooooooo`3o000Jooooo`050?l00?ooooooooooooooo`3o00000_ooool01@3o003ooooo
ooooooooool0o`0001Wooooo00D0o`00oooooooooooooooo0?l00003ooooo`050?l00?oooooooooo
ooooo`3o00006Oooool01@3o003oooooooooooooool0o`0000;ooooo00D0o`00oooooooooooooooo
0?l0000Iooooo`050?l00?ooooooooooooooo`3o00000oooool01@3o003oooooooooooooool0o`00
00_ooooo00?o0000ooooooooool02oooool001oooooo00Co0000oooooooooooo00000oooool00ol0
003oooooooooo`0Eooooo`05o`00ooooooooooooooooool00?l00_ooool01Ol00?oooooooooooooo
oooo003o00?ooooo00?o003oooooooooool04oooool01Ol00?oooooooooooooooooo003o00?ooooo
00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo01Cooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool05?ooool0
1?l00?ooooooooooool00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`0Cooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooool00?l3oooo
o`03o`00oooooooooooo00Wooooo00?o0000ooooooooool09oooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo01?ooooo0ooo0002ooooo`050?l00?ooooooooooooooo`3o00000ooo
ool0103o003oooooooooo`3o0002ooooo`?oo`004?ooool3ool000;ooooo00D0o`00oooooooooooo
oooo0?l00002ooooo`050?l00?ooooooooooooooo`3o00000_ooool3ool0013ooooo0ooo00000ooo
ool0o`00ooooo`02ooooo`050?l00?ooooooooooooooo`3o00000oooool00`3o003oooooool00002
ool0013ooooo0ooo0002ooooo`050?l00?ooooooooooooooo`3o00000_ooool01@3o003ooooooooo
ooooool0o`0000;ooooo0ooo000@ooooo`?oo`0000?ooooo0?l00?ooool00_ooool01@3o003ooooo
ooooooooool0o`0000?ooooo00<0o`00ooooooooool00ooo0006ooooo`03o`000?oooooooooo00_o
oooo000Oooooo`04o`000?ooooooooooo`0000?ooooo00?o00000000000000001_ooool01Ol00?oo
oooooooooooooooo003o00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooo
ooooooooool00?l00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`02ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo
003o00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
0_ooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`02oooo
o`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00?ooooo00Co
003ooooooooooooo003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooo
oooo003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooo003o0ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooo003o0oooool01Ol00?oo
oooooooooooooooo003o00?ooooo00Co003ooooooooooooo003o0oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Co003ooooooooooooo003o0oooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool00_l0000Yooooo`04o`000?ooooooooooo`0000Cooooo0_l00006oooo
o`05ool00?oooooooooooooooooo00000oooool01_oo003oooooooooooooooooo`00ooooo`?oo`00
0_ooool01@3o003oooooooooooooool0o`0000?ooooo00@0o`00ooooooooool0o`000_ooool3ool0
00;ooooo00D0o`00oooooooooooooooo0?l00003ooooo`040?l00?oooooooooo0?l000;ooooo0ooo
0002ooooo`050?l00?ooooooooooooooo`3o00000_ooool01@3o003oooooooooooooool0o`0000;o
oooo0ooo0002ooooo`040?l00?oooooooooo0?l000?ooooo00D0o`00oooooooooooooooo0?l00002
ooooo`?oo`0000?ooooo0?l00?ooool00_ooool01@3o003oooooooooooooool0o`0000?ooooo00<0
o`00oooooooo00000_oo0002ooooo`050?l00?ooooooooooooooo`3o00000oooool0103o003ooooo
ooooo`3o0002ooooo`?oo`000_ooool01@3o003oooooooooooooool0o`0000;ooooo00D0o`00oooo
oooooooooooo0?l00002ooooo`?oo`000_ooool0103o003oooooooooo`3o0003ooooo`050?l00?oo
ooooooooooooo`3o00000_ooool3ool00003ooooo`3o003ooooo00;ooooo00D0o`00oooooooooooo
oooo0?l00003ooooo`030?l00?oooooooooo00?oo`0000?ooooo0?l00?ooool00_ooool2o`0000go
oooo000Oooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01_ooool01Ol00?oo
oooooooooooooooo003o00;ooooo00Go003oooooooooooooooooo`00o`0Fooooo`04o`00oooooooo
ooooo`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003ooooo
ooooool05?ooool01Ol00?oooooooooooooooooo003o00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo01?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0Dooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol0003oooooooooo`0Wooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool01Oooool01Ooo003oooooooooooooooooo`0000?ooooo00Koo`00oooooooooooooooo
ool00?ooool3ool0013ooooo0ooo0002ooooo`050?l00?ooooooooooooooo`3o00000oooool0103o
003oooooooooo`3o0002ooooo`?oo`004?ooool3ool000;ooooo00@0o`00ooooooooool0o`000ooo
ool01@3o003oooooooooooooool0o`0000;ooooo0ooo000?ooooo`?oo`000_ooool01@3o003ooooo
ooooooooool0o`0000?ooooo00@0o`00ooooooooool0o`000_ooool3ool0013ooooo0ooo0002oooo
o`040?l00?oooooooooo0?l000?ooooo00D0o`00oooooooooooooooo0?l00002ooooo`?oo`004?oo
ool3ool00003ooooo`3o003ooooo00?ooooo00?o0000ooooooooool02oooool001oooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`06ooooo`05o`00ooooooooooooooooool00?l0
0_ooool01Ol00?oooooooooooooooooo003o01Kooooo00Co003ooooooooooooo003o0oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool04oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`0Dooooo`05o`00
ooooooooooooooooool00?l00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooo
ooooool04oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00
o`02ooooo`03o`00oooooooooooo01Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
0?oooooooooo02Oooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`05
ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0001Wooooo00D0o`00
oooooooooooooooo0?l00003ooooo`040?l00?oooooooooo0?l001[ooooo00@0o`00ooooooooool0
o`000oooool01@3o003oooooooooooooool0o`0001Wooooo00D0o`00oooooooooooooooo0?l00003
ooooo`040?l00?oooooooooo0?l001[ooooo00@0o`00ooooooooool0o`000oooool01@3o003ooooo
ooooooooool0o`0001Wooooo00<0o`00ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`00
8?ooool2o`0000Cooooo00?o0000ooooooooool01_ooool01Ol00?oooooooooooooooooo003o00;o
oooo00Go003oooooooooooooooooo`00o`0Fooooo`04o`00ooooooooooooo`00o`?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool05?ooool01Ol00?oo
oooooooooooooooo003o00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo01?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
0_ooool00ol00?ooooooooooo`0Dooooo`05o`00ooooooooooooooooool00?l00oooool00ol0003o
ooooooooo`0Xooooo`;o00001Oooool00ol0003oooooooooo`05ooooo`05ool00?oooooooooooooo
oooo00000oooool01Ooo003oooooooooooooooooo`0001Wooooo00D0o`00oooooooooooooooo0?l0
0003ooooo`040?l00?oooooooooo0?l001[ooooo00@0o`00ooooooooool0o`000oooool01@3o003o
ooooooooooooool0o`0001Wooooo00D0o`00oooooooooooooooo0?l00003ooooo`040?l00?oooooo
oooo0?l001[ooooo00@0o`00ooooooooool0o`000oooool01@3o003oooooooooooooool0o`0001Wo
oooo00<0o`00ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`009_ooool00ol0003ooooo
ooooo`06ooooo`05o`00ooooooooooooooooool00?l00_ooool01Ol00?oooooooooooooooooo003o
01Kooooo00Co003ooooooooooooo003o0oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool04oooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooooooooooo
003o0oooool00ol00?ooooooooooo`0Dooooo`05o`00ooooooooooooooooool00?l00_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool04oooool01Ol00?oooooooooooooo
oooo003o00?ooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo01Cooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool01Oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0000I
ooooo`050?l00?ooooooooooooooo`3o00000oooool0103o003oooooooooo`3o000Jooooo`040?l0
0?oooooooooo0?l000?ooooo00D0o`00oooooooooooooooo0?l0000Iooooo`050?l00?oooooooooo
ooooo`3o00000oooool0103o003oooooooooo`3o000Jooooo`040?l00?oooooooooo0?l000?ooooo
00D0o`00oooooooooooooooo0?l0000Iooooo`030?l00?oooooooooo00;ooooo00?o0000oooooooo
ool02oooool002Kooooo00?o0000ooooooooool01_ooool01Ol00?oooooooooooooooooo003o00;o
oooo00Go003oooooooooooooooooo`00o`0Fooooo`04o`00ooooooooooooo`00o`?ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool05?ooool01Ol00?oo
oooooooooooooooo003o00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo01?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00ooooooooooooooooool00?l0
0_ooool00ol00?ooooooooooo`0Dooooo`05o`00ooooooooooooooooool00?l00oooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo00Gooooo00Goo`00ooooooooooooooooool00003oooo
o`05ool00?oooooooooooooooooo00006Oooool01@3o003oooooooooooooool0o`0000?ooooo00@0
o`00ooooooooool0o`006_ooool0103o003oooooooooo`3o0003ooooo`050?l00?oooooooooooooo
o`3o00006Oooool01@3o003oooooooooooooool0o`0000?ooooo00@0o`00ooooooooool0o`006_oo
ool0103o003oooooooooo`3o0003ooooo`050?l00?ooooooooooooooo`3o00006Oooool00`3o003o
ooooooooo`02ooooo`03o`000?oooooooooo00_ooooo000Vooooo`;o00001oooool01Ol00?oooooo
oooooooooooo003o00;ooooo00Go003oooooooooooooooooo`00o`0Fooooo`04o`00oooooooooooo
o`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01?ooooo00Go
003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003ooooooooo
ool05?ooool01Ol00?oooooooooooooooooo003o00;ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo01?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooo
ooooooooooooool00?l00_ooool00ol00?ooooooooooo`0Dooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol0003oooooooooo`0_ooooo`;o00001_ooool01Ooo003oooooooooooooooooo`00
00?ooooo00Goo`00ooooooooooooooooool0000Iooooo`050?l00?ooooooooooooooo`3o00000ooo
ool0103o003oooooooooo`3o000Jooooo`040?l00?oooooooooo0?l000?ooooo00D0o`00oooooooo
oooooooo0?l0000Iooooo`050?l00?ooooooooooooooo`3o00000oooool0103o003oooooooooo`3o
000Jooooo`040?l00?oooooooooo0?l000?ooooo00D0o`00oooooooooooooooo0?l0000Iooooo`04
0?l00?ooooooooooooooo`;o00003Oooool002Kooooo00?o0000ooooooooool01_ooool01Ol00?oo
oooooooooooooooo003o00;ooooo00Go003oooooooooooooooooo`00o`0Fooooo`04o`00oooooooo
ooooo`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003ooooo
ooooool05?ooool01Ol00?oooooooooooooooooo003o00;ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo01?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00
ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0Dooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Gooooo00Goo`00oooo
ooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00006Oooool01@3o003ooooooooo
ooooool0o`0000?ooooo00@0o`00ooooooooool0o`006_ooool0103o003oooooooooo`3o0003oooo
o`050?l00?ooooooooooooooo`3o00006Oooool01@3o003oooooooooooooool0o`0000?ooooo00@0
o`00ooooooooool0o`006_ooool0103o003oooooooooo`3o0003ooooo`050?l00?oooooooooooooo
o`3o00006Oooool00`3o003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo000Vooooo`03
o`000?oooooooooo00Kooooo00Go003oooooooooooooooooo`00o`02ooooo`05o`00oooooooooooo
ooooool00?l05_ooool01?l00?ooooooooooool00?l3ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`0Cooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?oo
ooooooooool00?l3ooooo`03o`00oooooooooooo01Cooooo00Go003oooooooooooooooooo`00o`02
ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Cooooo`05o`00oooo
ooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003ooooooooo
ool05?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`05ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooo
ooooo`0001Wooooo00D0o`00oooooooooooooooo0?l00003ooooo`040?l00?oooooooooo0?l001[o
oooo00@0o`00ooooooooool0o`000oooool01@3o003oooooooooooooool0o`0001Wooooo00D0o`00
oooooooooooooooo0?l00003ooooo`040?l00?oooooooooo0?l001[ooooo00@0o`00ooooooooool0
o`000oooool01@3o003oooooooooooooool0o`0001Wooooo00<0o`00ooooooooool00_ooool00ol0
003oooooooooo`0;ooooo`009_ooool00ol0003oooooooooo`06ooooo`05o`00oooooooooooooooo
ool00?l00_ooool01Ol00?oooooooooooooooooo003o01Kooooo00Co003ooooooooooooo003o0ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool04oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`0Doooo
o`05o`00ooooooooooooooooool00?l00_ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool04oooool01Ol00?oooooooooooooooooo003o00?ooooo00Go003ooooooooooooo
ooooo`00o`02ooooo`03o`00oooooooooooo01Cooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool01Oooool01Ooo003ooooooooooooooooo
o`0000?ooooo00Goo`00ooooooooooooooooool0000Iooooo`050?l00?ooooooooooooooo`3o0000
0oooool0103o003oooooooooo`3o000Jooooo`040?l00?oooooooooo0?l000?ooooo00D0o`00oooo
oooooooooooo0?l0000Iooooo`050?l00?ooooooooooooooo`3o00000oooool0103o003ooooooooo
o`3o000Jooooo`040?l00?oooooooooo0?l000?ooooo00D0o`00oooooooooooooooo0?l0000Ioooo
o`030?l00?oooooooooo00;ooooo00?o0000ooooooooool02oooool002Kooooo00?o0000oooooooo
ool01_ooool01Ol00?oooooooooooooooooo003o00;ooooo00Go003oooooooooooooooooo`00o`0F
ooooo`04o`00ooooooooooooo`00o`?ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo01?ooooo00Go003oooooooooooooooooo`00o`03ooooo`04o`00ooooooooooooo`00
o`?ooooo00?o003oooooooooool05?ooool01Ol00?oooooooooooooooooo003o00;ooooo00Go003o
ooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01?ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0Dooooo`05
o`00ooooooooooooooooool00?l00oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
00Gooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00006Ooo
ool01@3o003oooooooooooooool0o`0000?ooooo00@0o`00ooooooooool0o`006_ooool0103o003o
ooooooooo`3o0003ooooo`050?l00?ooooooooooooooo`3o00006Oooool01@3o003ooooooooooooo
ool0o`0000?ooooo00@0o`00ooooooooool0o`006_ooool0103o003oooooooooo`3o0003ooooo`05
0?l00?ooooooooooooooo`3o00006Oooool00`3o003oooooooooo`02ooooo`03o`000?oooooooooo
00_ooooo000Vooooo`03o`000?oooooooooo00Kooooo00Go003oooooooooooooooooo`00o`02oooo
o`05o`00ooooooooooooooooool00?l05_ooool01?l00?ooooooooooool00?l3ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`0Cooooo`05o`00ooooooooooooooooool0
0?l00oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo01Cooooo00Go003ooooo
ooooooooooooo`00o`02ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooooooo
o`0Cooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooooooooooooooo003o00;o
oooo00?o003oooooooooool05?ooool01Ol00?oooooooooooooooooo003o00?ooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`05ooooo`05ool00?oooooooooooooooooo00000oooool0
1Ooo003oooooooooooooooooo`0001Wooooo00D0o`00oooooooooooooooo0?l00003ooooo`040?l0
0?oooooooooo0?l001[ooooo00@0o`00ooooooooool0o`000oooool01@3o003oooooooooooooool0
o`0001Wooooo00D0o`00oooooooooooooooo0?l00003ooooo`040?l00?oooooooooo0?l001[ooooo
00@0o`00ooooooooool0o`000oooool01@3o003oooooooooooooool0o`0001Wooooo00<0o`00oooo
ooooool00_ooool00ol0003oooooooooo`0;ooooo`009_ooool2o`0000Oooooo00Go003ooooooooo
ooooooooo`00o`02ooooo`05o`00ooooooooooooooooool00?l05_ooool01?l00?ooooooooooool0
0?l3ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Cooooo`05o`00
ooooooooooooooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo
01Cooooo00Go003oooooooooooooooooo`00o`02ooooo`05o`00ooooooooooooooooool00?l00ooo
ool00ol00?ooooooooooo`0Cooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oooooo
oooooooooooo003o00;ooooo00?o003oooooooooool05?ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o0000ooooooooool0;oooool2o`0000Kooooo00Goo`00ooooooooooooooooool00003
ooooo`05ool00?oooooooooooooooooo00006Oooool01@3o003oooooooooooooool0o`0000?ooooo
00@0o`00ooooooooool0o`006_ooool0103o003oooooooooo`3o0003ooooo`050?l00?oooooooooo
ooooo`3o00006Oooool01@3o003oooooooooooooool0o`0000?ooooo00@0o`00ooooooooool0o`00
6_ooool0103o003oooooooooo`3o0003ooooo`050?l00?ooooooooooooooo`3o00006Oooool0103o
003oooooooooooooool2o`0000gooooo000Vooooo`03o`000?oooooooooo00Kooooo00Go003ooooo
ooooooooooooo`00o`02ooooo`05o`00ooooooooooooooooool00?l05_ooool01?l00?oooooooooo
ool00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Cooooo`05
o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooo
oooo01Cooooo00Go003oooooooooooooooooo`00o`02ooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`0Cooooo`05o`00ooooooooooooooooool00?l00oooool01Ol00?oo
oooooooooooooooo003o00;ooooo00?o003oooooooooool05?ooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`05ooooo`05ool00?oooooo
oooooooooooo00000oooool01Ooo003oooooooooooooooooo`0001Wooooo00D0o`00oooooooooooo
oooo0?l00003ooooo`040?l00?oooooooooo0?l001[ooooo00@0o`00ooooooooool0o`000oooool0
1@3o003oooooooooooooool0o`0001Wooooo00D0o`00oooooooooooooooo0?l00003ooooo`040?l0
0?oooooooooo0?l001[ooooo00@0o`00ooooooooool0o`000oooool01@3o003oooooooooooooool0
o`0001Wooooo00<0o`00ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`009_ooool00ol0
003oooooooooo`06ooooo`05o`00ooooooooooooooooool00?l00_ooool01Ol00?oooooooooooooo
oooo003o01Kooooo00Co003ooooooooooooo003o0oooool01Ol00?oooooooooooooooooo003o00?o
oooo00?o003oooooooooool04oooool01Ol00?oooooooooooooooooo003o00?ooooo00Co003ooooo
oooooooo003o0oooool00ol00?ooooooooooo`0Dooooo`05o`00ooooooooooooooooool00?l00_oo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool04oooool01Ol00?oooooo
oooooooooooo003o00?ooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo
01Cooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool01Oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooooooo
ool0000Iooooo`050?l00?ooooooooooooooo`3o00000oooool0103o003oooooooooo`3o000Joooo
o`040?l00?oooooooooo0?l000?ooooo00D0o`00oooooooooooooooo0?l0000Iooooo`050?l00?oo
ooooooooooooo`3o00000oooool0103o003oooooooooo`3o000Jooooo`040?l00?oooooooooo0?l0
00?ooooo00D0o`00oooooooooooooooo0?l0000Iooooo`030?l00?oooooooooo00;ooooo00?o0000
ooooooooool02oooool002Kooooo00?o0000ooooooooool01_ooool01Ol00?oooooooooooooooooo
003o00;ooooo00Go003oooooooooooooooooo`00o`0Fooooo`04o`00ooooooooooooo`00o`?ooooo
00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01?ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool05?ooool0
1Ol00?oooooooooooooooooo003o00;ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo01?ooooo00Go003oooooooooooooooooo`00o`03ooooo`05o`00oooooooooooooooo
ool00?l00_ooool00ol00?ooooooooooo`0Dooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Gooooo00Goo`00ooooooooooooooooool0
0003ooooo`05ool00?oooooooooooooooooo00006Oooool01@3o003oooooooooooooool0o`0000?o
oooo00@0o`00ooooooooool0o`006_ooool0103o003oooooooooo`3o0003ooooo`050?l00?oooooo
ooooooooo`3o00006Oooool01@3o003oooooooooooooool0o`0000?ooooo00@0o`00ooooooooool0
o`006_ooool0103o003oooooooooo`3o0003ooooo`050?l00?ooooooooooooooo`3o00006Oooool0
0`3o003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo000Vooooo`03o`000?oooooooooo
00Kooooo00Go003oooooooooooooooooo`00o`02ooooo`05o`00ooooooooooooooooool00?l05_oo
ool01?l00?ooooooooooool00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oo
ooooooooo`0Cooooo`05o`00ooooooooooooooooool00?l00oooool01?l00?ooooooooooool00?l3
ooooo`03o`00oooooooooooo01Cooooo00Go003oooooooooooooooooo`00o`02ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`0Cooooo`05o`00ooooooooooooooooool0
0?l00oooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool05?ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`05
ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0001Wooooo
00D0o`00oooooooooooooooo0?l00003ooooo`040?l00?oooooooooo0?l001[ooooo00@0o`00oooo
ooooool0o`000oooool01@3o003oooooooooooooool0o`0001Wooooo00D0o`00oooooooooooooooo
0?l00003ooooo`040?l00?oooooooooo0?l001[ooooo00@0o`00ooooooooool0o`000oooool01@3o
003oooooooooooooool0o`0001Wooooo00<0o`00ooooooooool00_ooool00ol0003oooooooooo`0;
ooooo`009_ooool2o`0000Oooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooo
oooo00?o003o5?ooool3o`00o`03ooooool00?oooooo00;ooooo00Go003oooooooooooooooooo`00
o`02ooooo`?o003o4oooool3o`00o`;ooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00
oooooooooooo00?o003o5?ooool3o`00o`;ooooo00Co003ooooooooooooo003o0oooool00ol00?oo
ooooooooo`03o`00oa?ooooo0ol00?l2ooooo`05o`00ooooooooooooooooool00?l00oooool00ol0
0?ooooooo`00o`02o`00oaCooooo0ol00?l2ooooo`05o`00ooooooooooooooooool00000<Oooool2
o`0000Kooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo0000
6Oooool01@3o003oooooooooooooool0o`0000?ooooo00@0o`00ooooooooool0o`006_ooool0103o
003oooooooooo`3o0003ooooo`050?l00?ooooooooooooooo`3o00006Oooool01@3o003ooooooooo
ooooool0o`0000?ooooo00@0o`00ooooooooool0o`006_ooool0103o003oooooooooo`3o0003oooo
o`050?l00?ooooooooooooooo`3o00006Oooool0103o003oooooooooooooool2o`0000gooooo000V
ooooo`03o`000?oooooooooo00Kooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooo
oooooooo00?o003o5?ooool3o`00o`03ooooool00?oooooo00;ooooo00Go003ooooooooooooooooo
o`00o`02ooooo`?o003o4oooool3o`00o`;ooooo00Go003oooooooooooooooooo`00o`02ooooo`03
o`00oooooooooooo00?o003o5?ooool3o`00o`;ooooo00Co003ooooooooooooo003o0oooool00ol0
0?ooooooooooo`03o`00oa?ooooo0ol00?l2ooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooo`00o`02o`00oaCooooo0ol00?l2ooooo`05o`00ooooooooooooooooool00000<Ooo
ool00ol0003oooooooooo`05ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooo
ooooooooooooo`0001Wooooo00D0o`00oooooooooooooooo0?l00003ooooo`040?l00?oooooooooo
0?l001[ooooo00@0o`00ooooooooool0o`000oooool01@3o003oooooooooooooool0o`0001Wooooo
00D0o`00oooooooooooooooo0?l00003ooooo`040?l00?oooooooooo0?l001[ooooo00@0o`00oooo
ooooool0o`000oooool01@3o003oooooooooooooool0o`0001Wooooo00<0o`00ooooooooool00_oo
ool00ol0003oooooooooo`0;ooooo`009_ooool00ol0003oooooooooo`06ooooo`05o`00oooooooo
ooooooooool00?l00_ooool00ol00?ooooooooooo`03o`00oaCooooo0ol00?l00ooooooo003ooooo
o`02ooooo`05o`00ooooooooooooooooool00?l00_ooool3o`00oa?ooooo0ol00?l2ooooo`05o`00
ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`03o`00oaCooooo0ol00?l2ooooo`04
o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool00ol00?lCooooo`?o003o0_ooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooool00?l00_l00?lDooooo`?o003o0_ooool0
1Ol00?oooooooooooooooooo0000037ooooo00?o0000ooooooooool01Oooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0000Iooooo`050?l00?oooooooooooooo
o`3o00000oooool0103o003oooooooooo`3o000Jooooo`040?l00?oooooooooo0?l000?ooooo00D0
o`00oooooooooooooooo0?l0000Iooooo`050?l00?ooooooooooooooo`3o00000oooool0103o003o
ooooooooo`3o000Jooooo`040?l00?oooooooooo0?l000?ooooo00D0o`00oooooooooooooooo0?l0
000Iooooo`030?l00?oooooooooo00;ooooo00?o0000ooooooooool02oooool002Kooooo00?o0000
ooooooooool01_ooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool06ooo
ool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06oooool01Ol00?oooooo
oooooooooooo003o00;ooooo00?o003oooooooooool07?ooool01?l00?ooooooooooool00?l3oooo
o`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooo
oooo01_ooooo00Go003oooooooooooooooooo`00000aooooo`03o`000?oooooooooo00Gooooo00Go
o`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00006Oooool01@3o003o
ooooooooooooool0o`0000?ooooo00@0o`00ooooooooool0o`006_ooool0103o003oooooooooo`3o
0003ooooo`050?l00?ooooooooooooooo`3o00006Oooool01@3o003oooooooooooooool0o`0000?o
oooo00@0o`00ooooooooool0o`006_ooool0103o003oooooooooo`3o0003ooooo`050?l00?oooooo
ooooooooo`3o00006Oooool00`3o003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo000V
ooooo`03o`000?oooooooooo00Kooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooo
oooooooo01_ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01_ooooo
00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo01cooooo00Co003ooooooooo
oooo003o0oooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00oooool0
0ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00000<Oooool00ol0003ooooooooo
o`05ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0001Wo
oooo00D0o`00oooooooooooooooo0?l00003ooooo`040?l00?oooooooooo0?l001[ooooo00@0o`00
ooooooooool0o`000oooool01@3o003oooooooooooooool0o`0001Wooooo00D0o`00oooooooooooo
oooo0?l00003ooooo`040?l00?oooooooooo0?l001[ooooo00@0o`00ooooooooool0o`000oooool0
1@3o003oooooooooooooool0o`0001Wooooo00<0o`00ooooooooool00_ooool00ol0003ooooooooo
o`0;ooooo`009_ooool00ol0003oooooooooo`06ooooo`05o`00ooooooooooooooooool00?l00_oo
ool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`0Kooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0Looooo`04
o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo0000037ooooo00?o
0000ooooooooool01Oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooo
ooooool0000Iooooo`050?l00?ooooooooooooooo`3o00000oooool0103o003oooooooooo`3o000J
ooooo`040?l00?oooooooooo0?l000?ooooo00D0o`00oooooooooooooooo0?l0000Iooooo`050?l0
0?ooooooooooooooo`3o00000oooool0103o003oooooooooo`3o000Jooooo`040?l00?oooooooooo
0?l000?ooooo00D0o`00oooooooooooooooo0?l0000Iooooo`030?l00?oooooooooo00;ooooo00?o
0000ooooooooool02oooool002Kooooo0_l00007ooooo`05o`00ooooooooooooooooool00?l00_oo
ool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?oooooo
ooooo`0Kooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0Looooo`04
o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo
003o00?ooooo00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo0000037ooooo0_l0
0006ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0001Wo
oooo00D0o`00oooooooooooooooo0?l00003ooooo`040?l00?oooooooooo0?l001[ooooo00@0o`00
ooooooooool0o`000oooool01@3o003oooooooooooooool0o`0001Wooooo00D0o`00oooooooooooo
oooo0?l00003ooooo`040?l00?oooooooooo0?l001[ooooo00@0o`00ooooooooool0o`000oooool0
1@3o003oooooooooooooool0o`0001Wooooo00@0o`00oooooooooooooooo0_l0000=ooooo`009_oo
ool00ol0003oooooooooo`06ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?oooooo
ooooo`0Kooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`05
o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0Looooo`04o`00oooooooooooo
o`00o`?ooooo00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o
003oooooooooool06oooool01Ol00?oooooooooooooooooo0000037ooooo00?o0000ooooooooool0
1Oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0000Ioooo
o`050?l00?ooooooooooooooo`3o00000oooool0103o003oooooooooo`3o000Jooooo`040?l00?oo
oooooooo0?l000?ooooo00D0o`00oooooooooooooooo0?l0000Iooooo`050?l00?oooooooooooooo
o`3o00000oooool0103o003oooooooooo`3o000Jooooo`040?l00?oooooooooo0?l000?ooooo00D0
o`00oooooooooooooooo0?l0000Iooooo`030?l00?oooooooooo00;ooooo00?o0000ooooooooool0
2oooool002Kooooo00?o0000ooooooooool01_ooool01Ol00?oooooooooooooooooo003o00;ooooo
00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool06oooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool07?ooool01?l0
0?ooooooooooool00?l3ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00000aooooo`03o`00
0?oooooooooo00Gooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooo
oooo00006Oooool01@3o003oooooooooooooool0o`0000?ooooo00@0o`00ooooooooool0o`006_oo
ool0103o003oooooooooo`3o0003ooooo`050?l00?ooooooooooooooo`3o00006Oooool01@3o003o
ooooooooooooool0o`0000?ooooo00@0o`00ooooooooool0o`006_ooool0103o003oooooooooo`3o
0003ooooo`050?l00?ooooooooooooooo`3o00006Oooool00`3o003oooooooooo`02ooooo`03o`00
0?oooooooooo00_ooooo000Vooooo`03o`000?oooooooooo00Kooooo00Go003ooooooooooooooooo
o`00o`02ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`03ooooo`03
o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo
01cooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`0Kooooo`05o`00oooooooo
ooooooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00000
<Oooool00ol0003oooooooooo`05ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003o
ooooooooooooooooo`0001Wooooo00D0o`00oooooooooooooooo0?l00003ooooo`040?l00?oooooo
oooo0?l001[ooooo00@0o`00ooooooooool0o`000oooool01@3o003oooooooooooooool0o`0001Wo
oooo00D0o`00oooooooooooooooo0?l00003ooooo`040?l00?oooooooooo0?l001[ooooo00@0o`00
ooooooooool0o`000oooool01@3o003oooooooooooooool0o`0001Wooooo00<0o`00ooooooooool0
0_ooool00ol0003oooooooooo`0;ooooo`005?ooool2o`0000Cooooo00?o0000ooooooooool00_oo
ool3o`0000Cooooo00?o0000ooooooooool01_ooool01Ol00?oooooooooooooooooo003o00;ooooo
00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool06oooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool07?ooool01?l0
0?ooooooooooool00?l3ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00
o`03ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00000Nooooo`;o0000
1?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`05ooooo`05ool0
0?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0001Wooooo00D0o`00oooo
oooooooooooo0?l00003ooooo`040?l00?oooooooooo0?l001[ooooo00@0o`00ooooooooool0o`00
0oooool01@3o003oooooooooooooool0o`0001Wooooo00D0o`00oooooooooooooooo0?l00003oooo
o`040?l00?oooooooooo0?l001[ooooo00@0o`00ooooooooool0o`000oooool01@3o003ooooooooo
ooooool0o`0001Wooooo00<0o`00ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`004ooo
ool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`06ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0Koooo
o`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`05o`00oooooooo
ooooooooool00?l00_ooool00ol00?ooooooooooo`0Looooo`04o`00ooooooooooooo`00o`?ooooo
00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003ooooooooo
ool06oooool01Ol00?oooooooooooooooooo000001gooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool01Oooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0000Iooooo`050?l00?oooooooooooooo
o`3o00000oooool0103o003oooooooooo`3o000Jooooo`040?l00?oooooooooo0?l000?ooooo00D0
o`00oooooooooooooooo0?l0000Iooooo`050?l00?ooooooooooooooo`3o00000oooool0103o003o
ooooooooo`3o000Jooooo`040?l00?oooooooooo0?l000?ooooo00D0o`00oooooooooooooooo0?l0
000Iooooo`030?l00?oooooooooo00;ooooo00?o0000ooooooooool02oooool001?ooooo00Co0000
oooooooooooo00002oooool01?l0003oooooooooooooool3o`0000Kooooo00Go003ooooooooooooo
ooooo`00o`02ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`03oooo
o`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooo
oooo01cooooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`0Kooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00;o0000
7Oooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00;ooooo0_l00006ooooo`05
ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0001Wooooo00D0o`00
oooooooooooooooo0?l00003ooooo`040?l00?oooooooooo0?l001[ooooo00@0o`00ooooooooool0
o`000oooool01@3o003oooooooooooooool0o`0001Wooooo00D0o`00oooooooooooooooo0?l00003
ooooo`040?l00?oooooooooo0?l001[ooooo00@0o`00ooooooooool0o`000oooool01@3o003ooooo
ooooooooool0o`0001Wooooo00@0o`00oooooooooooooooo0_l0000=ooooo`004oooool01?l0003o
ooooooooool0000;ooooo`05o`000?ooooooooooooooool000002?ooool01Ol00?oooooooooooooo
oooo003o00;ooooo00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003ooooooooo
ool07?ooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo01_ooooo00Go003ooooo
ooooooooooooo`00o`03ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00
000Mooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`05ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`00
01Wooooo00D0o`00oooooooooooooooo0?l00003ooooo`040?l00?oooooooooo0?l001[ooooo00@0
o`00ooooooooool0o`000oooool01@3o003oooooooooooooool0o`0001Wooooo00D0o`00oooooooo
oooooooo0?l00003ooooo`040?l00?oooooooooo0?l001[ooooo00@0o`00ooooooooool0o`000ooo
ool01@3o003oooooooooooooool0o`0001Wooooo00<0o`00ooooooooool00_ooool00ol0003ooooo
ooooo`0;ooooo`004oooool01?l0003oooooooooool00007ooooo`Co00001?ooool00ol0003ooooo
ooooo`06ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0Kooooo`05
o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`05o`00oooooooooooo
ooooool00?l00_ooool00ol00?ooooooooooo`0Looooo`04o`00ooooooooooooo`00o`?ooooo00?o
003oooooooooool06oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
6oooool01Ol00?oooooooooooooooooo000001gooooo00Co0000oooooooooooo00001oooool4o`00
00Gooooo00?o0000ooooooooool01Oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00
ooooooooooooooooool0000Iooooo`050?l00?ooooooooooooooo`3o00000oooool0103o003ooooo
ooooo`3o000Jooooo`040?l00?oooooooooo0?l000?ooooo00D0o`00oooooooooooooooo0?l0000I
ooooo`050?l00?ooooooooooooooo`3o00000oooool0103o003oooooooooo`3o000Jooooo`040?l0
0?oooooooooo0?l000?ooooo00D0o`00oooooooooooooooo0?l0000Iooooo`030?l00?oooooooooo
00;ooooo00?o0000ooooooooool02oooool001?ooooo00Co0000oooooooooooo00001oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00Go003oooooooooooooooooo`00o`02
ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooo
oooooooo01_ooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo01cooooo
00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`0Kooooo`05o`00oooooooooooooooo
ool00?l00oooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool000007Oooool0
1?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?oo
ool3ool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`?oo`005oooool3ool000;ooooo
00H0o`00oooooooooooooooo0?l00?ooool3ool001Sooooo0ooo00000oooool0o`00ooooo`02oooo
o`030?l00?oooooooooo00?oo`005oooool3ool000;ooooo00H0o`00oooooooooooooooo0?l00?oo
ool3ool001Sooooo0ooo00000oooool0o`00ooooo`02ooooo`030?l00?oooooooooo00?oo`005ooo
ool3ool000?ooooo00?o0000ooooooooool02oooool001Cooooo0_l00008ooooo`Go00000oooool0
0ol0003oooooooooo`06ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?oooooooooo
o`0Kooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`05o`00
ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0Looooo`04o`00ooooooooooooo`00
o`?ooooo00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool06oooool01Ol00?oooooooooooooooooo000001kooooo0_l00008ooooo`Go00001?oo
ool00ol0003oooooooooo`04ooooo`?oo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo
0ooo000Gooooo`?oo`000_ooool01P3o003oooooooooooooool0o`00ooooo`?oo`006?ooool3ool0
0003ooooo`3o003ooooo00;ooooo00<0o`00ooooooooool00ooo000Gooooo`?oo`000_ooool01P3o
003oooooooooooooool0o`00ooooo`?oo`006?ooool3ool00003ooooo`3o003ooooo00;ooooo00<0
o`00ooooooooool00ooo000Gooooo`?oo`000oooool00ol0003oooooooooo`0;ooooo`009_ooool0
0ol0003oooooooooo`06ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?oooooooooo
o`0Kooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`05o`00
ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0Looooo`04o`00ooooooooooooo`00
o`?ooooo00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool06oooool01Ol00?oooooooooooooooooo0000037ooooo00?o0000ooooooooool01?oo
ool3ool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`?oo`005oooool3ool000;ooooo
00H0o`00oooooooooooooooo0?l00?ooool3ool001Sooooo0ooo00000oooool0o`00ooooo`02oooo
o`030?l00?oooooooooo00?oo`005oooool3ool000;ooooo00H0o`00oooooooooooooooo0?l00?oo
ool3ool001Sooooo0ooo00000oooool0o`00ooooo`02ooooo`030?l00?oooooooooo00?oo`005ooo
ool3ool000?ooooo00?o0000ooooooooool02oooool002Kooooo0_l00007ooooo`05o`00oooooooo
ooooooooool00?l00_ooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?oo
ooooooooo`0Looooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool06oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06oooool01Ol00?oooooooooooooo
oooo0000037ooooo0_l0000:ooooo`05ool00?oooooooooooooooooo00008Oooool01@3o003ooooo
ooooooooool0o`00023ooooo00D0o`00oooooooooooooooo0?l0000Qooooo`050?l00?oooooooooo
ooooo`3o00008?ooool01@3o003oooooooooooooool0o`00027ooooo0_l0000=ooooo`009_ooool0
0ol0003oooooooooo`06ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?oooooooooo
o`0Kooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`05o`00
ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0Looooo`04o`00ooooooooooooo`00
o`?ooooo00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool06oooool01Ol00?oooooooooooooooooo0000037ooooo00?o0000ooooooooool02Ooo
ool01Ooo003oooooooooooooooooo`00027ooooo00D0o`00oooooooooooooooo0?l0000Pooooo`05
0?l00?ooooooooooooooo`3o00008Oooool01@3o003oooooooooooooool0o`00023ooooo00D0o`00
oooooooooooooooo0?l0000Rooooo`03o`000?oooooooooo00_ooooo000Vooooo`03o`000?oooooo
oooo00Kooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo01_ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01_ooooo00Go003ooooooooooooo
ooooo`00o`02ooooo`03o`00oooooooooooo01cooooo00Co003ooooooooooooo003o0oooool00ol0
0?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0K
ooooo`05o`00ooooooooooooooooool00000<Oooool00ol0003oooooooooo`09ooooo`05ool00?oo
oooooooooooooooo00008Oooool01@3o003oooooooooooooool0o`00023ooooo00D0o`00oooooooo
oooooooo0?l0000Qooooo`050?l00?ooooooooooooooo`3o00008?ooool01@3o003ooooooooooooo
ool0o`0002;ooooo00?o0000ooooooooool02oooool002Kooooo00?o0000ooooooooool01_ooool0
1Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool06oooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo003o00;o
oooo00?o003oooooooooool07?ooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo
01_ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01_ooooo00Go003o
ooooooooooooooooo`00000aooooo`03o`000?oooooooooo00Wooooo00Goo`00oooooooooooooooo
ool0000Qooooo`050?l00?ooooooooooooooo`3o00008?ooool01@3o003oooooooooooooool0o`00
027ooooo00D0o`00oooooooooooooooo0?l0000Pooooo`050?l00?ooooooooooooooo`3o00008_oo
ool00ol0003oooooooooo`0;ooooo`009_ooool00ol0003oooooooooo`06ooooo`05o`00oooooooo
ooooooooool00?l00_ooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?oo
ooooooooo`0Looooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool06oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06oooool01Ol00?oooooooooooooo
oooo0000037ooooo00?o0000ooooooooool02Oooool01Ooo003oooooooooooooooooo`00027ooooo
00D0o`00oooooooooooooooo0?l0000Pooooo`050?l00?ooooooooooooooo`3o00008Oooool01@3o
003oooooooooooooool0o`00023ooooo00D0o`00oooooooooooooooo0?l0000Rooooo`03o`000?oo
oooooooo00_ooooo000Vooooo`03o`000?oooooooooo00Kooooo00Go003oooooooooooooooooo`00
o`02ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo01co
oooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`0Kooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00000<Ooo
ool00ol0003oooooooooo`09ooooo`05ool00?oooooooooooooooooo00008Oooool01@3o003ooooo
ooooooooool0o`00023ooooo00D0o`00oooooooooooooooo0?l0000Qooooo`050?l00?oooooooooo
ooooo`3o00008?ooool01@3o003oooooooooooooool0o`0002;ooooo00?o0000ooooooooool02ooo
ool002Kooooo0_l00007ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?oooooooooo
o`0Kooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`05o`00
ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0Looooo`04o`00ooooooooooooo`00
o`?ooooo00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool06oooool01Ol00?oooooooooooooooooo0000037ooooo0_l0000:ooooo`05ool00?oo
oooooooooooooooo00008Oooool01@3o003oooooooooooooool0o`00023ooooo00D0o`00oooooooo
oooooooo0?l0000Qooooo`050?l00?ooooooooooooooo`3o00008?ooool01@3o003ooooooooooooo
ool0o`00027ooooo0_l0000=ooooo`009_ooool00ol0003oooooooooo`06ooooo`05o`00oooooooo
ooooooooool00?l00_ooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l0
0oooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?oo
ooooooooo`0Looooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool06oooool01Ol0
0?oooooooooooooooooo003o00?ooooo00?o003oooooooooool06oooool01Ol00?oooooooooooooo
oooo0000037ooooo00?o0000ooooooooool02Oooool01Ooo003oooooooooooooooooo`00027ooooo
00D0o`00oooooooooooooooo0?l0000Pooooo`050?l00?ooooooooooooooo`3o00008Oooool01@3o
003oooooooooooooool0o`00023ooooo00D0o`00oooooooooooooooo0?l0000Rooooo`03o`000?oo
oooooooo00_ooooo000Vooooo`03o`000?oooooooooo00Kooooo00Go003oooooooooooooooooo`00
o`02ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`03ooooo`03o`00
oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo01co
oooo00Co003ooooooooooooo003o0oooool00ol00?ooooooooooo`0Kooooo`05o`00oooooooooooo
ooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00000<Ooo
ool00ol0003oooooooooo`09ooooo`05ool00?oooooooooooooooooo00008Oooool01@3o003ooooo
ooooooooool0o`00023ooooo00D0o`00oooooooooooooooo0?l0000Qooooo`050?l00?oooooooooo
ooooo`3o00008?ooool01@3o003oooooooooooooool0o`0002;ooooo00?o0000ooooooooool02ooo
ool002Kooooo00?o0000ooooooooool01_ooool01Ol00?oooooooooooooooooo003o00;ooooo00?o
003oooooooooool06oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool0
6oooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooooooool07?ooool01?l00?oo
ooooooooool00?l3ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00o`03
ooooo`03o`00oooooooooooo01_ooooo00Go003oooooooooooooooooo`00000aooooo`03o`000?oo
oooooooo00Wooooo00Goo`00ooooooooooooooooool0000Qooooo`050?l00?ooooooooooooooo`3o
00008?ooool01@3o003oooooooooooooool0o`00027ooooo00D0o`00oooooooooooooooo0?l0000P
ooooo`050?l00?ooooooooooooooo`3o00008_ooool00ol0003oooooooooo`0;ooooo`009_ooool0
0ol0003oooooooooo`06ooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?oooooooooo
o`0Kooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0Kooooo`05o`00
ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0Looooo`04o`00ooooooooooooo`00
o`?ooooo00?o003oooooooooool06oooool01Ol00?oooooooooooooooooo003o00?ooooo00?o003o
ooooooooool06oooool01Ol00?oooooooooooooooooo0000037ooooo00?o0000ooooooooool02Ooo
ool01Ooo003oooooooooooooooooo`00027ooooo00D0o`00oooooooooooooooo0?l0000Pooooo`05
0?l00?ooooooooooooooo`3o00008Oooool01@3o003oooooooooooooool0o`00023ooooo00D0o`00
oooooooooooooooo0?l0000Rooooo`03o`000?oooooooooo00_ooooo000Vooooo`03o`000?oooooo
oooo00Kooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo01_ooooo00Go
003oooooooooooooooooo`00o`03ooooo`03o`00oooooooooooo01_ooooo00Go003ooooooooooooo
ooooo`00o`02ooooo`03o`00oooooooooooo01cooooo00Co003ooooooooooooo003o0oooool00ol0
0?ooooooooooo`0Kooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`0K
ooooo`05o`00ooooooooooooooooool00000<Oooool00ol0003oooooooooo`09ooooo`05ool00?oo
oooooooooooooooo00008Oooool01@3o003oooooooooooooool0o`00023ooooo00D0o`00oooooooo
oooooooo0?l0000Qooooo`050?l00?ooooooooooooooo`3o00008?ooool01@3o003ooooooooooooo
ool0o`0002;ooooo00?o0000ooooooooool02oooool002Kooooo0_l00006ooooo`?o003o0_ooool0
0ol00?ooooooo`00o`02o`00oa_ooooo0ol00?l2ooooo`03o`00oooooooooooo00?o003o6oooool3
o`00o`;ooooo00?o003oooooool00?l00_l00?lLooooo`?o003o00Coooooo`00oooooooooooo0ol0
0?lKooooo`?o003o0_ooool00ol00?ooooooooooo`03o`00oa_ooooo0ol00?l2ooooo`03o`000?oo
oooooooo02oooooo0_l0000:ooooo`05ool00?oooooooooooooooooo00008Oooool01@3o003ooooo
ooooooooool0o`00023ooooo00D0o`00oooooooooooooooo0?l0000Qooooo`050?l00?oooooooooo
ooooo`3o00008?ooool01@3o003oooooooooooooool0o`00027ooooo0_l0000=ooooo`009_ooool0
0ol0003oooooooooo`05ooooo`?o003o0_ooool00ol00?ooooooo`00o`02o`00oa_ooooo0ol00?l2
ooooo`03o`00oooooooooooo00?o003o6oooool3o`00o`;ooooo00?o003oooooool00?l00_l00?lL
ooooo`?o003o00Coooooo`00oooooooooooo0ol00?lKooooo`?o003o0_ooool00ol00?oooooooooo
o`03o`00oa_ooooo0ol00?l2ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool02Ooo
ool01Ooo003oooooooooooooooooo`00027ooooo00D0o`00oooooooooooooooo0?l0000Pooooo`05
0?l00?ooooooooooooooo`3o00008Oooool01@3o003oooooooooooooool0o`00023ooooo00D0o`00
oooooooooooooooo0?l0000Rooooo`03o`000?oooooooooo00_ooooo000Vooooo`03o`000?oooooo
oooo00Gooooo0ol00?l2ooooo`03o`00oooooooo003o00;o003o6oooool3o`00o`;ooooo00?o003o
ooooooooool00ol00?lKooooo`?o003o0_ooool00ol00?ooooooo`00o`02o`00oacooooo0ol00?l0
1?oooooo003oooooooooool3o`00oa_ooooo0ol00?l2ooooo`03o`00oooooooooooo00?o003o6ooo
ool3o`00o`;ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`09ooooo`05ool00?oo
oooooooooooooooo00008Oooool01@3o003oooooooooooooool0o`00023ooooo00D0o`00oooooooo
oooooooo0?l0000Qooooo`050?l00?ooooooooooooooo`3o00008?ooool01@3o003ooooooooooooo
ool0o`0002;ooooo00?o0000ooooooooool02oooool002Kooooo00?o0000ooooooooool02_ooool0
0ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo02?ooooo00?o003oooooooooool08_ooool0
0ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo02?ooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`09ooooo`05ool00?oooooooooooooooooo00008Oooool01@3o003ooooooooo
ooooool0o`00023ooooo00D0o`00oooooooooooooooo0?l0000Qooooo`050?l00?oooooooooooooo
o`3o00008?ooool01@3o003oooooooooooooool0o`0002;ooooo00?o0000ooooooooool02oooool0
02Kooooo00?o0000ooooooooool02_ooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo
02?ooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo
02?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`09ooooo`05ool00?oooooooooo
oooooooo00008Oooool01@3o003oooooooooooooool0o`00023ooooo00D0o`00oooooooooooooooo
0?l0000Qooooo`050?l00?ooooooooooooooo`3o00008?ooool01@3o003oooooooooooooool0o`00
02;ooooo00?o0000ooooooooool02oooool002Kooooo00?o0000ooooooooool02_ooool00ol00?oo
ooooooooo`0Rooooo`03o`00oooooooooooo02?ooooo00?o003oooooooooool08_ooool00ol00?oo
ooooooooo`0Sooooo`03o`00oooooooooooo02?ooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`08ooooo`?oo`0000Coooooool00?oo003oo`007oooool3ool00004oooooooo003oo`00
ool001kooooo0ooo00001?ooooooo`00ool00?oo000Oooooo`?oo`0000Coooooool00?oo003oo`00
7_ooool3ool00004oooooooo003oo`00ool0027ooooo00?o0000ooooooooool02oooool002Kooooo
0_l0000;ooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool08oooool00ol00?oooooo
ooooo`0Rooooo`03o`00oooooooooooo02?ooooo00?o003oooooooooool08oooool00ol0003ooooo
ooooo`0_ooooo`;o00002Oooool3ool00004oooooooo003oo`00ool001oooooo0ooo00001?oooooo
o`00ool00?oo000Nooooo`?oo`0000Coooooool00?oo003oo`007oooool3ool00004oooooooo003o
o`00ool001kooooo0ooo00001?ooooooo`00ool00?oo000Pooooo`;o00003Oooool002Kooooo00?o
0000ooooooooool02_ooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo02?ooooo00?o
003oooooooooool08_ooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo02?ooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`08ooooo`?oo`0000Coooooool00?oo003oo`00
7oooool3ool00004oooooooo003oo`00ool001kooooo0ooo00001?ooooooo`00ool00?oo000Ooooo
o`?oo`0000Coooooool00?oo003oo`007_ooool3ool00004oooooooo003oo`00ool0027ooooo00?o
0000ooooooooool02oooool002Kooooo00?o0000ooooooooool02_ooool00ol00?ooooooooooo`0R
ooooo`03o`00oooooooooooo02?ooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`0S
ooooo`03o`00oooooooooooo02?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`36
ooooo`03o`000?oooooooooo00_ooooo000Oooooo`?o00001?ooool00ol0003oooooooooo`0:oooo
o`03o`00oooooooooooo02;ooooo00?o003oooooooooool08oooool00ol00?ooooooooooo`0Roooo
o`03o`00oooooooooooo02?ooooo00?o003oooooooooool08oooool00ol0003oooooooooo`0Woooo
o`?o00001Oooool00ol0003oooooooooo`36ooooo`03o`000?oooooooooo00_ooooo000Pooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol00?ooooooooooo`0Rooooo`03
o`00oooooooooooo02?ooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`0Sooooo`03
o`00oooooooooooo02?ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo0<Kooooo00?o0000ooooooooool02oooool0023ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`09ooooo`?o003o8_ooool3o`00ob?ooooo0ol00?lRooooo`?o003o
8oooool3o`00obCooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo0<Kooooo00?o0000ooooooooool02oooool0023ooooo00?o0000ooooooooool00ooo
ool00ol00000000000000009ooooo`?o003o8_ooool3o`00ob?ooooo0ol00?lRooooo`?o003o8ooo
ool3o`00ob?ooooo0_l0000Zooooo`03o`000?oooooooooo00Cooooo0_l00036ooooo`;o00003Ooo
ool0023ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`?o003o8_ooool3
o`00ob?ooooo0ol00?lRooooo`?o003o8oooool3o`00obCooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0<Kooooo00?o0000ooooooooool02oooool0
01oooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`;o0000:Oooool2o`0000Kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l0000=ooooo`008?ooool00ol0003o
ooooooooo`03oooool[o0000:_ooool00ol0003oooooooooo`04oooool[o00003Oooool00?oooooo
nOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooo
nOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00001\
\>"],
  ImageRangeCache->{{{0, 503}, {310.438, 0}} -> {-0.0514703, -0.0309082, \
0.0041808, 0.0041808}, {{12.3125, 240.062}, {303, 162.25}} -> {-11.6137, \
-1.39894, 0.266274, 0.0168957}, {{262.875, 490.688}, {303, 162.25}} -> \
{-78.3085, -1.39853, 0.266192, 0.0168905}, {{12.3125, 240.062}, {148.125, \
7.375}} -> {-11.6137, -4.01566, 0.266274, 0.0168957}, {{262.875, 490.688}, \
{148.125, 7.375}} -> {-78.3085, -4.01444, 0.266192, 0.0168905}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["(2) Example of phase distortion", "Section"],

Cell[CellGroupData[{

Cell["Linear phase (no distortion)", "Subsection"],

Cell[BoxData[{
    \(\(x1[n_] := 
        Cos[2  \[Pi]\ n/50]\  + \ 
          2\ Cos[4  \[Pi]\ n/50];\)\), "\[IndentingNewLine]", 
    \(\(y1[n_] := 
        Cos[2  \[Pi]\ n/50\  - \ 5 \((2  \[Pi]/50)\)]\  + \ 
          2\ Cos[4  \[Pi]\ n/50\  - \ 5 \((4  \[Pi]/50)\)];\)\)}], "Input"],

Cell[BoxData[{
    \(\(xn\  = \ Table[{n, x1[n]}, {n, 0, 100}];\)\), "\[IndentingNewLine]", 
    \(\(xn2\  = \ 
        Table[{n, y1[n]}, {n, 0, 100}];\)\), "\[IndentingNewLine]", 
    \(\(g1a = 
        DiscreteListPlot[xn, \ Blue, \ DisplayFunction \[Rule] Identity, \ 
          Frame \[Rule] True];\)\), "\[IndentingNewLine]", 
    \(\(g2a = 
        DiscreteListPlot[xn2, \ Red, \ DisplayFunction \[Rule] Identity, \ 
          Frame \[Rule] True];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ga = 
        Show[GraphicsArray[{{g1a, g2a}}], \ 
          ImageSize \[Rule] 504];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
%%ImageSize: 504 148.328 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.253447 0.116624 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -6 -9 ]
[.21429 -0.0125 6 0 ]
[.40476 -0.0125 -6 -9 ]
[.40476 -0.0125 6 0 ]
[.59524 -0.0125 -6 -9 ]
[.59524 -0.0125 6 0 ]
[.78571 -0.0125 -6 -9 ]
[.78571 -0.0125 6 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0202 -12 -4.5 ]
[-0.0125 .0202 0 4.5 ]
[-0.0125 .13682 -12 -4.5 ]
[-0.0125 .13682 0 4.5 ]
[-0.0125 .25345 -6 -4.5 ]
[-0.0125 .25345 0 4.5 ]
[-0.0125 .37007 -6 -4.5 ]
[-0.0125 .37007 0 4.5 ]
[-0.0125 .48669 -6 -4.5 ]
[-0.0125 .48669 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(20)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(40)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(60)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(80)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(100)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0202 m
.00625 .0202 L
s
[(-2)] -0.0125 .0202 1 0 Mshowa
0 .13682 m
.00625 .13682 L
s
[(-1)] -0.0125 .13682 1 0 Mshowa
0 .25345 m
.00625 .25345 L
s
[(0)] -0.0125 .25345 1 0 Mshowa
0 .37007 m
.00625 .37007 L
s
[(1)] -0.0125 .37007 1 0 Mshowa
0 .48669 m
.00625 .48669 L
s
[(2)] -0.0125 .48669 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(3)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04352 m
.00375 .04352 L
s
0 .06685 m
.00375 .06685 L
s
0 .09017 m
.00375 .09017 L
s
0 .1135 m
.00375 .1135 L
s
0 .16015 m
.00375 .16015 L
s
0 .18347 m
.00375 .18347 L
s
0 .2068 m
.00375 .2068 L
s
0 .23012 m
.00375 .23012 L
s
0 .27677 m
.00375 .27677 L
s
0 .3001 m
.00375 .3001 L
s
0 .32342 m
.00375 .32342 L
s
0 .34675 m
.00375 .34675 L
s
0 .3934 m
.00375 .3934 L
s
0 .41672 m
.00375 .41672 L
s
0 .44005 m
.00375 .44005 L
s
0 .46337 m
.00375 .46337 L
s
0 .51002 m
.00375 .51002 L
s
0 .53334 m
.00375 .53334 L
s
0 .55667 m
.00375 .55667 L
s
0 .57999 m
.00375 .57999 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0202 m
1 .0202 L
s
.99375 .13682 m
1 .13682 L
s
.99375 .25345 m
1 .25345 L
s
.99375 .37007 m
1 .37007 L
s
.99375 .48669 m
1 .48669 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04352 m
1 .04352 L
s
.99625 .06685 m
1 .06685 L
s
.99625 .09017 m
1 .09017 L
s
.99625 .1135 m
1 .1135 L
s
.99625 .16015 m
1 .16015 L
s
.99625 .18347 m
1 .18347 L
s
.99625 .2068 m
1 .2068 L
s
.99625 .23012 m
1 .23012 L
s
.99625 .27677 m
1 .27677 L
s
.99625 .3001 m
1 .3001 L
s
.99625 .32342 m
1 .32342 L
s
.99625 .34675 m
1 .34675 L
s
.99625 .3934 m
1 .3934 L
s
.99625 .41672 m
1 .41672 L
s
.99625 .44005 m
1 .44005 L
s
.99625 .46337 m
1 .46337 L
s
.99625 .51002 m
1 .51002 L
s
.99625 .53334 m
1 .53334 L
s
.99625 .55667 m
1 .55667 L
s
.99625 .57999 m
1 .57999 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .25345 m
.02381 .60332 L
s
.03333 .25345 m
.03333 .59507 L
s
.04286 .25345 m
.04286 .5708 L
s
.05238 .25345 m
.05238 .53191 L
s
.0619 .25345 m
.0619 .48063 L
s
.07143 .25345 m
.07143 .41988 L
s
.08095 .25345 m
.08095 .35311 L
s
.09048 .25345 m
.09048 .28408 L
s
.1 .25345 m
.1 .21662 L
s
.10952 .25345 m
.10952 .15442 L
s
.11905 .25345 m
.11905 .10078 L
s
.12857 .25345 m
.12857 .05843 L
s
.1381 .25345 m
.1381 .02936 L
s
.14762 .25345 m
.14762 .01472 L
s
.15714 .25345 m
.15714 .01473 L
s
.16667 .25345 m
.16667 .02871 L
s
.17619 .25345 m
.17619 .05511 L
s
.18571 .25345 m
.18571 .09164 L
s
.19524 .25345 m
.19524 .1354 L
s
.20476 .25345 m
.20476 .18308 L
s
.21429 .25345 m
.21429 .23117 L
s
.22381 .25345 m
.22381 .27623 L
s
.23333 .25345 m
.23333 .31504 L
s
.24286 .25345 m
.24286 .34488 L
s
.25238 .25345 m
.25238 .36366 L
s
.2619 .25345 m
.2619 .37007 L
s
.27143 .25345 m
.27143 .36366 L
s
.28095 .25345 m
.28095 .34488 L
s
.29048 .25345 m
.29048 .31504 L
s
.3 .25345 m
.3 .27623 L
s
.30952 .25345 m
.30952 .23117 L
s
.31905 .25345 m
.31905 .18308 L
s
.32857 .25345 m
.32857 .1354 L
s
.3381 .25345 m
.3381 .09164 L
s
.34762 .25345 m
.34762 .05511 L
s
.35714 .25345 m
.35714 .02871 L
s
.36667 .25345 m
.36667 .01473 L
s
.37619 .25345 m
.37619 .01472 L
s
.38571 .25345 m
.38571 .02936 L
s
.39524 .25345 m
.39524 .05843 L
s
.40476 .25345 m
.40476 .10078 L
s
.41429 .25345 m
.41429 .15442 L
s
.42381 .25345 m
.42381 .21662 L
s
.43333 .25345 m
.43333 .28408 L
s
.44286 .25345 m
.44286 .35311 L
s
.45238 .25345 m
.45238 .41988 L
s
.4619 .25345 m
.4619 .48063 L
s
.47143 .25345 m
.47143 .53191 L
s
.48095 .25345 m
.48095 .5708 L
s
.49048 .25345 m
.49048 .59507 L
s
.5 .25345 m
.5 .60332 L
s
.50952 .25345 m
.50952 .59507 L
s
.51905 .25345 m
.51905 .5708 L
s
.52857 .25345 m
.52857 .53191 L
s
.5381 .25345 m
.5381 .48063 L
s
.54762 .25345 m
.54762 .41988 L
s
.55714 .25345 m
.55714 .35311 L
s
.56667 .25345 m
.56667 .28408 L
s
.57619 .25345 m
.57619 .21662 L
s
.58571 .25345 m
.58571 .15442 L
s
.59524 .25345 m
.59524 .10078 L
s
.60476 .25345 m
.60476 .05843 L
s
.61429 .25345 m
.61429 .02936 L
s
.62381 .25345 m
.62381 .01472 L
s
.63333 .25345 m
.63333 .01473 L
s
.64286 .25345 m
.64286 .02871 L
s
.65238 .25345 m
.65238 .05511 L
s
.6619 .25345 m
.6619 .09164 L
s
.67143 .25345 m
.67143 .1354 L
s
.68095 .25345 m
.68095 .18308 L
s
.69048 .25345 m
.69048 .23117 L
s
.7 .25345 m
.7 .27623 L
s
.70952 .25345 m
.70952 .31504 L
s
.71905 .25345 m
.71905 .34488 L
s
.72857 .25345 m
.72857 .36366 L
s
.7381 .25345 m
.7381 .37007 L
s
.74762 .25345 m
.74762 .36366 L
s
.75714 .25345 m
.75714 .34488 L
s
.76667 .25345 m
.76667 .31504 L
s
.77619 .25345 m
.77619 .27623 L
s
.78571 .25345 m
.78571 .23117 L
s
.79524 .25345 m
.79524 .18308 L
s
.80476 .25345 m
.80476 .1354 L
s
.81429 .25345 m
.81429 .09164 L
s
.82381 .25345 m
.82381 .05511 L
s
.83333 .25345 m
.83333 .02871 L
s
.84286 .25345 m
.84286 .01473 L
s
.85238 .25345 m
.85238 .01472 L
s
.8619 .25345 m
.8619 .02936 L
s
.87143 .25345 m
.87143 .05843 L
s
.88095 .25345 m
.88095 .10078 L
s
.89048 .25345 m
.89048 .15442 L
s
.9 .25345 m
.9 .21662 L
s
.90952 .25345 m
.90952 .28408 L
s
.91905 .25345 m
.91905 .35311 L
s
.92857 .25345 m
.92857 .41988 L
s
.9381 .25345 m
.9381 .48063 L
s
.94762 .25345 m
.94762 .53191 L
s
.95714 .25345 m
.95714 .5708 L
s
.96667 .25345 m
.96667 .59507 L
s
.97619 .25345 m
.97619 .60332 L
s
.015 w
.02381 .60332 Mdot
.03333 .59507 Mdot
.04286 .5708 Mdot
.05238 .53191 Mdot
.0619 .48063 Mdot
.07143 .41988 Mdot
.08095 .35311 Mdot
.09048 .28408 Mdot
.1 .21662 Mdot
.10952 .15442 Mdot
.11905 .10078 Mdot
.12857 .05843 Mdot
.1381 .02936 Mdot
.14762 .01472 Mdot
.15714 .01473 Mdot
.16667 .02871 Mdot
.17619 .05511 Mdot
.18571 .09164 Mdot
.19524 .1354 Mdot
.20476 .18308 Mdot
.21429 .23117 Mdot
.22381 .27623 Mdot
.23333 .31504 Mdot
.24286 .34488 Mdot
.25238 .36366 Mdot
.2619 .37007 Mdot
.27143 .36366 Mdot
.28095 .34488 Mdot
.29048 .31504 Mdot
.3 .27623 Mdot
.30952 .23117 Mdot
.31905 .18308 Mdot
.32857 .1354 Mdot
.3381 .09164 Mdot
.34762 .05511 Mdot
.35714 .02871 Mdot
.36667 .01473 Mdot
.37619 .01472 Mdot
.38571 .02936 Mdot
.39524 .05843 Mdot
.40476 .10078 Mdot
.41429 .15442 Mdot
.42381 .21662 Mdot
.43333 .28408 Mdot
.44286 .35311 Mdot
.45238 .41988 Mdot
.4619 .48063 Mdot
.47143 .53191 Mdot
.48095 .5708 Mdot
.49048 .59507 Mdot
.5 .60332 Mdot
.50952 .59507 Mdot
.51905 .5708 Mdot
.52857 .53191 Mdot
.5381 .48063 Mdot
.54762 .41988 Mdot
.55714 .35311 Mdot
.56667 .28408 Mdot
.57619 .21662 Mdot
.58571 .15442 Mdot
.59524 .10078 Mdot
.60476 .05843 Mdot
.61429 .02936 Mdot
.62381 .01472 Mdot
.63333 .01473 Mdot
.64286 .02871 Mdot
.65238 .05511 Mdot
.6619 .09164 Mdot
.67143 .1354 Mdot
.68095 .18308 Mdot
.69048 .23117 Mdot
.7 .27623 Mdot
.70952 .31504 Mdot
.71905 .34488 Mdot
.72857 .36366 Mdot
.7381 .37007 Mdot
.74762 .36366 Mdot
.75714 .34488 Mdot
.76667 .31504 Mdot
.77619 .27623 Mdot
.78571 .23117 Mdot
.79524 .18308 Mdot
.80476 .1354 Mdot
.81429 .09164 Mdot
.82381 .05511 Mdot
.83333 .02871 Mdot
.84286 .01473 Mdot
.85238 .01472 Mdot
.8619 .02936 Mdot
.87143 .05843 Mdot
.88095 .10078 Mdot
.89048 .15442 Mdot
.9 .21662 Mdot
.90952 .28408 Mdot
.91905 .35311 Mdot
.92857 .41988 Mdot
.9381 .48063 Mdot
.94762 .53191 Mdot
.95714 .5708 Mdot
.96667 .59507 Mdot
.97619 .60332 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.253447 0.116624 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -6 -9 ]
[.21429 -0.0125 6 0 ]
[.40476 -0.0125 -6 -9 ]
[.40476 -0.0125 6 0 ]
[.59524 -0.0125 -6 -9 ]
[.59524 -0.0125 6 0 ]
[.78571 -0.0125 -6 -9 ]
[.78571 -0.0125 6 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0202 -12 -4.5 ]
[-0.0125 .0202 0 4.5 ]
[-0.0125 .13682 -12 -4.5 ]
[-0.0125 .13682 0 4.5 ]
[-0.0125 .25345 -6 -4.5 ]
[-0.0125 .25345 0 4.5 ]
[-0.0125 .37007 -6 -4.5 ]
[-0.0125 .37007 0 4.5 ]
[-0.0125 .48669 -6 -4.5 ]
[-0.0125 .48669 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(20)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(40)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(60)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(80)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(100)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0202 m
.00625 .0202 L
s
[(-2)] -0.0125 .0202 1 0 Mshowa
0 .13682 m
.00625 .13682 L
s
[(-1)] -0.0125 .13682 1 0 Mshowa
0 .25345 m
.00625 .25345 L
s
[(0)] -0.0125 .25345 1 0 Mshowa
0 .37007 m
.00625 .37007 L
s
[(1)] -0.0125 .37007 1 0 Mshowa
0 .48669 m
.00625 .48669 L
s
[(2)] -0.0125 .48669 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(3)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04352 m
.00375 .04352 L
s
0 .06685 m
.00375 .06685 L
s
0 .09017 m
.00375 .09017 L
s
0 .1135 m
.00375 .1135 L
s
0 .16015 m
.00375 .16015 L
s
0 .18347 m
.00375 .18347 L
s
0 .2068 m
.00375 .2068 L
s
0 .23012 m
.00375 .23012 L
s
0 .27677 m
.00375 .27677 L
s
0 .3001 m
.00375 .3001 L
s
0 .32342 m
.00375 .32342 L
s
0 .34675 m
.00375 .34675 L
s
0 .3934 m
.00375 .3934 L
s
0 .41672 m
.00375 .41672 L
s
0 .44005 m
.00375 .44005 L
s
0 .46337 m
.00375 .46337 L
s
0 .51002 m
.00375 .51002 L
s
0 .53334 m
.00375 .53334 L
s
0 .55667 m
.00375 .55667 L
s
0 .57999 m
.00375 .57999 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0202 m
1 .0202 L
s
.99375 .13682 m
1 .13682 L
s
.99375 .25345 m
1 .25345 L
s
.99375 .37007 m
1 .37007 L
s
.99375 .48669 m
1 .48669 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04352 m
1 .04352 L
s
.99625 .06685 m
1 .06685 L
s
.99625 .09017 m
1 .09017 L
s
.99625 .1135 m
1 .1135 L
s
.99625 .16015 m
1 .16015 L
s
.99625 .18347 m
1 .18347 L
s
.99625 .2068 m
1 .2068 L
s
.99625 .23012 m
1 .23012 L
s
.99625 .27677 m
1 .27677 L
s
.99625 .3001 m
1 .3001 L
s
.99625 .32342 m
1 .32342 L
s
.99625 .34675 m
1 .34675 L
s
.99625 .3934 m
1 .3934 L
s
.99625 .41672 m
1 .41672 L
s
.99625 .44005 m
1 .44005 L
s
.99625 .46337 m
1 .46337 L
s
.99625 .51002 m
1 .51002 L
s
.99625 .53334 m
1 .53334 L
s
.99625 .55667 m
1 .55667 L
s
.99625 .57999 m
1 .57999 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .25345 m
.02381 .41988 L
s
.03333 .25345 m
.03333 .48063 L
s
.04286 .25345 m
.04286 .53191 L
s
.05238 .25345 m
.05238 .5708 L
s
.0619 .25345 m
.0619 .59507 L
s
.07143 .25345 m
.07143 .60332 L
s
.08095 .25345 m
.08095 .59507 L
s
.09048 .25345 m
.09048 .5708 L
s
.1 .25345 m
.1 .53191 L
s
.10952 .25345 m
.10952 .48063 L
s
.11905 .25345 m
.11905 .41988 L
s
.12857 .25345 m
.12857 .35311 L
s
.1381 .25345 m
.1381 .28408 L
s
.14762 .25345 m
.14762 .21662 L
s
.15714 .25345 m
.15714 .15442 L
s
.16667 .25345 m
.16667 .10078 L
s
.17619 .25345 m
.17619 .05843 L
s
.18571 .25345 m
.18571 .02936 L
s
.19524 .25345 m
.19524 .01472 L
s
.20476 .25345 m
.20476 .01473 L
s
.21429 .25345 m
.21429 .02871 L
s
.22381 .25345 m
.22381 .05511 L
s
.23333 .25345 m
.23333 .09164 L
s
.24286 .25345 m
.24286 .1354 L
s
.25238 .25345 m
.25238 .18308 L
s
.2619 .25345 m
.2619 .23117 L
s
.27143 .25345 m
.27143 .27623 L
s
.28095 .25345 m
.28095 .31504 L
s
.29048 .25345 m
.29048 .34488 L
s
.3 .25345 m
.3 .36366 L
s
.30952 .25345 m
.30952 .37007 L
s
.31905 .25345 m
.31905 .36366 L
s
.32857 .25345 m
.32857 .34488 L
s
.3381 .25345 m
.3381 .31504 L
s
.34762 .25345 m
.34762 .27623 L
s
.35714 .25345 m
.35714 .23117 L
s
.36667 .25345 m
.36667 .18308 L
s
.37619 .25345 m
.37619 .1354 L
s
.38571 .25345 m
.38571 .09164 L
s
.39524 .25345 m
.39524 .05511 L
s
.40476 .25345 m
.40476 .02871 L
s
.41429 .25345 m
.41429 .01473 L
s
.42381 .25345 m
.42381 .01472 L
s
.43333 .25345 m
.43333 .02936 L
s
.44286 .25345 m
.44286 .05843 L
s
.45238 .25345 m
.45238 .10078 L
s
.4619 .25345 m
.4619 .15442 L
s
.47143 .25345 m
.47143 .21662 L
s
.48095 .25345 m
.48095 .28408 L
s
.49048 .25345 m
.49048 .35311 L
s
.5 .25345 m
.5 .41988 L
s
.50952 .25345 m
.50952 .48063 L
s
.51905 .25345 m
.51905 .53191 L
s
.52857 .25345 m
.52857 .5708 L
s
.5381 .25345 m
.5381 .59507 L
s
.54762 .25345 m
.54762 .60332 L
s
.55714 .25345 m
.55714 .59507 L
s
.56667 .25345 m
.56667 .5708 L
s
.57619 .25345 m
.57619 .53191 L
s
.58571 .25345 m
.58571 .48063 L
s
.59524 .25345 m
.59524 .41988 L
s
.60476 .25345 m
.60476 .35311 L
s
.61429 .25345 m
.61429 .28408 L
s
.62381 .25345 m
.62381 .21662 L
s
.63333 .25345 m
.63333 .15442 L
s
.64286 .25345 m
.64286 .10078 L
s
.65238 .25345 m
.65238 .05843 L
s
.6619 .25345 m
.6619 .02936 L
s
.67143 .25345 m
.67143 .01472 L
s
.68095 .25345 m
.68095 .01473 L
s
.69048 .25345 m
.69048 .02871 L
s
.7 .25345 m
.7 .05511 L
s
.70952 .25345 m
.70952 .09164 L
s
.71905 .25345 m
.71905 .1354 L
s
.72857 .25345 m
.72857 .18308 L
s
.7381 .25345 m
.7381 .23117 L
s
.74762 .25345 m
.74762 .27623 L
s
.75714 .25345 m
.75714 .31504 L
s
.76667 .25345 m
.76667 .34488 L
s
.77619 .25345 m
.77619 .36366 L
s
.78571 .25345 m
.78571 .37007 L
s
.79524 .25345 m
.79524 .36366 L
s
.80476 .25345 m
.80476 .34488 L
s
.81429 .25345 m
.81429 .31504 L
s
.82381 .25345 m
.82381 .27623 L
s
.83333 .25345 m
.83333 .23117 L
s
.84286 .25345 m
.84286 .18308 L
s
.85238 .25345 m
.85238 .1354 L
s
.8619 .25345 m
.8619 .09164 L
s
.87143 .25345 m
.87143 .05511 L
s
.88095 .25345 m
.88095 .02871 L
s
.89048 .25345 m
.89048 .01473 L
s
.9 .25345 m
.9 .01472 L
s
.90952 .25345 m
.90952 .02936 L
s
.91905 .25345 m
.91905 .05843 L
s
.92857 .25345 m
.92857 .10078 L
s
.9381 .25345 m
.9381 .15442 L
s
.94762 .25345 m
.94762 .21662 L
s
.95714 .25345 m
.95714 .28408 L
s
.96667 .25345 m
.96667 .35311 L
s
.97619 .25345 m
.97619 .41988 L
s
.015 w
.02381 .41988 Mdot
.03333 .48063 Mdot
.04286 .53191 Mdot
.05238 .5708 Mdot
.0619 .59507 Mdot
.07143 .60332 Mdot
.08095 .59507 Mdot
.09048 .5708 Mdot
.1 .53191 Mdot
.10952 .48063 Mdot
.11905 .41988 Mdot
.12857 .35311 Mdot
.1381 .28408 Mdot
.14762 .21662 Mdot
.15714 .15442 Mdot
.16667 .10078 Mdot
.17619 .05843 Mdot
.18571 .02936 Mdot
.19524 .01472 Mdot
.20476 .01473 Mdot
.21429 .02871 Mdot
.22381 .05511 Mdot
.23333 .09164 Mdot
.24286 .1354 Mdot
.25238 .18308 Mdot
.2619 .23117 Mdot
.27143 .27623 Mdot
.28095 .31504 Mdot
.29048 .34488 Mdot
.3 .36366 Mdot
.30952 .37007 Mdot
.31905 .36366 Mdot
.32857 .34488 Mdot
.3381 .31504 Mdot
.34762 .27623 Mdot
.35714 .23117 Mdot
.36667 .18308 Mdot
.37619 .1354 Mdot
.38571 .09164 Mdot
.39524 .05511 Mdot
.40476 .02871 Mdot
.41429 .01473 Mdot
.42381 .01472 Mdot
.43333 .02936 Mdot
.44286 .05843 Mdot
.45238 .10078 Mdot
.4619 .15442 Mdot
.47143 .21662 Mdot
.48095 .28408 Mdot
.49048 .35311 Mdot
.5 .41988 Mdot
.50952 .48063 Mdot
.51905 .53191 Mdot
.52857 .5708 Mdot
.5381 .59507 Mdot
.54762 .60332 Mdot
.55714 .59507 Mdot
.56667 .5708 Mdot
.57619 .53191 Mdot
.58571 .48063 Mdot
.59524 .41988 Mdot
.60476 .35311 Mdot
.61429 .28408 Mdot
.62381 .21662 Mdot
.63333 .15442 Mdot
.64286 .10078 Mdot
.65238 .05843 Mdot
.6619 .02936 Mdot
.67143 .01472 Mdot
.68095 .01473 Mdot
.69048 .02871 Mdot
.7 .05511 Mdot
.70952 .09164 Mdot
.71905 .1354 Mdot
.72857 .18308 Mdot
.7381 .23117 Mdot
.74762 .27623 Mdot
.75714 .31504 Mdot
.76667 .34488 Mdot
.77619 .36366 Mdot
.78571 .37007 Mdot
.79524 .36366 Mdot
.80476 .34488 Mdot
.81429 .31504 Mdot
.82381 .27623 Mdot
.83333 .23117 Mdot
.84286 .18308 Mdot
.85238 .1354 Mdot
.8619 .09164 Mdot
.87143 .05511 Mdot
.88095 .02871 Mdot
.89048 .01473 Mdot
.9 .01472 Mdot
.90952 .02936 Mdot
.91905 .05843 Mdot
.92857 .10078 Mdot
.9381 .15442 Mdot
.94762 .21662 Mdot
.95714 .28408 Mdot
.96667 .35311 Mdot
.97619 .41988 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 148.312},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0000U2000`400?l00000o`00003ooooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`008?ooool2
o`00027ooooo1Ol00003ooooo`;o00007oooool3o`0000?ooooo0_l0000Nooooo`?o00001?ooool2
o`0001kooooo0ol00004ooooo`;o00006oooool3o`0000Cooooo0_l00004ooooo`;o0000;_ooool2
o`00023ooooo1Ol00003ooooo`;o00007oooool3o`0000?ooooo0_l0000Oooooo`?o00001?ooool2
o`0001kooooo0ol00004ooooo`;o00006oooool3o`0000Cooooo0_l00004ooooo`;o00004_ooool0
01oooooo00Co0000oooooooooooo00008Oooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0001oooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo01[o
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001cooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001_ooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0002cooooo00Co0000oooo
oooooooo00008?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001oooooo
00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo01_ooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0001cooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0001_ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`00017ooooo000Oooooo`04o`000?ooooooooooo`00
02;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Looooo`Go00000_ooool0
1?l0003oooooooooool0000Looooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool0000Looooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000K
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool0000/ooooo`04o`000?ooooooooooo`00027ooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool0000Looooo`Go00000_ooool01?l0003oooooooooool0000Mooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool0000Looooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool0000Kooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool0000Aooooo`007oooool01?l0003oooooooooool0
000Sooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Jooooo`04o`00
0?ooooooooooo`0000?ooooo00Co0000oooooooooooo00007?ooool4o`0000?ooooo00Co0000oooo
oooooooo00007Oooool3o`0000?ooooo00Co0000oooooooooooo00006oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000;?ooool01?l0003o
ooooooooool0000Rooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0J
ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00007Oooool4o`0000?ooooo
00Co0000oooooooooooo00007Oooool3o`0000?ooooo00Co0000oooooooooooo00006oooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00004Ooo
ool001oooooo00Co0000oooooooooooo00008?ooool01Ol0003ooooooooooooooooo000000;ooooo
00Co0000oooooooooooo00007Oooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`00
01cooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0000Looooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool0000Kooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000/ooooo`04o`000?oooooooooo
o`0001oooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001gooooo
00?o0000ooooool000000oooool01?l0003oooooooooool0000Mooooo`03o`000?oooooooooo00Co
oooo00Co0000oooooooooooo00007?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00006oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00004Oooool001oooooo00Co0000oooooooooooo00008?ooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00007_ooool2o`0000?ooooo00Co0000
oooooooooooo00007Oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0001cooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001[ooooo0_l00004oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000;?ooool01?l0003ooooooooo
ool0000Oooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Noooo
o`;o00000oooool01?l0003oooooooooool0000Nooooo`03o`000?oooooooooo00?ooooo00Co0000
oooooooooooo00007?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00006_ooool2o`0000Cooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000A
ooooo`008?ooool2o`0002;ooooo0ol00004ooooo`;o00008?ooool00ol0003oooooooooo`02oooo
o`;o00007oooool2o`0000Cooooo0_l0000Nooooo`?o00001?ooool2o`0001cooooo00?o0000oooo
ooooool00oooool2o`0000Cooooo0_l0000^ooooo`;o00008Oooool3o`0000Cooooo0_l0000Poooo
o`03o`000?oooooooooo00;ooooo0_l0000Pooooo`;o00001?ooool2o`0001kooooo0ol00004oooo
o`;o00007?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`0001;ooooo003oooooooWo
oooo003oooooooWooooo003oooooooWooooo000Looooo`03o`000000000000000</0000000?o0000
ooooooooool0:Oooool00ol0000000000000003;00000003o`000?oooooooooo017ooooo000Loooo
o`03o`000?oooooooooo00;ooooo00<00000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo017ooooo000Dooooo`Go00000oooool00ol0003oooooooooo`02ooooo`03
00000?oooooooooo01Kooooo1Ol00?l:ooooo`03o`000?oooooooooo01_ooooo1Ol00?l4ooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool00_ooool5o`00oagooooo00?o0000oooooooo
ool02?ooool5o`00oaOooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Qooooo`Go
00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01oooooo1Ooo00000ol0003o
ooooooooo`0Tooooo`03o`000?oo003oo`0000?oo`008_ooool00ol0003oooooooooo`0;ooooo`Go
o`005?ooool00ol0003oooooooooo`0Aooooo`Goo`003_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo017ooooo000Eooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool06oooool5o`00obSooooo1Ol00?l`ooooo`Go003o:?ooool5o`00oacooooo00?o0000oooooooo
ool08_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo02Cooooo1Ooo000Xoooo
o`Goo`00<?ooool5ool002Sooooo1Ooo000Cooooo`03o`000?oooooooooo017ooooo000>ooooo`Go
00000oooool00ol0003oooooooooo`03ooooo`03o`0000000000000001_ooooo1Ol00?lXooooo`Go
003o<?ooool5o`00obSooooo1Ol00?lKooooo`;o00007Oooool5o`0000?ooooo00?o0000oooooooo
ool00oooool2o`0002Gooooo1Ooo000Xooooo`Goo`00<?ooool5ool002Sooooo1Ooo000Booooo`;o
00004oooool001Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`Co003o
00?oooooo`00ool00?l00_l00?lTooooo`Co003o00?oooooo`00ool00?l00_l00?l/ooooo`Co003o
00?oooooo`00ool00?l00_l00?lTooooo`Co003o00?oooooo`00ool00?l00_l00?lJooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Rooooo`Coo`00
00?oooooool00?oo00000_oo000Tooooo`Coo`0000?oooooool00?oo00000_oo000/ooooo`Coo`00
00?oooooool00?oo00000_oo000Tooooo`Coo`0000?oooooool00?oo00000_oo000Aooooo`03o`00
0?oooooooooo017ooooo000Dooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`0Iooooo`Co003o00?oooooo`00ool00?l00_l00?lTooooo`Co003o00?oooooo`00ool00?l0
0_l00?l/ooooo`Co003o00?oooooo`00ool00?l00_l00?lTooooo`Co003o00?oooooo`00ool00?l0
0_l00?lJooooo`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo02;ooooo1?oo00000oooooooo`00ool00002ool002Cooooo1?oo00000ooooooo
o`00ool00002ool002cooooo1?oo00000oooooooo`00ool00002ool002Cooooo1?oo00000ooooooo
o`00ool00002ool0017ooooo00?o0000ooooooooool04Oooool001Cooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo01Wooooo1?l00?l00ooooooo003oo`00o`02o`00obCo
oooo1?l00?l00ooooooo003oo`00o`02o`00obcooooo1?l00?l00ooooooo003oo`00o`02o`00obCo
oooo1?l00?l00ooooooo003oo`00o`02o`00oa[ooooo00?o0000ooooooooool08Oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool08_ooool4ool00003oooooooo003oo`00
00;oo`009?ooool4ool00003oooooooo003oo`0000;oo`00;?ooool4ool00003oooooooo003oo`00
00;oo`009?ooool4ool00003oooooooo003oo`0000;oo`004Oooool00ol0003oooooooooo`0Aoooo
o`005Oooool3o`0000Cooooo00?o0000ooooooooool06_ooool01ol00?ooooooo`00oooooooo003o
ooooool00?l09_ooool01ol00?ooooooo`00oooooooo003oooooool00?l0;_ooool01ol00?oooooo
o`00oooooooo003oooooool00?l09_ooool01ol00?ooooooo`00oooooooo003oooooool00?l06ooo
ool00ol0003oooooooooo`0Rooooo`?o00001?ooool00ol0003oooooooooo`0Sooooo`07ool00?oo
ooooo`00oooooooo003oooooool0000Vooooo`07ool00?ooooooo`00oooooooo003oooooool0000^
ooooo`07ool00?ooooooo`00oooooooo003oooooool0000Vooooo`07ool00?ooooooo`00oooooooo
003oooooool0000Booooo`03o`000?oooooooooo017ooooo000Looooo`;o00006oooool01ol00?oo
ooooo`00oooooooo003oooooool00?l09_ooool01ol00?ooooooo`00oooooooo003oooooool00?l0
;_ooool01ol00?ooooooo`00oooooooo003oooooool00?l09_ooool01ol00?ooooooo`00oooooooo
003oooooool00?l06oooool00ol0003oooooooooo`0Yooooo`;o00009?ooool01ooo003oooooool0
0?ooooooo`00oooooooo00009_ooool01ooo003oooooool00?ooooooo`00oooooooo0000;_ooool0
1ooo003oooooool00?ooooooo`00oooooooo00009_ooool01ooo003oooooool00?ooooooo`00oooo
oooo00004Oooool2o`0001?ooooo000Looooo`03o`000?oooooooooo01[ooooo00Oo003oooooool0
0?ooooooo`00oooooooo003o02Kooooo00Oo003oooooool00?ooooooo`00oooooooo003o02kooooo
00Oo003oooooool00?ooooooo`00oooooooo003o02Kooooo00Oo003oooooool00?ooooooo`00oooo
oooo003o01_ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Sooooo`07ool00?oo
ooooo`00oooooooo003oooooool0000Vooooo`07ool00?ooooooo`00oooooooo003oooooool0000^
ooooo`07ool00?ooooooo`00oooooooo003oooooool0000Vooooo`07ool00?ooooooo`00oooooooo
003oooooool0000Booooo`03o`000?oooooooooo017ooooo000Looooo`03o`000?oooooooooo01Oo
oooo1?l00?l01Ooooooo003oooooool00?oooooo00Co003o8?ooool4o`00o`05ooooool00?oooooo
o`00ooooool01?l00?lXooooo`Co003o00Goooooo`00oooooooo003oooooo`04o`00ob3ooooo1?l0
0?l01Ooooooo003oooooool00?oooooo00Co003o6?ooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo023ooooo1?oo00001Oooooooo`00oooooooo003ooooo00Coo`008?ooool4ool00005
oooooooo003oooooool00?ooool01?oo000Xooooo`Coo`0000Goooooool00?ooooooo`00ooooo`04
ool0023ooooo1?oo00001Oooooooo`00oooooooo003ooooo00Coo`003oooool00ol0003ooooooooo
o`0Aooooo`007?ooool00ol0003oooooooooo`0Gooooo`Co003o00Goooooo`00oooooooo003ooooo
o`04o`00ob3ooooo1?l00?l01Ooooooo003oooooool00?oooooo00Co003o:?ooool4o`00o`05oooo
ool00?ooooooo`00ooooool01?l00?lPooooo`Co003o00Goooooo`00oooooooo003oooooo`04o`00
oaSooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Pooooo`Coo`0000Goooooool0
0?ooooooo`00ooooo`04ool0023ooooo1?oo00001Oooooooo`00oooooooo003ooooo00Coo`00:?oo
ool4ool00005oooooooo003oooooool00?ooool01?oo000Pooooo`Coo`0000Goooooool00?oooooo
o`00ooooo`04ool000oooooo00?o0000ooooooooool04Oooool001cooooo00?o0000ooooooooool0
5oooool4o`00o`05ooooool00?ooooooo`00ooooool01?l00?lPooooo`Co003o00Goooooo`00oooo
oooo003oooooo`04o`00obSooooo1?l00?l01Ooooooo003oooooool00?oooooo00Co003o8?ooool4
o`00o`05ooooool00?ooooooo`00ooooool01?l00?lHooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool08?ooool4ool00005oooooooo003oooooool00?ooool01?oo000Pooooo`Coo`00
00Goooooool00?ooooooo`00ooooo`04ool002Sooooo1?oo00001Oooooooo`00oooooooo003ooooo
00Coo`008?ooool4ool00005oooooooo003oooooool00?ooool01?oo000?ooooo`03o`000?oooooo
oooo017ooooo000Looooo`;o00006Oooool02ol00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003o02;ooooo00_o003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00o`0Zooooo`0;o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?l08_oo
ool02ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o01Wooooo00?o0000
ooooooooool0:Oooool2o`0002;ooooo00_oo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool0000Rooooo`0;ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
0000:_ooool02ooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`0002;ooooo
00_oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0000?ooooo`;o00004ooo
ool001cooooo00?o0000ooooooooool06?ooool02ol00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003o02;ooooo00_o003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00o`0Zooooo`0;o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?l0
8_ooool02ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o01Wooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`0Qooooo`0;ool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo00008_ooool02ooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`0002[ooooo00_oo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool0000Rooooo`0;ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo0000
4?ooool00ol0003oooooooooo`0Aooooo`007?ooool00ol0003oooooooooo`0Hooooo`0;o`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?l08_ooool02ol00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003o02[ooooo00_o003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00o`0Rooooo`0;o`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?l06Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo027ooooo
00_oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0000Rooooo`0;ool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo0000:_ooool02ooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`0002;ooooo00_oo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool0000@ooooo`03o`000?oooooooooo017ooooo000Looooo`03o`00
0?oooooooooo01Sooooo00_o003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
o`0Rooooo`0;o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?l0:_ooool0
2ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o02;ooooo00_o003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0Iooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool08Oooool02ooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`0002;ooooo00_oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
000Zooooo`0;ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo00008_ooool0
2ooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00013ooooo00?o0000oooo
ooooool04Oooool001cooooo00?o0000ooooooooool06?ooool02_l00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00ooooool4o`00oacooooo1?l00?l02_oooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?lZooooo`0:o`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooo`Co003o7?ooool4o`00o`0:ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oaWooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Qooooo`0:ool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00ooooo`Coo`007Oooool3ool0000:oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool002[ooooo00[oo`00oooooooo003oooooool00?ooooooo`00
oooooooo003ooooo1?oo000Mooooo`?oo`0000[oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`004?ooool00ol0003oooooooooo`0Aooooo`007?ooool2o`0001Wooooo00[o003ooooo
ool00?ooooooo`00oooooooo003oooooool00?oooooo1?l00?lLooooo`Co003o00[oooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003o:_ooool02_l00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00ooooool4o`00oacooooo1?l00?l02_oooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?lIooooo`03o`000?oooooooooo02Wooooo0_l0000Rooooo`0:ool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00ooooo`Coo`007Oooool3ool0000:oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool002[ooooo00[oo`00oooooooo003oooooool00?oooooo
o`00oooooooo003ooooo1?oo000Mooooo`?oo`0000[oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`003oooool2o`0001?ooooo000Looooo`03o`000?oooooooooo01Gooooo1?l00?l0
2Ooooooo003oooooool00?ooooooo`00oooooooo003oooooo`04o`00oacooooo1?l00?l02Ooooooo
003oooooool00?ooooooo`00oooooooo003oooooo`04o`00obCooooo1?l00?l02Ooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooo`04o`00oacooooo1?l00?l02Ooooooo003oooooool00?oo
ooooo`00oooooooo003oooooo`04o`00oaKooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`0Nooooo`Coo`0000Woooooool00?ooooooo`00oooooooo003oooooool00?ooool01?oo000M
ooooo`?oo`0000Woooooool00?ooooooo`00oooooooo003oooooool00?ooool01?oo000Tooooo`Co
o`0000Woooooool00?ooooooo`00oooooooo003oooooool00?ooool01?oo000Mooooo`?oo`0000Wo
ooooool00?ooooooo`00oooooooo003oooooool00?ooool01?oo000=ooooo`03o`000?oooooooooo
017ooooo000Looooo`03o`000?oooooooooo01Gooooo1?l00?l03?oooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oakooooo00co003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00ooooool4o`00obCooooo1?l00?l03?oooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oakooooo00co003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00ooooool4o`00oaKooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0Nooooo`Coo`0000coooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo000Oooooo`;oo`0000Woooooool00?ooooooo`00oooooooo003oooooool00?ooool01?oo
000Tooooo`Coo`0000coooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
000Oooooo`;oo`0000Woooooool00?ooooooo`00oooooooo003oooooool00?ooool01?oo000=oooo
o`03o`000?oooooooooo017ooooo000Looooo`03o`000?oooooooooo01Gooooo1?l00?l03?oooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oakooooo00co003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooool4o`00obCooooo1?l00?l03?oooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oakooooo00co003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooool4o`00oaKooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`0Nooooo`Coo`0000coooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo000Oooooo`;oo`0000Woooooool00?ooooooo`00oooooooo003o
ooooool00?ooool01?oo000Tooooo`Coo`0000coooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo000Oooooo`;oo`0000Woooooool00?ooooooo`00oooooooo003oooooool0
0?ooool01?oo000=ooooo`03o`000?oooooooooo017ooooo000Looooo`03o`000?oooooooooo01Ko
oooo00oo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?l07_ooool03ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00o`0Vooooo`0?o`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003o01kooooo00oo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?l05oooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo01oooooo00ooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo00007oooool2ool0000<oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`009_ooool03ooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool0000Oooooo`;oo`0000coooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo000>ooooo`03o`000?oooooooooo017ooooo000Looooo`;o
00005oooool03ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00o`0Nooooo`0?o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003o02Kooooo00oo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?l07_ooool03ol00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0Gooooo`03o`000?oooooooooo02Wooooo
0_l0000Pooooo`0?ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`0001oooooo0_oo00003?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool002Kooooo00ooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo00007oooool2ool0000<oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`003Oooool2o`0001?ooooo000Looooo`03o`000?oooooooooo01Ko
oooo00oo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?l07_ooool03ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00o`0Vooooo`0?o`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003o01kooooo00oo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?l05oooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo01oooooo00ooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo00007oooool2ool0000<oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`009_ooool03ooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool0000Oooooo`;oo`0000coooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo000>ooooo`03o`000?oooooooooo017ooooo000Eooooo`?o
00001?ooool00ol0003oooooooooo`0Fooooo`0?o`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003o01kooooo00oo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?l09_ooool03ol00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0Nooooo`0?o`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o01Oooooo
00?o0000ooooooooool08_ooool3o`0000Cooooo00?o0000ooooooooool07oooool03ooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0000Oooooo`;o
o`0000coooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo000Vooooo`0?
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
01oooooo0_oo00003?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
00kooooo00?o0000ooooooooool04Oooool001Kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Fooooo`0>o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00ooooool4o`00oaSooooo1?l00?l03_oooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003o9_ooool03_l00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?oooooo1?l00?lHooooo`Co003o00koooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oaOooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01oooooo00koo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`Coo`006Oooool5ool0000<
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`009_ooool03_oo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo1?oo000Ioooo
o`Goo`0000coooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo000>oooo
o`03o`000?oooooooooo017ooooo000>ooooo`Go00000oooool00ol0003oooooooooo`03ooooo`?o
00005_ooool03_l00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?oooooo1?l00?lHooooo`Co003o00koooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00obKooooo00ko003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooo`Co003o6?ooool4o`00o`0>ooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?lFooooo`;o00007Oooool5o`0000?ooooo
00?o0000ooooooooool00oooool2o`00023ooooo00koo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00ooooo`Coo`006Oooool5ool0000<oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`009_ooool03_oo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003ooooo1?oo000Iooooo`Goo`0000coooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo000=ooooo`;o00004oooool001Ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Fooooo`0>o`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooool4o`00oaSooooo1?l00?l03_oo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o9_ooool0
3_l00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo1?l0
0?lHooooo`Co003o00koooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oaOooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo01oooooo00koo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00ooooo`Coo`006Oooool5ool0000<oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`009_ooool03_oo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003ooooo1?oo000Iooooo`Goo`0000coooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo000>ooooo`03o`000?oooooooooo017ooooo000Fooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool05_ooool04Ol00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o01[ooooo017o003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00o`0Vooooo`0Ao`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?l06_ooool04Ol00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003o01Oooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01oooooo017oo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0000Kooooo`0@
ool00?ooooooo`00ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool002Kooooo017oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool0000Kooooo`0@ool00?ooooooo`00ool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool000kooooo00?o0000ooooooooool04Oooool001Go
oooo0_l00005ooooo`03o`000?oooooooooo01?ooooo1?l00?l04?oooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?lJooooo`0@o`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooo`Co003o
8?ooool4o`00o`0@ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oa[ooooo013o003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?oooooo1?l00?lDooooo`03o`000?oooooooooo02;ooooo0_l0
0005ooooo`03o`000?oooooooooo01cooooo1?oo00004?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo000Kooooo`0?ool00?ooooooo`00ool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo00Coo`008?ooool4ool0
000@oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool001_ooooo00ooo`00oooooooo003oo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooool01?oo000;ooooo`03o`000?oooooooooo017ooooo000Fooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool04oooool4o`00o`0@ooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oa[ooooo013o003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo1?l00?lP
ooooo`Co003o013oooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003o6_ooool04?l00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00ooooool4o`00oaCooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo01cooooo1?oo00004?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo000Kooooo`0?ool00?oo
ooooo`00ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo00Coo`00
8?ooool4ool0000@oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool001_ooooo00ooo`00oooooooo003oo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooool01?oo000;ooooo`03o`000?oooooooooo017ooooo000Loooo
o`;o00005?ooool4o`00o`0@ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oa[ooooo013o003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?oooooo1?l00?lPooooo`Co003o013oooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o6_ooool0
4?l00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
ooooool4o`00oaCooooo00?o0000ooooooooool0:Oooool2o`0001gooooo1?oo00004?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo000Koooo
o`0?ool00?ooooooo`00ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
oooo00Coo`008?ooool4ool0000@oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool001_ooooo00ooo`00oooooooo003oo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooool01?oo000:ooooo`;o00004oooool001cooooo
00?o0000ooooooooool05?ooool04ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?l06_ooool04ol00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?l08_ooool04ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?l06_ooool04ol00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?l05Oooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo01gooooo01?oo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`0001_ooooo
01;oo`00oooooooo003oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo000Rooooo`0Cool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool0000Kooooo`0Bool00?ooooooo`00ool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`003?oo
ool00ol0003oooooooooo`0Aooooo`007?ooool00ol0003oooooooooo`0Dooooo`0Co`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00o`0Jooooo`0Co`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00o`0Rooooo`0Co`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0Joooo
o`0Co`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00o`0Eooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
7Oooool04ooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo00006oooool04_oo003oooooool00?oo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool002;ooooo01?oo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`0001_ooooo01;oo`00oooooooo003oo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo000<ooooo`03o`000?oooooooooo017ooooo000Looooo`03
o`000?oooooooooo01Cooooo01?o003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003o01[ooooo01?o003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
02;ooooo01?o003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003o01[ooooo01?o003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o01Gooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`0Mooooo`0Cool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0000Kooooo`0B
ool00?ooooooo`00ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`008_ooool04ooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo00006oooool04_oo003oooooool00?oo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool000cooooo
00?o0000ooooooooool04Oooool001cooooo00?o0000ooooooooool05?ooool04_l00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
o`Co003o5?ooool4o`00o`0Booooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003o8_ooool04_l00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooo`Co003o5?ooool4
o`00o`0Booooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003o5Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01go
oooo01;oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooool4ool001Gooooo1?oo00004Oooooooo`00ool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`0002;ooooo01;oo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ool4ool001Gooooo1?oo00004Oooooooo`00ool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`0000cooooo00?o0000ooooooooool04Oooool001cooooo
0_l0000Eooooo`0Bo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?oooooo1?l00?lDooooo`Co003o01;oooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?lRooooo`0B
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?oooooo1?l00?lDooooo`Co003o01;oooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?lEooooo`03o`000?oooooooooo
02Wooooo0_l0000Nooooo`0Bool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003ooooo1?oo000Eooooo`Coo`00017oooooool00?oo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0000Roooo
o`0Bool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003ooooo1?oo000Eooooo`Coo`00017oooooool00?oo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0000;ooooo`;o00004oooool001co
oooo00?o0000ooooooooool05?ooool04_l00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooo`Co003o5?ooool4o`00o`0Booooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003o8_ooool04_l00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooo`Co003o5?ooool4o`00o`0Booooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o5Oooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01gooooo01;oo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool4ool001Go
oooo1?oo00004Oooooooo`00ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`0002;ooooo01;oo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooool4ool001Gooooo1?oo00004Ooooooo
o`00ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`0000cooooo00?o0000ooooooooool04Oooool001cooooo00?o0000ooooooooool05?ooool05Ol0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00o`0Fooooo`0Eo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o02;ooooo
01Go003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?l05_ooool05Ol00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0E
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool07Oooool05Ooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool0000Gooooo`04ool00?ooooooo`00ooooo`;oo`0000koooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool002;ooooo01Goo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo00005oooool01?oo003oooooool00?ooool2ool0000>oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo000<ooooo`03o`000?oooooooooo017ooooo
000Looooo`03o`000?oooooooooo01Cooooo01Go003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?l05_ooool0
5Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00o`0Rooooo`0Eo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o01Ko
oooo01Go003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?l05Oooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo01gooooo01Goo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo00005oooool01?oo003oooooool0
0?ooool2ool0000>oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo000Rooooo`0Eool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`0001Oooooo00Coo`00oooooooo003o
oooo0_oo00003_ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`003?ooool00ol0003oooooooooo`0Aooooo`007?ooool00ol0003oooooooooo`0Dooooo`0E
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003o01Kooooo01Go003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?l08_oo
ool05Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00o`0Fooooo`0Eo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
01Gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Mooooo`0Eool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`0001Oooooo00Coo`00oooooooo003ooooo0_oo00003_ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`008_ooool05Ooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool0000Gooooo`04ool00?ooooooo`00ooooo`;oo`0000koooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool000cooooo00?o0000ooooooooool04Ooo
ool001cooooo0_l0000Eooooo`0Eo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o01Kooooo01Go003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?l08_ooool05Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0Fooooo`0Eo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003o01Gooooo00?o0000ooooooooool0:Oooool2o`0001kooooo01Go
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo00005oooool01?oo003oooooool00?ooool2ool0000>oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo000Rooooo`0Eool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`0001Oooooo00Coo`00oooooooo003ooooo0_oo00003_ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`002oooool2o`0001?o
oooo000Looooo`03o`000?oooooooooo017ooooo1?l00?l05?oooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o5_oo
ool05?l00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?oooooo1?l00?lLooooo`Co003o01Coooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oaKooooo01Co003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooo`Co003o4_ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo01_ooooo0ooo00005?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`005oooool01?oo003ooooo
ool00?ooool2ool0000=oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00ooooo`04ool001gooooo0ooo00005?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`005oooool01?oo003ooooo
ool00?ooool2ool0000=oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00ooooo`04ool000Wooooo00?o0000ooooooooool04Oooool001cooooo00?o0000ooooooooool0
4Oooool4o`00o`0Dooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?lFooooo`0Do`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooool4
o`00oacooooo1?l00?l05?oooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003o5_ooool05?l00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
oooo1?l00?lBooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06oooool3ool0000D
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo000Gooooo`04ool00?ooooooo`00ooooo`;oo`0000goooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo00Coo`007Oooool3ool0000D
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo000Gooooo`04ool00?ooooooo`00ooooo`;oo`0000goooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo00Coo`002Oooool00ol0003o
ooooooooo`0Aooooo`007?ooool00ol0003oooooooooo`0Aooooo`Co003o01Coooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oaKooooo01Co003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooo`Co003o7?ooool4o`00o`0Dooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?lFooooo`0Do`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooool4o`00oa;ooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`0Kooooo`?oo`0001Coooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool001Oooooo
00Coo`00oooooooo003ooooo0_oo00003Oooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooool01?oo000Mooooo`?oo`0001Coooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool001Oooooo
00Coo`00oooooooo003ooooo0_oo00003Oooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooool01?oo0009ooooo`03o`000?oooooooooo017ooooo000Looooo`03o`00
0?oooooooooo01;ooooo01Ko003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo1?l00?l@ooooo`Co003o
01Koooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003o7_ooool05_l00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
ooooool4o`00oa3ooooo1?l00?l05_oooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?lCooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool07?ooool2ool0000Coooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`04
ool0017ooooo1?oo00000oooooooo`00ooooo`02ool0000@oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool001oooooo0_oo00004oooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooool01?oo000Aooooo`Coo`0000?oooooool00?ooool00_oo00004?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo000:ooooo`03o`00
0?oooooooooo017ooooo000Looooo`;o00004oooool05_l00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
ool4o`00oa3ooooo1?l00?l05_oooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?lNooooo`0Fo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooo`Co003o4?ooool4o`00o`0Fooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oa?ooooo00?o0000ooooooooool0:Oooool2o`0001gooooo0_oo00004oooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooool01?oo000Aooooo`Coo`0000?oooooool00?ooool00_oo00004?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo000Oooooo`;oo`0001?o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003ooooo00Coo`004Oooool4ool00003oooooooo003ooooo00;oo`00013oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`002Ooo
ool2o`0001?ooooo000Looooo`03o`000?oooooooooo01;ooooo01Ko003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?oooooo1?l00?l@ooooo`Co003o01Koooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o7_ooool0
5_l00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00ooooool4o`00oa3ooooo1?l00?l05_oooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?lCooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool07?ooool2
ool0000Coooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00ooooo`04ool0017ooooo1?oo00000oooooooo`00ooooo`02ool0000@
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool001oooooo0_oo00004oooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooool01?oo000Aooooo`Coo`0000?oooooool00?oo
ool00_oo00004?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo000:ooooo`03o`000?oooooooooo017ooooo000Fooooo`;o00001?ooool00ol0
003oooooooooo`0Booooo`0Io`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0B
ooooo`0Io`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0Nooooo`0Io`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0Booooo`0Io`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00o`0Cooooo`03o`000?oooooooooo02?ooooo0_l00004ooooo`03
o`000?oooooooooo01cooooo0_oo00005_ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo000Cooooo`06
ool00?ooooooo`00oooooooo003ooooo0_oo00004?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo000Oooooo`;oo`0001Koooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`004oooool01_oo003oooooool00?ooooooo`00ooooo`;oo`00013oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`002_oo
ool00ol0003oooooooooo`0Aooooo`005Oooool01?l0003oooooooooool00003ooooo`03o`000?oo
oooooooo01;ooooo01Wo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o01;ooooo
01Wo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o01kooooo01Wo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003o01;ooooo01Wo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003o01?ooooo00?o0000ooooooooool08_ooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo01cooooo0_oo00005_ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
000Cooooo`06ool00?ooooooo`00oooooooo003ooooo0_oo00004?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo000Oooooo`;oo`0001Kooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`004oooool01_oo003oooooool00?ooooooo`00ooooo`;oo`00
013oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`002_ooool00ol0003oooooooooo`0Aooooo`005Oooool01?l0003oooooooooool00003oooo
o`?o00000_ooool0:_l00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
o`;o003o02ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooo`02o`00o`0_ooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00ooooool00_l00?l0;ooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo00;o003o00Kooooo
o`00oooooooo003oooooool00?l3ooooo`;o00009?ooool01?l0003oooooooooool00003ooooo`;o
00000oooool06_oo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo0_oo0000
;oooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003ooooo00;oo`0002ooooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00ooooo`02ool0000_oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool00_oo00005_ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo0003ooooo`;o00004oooool001Gooooo00Co0000oooooooooooo00000ooo
ool00ol0003oooooooooo`02ooooo`0?o`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003o01_ooooo0_l00?l03_oooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003o6oooool01_l00?ooooooo`00oooooooo003o
ooooo`;o003o01Coooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oa_ooooo0_l00?l03_oooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o6oooool01_l00?ooooooo`00oooo
oooo003oooooo`;o003o00Koooooo`00oooooooo003oooooool00?l4ooooo`03o`000?oooooooooo
02;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`0Iool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool0000Jooooo`0Aool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo00006_ooool07Ooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`0001[ooooo017o
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool0000Jooooo`05ool00?ooooooo`00oooooooo00001?ooool00ol0003oooooooooo`0Aoooo
o`005Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo00oo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?l06oooool2
o`00o`0>ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?lKooooo`06o`00oooooooo003oooooool00?oooooo0_l00?l05?oooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
6oooool2o`00o`0>ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?lKooooo`06o`00oooooooo003oooooool00?oooooo0_l00?l01_oooooo003oooooool0
0?ooooooo`00o`Cooooo00?o0000ooooooooool08_ooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo00;ooooo01Woo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
01[ooooo017oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool0000Jooooo`0Mool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo00006_ooool04Ooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`0001[ooooo00Goo`00oooooooo003ooooo
ool00004ooooo`03o`000?oooooooooo017ooooo000Eooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool00_ooool03ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00o`0Kooooo`;o003o00koooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oa_ooooo00Ko003oooooool00?ooooooo`00oooo
ool2o`00o`0Dooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?lKooooo`;o003o00koooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oa_ooooo00Ko003oooooool00?oooooo
o`00ooooool2o`00o`06ooooool00?ooooooo`00oooooooo003o1?ooool00ol0003oooooooooo`0R
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool06Ooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo00006_ooool04Ooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`0001[ooooo01goo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0000Jooooo`0Aool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo00006_ooool01Ooo003oooooool00?ooooooo`0000Cooooo00?o0000ooooooooool04Oooool0
01Kooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00oo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?l06_ooool3o`00o`0;ooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00ooooool01?l00?lJooooo`06o`00oooooooo003o
ooooool00?oooooo0_l00?l05?oooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o6_ooool3o`00o`0;ooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00ooooool01?l00?lJooooo`06o`00oooooooo003o
ooooool00?oooooo0_l00?l01_oooooo003oooooool00?ooooooo`00o`Cooooo00?o0000oooooooo
ool08oooool2o`0000Cooooo00?o0000ooooooooool00_ooool06Ooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo00006Oooool4ool0000;oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooool01?oo000Iooooo`0Mool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo00006Oooool4ool0000;oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooool01?oo000Iooooo`05ool00?ooooooo`00oooooooo00001?oo
ool00ol0003oooooooooo`0Aooooo`007?ooool2o`0000?ooooo00oo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?l06_ooool3o`00o`0;ooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooool01?l00?lJooooo`06o`00oooooooo
003oooooool00?oooooo0_l00?l05?oooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o6_ooool3o`00o`0;ooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooool01?l00?lJooooo`06o`00oooooooo
003oooooool00?oooooo0_l00?l01_oooooo003oooooool00?ooooooo`00o`Cooooo00?o0000oooo
ooooool0:Oooool2o`0000?ooooo01Woo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`0001Wooooo1?oo00002oooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
00Coo`006Oooool07Ooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`0001Wooooo1?oo00002oooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003ooooo00Coo`006Oooool01Ooo003oooooool00?ooooooo`0000?ooooo0_l0000Cooooo`007?oo
ool00ol0003oooooooooo`02ooooo`0<o`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?oooooo1?l00?lIooooo`?o003o00_oooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooo`04o`00oaWooooo1?l00?l00ooooooo003oooooo`02o`00o`0Aooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooool0
1?l00?lIooooo`?o003o00_oooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
o`04o`00oaWooooo1?l00?l00ooooooo003oooooo`02o`00o`06ooooool00?ooooooo`00oooooooo
003o1?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00;ooooo01Koo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003ooooo1?oo000Hooooo`Coo`0000_oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00ooooo`04ool001Sooooo1?oo00005oooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003ooooo00Coo`006?ooool4ool0000;oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooool01?oo000Hooooo`Coo`0000?oooooool00?ooool00oooool00ol0003ooooooooo
o`0Aooooo`007?ooool00ol0003oooooooooo`02ooooo`0<o`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?oooooo1?l00?lKooooo`0=o`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00o`0Looooo`Co003o00?oooooo`00ooooool00_l00?l0
4Ooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?oooooo00Co003o6oooool03Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?l07?ooool4o`00o`03ooooool00?oooooo00;o003o00Koooooo`00oooooooo
003oooooool00?l4ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool00_ooool05_oo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooool4ool001_ooooo00goo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`0001_ooooo1?oo00005oooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003ooooo00Coo`006oooool03Ooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo00006oooool4ool00003oooooooo003ooooo00?ooooo00?o0000oooo
ooooool04Oooool001cooooo00?o0000ooooooooool00_ooool03?l00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooo`Co003o6oooool03Ol00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?l07?ooool4o`00o`03ooooool00?oooooo00;o
003o017oooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooo`04o`00oa_ooooo00go003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003o01cooooo1?l00?l00ooooooo003oooooo`02o`00o`06ooooool00?oo
ooooo`00oooooooo003o1?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00;ooooo
01Koo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003ooooo1?oo000Kooooo`0=ool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool0000Kooooo`Coo`0001Ooooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00ooooo`04ool001_ooooo00goo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`0001_ooooo1?oo00000oooooooo`00ooooo`03ooooo`03o`00
0?oooooooooo017ooooo000Looooo`03o`000?oooooooooo00;ooooo00go003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003o01kooooo00go003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003o01oooooo00Co003oooooool00?oooooo
0_l00?l04_oooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oakooooo00go003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003o01oooooo00Co003oooooool00?oooooo0_l00?l01_oooooo003ooooo
ool00?ooooooo`00o`Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`02ooooo`0G
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo00007_ooool03Ooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo00007_ooool06Ooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo00007_ooool03Ooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo00007_ooool00ooo003oooooool00004ooooo`03o`000?oooooooooo
017ooooo000Looooo`;o00000oooool03Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?l07_ooool03Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?l07oooool01?l00?ooooooo`00ooooool2o`00o`0Booooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
7_ooool03Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?l0
7oooool01?l00?ooooooo`00ooooool2o`00o`06ooooool00?ooooooo`00oooooooo003o1?ooool0
0ol0003oooooooooo`0Yooooo`;o00000oooool05ooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`0001kooooo00goo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`0001kooooo01Woo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`0001kooooo00go
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`0001kooooo00?o
o`00oooooooo00000oooool2o`0001?ooooo000Looooo`03o`000?oooooooooo00;ooooo00go003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o01kooooo00go003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o01oooooo00Co003o
ooooool00?oooooo0_l00?l04_oooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oakooooo00go003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003o01oooooo00Co003oooooool00?oooooo0_l00?l0
1_oooooo003oooooool00?ooooooo`00o`Cooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`02ooooo`0Gool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo00007_ooool03Ooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo00007_ooool06Ooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo00007_ooool03Ooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo00007_ooool00ooo003oooooool00004ooooo`03
o`000?oooooooooo017ooooo000Looooo`03o`000?oooooooooo00;ooooo00go003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o01gooooo1?l00?l01ooooooo003o
ooooool00?ooooooo`00ooooool01?l00?lNooooo`04o`00oooooooo003oooooo`;o003o01;ooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?lMooooo`Co003o00Ooooooo`00oooooooo003oooooool00?oooooo00Co003o7_ooool0
1?l00?ooooooo`00ooooool2o`00o`06ooooool00?ooooooo`00oooooooo003o1?ooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo00;ooooo01Ooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool0000Mooooo`Coo`0000Ooooooool00?ooooooo`00oooooooo003ooooo00Coo`007Oooool0
6Ooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo00007Oooool4ool00007oooooooo
003oooooool00?ooooooo`00ooooo`04ool001gooooo00?oo`00oooooooo00001?ooool00ol0003o
ooooooooo`0Aooooo`007?ooool00ol0003oooooooooo`02ooooo`0=o`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0Mooooo`Co003o00Ooooooo`00oooooooo
003oooooool00?oooooo00Co003o7_ooool01?l00?ooooooo`00ooooool2o`00o`0Booooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003o7Oooool4o`00o`07ooooool00?ooooooo`00oooooooo003oooooo`04o`00oakooooo00Co003o
ooooool00?oooooo0_l00?l01_oooooo003oooooool00?ooooooo`00o`Cooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`02ooooo`0Gool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
00007Oooool4ool00007oooooooo003oooooool00?ooooooo`00ooooo`04ool001gooooo01Woo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`0001gooooo1?oo00001oooooooo`00oooo
oooo003oooooool00?ooool01?oo000Mooooo`03ool00?ooooooo`0000Cooooo00?o0000oooooooo
ool04Oooool001cooooo00?o0000ooooooooool00_ooool03Ol00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?l07Oooool4o`00o`07ooooool00?ooooooo`00oooo
oooo003oooooo`04o`00oakooooo00Co003oooooool00?oooooo0_l00?l04_oooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oago
oooo1?l00?l01ooooooo003oooooool00?ooooooo`00ooooool01?l00?lNooooo`04o`00oooooooo
003oooooo`;o003o00Koooooo`00oooooooo003oooooool00?l4ooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool00_ooool05ooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`0001go
oooo1?oo00001oooooooo`00oooooooo003oooooool00?ooool01?oo000Mooooo`0Iool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool0000Mooooo`Coo`0000Ooooooool00?ooooooo`00
oooooooo003ooooo00Coo`007Oooool00ooo003oooooool00004ooooo`03o`000?oooooooooo017o
oooo000Looooo`;o00000oooool03Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?l08?ooool02Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0Q
ooooo`04o`00oooooooo003oooooo`;o003o01;oooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?lPooooo`09o`00oooooooo003o
ooooool00?ooooooo`00oooooooo003o027ooooo00Co003oooooool00?oooooo0_l00?l01_oooooo
003oooooool00?ooooooo`00o`Cooooo00?o0000ooooooooool0:Oooool2o`0000?ooooo01Ooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool0000Pooooo`09ool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00023ooooo01Woo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
023ooooo00Woo`00oooooooo003oooooool00?ooooooo`00oooooooo00008?ooool00ooo003ooooo
ool00003ooooo`;o00004oooool001cooooo00?o0000ooooooooool00_ooool03Ol00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?l08?ooool02Ol00?ooooooo`00
oooooooo003oooooool00?ooooooo`00o`0Qooooo`04o`00oooooooo003oooooo`;o003o01;ooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?lPooooo`09o`00oooooooo003oooooool00?ooooooo`00oooooooo003o027ooooo00Co
003oooooool00?oooooo0_l00?l01_oooooo003oooooool00?ooooooo`00o`Cooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`02ooooo`0Gool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo00008?ooool02Ooo003oooooool00?ooooooo`00oooooooo003oooooool0000Pooooo`0Iool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool0000Pooooo`09ool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00023ooooo00?oo`00oooooooo00001?ooool00ol0003ooooooooo
o`0Aooooo`007?ooool00ol0003oooooooooo`02ooooo`0=o`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00o`0Pooooo`09o`00oooooooo003oooooool00?oooooo
o`00oooooooo003o027ooooo00Co003oooooool00?oooooo0_l00?l04_oooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ob3ooooo
00Wo003oooooool00?ooooooo`00oooooooo003oooooool00?l08Oooool01?l00?ooooooo`00oooo
ool2o`00o`06ooooool00?ooooooo`00oooooooo003o1?ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo00;ooooo01Ooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0000Pooooo`09
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00023ooooo01Woo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00023ooooo00Woo`00oooooooo003oooooool00?ooooooo`00
oooooooo00008?ooool00ooo003oooooool00004ooooo`03o`000?oooooooooo017ooooo000Loooo
o`03o`000?oooooooooo00;ooooo00go003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003o01oooooo1?l00?l00ooooooo003oooooo`04o`00ob3ooooo00Co003ooooo
ool00?oooooo0_l00?l04_oooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oaoooooo1?l00?l00ooooooo003oooooo`04o`00ob3o
oooo00Co003oooooool00?oooooo0_l00?l01_oooooo003oooooool00?ooooooo`00o`Cooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`02ooooo`0Gool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo00007oooool4ool00003oooooooo003ooooo00Coo`007oooool06Ooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo00007oooool4ool00003oooooooo003ooooo00Coo`00
7oooool00ooo003oooooool00004ooooo`03o`000?oooooooooo017ooooo000Looooo`03o`000?oo
oooooooo00;ooooo00go003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003o01oooooo1?l00?l00ooooooo003oooooo`04o`00ob3ooooo00Co003oooooool00?oooooo
0_l00?l04_oooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oaoooooo1?l00?l00ooooooo003oooooo`04o`00ob3ooooo00Co003o
ooooool00?oooooo0_l00?l01_oooooo003oooooool00?ooooooo`00o`Cooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`02ooooo`0Gool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
00007oooool4ool00003oooooooo003ooooo00Coo`007oooool06Ooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo00007oooool4ool00003oooooooo003ooooo00Coo`007oooool00ooo
003oooooool00004ooooo`03o`000?oooooooooo017ooooo000Looooo`;o00000oooool02_l00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00ooooool4o`00oakooooo1?l00?l00ooooooo003o
ooooo`04o`00oaoooooo1?l00?l04_oooooo003oo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooo`Co003o7_ooool4o`00o`03ooooool00?oo
oooo00Co003o7oooool4o`00o`09ooooool00?oo003oooooool00?ooooooo`00oooooooo003o00Co
oooo00?o0000ooooooooool0:Oooool2o`0000?ooooo01Coo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`Coo`00
7_ooool4ool00003oooooooo003ooooo00Coo`007_ooool4ool0000Coooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`04
ool001kooooo1?oo00000oooooooo`00ooooo`04ool001kooooo1?oo0003ooooo`;o00004oooool0
01cooooo00?o0000ooooooooool00_ooool02_l00?ooooooo`00oooooooo003oooooool00?oooooo
o`00ooooool4o`00ob7ooooo00Go003oooooool00?ooooooo`00o`0Rooooo`Co003o01;oooooo`00
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
ooooool4o`00ob7ooooo00Go003oooooool00?ooooooo`00o`0Rooooo`Co003o00Woooooo`00ool0
0?ooooooo`00oooooooo003oooooool00?l01?ooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo00;ooooo01Coo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00ooooo`Coo`008Oooool01Ooo003oooooool00?oo
ooooo`00027ooooo1?oo00004oooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooool01?oo000Qooooo`05ool00?ooooooo`00
oooooooo00008Oooool4ool000Cooooo00?o0000ooooooooool04Oooool001Gooooo0ol00004oooo
o`03o`000?oooooooooo00;ooooo00[o003oooooool00?ooooooo`00oooooooo003oooooool00?oo
oooo1?l00?lPooooo`Oo003o8Oooool4o`00o`0Booooool00?oo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo1?l00?lPooooo`Oo003o8Ooo
ool4o`00o`09ooooool00?oo003oooooool00?ooooooo`00oooooooo003o00Cooooo00?o0000oooo
ooooool08_ooool3o`0000Cooooo00?o0000ooooooooool00_ooool05?oo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
oooo1?oo000Pooooo`Ooo`008?ooool4ool0000Coooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`04ool0023ooooo1ooo
000Pooooo`Coo`001?ooool00ol0003oooooooooo`0Aooooo`005_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00_o003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00o`0Sooooo`Oo003o9?ooool05?l00?ooooooo`00ool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o8oooool7o`00obCo
oooo00[o003oooooool00?oo003oooooool00?ooooooo`00oooooooo003o1?ooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool05Ooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool0000Sooooo`Ooo`008oooool05Ooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0000S
ooooo`Ooo`008oooool00ooo003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo000Foooo
o`03o`000?oooooooooo00?ooooo0ol00002ooooo`0;o`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?l08oooool7o`00obCooooo01Co003oooooool00?oo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ob?ooooo
1ol00?lTooooo`0:o`00oooooooo003oo`00oooooooo003oooooool00?ooooooo`00o`?ooooo0_l0
000Uooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`0Eool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`0002?ooooo1ooo000Sooooo`0Eool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`0002?ooooo1ooo000Soooo
o`04ool00?ooooooooooooooo`;o00004oooool001Kooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`0;o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?l09Oooool3o`00obKooooo01Co003oooooool00?oo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00obGooooo0ol00?lVooooo`0:o`00
oooooooo003oo`00oooooooo003oooooool00?ooooooo`00o`Cooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo01Goo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo00009Oooool3ool002Gooooo01Goo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo00009Oooool3ool0
02Gooooo00?oo`00ooooooooool00_ooool00ol0003oooooooooo`0Aooooo`005_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00_o003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00o`1>ooooo`0Do`00oooooooo003oo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?m>ooooo`0:o`00oooo
oooo003oo`00oooooooo003oooooool00?ooooooo`00o`Cooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo01Goo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo0000COooool05Ooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool0001=ooooo`03ool00?oooooooooo00;o
oooo00?o0000ooooooooool04Oooool001Gooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo
00_o003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`1>ooooo`0Do`00oooo
oooo003oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?m>ooooo`0:o`00oooooooo003oo`00oooooooo003oooooool00?ooooooo`00
o`Cooooo00?o0000ooooooooool08_ooool2o`0000Gooooo00?o0000ooooooooool00_ooool05Ooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool0001=ooooo`0Eool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`0004gooooo
00?oo`00ooooooooool00_ooool00ol0003oooooooooo`0Aooooo`005_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00_o003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00o`1>ooooo`0Do`00oooooooo003oo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?m>ooooo`0:o`00oooooooo003o
o`00oooooooo003oooooool00?ooooooo`00o`Cooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo01Goo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo0000
COooool05Ooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool0001=ooooo`03ool00?oooooooooo00;ooooo00?o
0000ooooooooool04Oooool001cooooo0_l00003ooooo`0;o`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?l0C_ooool05?l00?ooooooo`00ool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oC_ooool02_l00?oo
ooooo`00ool00?ooooooo`00oooooooo003oooooool00?l4ooooo`03o`000?oooooooooo02Wooooo
0_l00003ooooo`0Eool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`0004gooooo01Goo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo0000COooool01?oo003oooooooooooooool2o`0001?ooooo000Looooo`03o`000?oooooo
oooo00;ooooo00_o003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`1>oooo
o`0Do`00oooooooo003oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?m>ooooo`0:o`00oooooooo003oo`00oooooooo003oooooool0
0?ooooooo`00o`Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`02ooooo`0Eool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`0004gooooo01Goo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo0000COooool0
0ooo003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo000Looooo`03o`000?oooooooooo
00;ooooo00_o003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`1>ooooo`0D
o`00oooooooo003oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?m>ooooo`0:o`00oooooooo003oo`00oooooooo003oooooool00?oo
ooooo`00o`Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`02ooooo`0Eool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`0004gooooo01Goo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo0000COooool00ooo
003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo000Looooo`03o`000?oooooooooo00;o
oooo00_o003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`1>ooooo`0Do`00
oooooooo003oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?m>ooooo`0:o`00oooooooo003oo`00oooooooo003oooooool00?oooooo
o`00o`Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`02ooooo`0Eool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`0004gooooo01Goo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo0000COooool00ooo003o
ooooooooo`02ooooo`03o`000?oooooooooo017ooooo000Looooo`03o`000?oooooooooo00;ooooo
00_o003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`1>ooooo`0Do`00oooo
oooo003oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?m>ooooo`0:o`00oooooooo003oo`00oooooooo003oooooool00?ooooooo`00
o`Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`02ooooo`0Eool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`0004gooooo01Goo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo0000COooool00ooo003ooooo
ooooo`02ooooo`03o`000?oooooooooo017ooooo000Looooo`;o00000oooool02?l00?ooooooo`00
oooooooo003oooooool00?oooooo1?l00?m<ooooo`Go003o00goooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?oooooo00Co003oC?ooool5o`00o`06ooooool00?oooooo
o`00oooooooo003o1?ooool00ol0003oooooooooo`0Yooooo`;o00000_ooool4ool0000?oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo00Coo`00
Boooool4ool0000?oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003ooooo00Coo`00Boooool3ool000;ooooo0_l0000Cooooo`007?ooool00ol0003ooooo
ooooo`02ooooo`08o`00oooooooo003oooooool00?ooooooo`00ooooool4o`00odcooooo1Ol00?l0
3Ooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooool01?l00?m<
ooooo`Go003o00Koooooo`00oooooooo003oooooool00?l4ooooo`03o`000?oooooooooo02Wooooo
00Co0000oooooooooooooooo1?oo00003oooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00ooooo`04ool004_ooooo1?oo00003oooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`04ool004_ooooo0ooo0003
ooooo`03o`000?oooooooooo017ooooo000Looooo`03o`000?oooooooooo00;ooooo00So003ooooo
ool00?ooooooo`00oooooooo003oooooo`Co003oC?ooool5o`00o`0=ooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooo`04o`00odcooooo1Ol00?l01_oooooo003o
ooooool00?ooooooo`00o`Cooooo00?o0000ooooooooool0:Oooool01?l0003oooooooooooooool4
ool0000?oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003ooooo00Coo`00Boooool4ool0000?oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003ooooo00Coo`00Boooool3ool000?ooooo00?o0000ooooooooool0
4Oooool001cooooo00?o0000ooooooooool00_ooool02Ol00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00o`1Booooo`;o003o00koooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oe;ooooo0_l00?l01_oooooo003oooooool00?ooooooo`00o`Cooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`04ooooo`0Aool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo0000DOooool04Ooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`0005Cooooo00?o0000ooooooooool04Oooool001cooooo00?o0000ooooooooool00_ooool0
2Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`1Booooo`;o003o00koooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oe;ooooo0_l00?l01_oo
oooo003oooooool00?ooooooo`00o`Cooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`04ooooo`0Aool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo0000DOooool04Ooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`0005Cooooo00?o0000ooooooooool04Oooool0
01cooooo0_l00003ooooo`09o`00oooooooo003oooooool00?ooooooo`00oooooooo003o05;ooooo
0_l00?l03_oooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oD_ooool2o`00o`06ooooool00?ooooooo`00oooooooo003o1?ooool00ol0003oooooooooo`0Y
ooooo`;o00001Oooool04Ooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00057ooooo017oo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0001Cooooo`;o00004oooool001co
oooo00?o0000ooooooooool00_ooool02Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00
o`1Booooo`;o003o00koooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oe;ooooo0_l00?l01_oooooo003oooooool00?ooooooo`00o`Cooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`04ooooo`0Aool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo0000DOooool04Ooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`0005Co
oooo00?o0000ooooooooool04Oooool001cooooo00?o0000ooooooooool00_ooool02Ol00?oooooo
o`00oooooooo003oooooool00?ooooooo`00o`1Booooo`;o003o00koooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oe;ooooo0_l00?l01_oooooo003ooooo
ool00?ooooooo`00o`Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`04ooooo`0A
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo0000DOooool04Ooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`0005Cooooo00?o0000ooooooooool04Oooool001cooooo00?o
0000ooooooooool00_ooool02Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`1Boooo
o`;o003o00koooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oe;ooooo0_l00?l01_oooooo003oooooool00?ooooooo`00o`Cooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`04ooooo`0Aool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo0000DOooool04Ooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`0005Cooooo00?o
0000ooooooooool04Oooool001cooooo00?o0000ooooooooool00_ooool02Ol00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00o`1Booooo`;o003o00koooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oe;ooooo0_l00?l01_oooooo003oooooool00?oo
ooooo`00o`Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`04ooooo`0Aool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
0000DOooool04Ooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`0005Cooooo00?o0000ooooooooool04Oooool001cooooo0_l00003oooo
o`09o`00oooooooo003oooooool00?ooooooo`00oooooooo003o05;ooooo0_l00?l03_oooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oD_ooool2o`00o`06
ooooool00?ooooooo`00oooooooo003o1?ooool00ol0003oooooooooo`0Yooooo`;o00001Oooool0
4Ooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00057ooooo017oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool0001Cooooo`;o00004oooool001cooooo00?o0000oooooooo
ool00_ooool02Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`1Booooo`;o003o00ko
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oe;ooooo
0_l00?l01_oooooo003oooooool00?ooooooo`00o`Cooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`04ooooo`0Aool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo0000DOooool04Ooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`0005Cooooo00?o0000oooooooo
ool04Oooool001Cooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo00Ko003oooooool00?oo
ooooo`00ooooool4o`00oe3ooooo0ol00?l02ooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?oooooo00Co003oD?ooool3o`00o`06ooooool00?ooooooo`00oooooooo003o1?ooool0
0ol0003oooooooooo`0Qooooo`Go00000oooool00ol0003oooooooooo`03ooooo`Coo`0000_ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`04ool004oooooo1?oo00002ooo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo00Coo`00Doooool00ol0003o
ooooooooo`0Aooooo`005Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;o
oooo00Ko003oooooool00?ooooooo`00ooooool4o`00oe3ooooo0ol00?l02ooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?oooooo00Co003oD?ooool3o`00o`06ooooool00?oooooo
o`00oooooooo003o1?ooool00ol0003oooooooooo`0Rooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool00oooool4ool0000;oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooool01?oo001?ooooo`Coo`0000_oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00ooooo`04ool005?ooooo00?o0000ooooooooool04Oooool001Kooooo00?o0000oooo
ooooool00oooool3o`0000;ooooo00Ko003oooooool00?ooooooo`00ooooool4o`00oe3ooooo0ol0
0?l02ooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo00Co003oD?ooool3
o`00o`06ooooool00?ooooooo`00oooooooo003o0oooool2o`0002Gooooo00?o0000ooooooooool0
0oooool2o`0000Cooooo1?oo00002oooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003ooooo00Coo`00Coooool4ool0000;oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooool01?oo001Booooo`;o00004oooool001Oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`1Eooooo`0=o`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`1Eooooo`07o`00oooo
oooo003oooooool00?ooooooo`00o`04ooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`06ooooo`0=ool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool0001Eooooo`0=ool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool0001Fooooo`03o`000?oooooooooo017ooooo000Dooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`07o`00oooooooo003ooooo
ool00?ooooooo`00o`1Eooooo`0=o`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00o`1Eooooo`07o`00oooooooo003oooooool00?ooooooo`00o`04ooooo`03o`00
0?oooooooooo027ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Ko
oooo00goo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`0005Go
oooo00goo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`0005Ko
oooo00?o0000ooooooooool04Oooool001Cooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo00;ooooo00Oo003oooooool00?ooooooo`00oooooooo003o05Gooooo00go003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o05Gooooo00Oo003o
ooooool00?ooooooo`00oooooooo003o00Cooooo00?o0000ooooooooool08Oooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool01_ooool03Ooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo0000EOooool03Ooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo0000E_ooool00ol0003oooooooooo`0Aooooo`00
5Oooool3o`0000Cooooo00?o0000ooooooooool00_ooool01ol00?ooooooo`00oooooooo003ooooo
ool00?l0EOooool03Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?l0EOooool01ol00?ooooooo`00oooooooo003oooooool00?l01?ooool00ol0003ooooooooo
o`0Rooooo`?o00001?ooool00ol0003oooooooooo`06ooooo`0=ool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool0001Eooooo`0=ool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool0001Fooooo`03o`000?oooooooooo017ooooo000L
ooooo`;o00000oooool01ol00?ooooooo`00oooooooo003oooooool00?l0EOooool03Ol00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?l0EOooool01ol00?oooooo
o`00oooooooo003oooooool00?l01?ooool00ol0003oooooooooo`0Yooooo`;o00001oooool03Ooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo0000EOooool03Ooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo0000EOooool2o`00
01?ooooo000Looooo`03o`000?oooooooooo00;ooooo00Oo003oooooool00?ooooooo`00oooooooo
003o05Gooooo00go003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003o05Gooooo00Oo003oooooool00?ooooooo`00oooooooo003o00Cooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`06ooooo`0=ool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool0001Eooooo`0=ool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool0001Fooooo`03o`000?oooooooooo017ooooo000Looooo`03o`000?oo
oooooooo00;ooooo00Oo003oooooool00?ooooooo`00oooooooo003o05Gooooo00go003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o05Gooooo00Oo003oooooool0
0?ooooooo`00oooooooo003o00Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`06
ooooo`0=ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0001E
ooooo`0=ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0001F
ooooo`03o`000?oooooooooo017ooooo000Looooo`03o`000?oooooooooo00;ooooo00Oo003ooooo
ool00?ooooooo`00oooooooo003o05Gooooo00go003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003o05Gooooo00Oo003oooooool00?ooooooo`00oooooooo003o00Co
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`06ooooo`0=ool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool0001Eooooo`0=ool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool0001Fooooo`03o`000?oooooooooo017o
oooo000Looooo`03o`000?oooooooooo00;ooooo00Co003oooooool00?oooooo1?l00?mCooooo`Co
003o00Ooooooo`00oooooooo003oooooool00?oooooo00Co003oDoooool4o`00o`04ooooool00?oo
ooooo`00o`Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`05ooooo`Coo`0000Oo
ooooool00?ooooooo`00oooooooo003ooooo00Coo`00Doooool4ool00007oooooooo003oooooool0
0?ooooooo`00ooooo`04ool005Gooooo00?o0000ooooooooool04Oooool001cooooo0_l00003oooo
o`04o`00oooooooo003oooooo`Co003oDoooool4o`00o`07ooooool00?ooooooo`00oooooooo003o
ooooo`04o`00oe?ooooo1?l00?l01?oooooo003oooooool00?l4ooooo`03o`000?oooooooooo02Wo
oooo0_l00006ooooo`Coo`0000Ooooooool00?ooooooo`00oooooooo003ooooo00Coo`00Doooool4
ool00007oooooooo003oooooool00?ooooooo`00ooooo`04ool005Cooooo0_l0000Cooooo`007?oo
ool00ol0003oooooooooo`02ooooo`04o`00oooooooo003oooooo`Co003oDoooool4o`00o`07oooo
ool00?ooooooo`00oooooooo003oooooo`04o`00oe?ooooo1?l00?l01?oooooo003oooooool00?l4
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01Oooool4ool00007oooooooo003o
ooooool00?ooooooo`00ooooo`04ool005?ooooo1?oo00001oooooooo`00oooooooo003oooooool0
0?ooool01?oo001Eooooo`03o`000?oooooooooo017ooooo000Looooo`03o`000?oooooooooo00;o
oooo00Go003oooooool00?ooooooo`00o`1Iooooo`09o`00oooooooo003oooooool00?ooooooo`00
oooooooo003o05Wooooo00Go003oooooool00?ooooooo`00o`04ooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool02?ooool02Ooo003oooooool00?ooooooo`00oooooooo003oooooool0
001Iooooo`09ool00?ooooooo`00oooooooo003oooooool00?ooooooo`0005Sooooo00?o0000oooo
ooooool04Oooool001cooooo00?o0000ooooooooool00_ooool01Ol00?ooooooo`00oooooooo003o
05Wooooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool00?l0FOooool01Ol00?oooooo
o`00oooooooo003o00Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`08ooooo`09
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`0005Wooooo00Woo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo0000F?ooool00ol0003oooooooooo`0Aooooo`007?ooool00ol0003o
ooooooooo`02ooooo`05o`00oooooooo003oooooool00?l0FOooool02Ol00?ooooooo`00oooooooo
003oooooool00?ooooooo`00o`1Iooooo`05o`00oooooooo003oooooool00?l01?ooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo00Sooooo00Woo`00oooooooo003oooooool00?oooooo
o`00oooooooo0000FOooool02Ooo003oooooool00?ooooooo`00oooooooo003oooooool0001Hoooo
o`03o`000?oooooooooo017ooooo000Looooo`;o00000oooool01Ol00?ooooooo`00oooooooo003o
05Wooooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool00?l0FOooool01Ol00?oooooo
o`00oooooooo003o00Cooooo00?o0000ooooooooool0:Oooool2o`0000Wooooo00Woo`00oooooooo
003oooooool00?ooooooo`00oooooooo0000FOooool02Ooo003oooooool00?ooooooo`00oooooooo
003oooooool0001Gooooo`;o00004oooool001cooooo00?o0000ooooooooool00_ooool01Ol00?oo
ooooo`00oooooooo003o05Wooooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool00?l0
FOooool01Ol00?ooooooo`00oooooooo003o00Cooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`08ooooo`09ool00?ooooooo`00oooooooo003oooooool00?ooooooo`0005Wooooo00Wo
o`00oooooooo003oooooool00?ooooooo`00oooooooo0000F?ooool00ol0003oooooooooo`0Aoooo
o`007?ooool00ol0003oooooooooo`02ooooo`03o`00oooooooo003o00?o003oEoooool4o`00o`03
ooooool00?oooooo00Co003oEoooool4o`00o`03ooooool00?oooooo00?ooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`07ooooo`Coo`0000?oooooool00?ooool01?oo001Gooooo`Co
o`0000?oooooool00?ooool01?oo001Gooooo`03o`000?oooooooooo017ooooo000Looooo`03o`00
0?oooooooooo00;ooooo00?o003oooooool00?l00ol00?mGooooo`Co003o00?oooooo`00ooooool0
1?l00?mGooooo`Co003o00?oooooo`00ooooool00oooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo00Oooooo1?oo00000oooooooo`00ooooo`04ool005Oooooo1?oo00000oooooooo`00
ooooo`04ool005Oooooo00?o0000ooooooooool04Oooool001cooooo00?o0000ooooooooool00_oo
ool00ol00?ooooooo`00o`03o`00oeOooooo1?l00?l00ooooooo003oooooo`04o`00oeOooooo1?l0
0?l00ooooooo003oooooo`03ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01ooo
ool4ool00003oooooooo003ooooo00Coo`00Eoooool4ool00003oooooooo003ooooo00Coo`00Eooo
ool00ol0003oooooooooo`0Aooooo`007?ooool2o`0000?ooooo00?o003oooooool00?l0GOooool0
1Ol00?ooooooo`00oooooooo003o05gooooo00?o003oooooool00?l01?ooool00ol0003ooooooooo
o`0Yooooo`;o00002oooool01Ooo003oooooool00?ooooooo`0005gooooo00Goo`00oooooooo003o
ooooool0001Iooooo`;o00004oooool001cooooo00?o0000ooooooooool00_ooool00ol00?oooooo
o`00o`1Mooooo`05o`00oooooooo003oooooool00?l0GOooool00ol00?ooooooo`00o`04ooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool02_ooool01Ooo003oooooool00?ooooooo`00
05gooooo00Goo`00oooooooo003oooooool0001Jooooo`03o`000?oooooooooo017ooooo000Eoooo
o`?o00001?ooool00ol0003oooooooooo`02ooooo`Co003oFoooool7o`00oe_ooooo1?l00?l4oooo
o`03o`000?oooooooooo02;ooooo0ol00004ooooo`03o`000?oooooooooo00Wooooo1ooo001Koooo
o`Ooo`00FOooool00ol0003oooooooooo`0Aooooo`005?ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Co0000oooooooooooooooo1Ol00?mKooooo`Oo003oFoooool5o`00o`?ooooo00?o0000
ooooooooool08Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool02Ooo
ool7ool005_ooooo1ooo001Iooooo`03o`000?oooooooooo017ooooo000Hooooo`04o`000?oooooo
ooooooooo`?o000000?oooooo`00ool00?l00ol00?mKooooo`Oo003oFoooool5o`00o`;ooooo0_l0
000Wooooo`04o`000?ooooooooooooooo`;o00002_ooool7ool005_ooooo1ooo001Hooooo`;o0000
4oooool001Kooooo0_l00004ooooo`04o`000?ooooooooooooooo`?o003oGoooool3o`00oeoooooo
0ol00?l3ooooo`03o`000?oooooooooo02?ooooo0_l00004ooooo`03o`000?oooooooooo00_ooooo
0ooo001Oooooo`?oo`00Foooool00ol0003oooooooooo`0Aooooo`006?ooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool09Oooool01Ol0003ooooooooooooooooo000000Co
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool04Oooool001Cooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool08Oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Aooooo`005Oooool3o`0000Co
oooocol0000Tooooo`?o00001?ooooo?o`0001?ooooo003oooooooWooooo003oooooooWooooo003o
ooooooWooooo003oooooooWooooo0000\
\>"],
  ImageRangeCache->{{{0, 503}, {147.312, 0}} -> {-0.0551454, -0.0147182, \
0.00419541, 0.00419541}, {{13.125, 240.125}, {143.75, 3.5}} -> {-17.2695, \
-2.80376, 0.510152, 0.0416603}, {{262.812, 489.812}, {143.75, 3.5}} -> \
{-144.648, -2.80376, 0.510152, 0.0416603}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Nonlinear phase (distortion)", "Subsection"],

Cell[BoxData[{
    \(\(x1[n_] := 
        Cos[2  \[Pi]\ n/50]\  + \ 
          2\ Cos[4  \[Pi]\ n/50];\)\), "\[IndentingNewLine]", 
    \(\(y1[n_] := 
        Cos[2  \[Pi]/50  n\  - 5]\  + \ 
          2\ Cos[4  \[Pi]\ /50  n\  - \ 5];\)\)}], "Input"],

Cell[BoxData[{
    \(\(xn\  = \ Table[{n, x1[n]}, {n, 0, 100}];\)\), "\[IndentingNewLine]", 
    \(\(xn2\  = \ 
        Table[{n, y1[n]}, {n, 0, 100}];\)\), "\[IndentingNewLine]", 
    \(\(g1b = 
        DiscreteListPlot[xn, \ Blue, \ DisplayFunction \[Rule] Identity, \ 
          Frame \[Rule] True];\)\), "\[IndentingNewLine]", 
    \(\(g2b = 
        DiscreteListPlot[xn2, \ Red, \ DisplayFunction \[Rule] Identity, \ 
          Frame \[Rule] True];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(gb = 
        Show[GraphicsArray[{{g1b, g2b}}], \ 
          ImageSize \[Rule] 504];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
%%ImageSize: 504 148.328 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.253447 0.116624 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -6 -9 ]
[.21429 -0.0125 6 0 ]
[.40476 -0.0125 -6 -9 ]
[.40476 -0.0125 6 0 ]
[.59524 -0.0125 -6 -9 ]
[.59524 -0.0125 6 0 ]
[.78571 -0.0125 -6 -9 ]
[.78571 -0.0125 6 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0202 -12 -4.5 ]
[-0.0125 .0202 0 4.5 ]
[-0.0125 .13682 -12 -4.5 ]
[-0.0125 .13682 0 4.5 ]
[-0.0125 .25345 -6 -4.5 ]
[-0.0125 .25345 0 4.5 ]
[-0.0125 .37007 -6 -4.5 ]
[-0.0125 .37007 0 4.5 ]
[-0.0125 .48669 -6 -4.5 ]
[-0.0125 .48669 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(20)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(40)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(60)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(80)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(100)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0202 m
.00625 .0202 L
s
[(-2)] -0.0125 .0202 1 0 Mshowa
0 .13682 m
.00625 .13682 L
s
[(-1)] -0.0125 .13682 1 0 Mshowa
0 .25345 m
.00625 .25345 L
s
[(0)] -0.0125 .25345 1 0 Mshowa
0 .37007 m
.00625 .37007 L
s
[(1)] -0.0125 .37007 1 0 Mshowa
0 .48669 m
.00625 .48669 L
s
[(2)] -0.0125 .48669 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(3)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04352 m
.00375 .04352 L
s
0 .06685 m
.00375 .06685 L
s
0 .09017 m
.00375 .09017 L
s
0 .1135 m
.00375 .1135 L
s
0 .16015 m
.00375 .16015 L
s
0 .18347 m
.00375 .18347 L
s
0 .2068 m
.00375 .2068 L
s
0 .23012 m
.00375 .23012 L
s
0 .27677 m
.00375 .27677 L
s
0 .3001 m
.00375 .3001 L
s
0 .32342 m
.00375 .32342 L
s
0 .34675 m
.00375 .34675 L
s
0 .3934 m
.00375 .3934 L
s
0 .41672 m
.00375 .41672 L
s
0 .44005 m
.00375 .44005 L
s
0 .46337 m
.00375 .46337 L
s
0 .51002 m
.00375 .51002 L
s
0 .53334 m
.00375 .53334 L
s
0 .55667 m
.00375 .55667 L
s
0 .57999 m
.00375 .57999 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0202 m
1 .0202 L
s
.99375 .13682 m
1 .13682 L
s
.99375 .25345 m
1 .25345 L
s
.99375 .37007 m
1 .37007 L
s
.99375 .48669 m
1 .48669 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04352 m
1 .04352 L
s
.99625 .06685 m
1 .06685 L
s
.99625 .09017 m
1 .09017 L
s
.99625 .1135 m
1 .1135 L
s
.99625 .16015 m
1 .16015 L
s
.99625 .18347 m
1 .18347 L
s
.99625 .2068 m
1 .2068 L
s
.99625 .23012 m
1 .23012 L
s
.99625 .27677 m
1 .27677 L
s
.99625 .3001 m
1 .3001 L
s
.99625 .32342 m
1 .32342 L
s
.99625 .34675 m
1 .34675 L
s
.99625 .3934 m
1 .3934 L
s
.99625 .41672 m
1 .41672 L
s
.99625 .44005 m
1 .44005 L
s
.99625 .46337 m
1 .46337 L
s
.99625 .51002 m
1 .51002 L
s
.99625 .53334 m
1 .53334 L
s
.99625 .55667 m
1 .55667 L
s
.99625 .57999 m
1 .57999 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .25345 m
.02381 .60332 L
s
.03333 .25345 m
.03333 .59507 L
s
.04286 .25345 m
.04286 .5708 L
s
.05238 .25345 m
.05238 .53191 L
s
.0619 .25345 m
.0619 .48063 L
s
.07143 .25345 m
.07143 .41988 L
s
.08095 .25345 m
.08095 .35311 L
s
.09048 .25345 m
.09048 .28408 L
s
.1 .25345 m
.1 .21662 L
s
.10952 .25345 m
.10952 .15442 L
s
.11905 .25345 m
.11905 .10078 L
s
.12857 .25345 m
.12857 .05843 L
s
.1381 .25345 m
.1381 .02936 L
s
.14762 .25345 m
.14762 .01472 L
s
.15714 .25345 m
.15714 .01473 L
s
.16667 .25345 m
.16667 .02871 L
s
.17619 .25345 m
.17619 .05511 L
s
.18571 .25345 m
.18571 .09164 L
s
.19524 .25345 m
.19524 .1354 L
s
.20476 .25345 m
.20476 .18308 L
s
.21429 .25345 m
.21429 .23117 L
s
.22381 .25345 m
.22381 .27623 L
s
.23333 .25345 m
.23333 .31504 L
s
.24286 .25345 m
.24286 .34488 L
s
.25238 .25345 m
.25238 .36366 L
s
.2619 .25345 m
.2619 .37007 L
s
.27143 .25345 m
.27143 .36366 L
s
.28095 .25345 m
.28095 .34488 L
s
.29048 .25345 m
.29048 .31504 L
s
.3 .25345 m
.3 .27623 L
s
.30952 .25345 m
.30952 .23117 L
s
.31905 .25345 m
.31905 .18308 L
s
.32857 .25345 m
.32857 .1354 L
s
.3381 .25345 m
.3381 .09164 L
s
.34762 .25345 m
.34762 .05511 L
s
.35714 .25345 m
.35714 .02871 L
s
.36667 .25345 m
.36667 .01473 L
s
.37619 .25345 m
.37619 .01472 L
s
.38571 .25345 m
.38571 .02936 L
s
.39524 .25345 m
.39524 .05843 L
s
.40476 .25345 m
.40476 .10078 L
s
.41429 .25345 m
.41429 .15442 L
s
.42381 .25345 m
.42381 .21662 L
s
.43333 .25345 m
.43333 .28408 L
s
.44286 .25345 m
.44286 .35311 L
s
.45238 .25345 m
.45238 .41988 L
s
.4619 .25345 m
.4619 .48063 L
s
.47143 .25345 m
.47143 .53191 L
s
.48095 .25345 m
.48095 .5708 L
s
.49048 .25345 m
.49048 .59507 L
s
.5 .25345 m
.5 .60332 L
s
.50952 .25345 m
.50952 .59507 L
s
.51905 .25345 m
.51905 .5708 L
s
.52857 .25345 m
.52857 .53191 L
s
.5381 .25345 m
.5381 .48063 L
s
.54762 .25345 m
.54762 .41988 L
s
.55714 .25345 m
.55714 .35311 L
s
.56667 .25345 m
.56667 .28408 L
s
.57619 .25345 m
.57619 .21662 L
s
.58571 .25345 m
.58571 .15442 L
s
.59524 .25345 m
.59524 .10078 L
s
.60476 .25345 m
.60476 .05843 L
s
.61429 .25345 m
.61429 .02936 L
s
.62381 .25345 m
.62381 .01472 L
s
.63333 .25345 m
.63333 .01473 L
s
.64286 .25345 m
.64286 .02871 L
s
.65238 .25345 m
.65238 .05511 L
s
.6619 .25345 m
.6619 .09164 L
s
.67143 .25345 m
.67143 .1354 L
s
.68095 .25345 m
.68095 .18308 L
s
.69048 .25345 m
.69048 .23117 L
s
.7 .25345 m
.7 .27623 L
s
.70952 .25345 m
.70952 .31504 L
s
.71905 .25345 m
.71905 .34488 L
s
.72857 .25345 m
.72857 .36366 L
s
.7381 .25345 m
.7381 .37007 L
s
.74762 .25345 m
.74762 .36366 L
s
.75714 .25345 m
.75714 .34488 L
s
.76667 .25345 m
.76667 .31504 L
s
.77619 .25345 m
.77619 .27623 L
s
.78571 .25345 m
.78571 .23117 L
s
.79524 .25345 m
.79524 .18308 L
s
.80476 .25345 m
.80476 .1354 L
s
.81429 .25345 m
.81429 .09164 L
s
.82381 .25345 m
.82381 .05511 L
s
.83333 .25345 m
.83333 .02871 L
s
.84286 .25345 m
.84286 .01473 L
s
.85238 .25345 m
.85238 .01472 L
s
.8619 .25345 m
.8619 .02936 L
s
.87143 .25345 m
.87143 .05843 L
s
.88095 .25345 m
.88095 .10078 L
s
.89048 .25345 m
.89048 .15442 L
s
.9 .25345 m
.9 .21662 L
s
.90952 .25345 m
.90952 .28408 L
s
.91905 .25345 m
.91905 .35311 L
s
.92857 .25345 m
.92857 .41988 L
s
.9381 .25345 m
.9381 .48063 L
s
.94762 .25345 m
.94762 .53191 L
s
.95714 .25345 m
.95714 .5708 L
s
.96667 .25345 m
.96667 .59507 L
s
.97619 .25345 m
.97619 .60332 L
s
.015 w
.02381 .60332 Mdot
.03333 .59507 Mdot
.04286 .5708 Mdot
.05238 .53191 Mdot
.0619 .48063 Mdot
.07143 .41988 Mdot
.08095 .35311 Mdot
.09048 .28408 Mdot
.1 .21662 Mdot
.10952 .15442 Mdot
.11905 .10078 Mdot
.12857 .05843 Mdot
.1381 .02936 Mdot
.14762 .01472 Mdot
.15714 .01473 Mdot
.16667 .02871 Mdot
.17619 .05511 Mdot
.18571 .09164 Mdot
.19524 .1354 Mdot
.20476 .18308 Mdot
.21429 .23117 Mdot
.22381 .27623 Mdot
.23333 .31504 Mdot
.24286 .34488 Mdot
.25238 .36366 Mdot
.2619 .37007 Mdot
.27143 .36366 Mdot
.28095 .34488 Mdot
.29048 .31504 Mdot
.3 .27623 Mdot
.30952 .23117 Mdot
.31905 .18308 Mdot
.32857 .1354 Mdot
.3381 .09164 Mdot
.34762 .05511 Mdot
.35714 .02871 Mdot
.36667 .01473 Mdot
.37619 .01472 Mdot
.38571 .02936 Mdot
.39524 .05843 Mdot
.40476 .10078 Mdot
.41429 .15442 Mdot
.42381 .21662 Mdot
.43333 .28408 Mdot
.44286 .35311 Mdot
.45238 .41988 Mdot
.4619 .48063 Mdot
.47143 .53191 Mdot
.48095 .5708 Mdot
.49048 .59507 Mdot
.5 .60332 Mdot
.50952 .59507 Mdot
.51905 .5708 Mdot
.52857 .53191 Mdot
.5381 .48063 Mdot
.54762 .41988 Mdot
.55714 .35311 Mdot
.56667 .28408 Mdot
.57619 .21662 Mdot
.58571 .15442 Mdot
.59524 .10078 Mdot
.60476 .05843 Mdot
.61429 .02936 Mdot
.62381 .01472 Mdot
.63333 .01473 Mdot
.64286 .02871 Mdot
.65238 .05511 Mdot
.6619 .09164 Mdot
.67143 .1354 Mdot
.68095 .18308 Mdot
.69048 .23117 Mdot
.7 .27623 Mdot
.70952 .31504 Mdot
.71905 .34488 Mdot
.72857 .36366 Mdot
.7381 .37007 Mdot
.74762 .36366 Mdot
.75714 .34488 Mdot
.76667 .31504 Mdot
.77619 .27623 Mdot
.78571 .23117 Mdot
.79524 .18308 Mdot
.80476 .1354 Mdot
.81429 .09164 Mdot
.82381 .05511 Mdot
.83333 .02871 Mdot
.84286 .01473 Mdot
.85238 .01472 Mdot
.8619 .02936 Mdot
.87143 .05843 Mdot
.88095 .10078 Mdot
.89048 .15442 Mdot
.9 .21662 Mdot
.90952 .28408 Mdot
.91905 .35311 Mdot
.92857 .41988 Mdot
.9381 .48063 Mdot
.94762 .53191 Mdot
.95714 .5708 Mdot
.96667 .59507 Mdot
.97619 .60332 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.299381 0.108052 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -6 -9 ]
[.21429 -0.0125 6 0 ]
[.40476 -0.0125 -6 -9 ]
[.40476 -0.0125 6 0 ]
[.59524 -0.0125 -6 -9 ]
[.59524 -0.0125 6 0 ]
[.78571 -0.0125 -6 -9 ]
[.78571 -0.0125 6 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08328 -12 -4.5 ]
[-0.0125 .08328 0 4.5 ]
[-0.0125 .19133 -12 -4.5 ]
[-0.0125 .19133 0 4.5 ]
[-0.0125 .29938 -6 -4.5 ]
[-0.0125 .29938 0 4.5 ]
[-0.0125 .40743 -6 -4.5 ]
[-0.0125 .40743 0 4.5 ]
[-0.0125 .51548 -6 -4.5 ]
[-0.0125 .51548 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(20)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(40)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(60)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(80)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(100)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08328 m
.00625 .08328 L
s
[(-2)] -0.0125 .08328 1 0 Mshowa
0 .19133 m
.00625 .19133 L
s
[(-1)] -0.0125 .19133 1 0 Mshowa
0 .29938 m
.00625 .29938 L
s
[(0)] -0.0125 .29938 1 0 Mshowa
0 .40743 m
.00625 .40743 L
s
[(1)] -0.0125 .40743 1 0 Mshowa
0 .51548 m
.00625 .51548 L
s
[(2)] -0.0125 .51548 1 0 Mshowa
.125 Mabswid
0 .10489 m
.00375 .10489 L
s
0 .1265 m
.00375 .1265 L
s
0 .14811 m
.00375 .14811 L
s
0 .16972 m
.00375 .16972 L
s
0 .21294 m
.00375 .21294 L
s
0 .23455 m
.00375 .23455 L
s
0 .25616 m
.00375 .25616 L
s
0 .27777 m
.00375 .27777 L
s
0 .32099 m
.00375 .32099 L
s
0 .3426 m
.00375 .3426 L
s
0 .36421 m
.00375 .36421 L
s
0 .38582 m
.00375 .38582 L
s
0 .42904 m
.00375 .42904 L
s
0 .45065 m
.00375 .45065 L
s
0 .47226 m
.00375 .47226 L
s
0 .49387 m
.00375 .49387 L
s
0 .06167 m
.00375 .06167 L
s
0 .04006 m
.00375 .04006 L
s
0 .01845 m
.00375 .01845 L
s
0 .53709 m
.00375 .53709 L
s
0 .5587 m
.00375 .5587 L
s
0 .58032 m
.00375 .58032 L
s
0 .60193 m
.00375 .60193 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .08328 m
1 .08328 L
s
.99375 .19133 m
1 .19133 L
s
.99375 .29938 m
1 .29938 L
s
.99375 .40743 m
1 .40743 L
s
.99375 .51548 m
1 .51548 L
s
.125 Mabswid
.99625 .10489 m
1 .10489 L
s
.99625 .1265 m
1 .1265 L
s
.99625 .14811 m
1 .14811 L
s
.99625 .16972 m
1 .16972 L
s
.99625 .21294 m
1 .21294 L
s
.99625 .23455 m
1 .23455 L
s
.99625 .25616 m
1 .25616 L
s
.99625 .27777 m
1 .27777 L
s
.99625 .32099 m
1 .32099 L
s
.99625 .3426 m
1 .3426 L
s
.99625 .36421 m
1 .36421 L
s
.99625 .38582 m
1 .38582 L
s
.99625 .42904 m
1 .42904 L
s
.99625 .45065 m
1 .45065 L
s
.99625 .47226 m
1 .47226 L
s
.99625 .49387 m
1 .49387 L
s
.99625 .06167 m
1 .06167 L
s
.99625 .04006 m
1 .04006 L
s
.99625 .01845 m
1 .01845 L
s
.99625 .53709 m
1 .53709 L
s
.99625 .5587 m
1 .5587 L
s
.99625 .58032 m
1 .58032 L
s
.99625 .60193 m
1 .60193 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .29938 m
.02381 .39133 L
s
.03333 .29938 m
.03333 .32464 L
s
.04286 .29938 m
.04286 .25719 L
s
.05238 .29938 m
.05238 .19257 L
s
.0619 .29938 m
.0619 .1342 L
s
.07143 .29938 m
.07143 .08513 L
s
.08095 .29938 m
.08095 .04783 L
s
.09048 .29938 m
.09048 .02404 L
s
.1 .29938 m
.1 .01472 L
s
.10952 .29938 m
.10952 .01993 L
s
.11905 .29938 m
.11905 .03891 L
s
.12857 .29938 m
.12857 .07006 L
s
.1381 .29938 m
.1381 .11111 L
s
.14762 .29938 m
.14762 .1592 L
s
.15714 .29938 m
.15714 .21115 L
s
.16667 .29938 m
.16667 .26358 L
s
.17619 .29938 m
.17619 .31317 L
s
.18571 .29938 m
.18571 .35688 L
s
.19524 .29938 m
.19524 .39208 L
s
.20476 .29938 m
.20476 .41678 L
s
.21429 .29938 m
.21429 .42971 L
s
.22381 .29938 m
.22381 .43042 L
s
.23333 .29938 m
.23333 .41928 L
s
.24286 .29938 m
.24286 .39748 L
s
.25238 .29938 m
.25238 .3669 L
s
.2619 .29938 m
.2619 .33003 L
s
.27143 .29938 m
.27143 .2898 L
s
.28095 .29938 m
.28095 .24935 L
s
.29048 .29938 m
.29048 .21185 L
s
.3 .29938 m
.3 .18032 L
s
.30952 .29938 m
.30952 .15734 L
s
.31905 .29938 m
.31905 .145 L
s
.32857 .29938 m
.32857 .14464 L
s
.3381 .29938 m
.3381 .15684 L
s
.34762 .29938 m
.34762 .18134 L
s
.35714 .29938 m
.35714 .21705 L
s
.36667 .29938 m
.36667 .26213 L
s
.37619 .29938 m
.37619 .31408 L
s
.38571 .29938 m
.38571 .36987 L
s
.39524 .29938 m
.39524 .42619 L
s
.40476 .29938 m
.40476 .47961 L
s
.41429 .29938 m
.41429 .52678 L
s
.42381 .29938 m
.42381 .56469 L
s
.43333 .29938 m
.43333 .59082 L
s
.44286 .29938 m
.44286 .60332 L
s
.45238 .29938 m
.45238 .60111 L
s
.4619 .29938 m
.4619 .58397 L
s
.47143 .29938 m
.47143 .55256 L
s
.48095 .29938 m
.48095 .50839 L
s
.49048 .29938 m
.49048 .45369 L
s
.5 .29938 m
.5 .39133 L
s
.50952 .29938 m
.50952 .32464 L
s
.51905 .29938 m
.51905 .25719 L
s
.52857 .29938 m
.52857 .19257 L
s
.5381 .29938 m
.5381 .1342 L
s
.54762 .29938 m
.54762 .08513 L
s
.55714 .29938 m
.55714 .04783 L
s
.56667 .29938 m
.56667 .02404 L
s
.57619 .29938 m
.57619 .01472 L
s
.58571 .29938 m
.58571 .01993 L
s
.59524 .29938 m
.59524 .03891 L
s
.60476 .29938 m
.60476 .07006 L
s
.61429 .29938 m
.61429 .11111 L
s
.62381 .29938 m
.62381 .1592 L
s
.63333 .29938 m
.63333 .21115 L
s
.64286 .29938 m
.64286 .26358 L
s
.65238 .29938 m
.65238 .31317 L
s
.6619 .29938 m
.6619 .35688 L
s
.67143 .29938 m
.67143 .39208 L
s
.68095 .29938 m
.68095 .41678 L
s
.69048 .29938 m
.69048 .42971 L
s
.7 .29938 m
.7 .43042 L
s
.70952 .29938 m
.70952 .41928 L
s
.71905 .29938 m
.71905 .39748 L
s
.72857 .29938 m
.72857 .3669 L
s
.7381 .29938 m
.7381 .33003 L
s
.74762 .29938 m
.74762 .2898 L
s
.75714 .29938 m
.75714 .24935 L
s
.76667 .29938 m
.76667 .21185 L
s
.77619 .29938 m
.77619 .18032 L
s
.78571 .29938 m
.78571 .15734 L
s
.79524 .29938 m
.79524 .145 L
s
.80476 .29938 m
.80476 .14464 L
s
.81429 .29938 m
.81429 .15684 L
s
.82381 .29938 m
.82381 .18134 L
s
.83333 .29938 m
.83333 .21705 L
s
.84286 .29938 m
.84286 .26213 L
s
.85238 .29938 m
.85238 .31408 L
s
.8619 .29938 m
.8619 .36987 L
s
.87143 .29938 m
.87143 .42619 L
s
.88095 .29938 m
.88095 .47961 L
s
.89048 .29938 m
.89048 .52678 L
s
.9 .29938 m
.9 .56469 L
s
.90952 .29938 m
.90952 .59082 L
s
.91905 .29938 m
.91905 .60332 L
s
.92857 .29938 m
.92857 .60111 L
s
.9381 .29938 m
.9381 .58397 L
s
.94762 .29938 m
.94762 .55256 L
s
.95714 .29938 m
.95714 .50839 L
s
.96667 .29938 m
.96667 .45369 L
s
.97619 .29938 m
.97619 .39133 L
s
.015 w
.02381 .39133 Mdot
.03333 .32464 Mdot
.04286 .25719 Mdot
.05238 .19257 Mdot
.0619 .1342 Mdot
.07143 .08513 Mdot
.08095 .04783 Mdot
.09048 .02404 Mdot
.1 .01472 Mdot
.10952 .01993 Mdot
.11905 .03891 Mdot
.12857 .07006 Mdot
.1381 .11111 Mdot
.14762 .1592 Mdot
.15714 .21115 Mdot
.16667 .26358 Mdot
.17619 .31317 Mdot
.18571 .35688 Mdot
.19524 .39208 Mdot
.20476 .41678 Mdot
.21429 .42971 Mdot
.22381 .43042 Mdot
.23333 .41928 Mdot
.24286 .39748 Mdot
.25238 .3669 Mdot
.2619 .33003 Mdot
.27143 .2898 Mdot
.28095 .24935 Mdot
.29048 .21185 Mdot
.3 .18032 Mdot
.30952 .15734 Mdot
.31905 .145 Mdot
.32857 .14464 Mdot
.3381 .15684 Mdot
.34762 .18134 Mdot
.35714 .21705 Mdot
.36667 .26213 Mdot
.37619 .31408 Mdot
.38571 .36987 Mdot
.39524 .42619 Mdot
.40476 .47961 Mdot
.41429 .52678 Mdot
.42381 .56469 Mdot
.43333 .59082 Mdot
.44286 .60332 Mdot
.45238 .60111 Mdot
.4619 .58397 Mdot
.47143 .55256 Mdot
.48095 .50839 Mdot
.49048 .45369 Mdot
.5 .39133 Mdot
.50952 .32464 Mdot
.51905 .25719 Mdot
.52857 .19257 Mdot
.5381 .1342 Mdot
.54762 .08513 Mdot
.55714 .04783 Mdot
.56667 .02404 Mdot
.57619 .01472 Mdot
.58571 .01993 Mdot
.59524 .03891 Mdot
.60476 .07006 Mdot
.61429 .11111 Mdot
.62381 .1592 Mdot
.63333 .21115 Mdot
.64286 .26358 Mdot
.65238 .31317 Mdot
.6619 .35688 Mdot
.67143 .39208 Mdot
.68095 .41678 Mdot
.69048 .42971 Mdot
.7 .43042 Mdot
.70952 .41928 Mdot
.71905 .39748 Mdot
.72857 .3669 Mdot
.7381 .33003 Mdot
.74762 .2898 Mdot
.75714 .24935 Mdot
.76667 .21185 Mdot
.77619 .18032 Mdot
.78571 .15734 Mdot
.79524 .145 Mdot
.80476 .14464 Mdot
.81429 .15684 Mdot
.82381 .18134 Mdot
.83333 .21705 Mdot
.84286 .26213 Mdot
.85238 .31408 Mdot
.8619 .36987 Mdot
.87143 .42619 Mdot
.88095 .47961 Mdot
.89048 .52678 Mdot
.9 .56469 Mdot
.90952 .59082 Mdot
.91905 .60332 Mdot
.92857 .60111 Mdot
.9381 .58397 Mdot
.94762 .55256 Mdot
.95714 .50839 Mdot
.96667 .45369 Mdot
.97619 .39133 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 148.312},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0000U2000`400?l00000o`00003ooooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`008?ooool2
o`00027ooooo1Ol00003ooooo`;o00007oooool3o`0000?ooooo0_l0000Nooooo`?o00001?ooool2
o`0001kooooo0ol00004ooooo`;o00006oooool3o`0000Cooooo0_l00004ooooo`;o0000;Oooool2
o`00027ooooo1Ol00003ooooo`;o00007oooool3o`0000?ooooo0_l0000Oooooo`?o00001?ooool2
o`0001oooooo0ol00004ooooo`;o00006oooool3o`0000Cooooo0_l00004ooooo`;o00004Oooool0
01oooooo00Co0000oooooooooooo00008Oooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0001oooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo01[o
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001cooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001_ooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0002_ooooo00Co0000oooo
oooooooo00008Oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001oooooo
00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo01_ooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0001gooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0001_ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`00013ooooo000Oooooo`04o`000?ooooooooooo`00
02;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Looooo`Go00000_ooool0
1?l0003oooooooooool0000Looooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool0000Looooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000K
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool0000[ooooo`04o`000?ooooooooooo`0002;ooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool0000Looooo`Go00000_ooool01?l0003oooooooooool0000Mooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool0000Mooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool0000Kooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool0000@ooooo`007oooool01?l0003oooooooooool0
000Sooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Jooooo`04o`00
0?ooooooooooo`0000?ooooo00Co0000oooooooooooo00007?ooool4o`0000?ooooo00Co0000oooo
oooooooo00007Oooool3o`0000?ooooo00Co0000oooooooooooo00006oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000:oooool01?l0003o
ooooooooool0000Sooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0J
ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00007Oooool4o`0000?ooooo
00Co0000oooooooooooo00007_ooool3o`0000?ooooo00Co0000oooooooooooo00006oooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00004?oo
ool001oooooo00Co0000oooooooooooo00008?ooool01Ol0003ooooooooooooooooo000000;ooooo
00Co0000oooooooooooo00007Oooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`00
01cooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0000Looooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool0000Kooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000[ooooo`04o`000?oooooooooo
o`00023ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001gooooo
00?o0000ooooool000000oooool01?l0003oooooooooool0000Mooooo`03o`000?oooooooooo00Co
oooo00Co0000oooooooooooo00007Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00006oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00004?ooool001oooooo00Co0000oooooooooooo00008?ooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00007_ooool2o`0000?ooooo00Co0000
oooooooooooo00007Oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0001cooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001[ooooo0_l00004oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000:oooool01?l0003ooooooooo
ool0000Pooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Noooo
o`;o00000oooool01?l0003oooooooooool0000Nooooo`03o`000?oooooooooo00?ooooo00Co0000
oooooooooooo00007Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00006_ooool2o`0000Cooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000@
ooooo`008?ooool2o`0002;ooooo0ol00004ooooo`;o00008?ooool00ol0003oooooooooo`02oooo
o`;o00007oooool2o`0000Cooooo0_l0000Nooooo`?o00001?ooool2o`0001cooooo00?o0000oooo
ooooool00oooool2o`0000Cooooo0_l0000]ooooo`;o00008_ooool3o`0000Cooooo0_l0000Poooo
o`03o`000?oooooooooo00;ooooo0_l0000Pooooo`;o00001?ooool2o`0001oooooo0ol00004oooo
o`;o00007?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`00017ooooo003oooooooWo
oooo003oooooooWooooo003oooooooWooooo000Looooo`03o`000000000000000</0000000?o0000
ooooooooool0:?ooool00ol0000000000000003=00000003o`000?oooooooooo013ooooo000Loooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo013ooooo000Dooooo`Go00000oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo01Kooooo1Ol00?l:ooooo`03o`000?oooooooooo01_ooooo1Ol00?l4ooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool00_ooool5o`00oagooooo00?o0000oooooooo
ool02?ooool5o`00oaOooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool3ool001Kooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0Pooooo`?oo`000_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0@ooooo`00
5Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo01_ooooo1Ol00?lXooooo`Go
003o<?ooool5o`00obSooooo1Ol00?lLooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool04Oooool5ool005kooooo1Ooo001Dooooo`03o`000?oooooooooo013ooooo000>ooooo`Go0000
0oooool00ol0003oooooooooo`03ooooo`03o`0000000000000001_ooooo1Ol00?lXooooo`Go003o
<?ooool5o`00obSooooo1Ol00?lKooooo`;o0000:_ooool2o`00013ooooo1ooo001Looooo`Ooo`00
Doooool2o`0001;ooooo000Gooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06Ooo
ool4o`00o`03ooooool00?oo003o00;o003o9?ooool4o`00o`03ooooool00?oo003o00;o003o;?oo
ool4o`00o`03ooooool00?oo003o00;o003o9?ooool4o`00o`03ooooool00?oo003o00;o003o6_oo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00oooooo1ooo001Looooo`Ooo`00E?oo
ool00ol0003oooooooooo`0@ooooo`005?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool06Oooool4o`00o`03ooooool00?oo003o00;o003o9?ooool4o`00o`03ooooool0
0?oo003o00;o003o;?ooool4o`00o`03ooooool00?oo003o00;o003o9?ooool4o`00o`03ooooool0
0?oo003o00;o003o6_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00oooooo1?oo
00000oooooooo`00ooooo`1Looooo`Coo`0000?oooooool00?ooool0E?ooool00ol0003ooooooooo
o`0@ooooo`005?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool06Ooo
ool4o`00o`03ooooool00?oo003o00;o003o9?ooool4o`00o`03ooooool00?oo003o00;o003o;?oo
ool4o`00o`03ooooool00?oo003o00;o003o9?ooool4o`00o`03ooooool00?oo003o00;o003o6_oo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo013ooooo00Coo`00oooooooo003ooooo
1?oo001Kooooo`04ool00?ooooooo`00ooooo`Coo`00D_ooool00ol0003oooooooooo`0@ooooo`00
5Oooool3o`0000Cooooo00?o0000ooooooooool06_ooool01ol00?ooooooo`00oooooooo003ooooo
ool00?l09_ooool01ol00?ooooooo`00oooooooo003oooooool00?l0;_ooool01ol00?ooooooo`00
oooooooo003oooooool00?l09_ooool01ol00?ooooooo`00oooooooo003oooooool00?l06oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo013ooooo00Coo`00oooooooo003ooooo1?oo
001Kooooo`04ool00?ooooooo`00ooooo`Coo`00D_ooool00ol0003oooooooooo`0@ooooo`007?oo
ool2o`0001_ooooo00Oo003oooooool00?ooooooo`00oooooooo003o02Kooooo00Oo003oooooool0
0?ooooooo`00oooooooo003o02kooooo00Oo003oooooool00?ooooooo`00oooooooo003o02Kooooo
00Oo003oooooool00?ooooooo`00oooooooo003o01_ooooo00?o0000ooooooooool0:?ooool2o`00
00kooooo1?oo00000oooooooo`00ooooo`04ool005Sooooo1?oo00000oooooooo`00ooooo`04ool0
057ooooo0_l0000Booooo`007?ooool00ol0003oooooooooo`0Jooooo`07o`00oooooooo003ooooo
ool00?ooooooo`00o`0Vooooo`07o`00oooooooo003oooooool00?ooooooo`00o`0^ooooo`07o`00
oooooooo003oooooool00?ooooooo`00o`0Vooooo`07o`00oooooooo003oooooool00?ooooooo`00
o`0Kooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03Oooool4ool00006oooooooo
003oooooool00?ooooooo`00FOooool4ool00006oooooooo003oooooool00?ooooooo`00Doooool0
0ol0003oooooooooo`0@ooooo`007?ooool00ol0003oooooooooo`0Gooooo`Co003o00Goooooo`00
oooooooo003oooooo`04o`00ob3ooooo1?l00?l01Ooooooo003oooooool00?oooooo00Co003o:?oo
ool4o`00o`05ooooool00?ooooooo`00ooooool01?l00?lPooooo`Co003o00Goooooo`00oooooooo
003oooooo`04o`00oaSooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0=ooooo`Co
o`0000Koooooool00?ooooooo`00oooooooo001Iooooo`Coo`0000Koooooool00?ooooooo`00oooo
oooo001Cooooo`03o`000?oooooooooo013ooooo000Looooo`03o`000?oooooooooo01Oooooo1?l0
0?l01Ooooooo003oooooool00?oooooo00Co003o8?ooool4o`00o`05ooooool00?ooooooo`00oooo
ool01?l00?lXooooo`Co003o00Goooooo`00oooooooo003oooooo`04o`00ob3ooooo1?l00?l01Ooo
oooo003oooooool00?oooooo00Co003o6?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo00kooooo00Woo`00oooooooo003oooooool00?ooooooo`00oooooooo0000F_ooool02Ooo003o
ooooool00?ooooooo`00oooooooo003oooooool0001Cooooo`03o`000?oooooooooo013ooooo000L
ooooo`03o`000?oooooooooo01Oooooo1?l00?l01Ooooooo003oooooool00?oooooo00Co003o8?oo
ool4o`00o`05ooooool00?ooooooo`00ooooool01?l00?lXooooo`Co003o00Goooooo`00oooooooo
003oooooo`04o`00ob3ooooo1?l00?l01Ooooooo003oooooool00?oooooo00Co003o6?ooool00ol0
003oooooooooo`0Xooooo`;o00003oooool02Ooo003oooooool00?ooooooo`00oooooooo003ooooo
ool0001Jooooo`09ool00?ooooooo`00oooooooo003oooooool00?ooooooo`0005;ooooo0_l0000B
ooooo`007?ooool2o`0001Wooooo00_o003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00o`0Rooooo`0;o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?l0
:_ooool02ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o02;ooooo00_o
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0Iooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool03_ooool02?oo003oooooool00?ooooooo`00oooooooo003o
oooo1?oo001Gooooo`08ool00?ooooooo`00oooooooo003oooooool00?ooool4ool0053ooooo00?o
0000ooooooooool04?ooool001cooooo00?o0000ooooooooool06?ooool02ol00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003o02;ooooo00_o003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00o`0Zooooo`0;o`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?l08_ooool02ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003o01Wooooo00?o0000ooooooooool07oooool5o`0000Cooooo00?o0000ooooooooool03_oo
ool02?oo003oooooool00?ooooooo`00oooooooo003ooooo1?oo001Gooooo`08ool00?ooooooo`00
oooooooo003oooooool00?ooool4ool0053ooooo00?o0000ooooooooool04?ooool001cooooo00?o
0000ooooooooool06?ooool02ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003o02;ooooo00_o003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0Zoooo
o`0;o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?l08_ooool02ol00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o01Wooooo00?o0000ooooooooool0
8?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00kooooo00Soo`00oooooooo
003oooooool00?ooooooo`00ooooo`Coo`00Eoooool02?oo003oooooool00?ooooooo`00oooooooo
003ooooo1?oo001@ooooo`03o`000?oooooooooo013ooooo000Looooo`03o`000?oooooooooo01So
oooo00_o003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0Rooooo`0;o`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?l0:_ooool02ol00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003o02;ooooo00_o003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00o`0Iooooo`03o`000?oooooooooo01Wooooo1Ol00003oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool4ool0000:oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool005Gooooo1?oo00002_ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo001Aooooo`03o`000?oooooooooo013ooooo000Looooo`03o`000?oo
oooooooo01Sooooo00[o003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo1?l00?lL
ooooo`Co003o00[oooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o:_ooool02_l0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooool4o`00oacooooo1?l00?l02_oooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?lIooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool00oooool2o`0000cooooo1?oo00002_ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo001Eooooo`Coo`0000[oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00D?ooool2o`0001;ooooo000Looooo`;o00006Oooool02_l00?ooooooo`00oooooooo
003oooooool00?ooooooo`00ooooool4o`00oacooooo1?l00?l02_oooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?lZooooo`0:o`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooo`Co003o7?ooool4o`00o`0:ooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oaWooooo00?o0000ooooooooool07oooool01Ol0003ooooooooooooooooo000000Cooooo00?o
0000ooooooooool02oooool4ool0000:oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool005Gooooo1?oo00002_ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo001Aoooo
o`03o`000?oooooooooo013ooooo000Looooo`03o`000?oooooooooo01Gooooo1?l00?l02Ooooooo
003oooooool00?ooooooo`00oooooooo003oooooo`04o`00oacooooo1?l00?l02Ooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooo`04o`00obCooooo1?l00?l02Ooooooo003oooooool00?oo
ooooo`00oooooooo003oooooo`04o`00oacooooo1?l00?l02Ooooooo003oooooool00?ooooooo`00
oooooooo003oooooo`04o`00oaKooooo00?o0000ooooooooool07oooool01Ol0003ooooooooooooo
oooo000000Cooooo00?o0000ooooooooool03?ooool03Ooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo0000E_ooool03Ooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo0000DOooool00ol0003oooooooooo`0@ooooo`007?ooool0
0ol0003oooooooooo`0Eooooo`Co003o00coooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?lNooooo`0<o`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?oooooo1?l00?lTooooo`Co003o00coooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?lNooooo`0<o`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?oooooo1?l00?lFooooo`03o`000?oooooooooo023ooooo0ol00005ooooo`03o`000?oooooo
oooo00cooooo00goo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`0005Kooooo00goo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00057ooooo00?o0000ooooooooool04?ooool001cooooo00?o0000ooooooooool05Oooool4o`00
o`0<ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o7_ooool03?l0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooo`Co003o9?ooool4o`00
o`0<ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o7_ooool03?l0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooo`Co003o5_ooool00ol0
003oooooooooo`0Xooooo`;o00003Oooool03?oo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00ooooo`Coo`00Doooool03?oo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00ooooo`Coo`00COooool2o`0001;ooooo000Looooo`03o`000?oooooooooo01Ko
oooo00oo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?l07_ooool03ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00o`0Vooooo`0?o`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003o01kooooo00oo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?l05oooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo00cooooo00coo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooool4ool005?ooooo00coo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooool4ool004kooooo00?o0000ooooooooool04?ooool001cooooo0_l0000Gooooo`0?o`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o01kooooo
00oo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?l09_ooool03ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00o`0Nooooo`0?o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003o01Oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0<
ooooo`0<ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo1?oo001C
ooooo`0<ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo1?oo001>
ooooo`03o`000?oooooooooo013ooooo000Looooo`03o`000?oooooooooo01Kooooo00oo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?l07_ooool0
3ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
o`0Vooooo`0?o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003o01kooooo00oo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?l05oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00co
oooo00ooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo0000E?ooool03ooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool0001?ooooo`03o`000?oooooooooo013ooooo000Eooooo`?o00001?ooool00ol0
003oooooooooo`0Fooooo`0?o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003o01kooooo00oo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?l09_ooool03ol00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0Nooooo`0?o`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o01Oooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`0<ooooo`0?ool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`0005Cooooo00ooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo0000Coooool00ol0003oooooooooo`0@
ooooo`005_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo00ko003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooo`Co003o6?ooool4
o`00o`0>ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?lVooooo`0>o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
ooooool4o`00oaSooooo1?l00?l03_oooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003o5oooool00ol0003oooooooooo`0Xooooo`;o00002_ooool4ool0000>
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo001Aoooo
o`Coo`0000koooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool004kooooo0_l0000Booooo`003_ooool5o`0000?ooooo00?o0000ooooooooool00oooool3o`00
01Kooooo00ko003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooo`Co003o6?ooool4o`00o`0>ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?lVooooo`0>o`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00ooooool4o`00oaSooooo1?l00?l03_oooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003o5_ooool2o`0002[ooooo00?o0000oooooooo
ool02Oooool4ool0000>oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo001Aooooo`Coo`0000koooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool004oooooo00?o0000ooooooooool04?ooool001Kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Fooooo`0>o`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00ooooool4o`00oaSooooo1?l00?l03_oooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o9_ooool03_l00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo1?l00?lHooooo`Co003o
00koooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oaOo
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`09ooooo`Coo`0000koooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool002Gooooo0ooo000Yoooo
o`Coo`0000koooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool002Kooooo0ooo000Vooooo`03o`000?oooooooooo013ooooo000Fooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool05_ooool04Ol00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003o01[ooooo017o003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0Vooooo`0A
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?l06_ooool04Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003o01Oooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`0:ooooo`0Aool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo00008oooool5ool002[ooooo017oo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0000Tooooo`Goo`009_oo
ool00ol0003oooooooooo`0@ooooo`005Oooool2o`0000Gooooo00?o0000ooooooooool04oooool4
o`00o`0@ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oa[ooooo013o003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?oooooo1?l00?lPooooo`Co003o013oooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o6_ooool04?l00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooool4o`00oaCo
oooo00?o0000ooooooooool0:?ooool2o`0000_ooooo017oo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0000Sooooo`Goo`00:_ooool0
4Ooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`0002Cooooo1Ooo000Uooooo`;o00004_ooool001Kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Cooooo`Co003o013oooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003o6_ooool04?l00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooool4o`00ob3ooooo1?l00?l0
4?oooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?lJooooo`0@o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooo`Co003o5?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
00[ooooo013oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003ooooo1?oo000Nooooo`Woo`00:?ooool04?oo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooool4ool001oooooo2Ooo000Tooooo`03
o`000?oooooooooo013ooooo000Looooo`;o00005?ooool4o`00o`0@ooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oa[ooooo013o003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo1?l0
0?lPooooo`Co003o013oooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003o6_ooool04?l00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00ooooool4o`00oaCooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0:ooooo`0@ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00ooooo`Coo`007_ooool4ool00003oooooooo003oo`0000;oo`00
:?ooool04?oo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooool4ool001oooooo1?oo00000oooooooo`00ool00002ool002Cooooo00?o0000oooo
ooooool04?ooool001cooooo00?o0000ooooooooool05?ooool04ol00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?l06_oo
ool04ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?l08_ooool04ol00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?l06_ooool04ol00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?l05Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00[ooooo013oo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
1?oo000Nooooo`Coo`0000?oooooool00?oo00000_oo000Xooooo`0@ool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`Coo`007oooool4ool0
0003oooooooo003oo`0000;oo`009?ooool00ol0003oooooooooo`0@ooooo`007?ooool00ol0003o
ooooooooo`0Dooooo`0Co`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00o`0Jooooo`0Co`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0Roooo
o`0Co`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00o`0Jooooo`0Co`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0Eooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool02_ooool04ooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo00008?ooool01ooo003o
ooooool00?ooooooo`00oooooooo0000:Oooool04ooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo00008Oooool01ooo003o
ooooool00?ooooooo`00oooooooo00009Oooool00ol0003oooooooooo`0@ooooo`007?ooool00ol0
003oooooooooo`0Dooooo`0Co`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0Jooooo`0Co`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0R
ooooo`0Co`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00o`0Jooooo`0Co`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0Eooooo`03o`000?oo
oooooooo02Sooooo0_l0000;ooooo`0Cool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0000Pooooo`07ool00?ooooooo`00
oooooooo003oooooool0000Yooooo`0Cool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0000Qooooo`07ool00?ooooooo`00
oooooooo003oooooool0000Tooooo`;o00004_ooool001cooooo00?o0000ooooooooool05?ooool0
4_l00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooo`Co003o5?ooool4o`00o`0Booooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o8_ooool04_l00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
o`Co003o5?ooool4o`00o`0Booooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003o5Oooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo00[ooooo01?oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`0001gooooo1?oo00001Oooooooo`00oooooooo
003ooooo00Coo`009_ooool04ooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo00007_ooool4ool00005oooooooo003ooooo
ool00?ooool00ooo000Sooooo`03o`000?oooooooooo013ooooo000Looooo`;o00005Oooool04_l0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooo`Co003o5?ooool4o`00o`0Booooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o8_ooool04_l00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooo`Co
003o5?ooool4o`00o`0Booooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003o5Oooool00ol0003oooooooooo`0Pooooo`?o00001Ooo
ool00ol0003oooooooooo`0:ooooo`0Cool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0000Mooooo`Coo`0000Goooooool0
0?ooooooo`00ooooo`04ool002Kooooo01?oo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`0001kooooo1?oo00001Ooooooo
o`00oooooooo003ooooo00?oo`008oooool00ol0003oooooooooo`0@ooooo`007?ooool00ol0003o
ooooooooo`0Dooooo`0Bo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?oooooo1?l00?lDooooo`Co003o01;oooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?lRoooo
o`0Bo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?oooooo1?l00?lDooooo`Co003o01;oooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?lEooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`Coo`0001;ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo000Mooooo`Coo`0000Goooooool00?ooooooo`00ooooo`04ool002?ooooo1?oo00004_oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool001kooooo1?oo00001Oooooooo`00oooooooo003ooooo00?oo`008oooool00ol0003o
ooooooooo`0@ooooo`007?ooool00ol0003oooooooooo`0Dooooo`0Eo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003o01Kooooo01Go003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?l08_ooool05Ol00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00o`0Fooooo`0Eo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o01Gooooo00?o0000oooooooo
ool06Oooool5o`0000?ooooo00?o0000ooooooooool01?ooool2o`0000Sooooo1?oo00004_oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool001kooooo00_oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0000T
ooooo`Coo`0001;oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo000Oooooo`08ool00?ooooooo`00oooooooo003oooooool00?oo
ool2ool002?ooooo0_l0000Booooo`007?ooool00ol0003oooooooooo`0Dooooo`0Eo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003o01Kooooo01Go003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?l08_ooool05Ol00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00o`0Fooooo`0Eo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o01Gooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo1?oo
00004_ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool001kooooo00_oo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool0000Tooooo`Coo`0001;oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo000Oooooo`08ool00?ooooooo`00oooooooo003o
ooooool00?ooool2ool002Cooooo00?o0000ooooooooool04?ooool001cooooo00?o0000oooooooo
ool05?ooool05Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0Fooooo`0Eo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003o02;ooooo01Go003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?l05_ooool05Ol00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00o`0Eooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`08ooooo`0Eool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`0001kooooo00_oo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool0000Uooooo`0Eool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`0001oooooo00Soo`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`009?ooool00ol0
003oooooooooo`0@ooooo`007?ooool2o`0001Gooooo01Go003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?l0
5_ooool05Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00o`0Rooooo`0Eo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003o01Kooooo01Go003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?l05Oooool00ol0003oooooooooo`0Poooo
o`;o00001_ooool00ol0003oooooooooo`08ooooo`0Dool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool4ool001So
oooo1?oo00002_ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo000Uooooo`0Dool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooool4ool001Wooooo1?oo00001oooooooo`00oooooooo003oooooool00?oo
ool00_oo000Tooooo`03o`000?oooooooooo013ooooo000Looooo`03o`000?oooooooooo017ooooo
1?l00?l05?oooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003o5_ooool05?l00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo1?l00?lL
ooooo`Co003o01Coooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oaKooooo01Co003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooo`Co
003o4_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool02?ooool05?oo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003ooooo1?oo000Hooooo`Coo`0000[oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`009Oooool05?oo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo1?oo000I
ooooo`Coo`0000Ooooooool00?ooooooo`00oooooooo003ooooo00;oo`009?ooool00ol0003ooooo
ooooo`0@ooooo`007?ooool00ol0003oooooooooo`0Aooooo`Co003o01Coooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oaKooooo01Co003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooo`Co003o7?ooool4o`00o`0Dooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?lFooooo`0Do`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00ooooool4o`00oa;ooooo00?o0000ooooooooool0
:?ooool2o`0000Wooooo01Coo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`Coo`006?ooool4ool00009oooooooo
003oooooool00?ooooooo`00oooooooo003ooooo00Coo`008_ooool05?oo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
oooo1?oo000Iooooo`Coo`0000Ooooooool00?ooooooo`00oooooooo003ooooo00Goo`008?ooool2
o`0001;ooooo000Looooo`03o`000?oooooooooo017ooooo1?l00?l05?oooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003o5_ooool05?l00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?oooooo1?l00?lLooooo`Co003o01Coooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oaKooooo01Co003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooo`Co003o4_ooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo00Sooooo01Ooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0000J
ooooo`0<ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo1?oo000R
ooooo`0Gool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo00006oooool02_oo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooool5ool0027ooooo00?o0000ooooooooool04?ooool001co
oooo00?o0000ooooooooool04_ooool05_l00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooool4o`00oa3o
oooo1?l00?l05_oooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?lNooooo`0Fo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooo`Co003o4?ooool4o`00o`0Fooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oa?o
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`08ooooo`0Gool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo00006_ooool03?oo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00ooooo`Coo`008_ooool05ooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`0001_o
oooo00[oo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo1Ooo000Qooooo`03o`00
0?oooooooooo013ooooo000Looooo`;o00004oooool05_l00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
ool4o`00oa3ooooo1?l00?l05_oooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?lNooooo`0Fo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooo`Co003o4?ooool4o`00o`0Fooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oa?ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`08ooooo`0Gool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo00006_ooool03ooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool0000Sooooo`0Gool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo00006oooool02_oo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ool2ool00003oooooooo003ooooo027ooooo00?o0000ooooooooool04?ooool001cooooo00?o0000
ooooooooool04_ooool05_l00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooool4o`00oa3ooooo1?l00?l0
5_oooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?lNooooo`0Fo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooo`Co003o4?ooool4o`00o`0Fooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oa?ooooo00?o0000
ooooooooool0:?ooool2o`0000Wooooo01Ooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0000J
ooooo`0?ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`0002?ooooo01Ooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0000Kooooo`0:ool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`0000?oooooool00?ooool08?ooool2
o`0001;ooooo000Fooooo`;o00001?ooool00ol0003oooooooooo`0Booooo`0Io`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00o`0Booooo`0Io`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00o`0Nooooo`0Io`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00o`0Booooo`0Io`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0Cooooo`03
o`000?oooooooooo02Sooooo00?o0000ooooooooool02?ooool05ooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`0001[ooooo00ooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo00008oooool05ooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
01_ooooo00[oo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo0_oo00000ooooooo
o`00ooooo`0Qooooo`03o`000?oooooooooo013ooooo000Eooooo`04o`000?ooooooooooo`0000?o
oooo00?o0000ooooooooool04_ooool06Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?l04_ooool06Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?l07_ooool0
6Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?l04_ooool06Ol00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?l04oooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo00Sooooo01Ooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0000Gooooo`Coo`00
00koooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool002?o
oooo01Ooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool0000Hooooo`Coo`0000Woooooool00?oo
ooooo`00oooooooo003oooooool00?ooool00_oo00000oooooooo`00ooooo`0Qooooo`03o`000?oo
oooooooo013ooooo000Eooooo`04o`000?ooooooooooo`0000?ooooo0ol00002ooooo`0Zo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo0_l00?l0;ooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo00;o
003o02ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooo`02o`00o`0_ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00ooooool00_l00?l01_oooooo003oooooool00?ooooooo`00
o`?ooooo0_l0000Zooooo`03o`000?oooooooooo00Sooooo01Ooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool0000Gooooo`Coo`0000koooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool002?ooooo01Ooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0000H
ooooo`Coo`0000Woooooool00?ooooooo`00oooooooo003oooooool00?ooool00_oo00000ooooooo
o`00ooooo`0Qooooo`03o`000?oooooooooo013ooooo000Eooooo`04o`000?ooooooooooo`0000?o
oooo00?o0000ooooooooool00_ooool03ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00o`0Kooooo`;o003o00koooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oa_ooooo00Ko003oooooool00?ooooooo`00
ooooool2o`00o`0Dooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?lKooooo`;o003o00koooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oa_ooooo00Ko003oooooool00?oo
ooooo`00ooooool2o`00o`06ooooool00?ooooooo`00oooooooo003o1?ooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo00Gooooo1?oo00005_ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
000Gooooo`Coo`0000koooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool0023ooooo1?oo00005_ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo000Hooooo`Coo`00
00Woooooool00?ooooooo`00oooooooo003oooooool00?ooool00_oo00000oooooooo`00ooooo`0Q
ooooo`03o`000?oooooooooo013ooooo000Eooooo`04o`000?ooooooooooo`0000?ooooo00?o0000
ooooooooool00_ooool03ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00o`0Kooooo`;o003o00koooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oa_ooooo00Ko003oooooool00?ooooooo`00ooooool2o`00
o`0Dooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?lKooooo`;o003o00koooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oa_ooooo00Ko003oooooool00?ooooooo`00oooo
ool2o`00o`06ooooool00?ooooooo`00oooooooo003o1?ooool00ol0003oooooooooo`0Xooooo`;o
00001_ooool4ool0000Eoooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo00Coo`005Oooool04?oo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool4ool0
01gooooo1?oo00005Oooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`04ool001Kooooo00coo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooool2ool00003oooooooo003oo`0000;o
o`007_ooool2o`0001;ooooo000Eooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool00_ooool03ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00o`0Kooooo`;o003o00koooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oa_ooooo00Ko003oooooool00?ooooooo`00ooooool2o`00o`0Doooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?lKooooo`;o003o00koooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oa_ooooo00Ko003oooooool00?ooooooo`00ooooool2o`00
o`06ooooool00?ooooooo`00oooooooo003o1?ooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo00Gooooo1?oo00005Oooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`04ool001Gooooo013oo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
1?oo000Mooooo`Coo`0001Goooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool01?oo000Fooooo`0<ool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo0_oo00000oooooooo`00ool0
0002ool001oooooo00?o0000ooooooooool04?ooool001Kooooo0_l00004ooooo`03o`000?oooooo
oooo00;ooooo00oo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?l06_ooool3o`00o`0;ooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00ooooool01?l00?lJooooo`06o`00oooooooo003oooooool00?oooooo0_l00?l05?oooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003o6_ooool3o`00o`0;ooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00ooooool01?l00?lJooooo`06o`00oooooooo003oooooool00?oooooo0_l00?l01_oooooo003o
ooooool00?ooooooo`00o`Cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`06oooo
o`0Hool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo1?oo000Eooooo`0@ool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`Coo`00
7_ooool06?oo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`Coo`005_ooool03?oo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`;oo`0000?oooooool00?oo
00000_oo000Oooooo`03o`000?oooooooooo013ooooo000Looooo`;o00000oooool03ol00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0Jooooo`?o
003o00_oooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooo`04o`00oa[ooooo
00Ko003oooooool00?ooooooo`00ooooool2o`00o`0Dooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?lJooooo`?o
003o00_oooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooo`04o`00oa[ooooo
00Ko003oooooool00?ooooooo`00ooooool2o`00o`06ooooool00?ooooooo`00oooooooo003o1?oo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Kooooo01_oo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo00005_ooool04ooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo00007ooo
ool06ooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0000Gooooo`0<
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo0_oo00001?oooooo
o`00oooooooo000Pooooo`03o`000?oooooooooo013ooooo000Looooo`03o`000?oooooooooo00;o
oooo00co003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooool4o`00oaWo
oooo0ol00?l02ooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo00Co003o
6Oooool4o`00o`03ooooool00?oooooo00;o003o017oooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooo`04o`00oaWooooo0ol00?l02ooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo00Co003o6Oooool4o`00o`03
ooooool00?oooooo00;o003o00Koooooo`00oooooooo003oooooool00?l4ooooo`03o`000?oooooo
oooo02Sooooo0_l00007ooooo`0Kool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`0001Kooooo01?oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`0001oooooo01_oo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo00005oooool03?oo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00ooooo`;oo`0000Coooooool00?ooooooo`007oooool2o`0001;o
oooo000Looooo`03o`000?oooooooooo00;ooooo00co003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00ooooool4o`00oa_ooooo00go003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003o01cooooo1?l00?l00ooooooo003oooooo`02o`00o`0Aoooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
ooooool01?l00?lKooooo`0=o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00o`0Looooo`Co003o00?oooooo`00ooooool00_l00?l01_oooooo003oooooool00?oo
ooooo`00o`Cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`06ooooo`0Kool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`0001Kooooo01?oo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`0001oooooo01_oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
00005oooool03?oo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`;o
o`0000Coooooool00?ooooooo`008?ooool00ol0003oooooooooo`0@ooooo`007?ooool00ol0003o
ooooooooo`02ooooo`0<o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
oooo1?l00?lKooooo`0=o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00o`0Looooo`Co003o00?oooooo`00ooooool00_l00?l04Ooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo00Co003o6oooool0
3Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?l07?ooool4
o`00o`03ooooool00?oooooo00;o003o00Koooooo`00oooooooo003oooooool00?l4ooooo`03o`00
0?oooooooooo027ooooo0_l00005ooooo`03o`000?oooooooooo00Kooooo01_oo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo00005?ooool3ool0000Boooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
7oooool06ooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0000Doooo
o`Coo`0000_oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`02ool00004
oooooooo003oooooool0023ooooo00?o0000ooooooooool04?ooool001cooooo00?o0000oooooooo
ool00_ooool03Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?l07_ooool03Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?l07oooool01?l00?ooooooo`00ooooool2o`00o`0Booooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o7_ooool03Ol00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?l07oooool01?l00?oooooo
o`00ooooool2o`00o`06ooooool00?ooooooo`00oooooooo003o1?ooool00ol0003oooooooooo`0P
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01_ooool06ooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool0000Dooooo`?oo`0001;oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
000Oooooo`0Kool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`0001Co
oooo1?oo00002oooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo00;oo`00
00Coooooool00?ooooooo`008?ooool00ol0003oooooooooo`0@ooooo`007?ooool2o`0000?ooooo
00go003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o01kooooo
00go003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o01oooooo
00Co003oooooool00?oooooo0_l00?l04_oooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oakooooo00go003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003o01oooooo00Co003oooooool00?oooooo
0_l00?l01_oooooo003oooooool00?ooooooo`00o`Cooooo00?o0000ooooooooool08?ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo00Kooooo01_oo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo00005?ooool3ool0000Boooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`007oooool0
6ooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0000Dooooo`Coo`00
00_oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`02ool00004oooooooo
003oooooool0023ooooo00?o0000ooooooooool04?ooool001cooooo00?o0000ooooooooool00_oo
ool03Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?l07_oo
ool03Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?l07ooo
ool01?l00?ooooooo`00ooooool2o`00o`0Booooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o7_ooool03Ol00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?l07oooool01?l00?ooooooo`00oooo
ool2o`00o`06ooooool00?ooooooo`00oooooooo003o1?ooool00ol0003oooooooooo`0Pooooo`04
o`000?ooooooooooo`0000Cooooo0_l00003ooooo`0dool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
o`;oo`0006ooooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooool00_oo00008?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`000oooool2o`0001;o
oooo000Looooo`03o`000?oooooooooo00;ooooo00go003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003o01gooooo1?l00?l01ooooooo003oooooool00?ooooooo`00
ooooool01?l00?lNooooo`04o`00oooooooo003oooooo`;o003o01;oooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?lMooooo`Co
003o00Ooooooo`00oooooooo003oooooool00?oooooo00Co003o7_ooool01?l00?ooooooo`00oooo
ool2o`00o`06ooooool00?ooooooo`00oooooooo003o1?ooool00ol0003oooooooooo`0Pooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_ooool00ooo003oooooool0000Moooo
o`0Cool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool0000Fooooo`0Mool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo00007Oooool04ooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo00005_ooool06ooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00004ooooo`03o`000?oooooo
oooo013ooooo000Looooo`03o`000?oooooooooo00;ooooo00go003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003o01gooooo1?l00?l01ooooooo003oooooool00?oo
ooooo`00ooooool01?l00?lNooooo`04o`00oooooooo003oooooo`;o003o01;oooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?lM
ooooo`Co003o00Ooooooo`00oooooooo003oooooool00?oooooo00Co003o7_ooool01?l00?oooooo
o`00ooooool2o`00o`06ooooool00?ooooooo`00oooooooo003o1?ooool00ol0003oooooooooo`0P
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_ooool00ooo003oooooool0
000Looooo`Coo`00013oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`005Oooool4ool0000Joooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo000Looooo`Coo`00013oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`005Oooool4ool0000Hoooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`001?ooool00ol0003oooooooooo`0@ooooo`007?ooool00ol0003ooooo
ooooo`02ooooo`0=o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00o`0Mooooo`Co003o00Ooooooo`00oooooooo003oooooool00?oooooo00Co003o7_ooool01?l0
0?ooooooo`00ooooool2o`00o`0Booooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003o7Oooool4o`00o`07ooooool00?ooooooo`00
oooooooo003oooooo`04o`00oakooooo00Co003oooooool00?oooooo0_l00?l01_oooooo003ooooo
ool00?ooooooo`00o`Cooooo00?o0000ooooooooool08Oooool2o`0000Gooooo00?o0000oooooooo
ool00_ooool00ooo003oooooool0000Looooo`Coo`00013oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`005Oooool4ool0000Joooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo000Looooo`Coo`00013oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`005Oooool4ool0
000Hoooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`001?ooool00ol0003oooooooooo`0@
ooooo`007?ooool2o`0000?ooooo00go003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003o023ooooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool00?l0
8Oooool01?l00?ooooooo`00ooooool2o`00o`0Booooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o8?ooool02Ol00?ooooooo`00
oooooooo003oooooool00?ooooooo`00o`0Qooooo`04o`00oooooooo003oooooo`;o003o00Kooooo
o`00oooooooo003oooooool00?l4ooooo`03o`000?oooooooooo02Sooooo0_l00003ooooo`Coo`00
6oooool4ool0000@oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool001Gooooo1?oo00005oooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
00Coo`006oooool4ool0000@oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool001Gooooo1?oo00006?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool000?ooooo0_l0000Booooo`007?ooool00ol0003oooooooooo`02ooooo`0=o`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0Pooooo`09o`00oooo
oooo003oooooool00?ooooooo`00oooooooo003o027ooooo00Co003oooooool00?oooooo0_l00?l0
4_oooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00ob3ooooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool00?l08Ooo
ool01?l00?ooooooo`00ooooool2o`00o`06ooooool00?ooooooo`00oooooooo003o1?ooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo00;ooooo1?oo000Nooooo`0>ool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool4ool001Oooooo01Soo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooool4ool001kooooo00koo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`Coo`005oooool06Ooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo00001?ooool00ol0003oooooooooo`0@ooooo`00
7?ooool00ol0003oooooooooo`02ooooo`0=o`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00o`0Pooooo`09o`00oooooooo003oooooool00?ooooooo`00oooooooo
003o027ooooo00Co003oooooool00?oooooo0_l00?l04_oooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ob3ooooo00Wo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?l08Oooool01?l00?ooooooo`00ooooool2o`00o`06
ooooool00?ooooooo`00oooooooo003o1?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo00;ooooo1?oo000Nooooo`0>ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooool4ool001Oooooo01Soo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooool4ool001kooooo00koo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00ooooo`Coo`005oooool06Ooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo00001?ooool00ol0003oooooooooo`0@ooooo`007?ooool00ol0003oooooooooo`02ooooo`0=
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0Oooooo`Co
003o00?oooooo`00ooooool01?l00?lPooooo`04o`00oooooooo003oooooo`;o003o01;oooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?lOooooo`Co003o00?oooooo`00ooooool01?l00?lPooooo`04o`00oooooooo003oooooo`;o
003o00Koooooo`00oooooooo003oooooool00?l4ooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool00_ooool00ooo003oooooooooo`0Oooooo`0>ool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooool4ool001Oooooo01Woo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00027ooooo00koo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00ooooo`Coo`005oooool06Ooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo00001?ooool00ol0003oooooooooo`0@ooooo`007?ooool00ol0003o
ooooooooo`02ooooo`0=o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00o`0Oooooo`Co003o00?oooooo`00ooooool01?l00?lPooooo`04o`00oooooooo003ooooo
o`;o003o01;oooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?lOooooo`Co003o00?oooooo`00ooooool01?l00?lPooooo`04o`00
oooooooo003oooooo`;o003o00Koooooo`00oooooooo003oooooool00?l4ooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`0Oooooo`0?ool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`0001[ooooo01Wo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00027ooooo00ooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo00006_ooool06Ooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo00001?ooool00ol0003oooooooooo`0@oooo
o`007?ooool2o`0000?ooooo00[o003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
1?l00?lNooooo`Co003o00?oooooo`00ooooool01?l00?lOooooo`Co003o01;oooooo`00ool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooool4
o`00oakooooo1?l00?l00ooooooo003oooooo`04o`00oaoooooo1?l00?l02Ooooooo003oo`00oooo
oooo003oooooool00?ooooooo`00o`04ooooo`03o`000?oooooooooo02Sooooo0_l00003ooooo`03
ool00?oooooooooo01oooooo00ooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo00006_ooool06Ooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo00008Oooool03ooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool0000Jooooo`0Iool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00003ooooo`;o00004_ooool001cooooo00?o0000ooooooooool00_ooool02_l00?ooooooo`00
oooooooo003oooooool00?ooooooo`00ooooool4o`00ob7ooooo00Go003oooooool00?ooooooo`00
o`0Rooooo`Co003o01;oooooo`00ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00ooooool4o`00ob7ooooo00Go003oooooool00?ooooooo`00o`0R
ooooo`Co003o00Woooooo`00ool00?ooooooo`00oooooooo003oooooool00?l01?ooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool07oooool03ooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0000Joooo
o`0Iool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0000Qooooo`0?ool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`0001[ooooo01Wo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`0000Cooooo00?o0000ooooooooool0
4?ooool001Gooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo00[o003oooooool00?oooooo
o`00oooooooo003oooooool00?oooooo1?l00?lPooooo`Oo003o8Oooool4o`00o`0Booooool00?oo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
oooo1?l00?lPooooo`Oo003o8Oooool4o`00o`09ooooool00?oo003oooooool00?ooooooo`00oooo
oooo003o00Cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`02ooooo`03ool00?oo
oooooooo01kooooo1?oo00003?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool001[ooooo01Woo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00023ooooo
1?oo00003?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool001[ooooo
01Woo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`0000Cooooo00?o0000oooooooo
ool04?ooool001Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`0;o`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?l08oooool7o`00obCooooo01Co
003oooooool00?oo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00ob?ooooo1ol00?lTooooo`0:o`00oooooooo003oo`00oooooooo003o
ooooool00?ooooooo`00o`Cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`02oooo
o`03ool00?oooooooooo01kooooo1?oo00003?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool001[ooooo01Woo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00023ooooo1?oo00003?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool001[ooooo01Woo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`0000Cooooo00?o
0000ooooooooool04?ooool001Kooooo00?o0000ooooooooool00oooool3o`0000;ooooo00_o003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`0Sooooo`Oo003o9?ooool05?l0
0?ooooooo`00ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003o8oooool7o`00obCooooo00[o003oooooool00?oo003oooooool00?oo
ooooo`00oooooooo003o0oooool2o`0002[ooooo0_l00003ooooo`03ool00?oooooooooo01kooooo
1?oo00002Oooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`04ool001Sooooo1?oo0000
5_ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo000Pooooo`Coo`0000Woooooool00?ooooooo`00oooo
oooo003oooooool00?ooool01?oo000Hooooo`Coo`0001Koooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`000oooool2o`0001;ooooo000Fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool02ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o02Gooooo0ol0
0?lVooooo`0Do`00oooooooo003oo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?lUooooo`?o003o9_ooool02_l00?ooooooo`00ool0
0?ooooooo`00oooooooo003oooooool00?l4ooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool00_ooool00ooo003oooooooooo`0Qooooo`0:ool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00ooooo`Coo`006?ooool4ool0000Foooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool002?o
oooo00[oo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo1?oo000Hooooo`Coo`00
01Koooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`001?ooool00ol0003oooooooooo`0@ooooo`005_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00_o003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00o`1>ooooo`0Do`00oooooooo003oo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?m>oooo
o`0:o`00oooooooo003oo`00oooooooo003oooooool00?ooooooo`00o`Cooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo027ooooo00[oo`00oooooooo
003oooooool00?ooooooo`00oooooooo003ooooo1?oo000Hooooo`Coo`0001Koooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`008oooool02_oo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ool4ool001Sooooo1?oo00005_ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo0004ooooo`03o`000?oo
oooooooo013ooooo000Eooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`0;o`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?l0C_ooool05?l00?ooooooo`00ool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oC_ooool02_l00?ooooooo`00ool00?ooooooo`00oooooooo003oooooool00?l4ooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`0Qooooo`0;ool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo00007_ooool05ooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`0002?ooooo00_oo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool0000Nooooo`0Gool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo00001?ooool0
0ol0003oooooooooo`0@ooooo`005_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00_o003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`1>ooooo`0D
o`00oooooooo003oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?m>ooooo`0:o`00oooooooo003oo`00oooooooo003oooooool00?oo
ooooo`00o`Cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`02ooooo`03ool00?oo
oooooooo027ooooo00_oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0000N
ooooo`0Gool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo00008oooool02ooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`0001kooooo01Ooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00004ooooo`03o`000?oooooooooo013ooooo000Looooo`;o00000oooool02ol00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o04kooooo01Co003oooooool00?oo
003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00odkooooo00[o003oooooool00?oo003oooooool00?ooooooo`00oooooooo003o1?ooool0
0ol0003oooooooooo`0Xooooo`;o00000_ooool3ool0027ooooo1?oo00002?ooooooo`00oooooooo
003oooooool00?ooooooo`007_ooool05?oo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo1?oo000Qooooo`Coo`00
00Soooooool00?ooooooo`00oooooooo003oooooool001kooooo01Coo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
o`Coo`000_ooool2o`0001;ooooo000Looooo`03o`000?oooooooooo00;ooooo00_o003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00o`1>ooooo`0Do`00oooooooo003oo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?m>ooooo`0:o`00oooooooo003oo`00oooooooo003oooooool00?ooooooo`00o`Cooooo00?o0000
ooooooooool0:?ooool01?l0003oooooooooooooool3ool0027ooooo1?oo00001Oooooooo`00oooo
oooo003ooooo00Coo`007Oooool05?oo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo1?oo000Qooooo`Coo`0000Go
ooooool00?ooooooo`00ooooo`04ool001gooooo01Coo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`Coo`000ooo
ool00ol0003oooooooooo`0@ooooo`007?ooool00ol0003oooooooooo`02ooooo`0;o`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00?l0C_ooool05?l00?ooooooo`00ool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oC_ooool02_l00?ooooooo`00ool00?ooooooo`00oooooooo003oooooool00?l4ooooo`03o`00
0?oooooooooo023ooooo0ol00005ooooo`04o`000?ooooooooooooooo`?oo`008Oooool4ool00005
oooooooo003oooooool00?ooool01?oo000Mooooo`0Dool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool4ool0027o
oooo1?oo00001Oooooooo`00oooooooo003ooooo00Coo`007Oooool05?oo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
oooo1?oo0003ooooo`03o`000?oooooooooo013ooooo000Looooo`03o`000?oooooooooo00;ooooo
00_o003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`1>ooooo`0Do`00oooo
oooo003oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?m>ooooo`0:o`00oooooooo003oo`00oooooooo003oooooool00?ooooooo`00
o`Cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
02Sooooo00Koo`00oooooooo003oooooool00?ooool4ool001gooooo01Goo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo00009oooool01_oo003oooooool00?ooooooo`00ooooo`Coo`007Oooool05Ooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00006ooooo`03o`000?oooooooooo013ooooo000Looooo`03o`000?oooooo
oooo00;ooooo00_o003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`1>oooo
o`0Do`00oooooooo003oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?m>ooooo`0:o`00oooooooo003oo`00oooooooo003oooooool0
0?ooooooo`00o`Cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`04ooooo`;o0000
:Oooool01ooo003oooooool00?ooooooo`00oooooooo00008?ooool05Ooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool0000Wooooo`07ool00?ooooooo`00oooooooo003oooooool0000Pooooo`0Eool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`0000Gooooo0_l0000Booooo`007?ooool2o`0000?ooooo00So003oooooool0
0?ooooooo`00oooooooo003oooooo`Co003oC?ooool5o`00o`0=ooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooo`04o`00odcooooo1Ol00?l01_oooooo003ooooo
ool00?ooooooo`00o`Cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo02Oooooo1?oo00001?ooooooo`00oooooooo000Pooooo`0Eool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`0002Kooooo1?oo00001?ooooooo`00oooooooo000Pooooo`0Eool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`0000Kooooo00?o0000ooooooooool04?ooool001cooooo00?o0000ooooooooool0
0_ooool02?l00?ooooooo`00oooooooo003oooooool00?oooooo1?l00?m<ooooo`Go003o00gooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo00Co003oC?ooool5
o`00o`06ooooool00?ooooooo`00oooooooo003o1?ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool09oooool4ool00003oooooooo003oo`0000;oo`00
7oooool05Ooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool0000Vooooo`Coo`0000?oooooool00?oo00000_oo
000Oooooo`0Eool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`0000Kooooo00?o0000ooooooooool04?ooool0
01cooooo00?o0000ooooooooool00_ooool02?l00?ooooooo`00oooooooo003oooooool00?oooooo
1?l00?m<ooooo`Go003o00goooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?oooooo00Co003oC?ooool5o`00o`06ooooool00?ooooooo`00oooooooo003o1?ooool00ol0
003oooooooooo`0Pooooo`;o00001_ooool00ol0003oooooooooo`0Wooooo`Coo`0000?oooooool0
0?oo00000_oo000Nooooo`Coo`0001;oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`00oooooooo000Vooooo`Coo`0000?oooooool00?oo0000
0_oo000Nooooo`Coo`0001;oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo0006ooooo`03o`000?oooooooooo013ooooo000Loooo
o`03o`000?oooooooooo00;ooooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool00?l0
D_ooool2o`00o`0>ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?mBooooo`;o003o00Koooooo`00oooooooo003oooooool00?l4ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Yooooo`Ooo`007_ooool4
ool0000Boooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00:?ooool7ool001kooooo1?oo00004_ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool000Kooooo00?o
0000ooooooooool04?ooool001cooooo00?o0000ooooooooool00_ooool02Ol00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00o`1Booooo`;o003o00koooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oe;ooooo0_l00?l01_oooooo003oooooool00?oo
ooooo`00o`Cooooo00?o0000ooooooooool0:?ooool2o`0002[ooooo1Ooo000Pooooo`Coo`0001;o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo000Xooooo`Goo`008?ooool4ool0000Boooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`001Oooool2o`0001;ooooo
000Looooo`;o00000oooool02Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`1Boooo
o`;o003o00koooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oe;ooooo0_l00?l01_oooooo003oooooool00?ooooooo`00o`Cooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`0Yooooo`Goo`008oooool04ooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo0000:?ooool5
ool002?ooooo01?oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooooooo`0000Kooooo00?o0000ooooooooool04?ooool001cooooo
00?o0000ooooooooool00_ooool02Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`1B
ooooo`;o003o00koooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oe;ooooo0_l00?l01_oooooo003oooooool00?ooooooo`00o`Cooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`1Aooooo`0Cool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0001@ooooo`0Cool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00006ooooo`03o`000?oooooooooo013ooooo000Looooo`03o`000?oooooooooo00;o
oooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool00?l0D_ooool2o`00o`0>ooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?mBooooo`;o003o
00Koooooo`00oooooooo003oooooool00?l4ooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool0DOooool04ooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo0000D?ooool04ooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo00001_ooool0
0ol0003oooooooooo`0@ooooo`007?ooool00ol0003oooooooooo`02ooooo`09o`00oooooooo003o
ooooool00?ooooooo`00oooooooo003o05;ooooo0_l00?l03_oooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo003oD_ooool2o`00o`06ooooool00?ooooooo`00
oooooooo003o1?ooool00ol0003oooooooooo`0Xooooo`;o0000D_ooool04?oo003oooooool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool4ool004oooooo
013oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003ooooo1?oo0004ooooo`;o00004_ooool001cooooo00?o0000ooooooooool00_ooool02Ol00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00o`1Booooo`;o003o00koooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oe;ooooo0_l00?l01_oooooo003o
ooooool00?ooooooo`00o`Cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1Aoooo
o`0@ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00ooooo`Coo`00Coooool04?oo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?ooool4ool000Gooooo00?o0000ooooooooool04?ooool001cooooo
0_l00003ooooo`09o`00oooooooo003oooooool00?ooooooo`00oooooooo003o05;ooooo0_l00?l0
3_oooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oD_oo
ool2o`00o`06ooooool00?ooooooo`00oooooooo003o1?ooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo057ooooo013oo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003ooooo1?oo001?ooooo`0@ool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`Coo`001Oooool00ol0003ooooo
ooooo`0@ooooo`007?ooool00ol0003oooooooooo`02ooooo`09o`00oooooooo003oooooool00?oo
ooooo`00oooooooo003o05;ooooo0_l00?l03_oooooo003oooooool00?ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oD_ooool2o`00o`06ooooool00?ooooooo`00oooooooo003o
1?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo057ooooo017oo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0001Boooo
o`0Aool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo00002?ooool00ol0003oooooooooo`0@ooooo`005?ooool5o`0000?ooooo00?o0000
ooooooooool00_ooool01_l00?ooooooo`00oooooooo003oooooo`Co003oD?ooool3o`00o`0;oooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooool01?l00?m@ooooo`?o003o00Ko
ooooo`00oooooooo003oooooool00?l4ooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool0DOooool04Ooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`0005;ooooo017oo`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00oooooooo003oooooool00008ooooo`03o`000?oooooooooo013ooooo
000Eooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool01_l00?oooooo
o`00oooooooo003oooooo`Co003oD?ooool3o`00o`0;ooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00ooooool01?l00?m@ooooo`?o003o00Koooooo`00oooooooo003oooooool00?l4
ooooo`03o`000?oooooooooo02Sooooo0_l0001Aooooo`Coo`0000koooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool0057ooooo1?oo00003_ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`001oooool2o`0001;ooooo
000Fooooo`03o`000?oooooooooo00?ooooo0ol00002ooooo`06o`00oooooooo003oooooool00?oo
oooo1?l00?m@ooooo`?o003o00_oooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
ooooo`04o`00oe3ooooo0ol00?l01_oooooo003oooooool00?ooooooo`00o`?ooooo0_l0000Zoooo
o`03o`000?oooooooooo053ooooo1?oo00003_ooooooo`00oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00DOooool4ool0000>oooooooo003oooooool00?ooooooo`00
oooooooo003oooooool00?ooooooo`00oooooooo0008ooooo`03o`000?oooooooooo013ooooo000G
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01ol00?ooooooo`00oooo
oooo003oooooool00?l0EOooool03Ol00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooo
oooo003oooooool00?l0EOooool01ol00?ooooooo`00oooooooo003oooooool00?l01?ooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo053ooooo1?oo00003_ooooooo`00oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00DOooool4ool0000>oooooooo003o
ooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo0008ooooo`03o`000?oo
oooooooo013ooooo000Dooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`02ooooo`07o`00oooooooo003oooooool00?ooooooo`00o`1Eooooo`0=o`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00o`1Eooooo`07o`00oooooooo003ooooo
ool00?ooooooo`00o`04ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0Doooool0
3ooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
001Dooooo`0?ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`0000Sooooo00?o0000ooooooooool04?ooool001Cooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo00;ooooo00Oo003oooooool00?ooooooo`00oooooooo003o
05Gooooo00go003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o
05Gooooo00Oo003oooooool00?ooooooo`00oooooooo003o00Cooooo00?o0000ooooooooool0:?oo
ool2o`0005Cooooo00ooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo0000E?ooool03ooo003oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00oooooooo003oooooool00007ooooo`;o00004_ooool001Gooooo0ol00004ooooo`03o`00
0?oooooooooo00;ooooo00Oo003oooooool00?ooooooo`00oooooooo003o05Gooooo00go003ooooo
ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003o05Gooooo00Oo003ooooo
ool00?ooooooo`00oooooooo003o00Cooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`1Cooooo`0?ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`0005Cooooo00ooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo00002?ooool00ol0003oooooooooo`0@ooooo`007?ooool2o`0000?ooooo
00Oo003oooooool00?ooooooo`00oooooooo003o05Gooooo00go003oooooool00?ooooooo`00oooo
oooo003oooooool00?ooooooo`00oooooooo003o05Gooooo00Oo003oooooool00?ooooooo`00oooo
oooo003o00Cooooo00?o0000ooooooooool07oooool5o`0000Cooooo00?o0000ooooooooool0Dooo
ool03?oo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`Coo`00Dooo
ool03?oo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00ooooo`Coo`001ooo
ool00ol0003oooooooooo`0@ooooo`007?ooool00ol0003oooooooooo`02ooooo`07o`00oooooooo
003oooooool00?ooooooo`00o`1Eooooo`0=o`00oooooooo003oooooool00?ooooooo`00oooooooo
003oooooool00?ooooooo`00o`1Eooooo`07o`00oooooooo003oooooool00?ooooooo`00o`04oooo
o`03o`000?oooooooooo023ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1C
ooooo`0<ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo1?oo001C
ooooo`0<ool00?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003ooooo1?oo0007
ooooo`03o`000?oooooooooo013ooooo000Looooo`03o`000?oooooooooo00;ooooo00Oo003ooooo
ool00?ooooooo`00oooooooo003o05Gooooo00go003oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo003o05Gooooo00Oo003oooooool00?ooooooo`00oooooooo003o00Co
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05?o
oooo00coo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool4ool005?o
oooo00coo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooool4ool000Oo
oooo00?o0000ooooooooool04?ooool001cooooo00?o0000ooooooooool00_ooool01ol00?oooooo
o`00oooooooo003oooooool00?l0EOooool03Ol00?ooooooo`00oooooooo003oooooool00?oooooo
o`00oooooooo003oooooool00?l0EOooool01ol00?ooooooo`00oooooooo003oooooool00?l01?oo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00?ooooo0_l0001Dooooo`0=ool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool0001Fooooo`0=ool00?oo
ooooo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00009ooooo`;o00004_oo
ool001cooooo00?o0000ooooooooool00_ooool01?l00?ooooooo`00ooooool4o`00oe?ooooo1?l0
0?l01ooooooo003oooooool00?ooooooo`00ooooool01?l00?mCooooo`Co003o00Coooooo`00oooo
oooo003o1?ooool00ol0003oooooooooo`0Oooooo`05o`000?ooooooooooooooool000001?ooool0
0ol0003oooooooooo`1Booooo`Coo`0000[oooooool00?ooooooo`00oooooooo003oooooool00?oo
ooooo`00EOooool4ool0000:oooooooo003oooooool00?ooooooo`00oooooooo003oooooool000[o
oooo00?o0000ooooooooool04?ooool001cooooo0_l00003ooooo`04o`00oooooooo003oooooo`Co
003oDoooool4o`00o`07ooooool00?ooooooo`00oooooooo003oooooo`04o`00oe?ooooo1?l00?l0
1?oooooo003oooooool00?l4ooooo`03o`000?oooooooooo01oooooo00Go0000oooooooooooooooo
o`000004ooooo`03o`000?oooooooooo05;ooooo1?oo00002_ooooooo`00oooooooo003oooooool0
0?ooooooo`00oooooooo001Eooooo`Coo`0000[oooooool00?ooooooo`00oooooooo003oooooool0
0?ooooooo`002_ooool00ol0003oooooooooo`0@ooooo`007?ooool00ol0003oooooooooo`02oooo
o`04o`00oooooooo003oooooo`Co003oDoooool4o`00o`07ooooool00?ooooooo`00oooooooo003o
ooooo`04o`00oe?ooooo1?l00?l01?oooooo003oooooool00?l4ooooo`03o`000?oooooooooo023o
oooo0ol00005ooooo`03o`000?oooooooooo05;ooooo1?oo00002_ooooooo`00oooooooo003ooooo
ool00?ooooooo`00oooooooo001Eooooo`Coo`0000[oooooool00?ooooooo`00oooooooo003ooooo
ool00?ooooooo`002_ooool00ol0003oooooooooo`0@ooooo`007?ooool00ol0003oooooooooo`02
ooooo`05o`00oooooooo003oooooool00?l0FOooool02Ol00?ooooooo`00oooooooo003oooooool0
0?ooooooo`00o`1Iooooo`05o`00oooooooo003oooooool00?l01?ooool00ol0003oooooooooo`0X
ooooo`;o0000E_ooool02ooo003oooooool00?ooooooo`00oooooooo003oooooool00?ooooooo`00
05Sooooo00_oo`00oooooooo003oooooool00?ooooooo`00oooooooo003oooooool00009ooooo`;o
00004_ooool001cooooo00?o0000ooooooooool00_ooool01Ol00?ooooooo`00oooooooo003o05Wo
oooo00Wo003oooooool00?ooooooo`00oooooooo003oooooool00?l0FOooool01Ol00?ooooooo`00
oooooooo003o00Cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1Eooooo`0;ool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`00oooooooo0000F?ooool02ooo003oooooool0
0?ooooooo`00oooooooo003oooooool00?ooooooo`0000[ooooo00?o0000ooooooooool04?ooool0
01cooooo00?o0000ooooooooool00_ooool01Ol00?ooooooo`00oooooooo003o05Wooooo00Wo003o
ooooool00?ooooooo`00oooooooo003oooooool00?l0FOooool01Ol00?ooooooo`00oooooooo003o
00Cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1Eooooo`08ool00?ooooooo`00
oooooooo003oooooool00?ooool4ool005Oooooo00Soo`00oooooooo003oooooool00?ooooooo`00
ooooo`Coo`002Oooool00ol0003oooooooooo`0@ooooo`007?ooool2o`0000?ooooo00Go003ooooo
ool00?ooooooo`00o`1Iooooo`09o`00oooooooo003oooooool00?ooooooo`00oooooooo003o05Wo
oooo00Go003oooooool00?ooooooo`00o`04ooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool0EOooool02?oo003oooooool00?ooooooo`00oooooooo003ooooo1?oo001Gooooo`08ool0
0?ooooooo`00oooooooo003oooooool00?ooool4ool000Wooooo00?o0000ooooooooool04?ooool0
01cooooo00?o0000ooooooooool00_ooool01Ol00?ooooooo`00oooooooo003o05Wooooo00Wo003o
ooooool00?ooooooo`00oooooooo003oooooool00?l0FOooool01Ol00?ooooooo`00oooooooo003o
00Cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1Eooooo`08ool00?ooooooo`00
oooooooo003oooooool00?ooool4ool005Oooooo00Soo`00oooooooo003oooooool00?ooooooo`00
ooooo`Coo`002Oooool00ol0003oooooooooo`0@ooooo`007?ooool00ol0003oooooooooo`02oooo
o`03o`00oooooooo003o00?o003oEoooool4o`00o`03ooooool00?oooooo00Co003oEoooool4o`00
o`03ooooool00?oooooo00?ooooo00?o0000ooooooooool0:?ooool2o`0005Gooooo1?oo00001_oo
ooooo`00oooooooo003oooooool005Wooooo1?oo00001_ooooooo`00oooooooo003oooooool000_o
oooo0_l0000Booooo`007?ooool00ol0003oooooooooo`02ooooo`03o`00oooooooo003o00?o003o
Eoooool4o`00o`03ooooool00?oooooo00Co003oEoooool4o`00o`03ooooool00?oooooo00?ooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1Dooooo`Coo`0000Koooooool00?oooooo
o`00oooooooo001Iooooo`Coo`0000Koooooool00?ooooooo`00oooooooo000<ooooo`03o`000?oo
oooooooo013ooooo000Looooo`03o`000?oooooooooo00;ooooo00?o003oooooool00?l00ol00?mG
ooooo`Co003o00?oooooo`00ooooool01?l00?mGooooo`Co003o00?oooooo`00ooooool00oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo05Cooooo1?oo00001_ooooooo`00oooooooo
003oooooool005Wooooo1?oo00001_ooooooo`00oooooooo003oooooool000cooooo00?o0000oooo
ooooool04?ooool001cooooo0_l00003ooooo`03o`00oooooooo003o05gooooo00Go003oooooool0
0?ooooooo`00o`1Mooooo`03o`00oooooooo003o00Cooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`1Gooooo`07ool00?ooooooo`00oooooooo003oooooool0001Looooo`07ool00?oo
ooooo`00oooooooo003oooooool0000<ooooo`03o`000?oooooooooo013ooooo000Looooo`03o`00
0?oooooooooo00;ooooo00?o003oooooool00?l0GOooool01Ol00?ooooooo`00oooooooo003o05go
oooo00?o003oooooool00?l01?ooool00ol0003oooooooooo`0Xooooo`;o0000F?ooool01?oo003o
ooooool00?ooool4ool005_ooooo00Coo`00oooooooo003ooooo1?oo000:ooooo`;o00004_ooool0
01Gooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo1?l00?mKooooo`Oo003oFoooool4o`00
o`Cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1Fooooo`Coo`0000?oooooool0
0?oo00000_oo001Jooooo`Coo`0000?oooooool00?oo00000_oo000;ooooo`03o`000?oooooooooo
013ooooo000Dooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooooooool5
o`00oe_ooooo1ol00?mKooooo`Go003o0oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo05Kooooo1?oo00000oooooooo`00ool00002ool005[ooooo1?oo00000oooooooo`00ool00002
ool000_ooooo00?o0000ooooooooool04?ooool001Sooooo00Co0000oooooooooooooooo0ol00000
0ooooooo003oo`00o`03o`00oe_ooooo1ol00?mKooooo`Go003o0_ooool2o`0002[ooooo00?o0000
ooooooooool0E_ooool7ool005cooooo1ooo000=ooooo`03o`000?oooooooooo013ooooo000Foooo
o`;o00001?ooool01?l0003oooooooooooooool3o`00oeoooooo0ol00?mOooooo`?o003o0oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo05Sooooo1Ooo001Nooooo`Goo`003Oooool0
0ol0003oooooooooo`0@ooooo`006?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0:?ooool2o`0005Wooooo1Ooo001Nooooo`Goo`003?ooool2o`0001;ooooo000Doooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool0F?ooool3ool0063ooooo0ooo000?ooooo`03o`000?oooooo
oooo013ooooo000Eooooo`?o00001?ooooo?o`0002[ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0@ooooo`00oooooolFooooom7o00004_ooool00?oooooonOooool00?oooooonOoo
ool00?oooooonOooool00001\
\>"],
  ImageRangeCache->{{{0, 503}, {147.312, 0}} -> {-0.0551454, -0.0147182, \
0.00419541, 0.00419541}, {{13.125, 240.125}, {143.75, 3.5}} -> {-17.2695, \
-2.80376, 0.510152, 0.0416603}, {{262.812, 489.812}, {143.75, 3.5}} -> \
{-142.486, -3.44497, 0.504429, 0.0444609}}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
(3) Time-domain convolution \[DoubleLongLeftRightArrow] \
frequency-domain multiplication: an example\
\>", "Section"],

Cell[CellGroupData[{

Cell[TextData[{
  "Random ",
  Cell[BoxData[
      \(TraditionalForm\`x[n]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`h[n]\)]]
}], "Subsection"],

Cell[BoxData[{
    \(\(xn\  = \ 
        Table[{i, \ Random[Integer, {\(-10\), 10}]}, {i, 0, 
            9}];\)\), "\[IndentingNewLine]", 
    \(\(hn\  = \ 
        Table[{i, Random[Integer, \ {\(-10\), 10}]}, {i, 0, 
            9}];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Plot ",
  Cell[BoxData[
      \(TraditionalForm\`x[n]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`h[n]\)]]
}], "Subsection"],

Cell[CellGroupData[{

Cell["Input sequence x[n]", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(DiscreteListPlot[xn, \ Blue, \ Frame \[Rule] True, 
        PlotRange \[Rule] All, \ Axes \[Rule] {True, False}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.293527 0.0309791 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.23545 -0.0125 -3 -9 ]
[.23545 -0.0125 3 0 ]
[.44709 -0.0125 -3 -9 ]
[.44709 -0.0125 3 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.87037 -0.0125 -3 -9 ]
[.87037 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .06118 -24 -4.5 ]
[-0.0125 .06118 0 4.5 ]
[-0.0125 .13863 -12 -4.5 ]
[-0.0125 .13863 0 4.5 ]
[-0.0125 .21608 -24 -4.5 ]
[-0.0125 .21608 0 4.5 ]
[-0.0125 .29353 -6 -4.5 ]
[-0.0125 .29353 0 4.5 ]
[-0.0125 .37098 -18 -4.5 ]
[-0.0125 .37098 0 4.5 ]
[-0.0125 .44842 -6 -4.5 ]
[-0.0125 .44842 0 4.5 ]
[-0.0125 .52587 -18 -4.5 ]
[-0.0125 .52587 0 4.5 ]
[-0.0125 .60332 -12 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.23545 0 m
.23545 .00625 L
s
[(2)] .23545 -0.0125 0 1 Mshowa
.44709 0 m
.44709 .00625 L
s
[(4)] .44709 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(6)] .65873 -0.0125 0 1 Mshowa
.87037 0 m
.87037 .00625 L
s
[(8)] .87037 -0.0125 0 1 Mshowa
.125 Mabswid
.07672 0 m
.07672 .00375 L
s
.12963 0 m
.12963 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.28836 0 m
.28836 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.39418 0 m
.39418 .00375 L
s
.5 0 m
.5 .00375 L
s
.55291 0 m
.55291 .00375 L
s
.60582 0 m
.60582 .00375 L
s
.71164 0 m
.71164 .00375 L
s
.76455 0 m
.76455 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.92328 0 m
.92328 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .06118 m
.00625 .06118 L
s
[(-7.5)] -0.0125 .06118 1 0 Mshowa
0 .13863 m
.00625 .13863 L
s
[(-5)] -0.0125 .13863 1 0 Mshowa
0 .21608 m
.00625 .21608 L
s
[(-2.5)] -0.0125 .21608 1 0 Mshowa
0 .29353 m
.00625 .29353 L
s
[(0)] -0.0125 .29353 1 0 Mshowa
0 .37098 m
.00625 .37098 L
s
[(2.5)] -0.0125 .37098 1 0 Mshowa
0 .44842 m
.00625 .44842 L
s
[(5)] -0.0125 .44842 1 0 Mshowa
0 .52587 m
.00625 .52587 L
s
[(7.5)] -0.0125 .52587 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(10)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .07667 m
.00375 .07667 L
s
0 .09216 m
.00375 .09216 L
s
0 .10765 m
.00375 .10765 L
s
0 .12314 m
.00375 .12314 L
s
0 .15412 m
.00375 .15412 L
s
0 .16961 m
.00375 .16961 L
s
0 .1851 m
.00375 .1851 L
s
0 .20059 m
.00375 .20059 L
s
0 .23157 m
.00375 .23157 L
s
0 .24706 m
.00375 .24706 L
s
0 .26255 m
.00375 .26255 L
s
0 .27804 m
.00375 .27804 L
s
0 .30902 m
.00375 .30902 L
s
0 .32451 m
.00375 .32451 L
s
0 .34 m
.00375 .34 L
s
0 .35549 m
.00375 .35549 L
s
0 .38646 m
.00375 .38646 L
s
0 .40195 m
.00375 .40195 L
s
0 .41744 m
.00375 .41744 L
s
0 .43293 m
.00375 .43293 L
s
0 .46391 m
.00375 .46391 L
s
0 .4794 m
.00375 .4794 L
s
0 .49489 m
.00375 .49489 L
s
0 .51038 m
.00375 .51038 L
s
0 .54136 m
.00375 .54136 L
s
0 .55685 m
.00375 .55685 L
s
0 .57234 m
.00375 .57234 L
s
0 .58783 m
.00375 .58783 L
s
0 .04569 m
.00375 .04569 L
s
0 .0302 m
.00375 .0302 L
s
0 .01472 m
.00375 .01472 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.23545 .61178 m
.23545 .61803 L
s
.44709 .61178 m
.44709 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.87037 .61178 m
.87037 .61803 L
s
.125 Mabswid
.07672 .61428 m
.07672 .61803 L
s
.12963 .61428 m
.12963 .61803 L
s
.18254 .61428 m
.18254 .61803 L
s
.28836 .61428 m
.28836 .61803 L
s
.34127 .61428 m
.34127 .61803 L
s
.39418 .61428 m
.39418 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.55291 .61428 m
.55291 .61803 L
s
.60582 .61428 m
.60582 .61803 L
s
.71164 .61428 m
.71164 .61803 L
s
.76455 .61428 m
.76455 .61803 L
s
.81746 .61428 m
.81746 .61803 L
s
.92328 .61428 m
.92328 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .06118 m
1 .06118 L
s
.99375 .13863 m
1 .13863 L
s
.99375 .21608 m
1 .21608 L
s
.99375 .29353 m
1 .29353 L
s
.99375 .37098 m
1 .37098 L
s
.99375 .44842 m
1 .44842 L
s
.99375 .52587 m
1 .52587 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .07667 m
1 .07667 L
s
.99625 .09216 m
1 .09216 L
s
.99625 .10765 m
1 .10765 L
s
.99625 .12314 m
1 .12314 L
s
.99625 .15412 m
1 .15412 L
s
.99625 .16961 m
1 .16961 L
s
.99625 .1851 m
1 .1851 L
s
.99625 .20059 m
1 .20059 L
s
.99625 .23157 m
1 .23157 L
s
.99625 .24706 m
1 .24706 L
s
.99625 .26255 m
1 .26255 L
s
.99625 .27804 m
1 .27804 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .32451 m
1 .32451 L
s
.99625 .34 m
1 .34 L
s
.99625 .35549 m
1 .35549 L
s
.99625 .38646 m
1 .38646 L
s
.99625 .40195 m
1 .40195 L
s
.99625 .41744 m
1 .41744 L
s
.99625 .43293 m
1 .43293 L
s
.99625 .46391 m
1 .46391 L
s
.99625 .4794 m
1 .4794 L
s
.99625 .49489 m
1 .49489 L
s
.99625 .51038 m
1 .51038 L
s
.99625 .54136 m
1 .54136 L
s
.99625 .55685 m
1 .55685 L
s
.99625 .57234 m
1 .57234 L
s
.99625 .58783 m
1 .58783 L
s
.99625 .04569 m
1 .04569 L
s
.99625 .0302 m
1 .0302 L
s
.99625 .01472 m
1 .01472 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .29353 m
1 .29353 L
s
0 0 1 r
.5 Mabswid
.02381 .29353 m
.02381 .04569 L
s
.12963 .29353 m
.12963 .32451 L
s
.23545 .29353 m
.23545 .13863 L
s
.34127 .29353 m
.34127 .20059 L
s
.44709 .29353 m
.44709 .60332 L
s
.55291 .29353 m
.55291 .54136 L
s
.65873 .29353 m
.65873 .04569 L
s
.76455 .29353 m
.76455 .01472 L
s
.87037 .29353 m
.87037 .51038 L
s
.97619 .29353 m
.97619 .51038 L
s
.015 w
.02381 .04569 Mdot
.12963 .32451 Mdot
.23545 .13863 Mdot
.34127 .20059 Mdot
.44709 .60332 Mdot
.55291 .54136 Mdot
.65873 .04569 Mdot
.76455 .01472 Mdot
.87037 .51038 Mdot
.97619 .51038 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`008?ooool2o`0003?ooooo1Ol0000dooooo`?o0000<oooool3o`0003Co
oooo0ol0000Rooooo`007oooool01?l0003oooooooooool0000cooooo`04o`000?ooooooooooo`00
03Gooooo00?o0000ooooooooool0<Oooool01Ol0003ooooooooooooooooo000003;ooooo00Go0000
ooooooooooooooooo`00000Qooooo`007oooool01?l0003oooooooooool0000dooooo`03o`000?oo
oooooooo03;ooooo1Ol0000booooo`05o`000?ooooooooooooooool00000<_ooool01Ol0003ooooo
oooooooooooo0000027ooooo000Oooooo`04o`000?ooooooooooo`0003Gooooo00?o0000oooooooo
ool0<Oooool01?l0003oooooooooool0000cooooo`Co0000=?ooool3o`0002;ooooo000Oooooo`04
o`000?ooooooooooo`0003;ooooo00Go0000ooooooooooooooooo`00000cooooo`03o`000?oooooo
000003?ooooo00?o0000ooooooooool0=?ooool01Ol0003ooooooooooooooooo0000027ooooo000O
ooooo`04o`000?ooooooooooo`0003;ooooo00Go0000ooooooooooooooooo`00000dooooo`;o0000
=?ooool00ol0003oooooooooo`0cooooo`05o`000?ooooooooooooooool000008Oooool0023ooooo
0_l0000dooooo`?o0000=_ooool00ol0003oooooooooo`0cooooo`;o0000=?ooool3o`0002;ooooo
003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo
000Koooooooo00001Ol00001ooooo`006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00?ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`3oooooo`7ooooo0Ol00001oooo
o`006oooool2o`000<?ooooo0`000?ljooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0
`_ooool30000oc_ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`32ooooo`<0003o>ooo
ool1o`00007ooooo000Kooooo`03o`000?oooooooooo0<?ooooo00?o003oooooooooool0>_ooool1
o`00007ooooo000Kooooo`;o0000a?ooool00ol00?ooooooooooo`0iooooo`;o00000Oooool001_o
oooo00?o0000ooooooooool0`oooool00ol00?ooooooooooo`0jooooo`7o00000Oooool001_ooooo
00?o0000ooooooooool0`oooool00ol00?ooooooooooo`0jooooo`7o00000Oooool001_ooooo00?o
0000ooooooooool0`oooool00ol00?ooooooooooo`0jooooo`7o00000Oooool001_ooooo0_l00002
ooooo`<0003oX_ooool30000oa[ooooo00?o003oooooooooool0>Oooool2o`00007ooooo000Koooo
o`04o`000?ooooooooooooooo`<0003oX_ooool30000oa[ooooo00?o003oooooooooool0>_ooool1
o`00007ooooo0008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool3o`00
00Gooooo00Co0000oooooooooooooooo0`000?nRooooo`<0003o6_ooool00ol00?ooooooooooo`0j
ooooo`7o00000Oooool000Sooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo
000000Cooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`2Rooooo`03o`00oooooooo
oooo01Sooooo00?o003oooooooooool0>_ooool1o`00007ooooo0005o`0000Cooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`02ooooo`;o00001?ooool00ol00?ooooooooooo`2Roooo
o`03o`00oooooooooooo01Sooooo00?o003oooooooooool0>Oooool2o`00007ooooo0009ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`00oooooooooooo0:;ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0jooooo`7o
00000Oooool000[ooooo00?o0000ooooooooool01Oooool4o`0000Gooooo00?o0000ooooooooool0
0oooool00ol00?ooooooooooo`2Rooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool0
>_ooool1o`00007ooooo0006ooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool0X_ooool00ol00?oooooo
ooooo`0Hooooo`03o`00oooooooooooo03[ooooo0Ol00001ooooo`001_ooool5o`0000Oooooo1Ol0
0004ooooo`;o00001?ooool00ol00?ooooooooooo`2Rooooo`03o`00oooooooooooo01Sooooo00?o
003oooooooooool0>Oooool2o`00007ooooo000Kooooo`03o`000?oooooooooo00?ooooo00?o003o
ooooooooool0X_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo03[ooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo0:;ooooo00?o003ooooo
ooooool06?ooool00ol00?ooooooooooo`0jooooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool00oooool00ol00?ooooooooooo`2Rooooo`03o`00oooooooooooo01Sooooo00?o003ooooooooo
ool0>_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool0
X_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo03[ooooo0Ol00001ooooo`006ooo
ool2o`0000Cooooo00?o003oooooooooool0X_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooo
oooooooo03Wooooo0_l00001ooooo`006oooool00ol0003oooooooooo`03ooooo`03o`00oooooooo
oooo0:;ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0jooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`2Rooooo`03o`00oooooooooooo
01Sooooo00?o003oooooooooool0>_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00?o
oooo00?o003oooooooooool0X_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo03[o
oooo0Ol00001ooooo`006oooool2o`0000Cooooo00?o003oooooooooool0X_ooool00ol00?oooooo
ooooo`0Hooooo`03o`00oooooooooooo03Wooooo0_l00001ooooo`006oooool00ol0003ooooooooo
o`03ooooo`03o`00oooooooooooo0:;ooooo00?o003oooooooooool06?ooool00ol00?oooooooooo
o`0jooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`2R
ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool0>_ooool1o`00007ooooo000Koooo
o`03o`000?oooooooooo00?ooooo00?o003oooooooooool0X_ooool00ol00?ooooooooooo`0Hoooo
o`03o`00oooooooooooo03[ooooo0Ol00001ooooo`006oooool2o`0000Cooooo00?o003ooooooooo
ool0X_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo03Wooooo0_l00001ooooo`00
4oooool3o`0000Gooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`2Rooooo`03o`00
oooooooooooo01Sooooo00?o003oooooooooool0>_ooool1o`00007ooooo000Booooo`05o`000?oo
ooooooooooooool000001?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo0:;ooooo
00?o003oooooooooool06?ooool00ol00?ooooooooooo`0jooooo`7o00000Oooool000cooooo1Ol0
0005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol00?oooooooooo
o`0booooo`<0003oKOooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo03[ooooo0Ol0
0001ooooo`005_ooool00ol0003oooooooooo`02ooooo`;o00001?ooool00ol00?ooooooooooo`0b
ooooo`<0003oKOooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo03Wooooo0_l00001
ooooo`004_ooool4o`0000Gooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`0boooo
o`<0003oKOooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo03[ooooo0Ol00001oooo
o`004_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o003ooooooooo
ool0=?ooool00ol00?ooooooooooo`1[ooooo`03o`00oooooooooooo01Sooooo00?o003ooooooooo
ool0>_ooool1o`00007ooooo000Booooo`Go00001?ooool00ol0003oooooooooo`03ooooo`03o`00
oooooooooooo03Cooooo00?o003oooooooooool0Joooool00ol00?ooooooooooo`0Hooooo`03o`00
oooooooooooo03[ooooo0Ol00001ooooo`006oooool2o`0000Cooooo00?o003oooooooooool0=?oo
ool00ol00?ooooooooooo`1[ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool0>Ooo
ool2o`00007ooooo000Kooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool0=?ooool0
0ol00?ooooooooooo`1[ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool0>_ooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool0=?ooool00ol0
0?ooooooooooo`1[ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool0>_ooool1o`00
007ooooo000Kooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool0=?ooool00ol00?oo
ooooooooo`1[ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool0>_ooool1o`00007o
oooo000Kooooo`;o00001?ooool00ol00?ooooooooooo`0dooooo`03o`00oooooooooooo06_ooooo
00?o003oooooooooool06?ooool00ol00?ooooooooooo`0iooooo`;o00000Oooool001_ooooo00?o
0000ooooooooool00oooool00ol00?ooooooooooo`0dooooo`03o`00oooooooooooo06_ooooo00?o
003oooooooooool06?ooool00ol00?ooooooooooo`0jooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool00oooool00ol00?ooooooooooo`0dooooo`03o`00oooooooooooo06_ooooo00?o003o
ooooooooool06?ooool00ol00?ooooooooooo`0jooooo`7o00000Oooool001_ooooo00?o0000oooo
ooooool00oooool00ol00?ooooooooooo`0dooooo`03o`00oooooooooooo06_ooooo00?o003ooooo
ooooool06?ooool00ol00?ooooooooooo`0jooooo`7o00000Oooool001_ooooo0_l00004ooooo`03
o`00oooooooooooo03Cooooo00?o003oooooooooool0Joooool00ol00?ooooooooooo`0Hooooo`03
o`00oooooooooooo03Wooooo0_l00001ooooo`006oooool00ol0003oooooooooo`03ooooo`03o`00
oooooooooooo03Cooooo00?o003oooooooooool0Joooool00ol00?ooooooooooo`0Hooooo`03o`00
oooooooooooo03[ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`03ooooo`03o`00oooo
oooooooo03Cooooo00?o003oooooooooool0Joooool00ol00?ooooooooooo`0Hooooo`03o`00oooo
oooooooo03[ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`03ooooo`03o`00oooooooo
oooo03Cooooo00?o003oooooooooool05oooool30000oe7ooooo00?o003oooooooooool06?ooool0
0ol00?ooooooooooo`0jooooo`7o00000Oooool001_ooooo0_l00004ooooo`03o`00oooooooooooo
03Cooooo00?o003oooooooooool05oooool30000oe7ooooo00?o003oooooooooool06?ooool00ol0
0?ooooooooooo`0iooooo`;o00000Oooool000Kooooo1Ol00003ooooo`03o`000?oooooooooo00;o
oooo0ol00005ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool0=?ooool00ol00?oo
ooooooooo`0Gooooo`<0003oDOooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo03[o
oooo0Ol00001ooooo`001oooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooooooo
ool000001?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo03Cooooo00?o003ooooo
ooooool06?ooool00ol00?ooooooooooo`1@ooooo`03o`00oooooooooooo01Sooooo00?o003ooooo
ooooool0>_ooool1o`00007ooooo0005o`0000?ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool0=?ooool00ol00?oo
ooooooooo`0Hooooo`03o`00oooooooooooo053ooooo00?o003oooooooooool06?ooool00ol00?oo
ooooooooo`0jooooo`7o00000Oooool000Wooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`02ooooo`;o00001?ooool00ol00?ooooooooooo`0dooooo`03o`00oooooooooooo01Sooooo
00?o003oooooooooool0D?ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo03Wooooo
0_l00001ooooo`001_ooool01Ol0003ooooooooooooooooo000000Oooooo1?l00005ooooo`03o`00
0?oooooooooo00?ooooo00?o003oooooooooool0=?ooool00ol00?ooooooooooo`0Hooooo`03o`00
oooooooooooo053ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0jooooo`7o0000
0Oooool000Kooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool00oooool00ol00?ooooooooooo`0dooooo`03o`00oooooooooooo01Sooooo
00?o003oooooooooool0D?ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo03[ooooo
0Ol00001ooooo`001oooool3o`0000Sooooo1Ol00004ooooo`03o`000?oooooooooo00?ooooo00?o
003oooooooooool0=?ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo053ooooo00?o
003oooooooooool06?ooool00ol00?ooooooooooo`0jooooo`7o00000Oooool001_ooooo0_l00004
ooooo`03o`00oooooooooooo03Cooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`1@
ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool0>Oooool2o`00007ooooo000Koooo
o`03o`000?oooooooooo00?ooooo00?o003oooooooooool0=?ooool00ol00?ooooooooooo`0Hoooo
o`03o`00oooooooooooo053ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0joooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`0dooooo`03
o`00oooooooooooo01Sooooo00?o003oooooooooool0D?ooool00ol00?ooooooooooo`0Hooooo`03
o`00oooooooooooo03[ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`03ooooo`03o`00
oooooooooooo03Cooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`1@ooooo`03o`00
oooooooooooo01Sooooo00?o003oooooooooool0>_ooool1o`00007ooooo000Kooooo`;o00001?oo
ool00ol00?ooooooooooo`0dooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool0D?oo
ool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo03Wooooo0_l00001ooooo`006oooool0
0ol0003oooooooooo`03ooooo`03o`00oooooooooooo03Cooooo00?o003oooooooooool06?ooool0
0ol00?ooooooooooo`1@ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool0>_ooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool0=?ooool00ol0
0?ooooooooooo`0Hooooo`03o`00oooooooooooo053ooooo00?o003oooooooooool06?ooool00ol0
0?ooooooooooo`0jooooo`7o00000Oooool001_ooooo00?o0000ooooooooool00oooool00ol00?oo
ooooooooo`0dooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool0D?ooool00ol00?oo
ooooooooo`0Hooooo`03o`00oooooooooooo03[ooooo0Ol00001ooooo`006oooool2o`0000Cooooo
00?o003oooooooooool0=?ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo053ooooo
00?o003oooooooooool06?ooool00ol00?ooooooooooo`0iooooo`;o00000Oooool001_ooooo00?o
0000ooooooooool00oooool00ol00?ooooooooooo`0dooooo`03o`00oooooooooooo01Sooooo00?o
003oooooooooool0D?ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo03[ooooo0Ol0
0001ooooo`006oooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo03Cooooo00?o003o
ooooooooool06?ooool00ol00?ooooooooooo`1@ooooo`03o`00oooooooooooo01Sooooo00?o003o
ooooooooool0>_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00?ooooo00?o003ooooo
ooooool0=?ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo053ooooo00?o003ooooo
ooooool06?ooool00ol00?ooooooooooo`0jooooo`7o00000Oooool001_ooooo0_l00004ooooo`03
o`00oooooooooooo03Cooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`1@ooooo`03
o`00oooooooooooo01Sooooo00?o003oooooooooool0>Oooool2o`00007ooooo000Dooooo`;o0000
1Oooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo03Cooooo00?o003oooooooooool0
6?ooool00ol00?ooooooooooo`1@ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool0
>_ooool1o`00007ooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
0oooool00ol00?ooooooooooo`0dooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool0
D?ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo03[ooooo0Ol00001ooooo`004ooo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool0
=?ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo053ooooo00?o003oooooooooool0
6?ooool00ol00?ooooooooooo`0jooooo`7o00000Oooool001?ooooo00Co0000oooooooooooo0000
1?ooool6o`000003o`00ool0003o000001So000000?o003oo`000?l000006Ol000000ol00?oo0000
o`00000Ho`000003o`00ool0003o000001Wo000000?o003oo`000?l000006?l000000ol00?oo0000
o`00000Io`000003o`00ool0003o000001So000000?o003oo`000?l000006Ol000000ol00?oo0000
o`00000Ho`000003o`00ool0003o000000Co00000Oooool001?ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`0Nooooo`03o`00oooooooooooo053ooooo00?o003oooooooooool0
6?ooool00ol00?ooooooooooo`1@ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool0
0oooool1o`00007ooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
7_ooool00ol00?ooooooooooo`1@ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool0
D?ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00?ooooo0Ol00001ooooo`005?oo
ool2o`0000Gooooo00?o0000ooooooooool07_ooool00ol00?ooooooooooo`1@ooooo`03o`00oooo
oooooooo01Sooooo00?o003oooooooooool0D?ooool00ol00?ooooooooooo`0Hooooo`03o`00oooo
oooooooo00?ooooo0Ol00001ooooo`006oooool2o`0001oooooo00?o003oooooooooool0D?ooool0
0ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo053ooooo00?o003oooooooooool06?ooool0
0ol00?ooooooooooo`02ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool07_ooool00ol0
0?ooooooooooo`1@ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool0D?ooool00ol0
0?ooooooooooo`0Hooooo`03o`00oooooooooooo00?ooooo0Ol00001ooooo`006oooool00ol0003o
ooooooooo`0Nooooo`03o`00oooooooooooo053ooooo00?o003oooooooooool06?ooool00ol00?oo
ooooooooo`1@ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool00oooool1o`00007o
oooo000Kooooo`03o`000?oooooooooo01gooooo0`000?mAooooo`03o`00oooooooooooo01Sooooo
00?o003oooooooooool0D?ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00?ooooo
0Ol00001ooooo`006oooool2o`0001kooooo0`000?mAooooo`03o`00oooooooooooo01Sooooo00?o
003oooooooooool0D?ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00;ooooo0_l0
0001ooooo`006oooool00ol0003oooooooooo`0Mooooo`<0003oDOooool00ol00?ooooooooooo`0H
ooooo`03o`00oooooooooooo053ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`03
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0LOooool00ol00?ooooooooooo`0Hoooo
o`03o`00oooooooooooo053ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`03oooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool0LOooool00ol00?ooooooooooo`0Hooooo`03
o`00oooooooooooo053ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`03ooooo`7o
00000Oooool001_ooooo0_l0001booooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool0
D?ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00;ooooo0_l00001ooooo`006ooo
ool00ol0003oooooooooo`1aooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool0D?oo
ool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00?ooooo0Ol00001ooooo`006oooool0
0ol0003oooooooooo`1aooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool0D?ooool0
0ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00?ooooo0Ol00001ooooo`006oooool00ol0
003oooooooooo`1aooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool0D?ooool00ol0
0?ooooooooooo`0Hooooo`03o`00oooooooooooo00?ooooo0Ol00001ooooo`006oooool2o`0007;o
oooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`1@ooooo`03o`00oooooooooooo01So
oooo00?o003oooooooooool00_ooool2o`00007ooooo0006ooooo`Go00000oooool00ol0003ooooo
ooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`1aooooo`03o`00oooooooooooo01Sooooo
00?o003oooooooooool0D?ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00?ooooo
0Ol00001ooooo`001oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool0
00001?ooool00ol0003oooooooooo`1aooooo`03o`00oooooooooooo01Sooooo00?o003ooooooooo
ool0D?ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00?ooooo0Ol00001ooooo`00
2?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
LOooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo053ooooo00?o003oooooooooool0
6?ooool00ol00?ooooooooooo`03ooooo`7o00000Oooool000Wooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`02ooooo`;o0000L_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooo
oooooooo053ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`02ooooo`;o00000Ooo
ool000Kooooo00Go0000ooooooooooooooooo`000007ooooo`Co00001Oooool00ol0003ooooooooo
o`1aooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool0D?ooool00ol00?oooooooooo
o`0Hooooo`03o`00oooooooooooo00?ooooo0Ol00001ooooo`001_ooool01Ol0003ooooooooooooo
oooo000000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1aooooo`03o`00oooo
oooooooo01Sooooo00?o003oooooooooool0D?ooool00ol00?ooooooooooo`0Hooooo`03o`00oooo
oooooooo00?ooooo0Ol00001ooooo`001oooool3o`0000Sooooo1Ol00004ooooo`03o`000?oooooo
oooo077ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`1@ooooo`03o`00oooooooo
oooo01Sooooo00?o003oooooooooool00oooool1o`00007ooooo000Kooooo`;o0000L_ooool00ol0
0?ooooooooooo`0Hooooo`03o`00oooooooooooo053ooooo00?o003oooooooooool06?ooool00ol0
0?ooooooooooo`02ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0LOooool00ol00?oo
ooooooooo`0Hooooo`03o`00oooooooooooo053ooooo00?o003oooooooooool06?ooool00ol00?oo
ooooooooo`03ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0LOooool00ol00?oooooo
ooooo`0Hooooo`03o`00oooooooooooo053ooooo00?o003oooooooooool06?ooool00ol00?oooooo
ooooo`03ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0LOooool00ol00?oooooooooo
o`0Hooooo`03o`00oooooooooooo053ooooo00?o003oooooooooool06?ooool00ol00?oooooooooo
o`03ooooo`7o00000Oooool001_ooooo0_l0001booooo`03o`00oooooooooooo01Sooooo00?o003o
ooooooooool0D?ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00;ooooo0_l00001
ooooo`006oooool00ol0003oooooooooo`1aooooo`03o`00oooooooooooo01Sooooo00?o003ooooo
ooooool0D?ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00?ooooo0Ol00001oooo
o`006oooool00ol0003oooooooooo`1aooooo`03o`00oooooooooooo01Sooooo00?o003ooooooooo
ool0D?ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00?ooooo0Ol00001ooooo`00
6oooool00ol0003oooooooooo`1aooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool0
D?ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00?ooooo0Ol00001ooooo`006ooo
ool2o`0007;ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`1@ooooo`03o`00oooo
oooooooo01Sooooo00?o003oooooooooool00_ooool2o`00007ooooo000Kooooo`03o`000?oooooo
oooo077ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`1@ooooo`03o`00oooooooo
oooo01Sooooo00?o003oooooooooool00oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo
077ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`1@ooooo`03o`00oooooooooooo
01Sooooo00?o003oooooooooool00oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo077o
oooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`1@ooooo`03o`00oooooooooooo01So
oooo00?o003oooooooooool00oooool1o`00007ooooo000Kooooo`;o0000L_ooool00ol00?oooooo
ooooo`0Hooooo`03o`00oooooooooooo053ooooo00?o003oooooooooool06?ooool00ol00?oooooo
ooooo`02ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0LOooool00ol00?oooooooooo
o`0Hooooo`03o`00oooooooooooo053ooooo00?o003oooooooooool06?ooool00ol00?oooooooooo
o`03ooooo`7o00000Oooool001?ooooo0ol00005ooooo`03o`000?oooooooooo077ooooo00?o003o
ooooooooool06?ooool00ol00?ooooooooooo`1@ooooo`03o`00oooooooooooo01Sooooo00?o003o
ooooooooool00oooool1o`00007ooooo000Booooo`05o`000?ooooooooooooooool000001?ooool0
0ol0003oooooooooo`1aooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool0D?ooool0
0ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00?ooooo0Ol00001ooooo`005_ooool00ol0
003oooooooooo`02ooooo`;o0000L_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo
053ooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`02ooooo`;o00000Oooool001Ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1aooooo`03o`00oooooooooooo01So
oooo00?o003oooooooooool0D?ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00?o
oooo0Ol00001ooooo`004_ooool4o`0000Gooooo00?o0000ooooooooool0LOooool00ol00?oooooo
ooooo`0Hooooo`03o`00oooooooooooo053ooooo00?o003oooooooooool06?ooool00ol00?oooooo
ooooo`03ooooo`7o00000Oooool001;ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`1aooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool0D?ooool00ol00?oooooooooo
o`0Hooooo`03o`00oooooooooooo00?ooooo0Ol00001ooooo`004_ooool5o`0000Cooooo0_l0001b
ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool0D?ooool00ol00?ooooooooooo`0H
ooooo`03o`00oooooooooooo00;ooooo0_l00001ooooo`006oooool00ol0003oooooooooo`1aoooo
o`03o`00oooooooooooo01Sooooo00?o003oooooooooool0D?ooool00ol00?ooooooooooo`0Hoooo
o`03o`00oooooooooooo00?ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1aooooo`03
o`00oooooooooooo01Sooooo00?o003oooooooooool0D?ooool00ol00?ooooooooooo`0Hooooo`03
o`00oooooooooooo00?ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1aooooo`03o`00
oooooooooooo01Sooooo00?o003oooooooooool0D?ooool00ol00?ooooooooooo`0Hooooo`03o`00
oooooooooooo00?ooooo0Ol00001ooooo`006oooool2o`0007;ooooo00?o003oooooooooool06?oo
ool00ol00?ooooooooooo`1@ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool00_oo
ool2o`00007ooooo000Kooooo`03o`000?oooooooooo077ooooo00?o003oooooooooool06?ooool0
0ol00?ooooooooooo`1@ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool00oooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo077ooooo00?o003oooooooooool06?ooool00ol0
0?ooooooooooo`1@ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool00oooool1o`00
007ooooo000Kooooo`03o`000?oooooooooo077ooooo00?o003oooooooooool06?ooool00ol00?oo
ooooooooo`1@ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool00oooool1o`00007o
oooo000Kooooo`;o0000L_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo053ooooo
00?o003oooooooooool06?ooool00ol00?ooooooooooo`02ooooo`;o00000Oooool001_ooooo00?o
0000ooooooooool0LOooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo053ooooo00?o
003oooooooooool06?ooool00ol00?ooooooooooo`03ooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool0LOooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo053ooooo00?o003o
ooooooooool06?ooool00ol00?ooooooooooo`03ooooo`7o00000Oooool001_ooooo00?o0000oooo
ooooool0LOooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo053ooooo00?o003ooooo
ooooool06?ooool00ol00?ooooooooooo`03ooooo`7o00000Oooool001_ooooo0_l0001booooo`03
o`00oooooooooooo01Sooooo00?o003oooooooooool0C_ooool30000oaWooooo0`000?l3ooooo`;o
00000Oooool001_ooooo00?o0000ooooooooool0LOooool00ol00?ooooooooooo`0Hooooo`03o`00
oooooooooooo04kooooo0`000?lIooooo`<0003o1?ooool1o`00007ooooo0008ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0LOoo
ool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo04kooooo0`000?lIooooo`<0003o1?oo
ool1o`00007ooooo0008ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo077ooooo00?o003oooooooooool06?ooool00ol00?oooooooooo
o`1aooooo`7o00000Oooool000Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02
ooooo`;o0000L_ooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo073ooooo0_l00001
ooooo`002Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0LOooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo077ooooo0Ol00001oooo
o`002_ooool00ol0003oooooooooo`05ooooo`Co00001Oooool00ol0003oooooooooo`1aooooo`03
o`00oooooooooooo01Sooooo00?o003oooooooooool0LOooool1o`00007ooooo0006ooooo`05o`00
0?ooooooooooooooool000001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo077o
oooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`1aooooo`7o00000Oooool000Kooooo
1Ol00007ooooo`Go00001?ooool2o`0007;ooooo00?o003oooooooooool05oooool30000og7ooooo
0_l00001ooooo`006oooool00ol0003oooooooooo`1aooooo`03o`00oooooooooooo01Oooooo0`00
0?mbooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0LOooool00ol00?ooooooooooo`0G
ooooo`<0003oL_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo077ooooo00?o003ooooo
ooooool0S?ooool1o`00007ooooo000Kooooo`;o0000L_ooool00ol00?ooooooooooo`2;ooooo`;o
00000Oooool001_ooooo00?o0000ooooooooool0LOooool00ol00?ooooooooooo`2<ooooo`7o0000
0Oooool001_ooooo00?o0000ooooooooool0LOooool00ol00?ooooooooooo`2<ooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool0LOooool00ol00?ooooooooooo`2<ooooo`7o00000Oooool0
01_ooooo0_l0001booooo`03o`00oooooooooooo08_ooooo0_l00001ooooo`006oooool00ol0003o
ooooooooo`1aooooo`03o`00oooooooooooo08cooooo0Ol00001ooooo`006oooool00ol0003ooooo
ooooo`1aooooo`03o`00oooooooooooo08cooooo0Ol00001ooooo`006oooool00ol0003ooooooooo
o`1aooooo`03o`00oooooooooooo08cooooo0Ol00001ooooo`006oooool2o`0007;ooooo00?o003o
ooooooooool0Roooool2o`00007ooooo000Kooooo`03o`000?oooooooooo077ooooo00?o003ooooo
ooooool0S?ooool1o`00007ooooo000=ooooo`?o00001?ooool2o`0000Gooooo00?o0000oooooooo
ool0LOooool00ol00?ooooooooooo`2<ooooo`7o00000Oooool000kooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo077ooooo00?o003ooooooooo
ool0S?ooool1o`00007ooooo000>ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00001?ooool2o`00073ooooo0`000?n=ooooo`;o00000Oooool000kooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo06oooooo0`000?n>ooooo`7o
00000Oooool000kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0booooo`<0
003o=_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo01kooooo0Ol00001ooooo`00
3Oooool2o`0000Cooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00?ooooo0Ol00001ooooo`003_ooool00ol0003oooooooooo`03ooooo`;o0000
1Oooooooo`0000Go00000Oooool00?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.21673, -11.2184, \
0.0363984, 0.124332}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Impulse response function h[n]", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(DiscreteListPlot[hn, Blue, \ Frame \[Rule] True, 
        PlotRange \[Rule] All, \ Axes \[Rule] {True, False}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.10582 0.345805 0.0367877 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.23545 -0.0125 -3 -9 ]
[.23545 -0.0125 3 0 ]
[.44709 -0.0125 -3 -9 ]
[.44709 -0.0125 3 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.87037 -0.0125 -3 -9 ]
[.87037 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0699 -24 -4.5 ]
[-0.0125 .0699 0 4.5 ]
[-0.0125 .16187 -12 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .25384 -24 -4.5 ]
[-0.0125 .25384 0 4.5 ]
[-0.0125 .3458 -6 -4.5 ]
[-0.0125 .3458 0 4.5 ]
[-0.0125 .43777 -18 -4.5 ]
[-0.0125 .43777 0 4.5 ]
[-0.0125 .52974 -6 -4.5 ]
[-0.0125 .52974 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.23545 0 m
.23545 .00625 L
s
[(2)] .23545 -0.0125 0 1 Mshowa
.44709 0 m
.44709 .00625 L
s
[(4)] .44709 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(6)] .65873 -0.0125 0 1 Mshowa
.87037 0 m
.87037 .00625 L
s
[(8)] .87037 -0.0125 0 1 Mshowa
.125 Mabswid
.07672 0 m
.07672 .00375 L
s
.12963 0 m
.12963 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.28836 0 m
.28836 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.39418 0 m
.39418 .00375 L
s
.5 0 m
.5 .00375 L
s
.55291 0 m
.55291 .00375 L
s
.60582 0 m
.60582 .00375 L
s
.71164 0 m
.71164 .00375 L
s
.76455 0 m
.76455 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.92328 0 m
.92328 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0699 m
.00625 .0699 L
s
[(-7.5)] -0.0125 .0699 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(-5)] -0.0125 .16187 1 0 Mshowa
0 .25384 m
.00625 .25384 L
s
[(-2.5)] -0.0125 .25384 1 0 Mshowa
0 .3458 m
.00625 .3458 L
s
[(0)] -0.0125 .3458 1 0 Mshowa
0 .43777 m
.00625 .43777 L
s
[(2.5)] -0.0125 .43777 1 0 Mshowa
0 .52974 m
.00625 .52974 L
s
[(5)] -0.0125 .52974 1 0 Mshowa
.125 Mabswid
0 .08829 m
.00375 .08829 L
s
0 .10668 m
.00375 .10668 L
s
0 .12508 m
.00375 .12508 L
s
0 .14347 m
.00375 .14347 L
s
0 .18026 m
.00375 .18026 L
s
0 .19865 m
.00375 .19865 L
s
0 .21705 m
.00375 .21705 L
s
0 .23544 m
.00375 .23544 L
s
0 .27223 m
.00375 .27223 L
s
0 .29062 m
.00375 .29062 L
s
0 .30902 m
.00375 .30902 L
s
0 .32741 m
.00375 .32741 L
s
0 .3642 m
.00375 .3642 L
s
0 .38259 m
.00375 .38259 L
s
0 .40099 m
.00375 .40099 L
s
0 .41938 m
.00375 .41938 L
s
0 .45617 m
.00375 .45617 L
s
0 .47456 m
.00375 .47456 L
s
0 .49296 m
.00375 .49296 L
s
0 .51135 m
.00375 .51135 L
s
0 .54814 m
.00375 .54814 L
s
0 .56653 m
.00375 .56653 L
s
0 .58493 m
.00375 .58493 L
s
0 .60332 m
.00375 .60332 L
s
0 .0515 m
.00375 .0515 L
s
0 .03311 m
.00375 .03311 L
s
0 .01472 m
.00375 .01472 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.23545 .61178 m
.23545 .61803 L
s
.44709 .61178 m
.44709 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.87037 .61178 m
.87037 .61803 L
s
.125 Mabswid
.07672 .61428 m
.07672 .61803 L
s
.12963 .61428 m
.12963 .61803 L
s
.18254 .61428 m
.18254 .61803 L
s
.28836 .61428 m
.28836 .61803 L
s
.34127 .61428 m
.34127 .61803 L
s
.39418 .61428 m
.39418 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.55291 .61428 m
.55291 .61803 L
s
.60582 .61428 m
.60582 .61803 L
s
.71164 .61428 m
.71164 .61803 L
s
.76455 .61428 m
.76455 .61803 L
s
.81746 .61428 m
.81746 .61803 L
s
.92328 .61428 m
.92328 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0699 m
1 .0699 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .25384 m
1 .25384 L
s
.99375 .3458 m
1 .3458 L
s
.99375 .43777 m
1 .43777 L
s
.99375 .52974 m
1 .52974 L
s
.125 Mabswid
.99625 .08829 m
1 .08829 L
s
.99625 .10668 m
1 .10668 L
s
.99625 .12508 m
1 .12508 L
s
.99625 .14347 m
1 .14347 L
s
.99625 .18026 m
1 .18026 L
s
.99625 .19865 m
1 .19865 L
s
.99625 .21705 m
1 .21705 L
s
.99625 .23544 m
1 .23544 L
s
.99625 .27223 m
1 .27223 L
s
.99625 .29062 m
1 .29062 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .32741 m
1 .32741 L
s
.99625 .3642 m
1 .3642 L
s
.99625 .38259 m
1 .38259 L
s
.99625 .40099 m
1 .40099 L
s
.99625 .41938 m
1 .41938 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .47456 m
1 .47456 L
s
.99625 .49296 m
1 .49296 L
s
.99625 .51135 m
1 .51135 L
s
.99625 .54814 m
1 .54814 L
s
.99625 .56653 m
1 .56653 L
s
.99625 .58493 m
1 .58493 L
s
.99625 .60332 m
1 .60332 L
s
.99625 .0515 m
1 .0515 L
s
.99625 .03311 m
1 .03311 L
s
.99625 .01472 m
1 .01472 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .3458 m
1 .3458 L
s
0 0 1 r
.5 Mabswid
.02381 .3458 m
.02381 .0515 L
s
.12963 .3458 m
.12963 .01472 L
s
.23545 .3458 m
.23545 .01472 L
s
.34127 .3458 m
.34127 .52974 L
s
.44709 .3458 m
.44709 .01472 L
s
.55291 .3458 m
.55291 .30902 L
s
.65873 .3458 m
.65873 .16187 L
s
.76455 .3458 m
.76455 .16187 L
s
.87037 .3458 m
.87037 .60332 L
s
.97619 .3458 m
.97619 .0515 L
s
.015 w
.02381 .0515 Mdot
.12963 .01472 Mdot
.23545 .01472 Mdot
.34127 .52974 Mdot
.44709 .01472 Mdot
.55291 .30902 Mdot
.65873 .16187 Mdot
.76455 .16187 Mdot
.87037 .60332 Mdot
.97619 .0515 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Frequency-domain solution", "Subsection"],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`Y(
        e\^j\[Theta]) = \(X(e\^j\[Theta])\) \(H(
          e\^j\[Theta])\)\)]]], "Subsubsection"],

Cell[BoxData[{
    \(\(X\[Theta]\  = \ DTFT[xn, \[Theta]];\)\), "\[IndentingNewLine]", 
    \(\(H\[Theta]\  = \ DTFT[hn, \[Theta]];\)\), "\[IndentingNewLine]", 
    \(\(Y\[Theta]\  = \ X\[Theta]*H\[Theta];\)\)}], "Input",
  FontColor->GrayLevel[1],
  Background->RGBColor[1, 0, 0]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot frequency representation", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(g1 = 
        Plot[Abs[X\[Theta]*H\[Theta]], {\[Theta], \(-\[Pi]\), \[Pi]}, \ 
          PlotStyle \[Rule] {Red}, \ PlotRange \[Rule] All, 
          PlotPoints \[Rule] 200, \ 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(g2 = 
        Plot[Arg[X\[Theta]*\ H\[Theta]], {\[Theta], \(-\[Pi]\), \[Pi]}, \ 
          PlotStyle \[Rule] {Red}, \ PlotRange \[Rule] All, 
          PlotPoints \[Rule] 200, \ 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(Show[GraphicsArray[{{g1, g2}}], ImageSize \[Rule] 504];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
%%ImageSize: 504 148.328 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.151576 0.014388 0.000733898 [
[.04527 -0.0125 -6 -9 ]
[.04527 -0.0125 6 0 ]
[.19685 -0.0125 -6 -9 ]
[.19685 -0.0125 6 0 ]
[.34842 -0.0125 -6 -9 ]
[.34842 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65158 -0.0125 -3 -9 ]
[.65158 -0.0125 3 0 ]
[.80315 -0.0125 -3 -9 ]
[.80315 -0.0125 3 0 ]
[.95473 -0.0125 -3 -9 ]
[.95473 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01439 -6 -4.5 ]
[-0.0125 .01439 0 4.5 ]
[-0.0125 .16117 -18 -4.5 ]
[-0.0125 .16117 0 4.5 ]
[-0.0125 .30795 -18 -4.5 ]
[-0.0125 .30795 0 4.5 ]
[-0.0125 .45473 -18 -4.5 ]
[-0.0125 .45473 0 4.5 ]
[-0.0125 .60151 -18 -4.5 ]
[-0.0125 .60151 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 0 m
.04527 .00625 L
s
[(-3)] .04527 -0.0125 0 1 Mshowa
.19685 0 m
.19685 .00625 L
s
[(-2)] .19685 -0.0125 0 1 Mshowa
.34842 0 m
.34842 .00625 L
s
[(-1)] .34842 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.65158 0 m
.65158 .00625 L
s
[(1)] .65158 -0.0125 0 1 Mshowa
.80315 0 m
.80315 .00625 L
s
[(2)] .80315 -0.0125 0 1 Mshowa
.95473 0 m
.95473 .00625 L
s
[(3)] .95473 -0.0125 0 1 Mshowa
.125 Mabswid
.07559 0 m
.07559 .00375 L
s
.1059 0 m
.1059 .00375 L
s
.13622 0 m
.13622 .00375 L
s
.16653 0 m
.16653 .00375 L
s
.22716 0 m
.22716 .00375 L
s
.25748 0 m
.25748 .00375 L
s
.28779 0 m
.28779 .00375 L
s
.31811 0 m
.31811 .00375 L
s
.37874 0 m
.37874 .00375 L
s
.40905 0 m
.40905 .00375 L
s
.43937 0 m
.43937 .00375 L
s
.46968 0 m
.46968 .00375 L
s
.53032 0 m
.53032 .00375 L
s
.56063 0 m
.56063 .00375 L
s
.59095 0 m
.59095 .00375 L
s
.62126 0 m
.62126 .00375 L
s
.68189 0 m
.68189 .00375 L
s
.71221 0 m
.71221 .00375 L
s
.74252 0 m
.74252 .00375 L
s
.77284 0 m
.77284 .00375 L
s
.83347 0 m
.83347 .00375 L
s
.86378 0 m
.86378 .00375 L
s
.8941 0 m
.8941 .00375 L
s
.92441 0 m
.92441 .00375 L
s
.01496 0 m
.01496 .00375 L
s
.98504 0 m
.98504 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01439 m
.00625 .01439 L
s
[(0)] -0.0125 .01439 1 0 Mshowa
0 .16117 m
.00625 .16117 L
s
[(200)] -0.0125 .16117 1 0 Mshowa
0 .30795 m
.00625 .30795 L
s
[(400)] -0.0125 .30795 1 0 Mshowa
0 .45473 m
.00625 .45473 L
s
[(600)] -0.0125 .45473 1 0 Mshowa
0 .60151 m
.00625 .60151 L
s
[(800)] -0.0125 .60151 1 0 Mshowa
.125 Mabswid
0 .05108 m
.00375 .05108 L
s
0 .08778 m
.00375 .08778 L
s
0 .12447 m
.00375 .12447 L
s
0 .19786 m
.00375 .19786 L
s
0 .23456 m
.00375 .23456 L
s
0 .27125 m
.00375 .27125 L
s
0 .34464 m
.00375 .34464 L
s
0 .38134 m
.00375 .38134 L
s
0 .41803 m
.00375 .41803 L
s
0 .49142 m
.00375 .49142 L
s
0 .52812 m
.00375 .52812 L
s
0 .56481 m
.00375 .56481 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.04527 .61178 m
.04527 .61803 L
s
.19685 .61178 m
.19685 .61803 L
s
.34842 .61178 m
.34842 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65158 .61178 m
.65158 .61803 L
s
.80315 .61178 m
.80315 .61803 L
s
.95473 .61178 m
.95473 .61803 L
s
.125 Mabswid
.07559 .61428 m
.07559 .61803 L
s
.1059 .61428 m
.1059 .61803 L
s
.13622 .61428 m
.13622 .61803 L
s
.16653 .61428 m
.16653 .61803 L
s
.22716 .61428 m
.22716 .61803 L
s
.25748 .61428 m
.25748 .61803 L
s
.28779 .61428 m
.28779 .61803 L
s
.31811 .61428 m
.31811 .61803 L
s
.37874 .61428 m
.37874 .61803 L
s
.40905 .61428 m
.40905 .61803 L
s
.43937 .61428 m
.43937 .61803 L
s
.46968 .61428 m
.46968 .61803 L
s
.53032 .61428 m
.53032 .61803 L
s
.56063 .61428 m
.56063 .61803 L
s
.59095 .61428 m
.59095 .61803 L
s
.62126 .61428 m
.62126 .61803 L
s
.68189 .61428 m
.68189 .61803 L
s
.71221 .61428 m
.71221 .61803 L
s
.74252 .61428 m
.74252 .61803 L
s
.77284 .61428 m
.77284 .61803 L
s
.83347 .61428 m
.83347 .61803 L
s
.86378 .61428 m
.86378 .61803 L
s
.8941 .61428 m
.8941 .61803 L
s
.92441 .61428 m
.92441 .61803 L
s
.01496 .61428 m
.01496 .61803 L
s
.98504 .61428 m
.98504 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01439 m
1 .01439 L
s
.99375 .16117 m
1 .16117 L
s
.99375 .30795 m
1 .30795 L
s
.99375 .45473 m
1 .45473 L
s
.99375 .60151 m
1 .60151 L
s
.125 Mabswid
.99625 .05108 m
1 .05108 L
s
.99625 .08778 m
1 .08778 L
s
.99625 .12447 m
1 .12447 L
s
.99625 .19786 m
1 .19786 L
s
.99625 .23456 m
1 .23456 L
s
.99625 .27125 m
1 .27125 L
s
.99625 .34464 m
1 .34464 L
s
.99625 .38134 m
1 .38134 L
s
.99625 .41803 m
1 .41803 L
s
.99625 .49142 m
1 .49142 L
s
.99625 .52812 m
1 .52812 L
s
.99625 .56481 m
1 .56481 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .04962 m
.02395 .04962 L
.02408 .04963 L
.02423 .04966 L
.02437 .04969 L
.02462 .04978 L
.02489 .04991 L
.02519 .0501 L
.02551 .05034 L
.02608 .0509 L
.02722 .05244 L
.02847 .05474 L
.03109 .06111 L
.03355 .0684 L
.03823 .0842 L
.0432 .10244 L
.04799 .12095 L
.05259 .1397 L
.0575 .16088 L
.06221 .18253 L
.06723 .20661 L
.07206 .2302 L
.07671 .25235 L
.08166 .27413 L
.08642 .29214 L
.091 .30563 L
.09335 .31082 L
.09587 .31492 L
.0971 .31633 L
.09775 .31693 L
.09843 .31743 L
.09903 .31778 L
.09935 .31792 L
.0997 .31804 L
.10001 .31813 L
.10015 .31816 L
.1003 .31818 L
.10044 .3182 L
.10057 .31822 L
.10071 .31822 L
.10086 .31823 L
.10101 .31822 L
.10109 .31822 L
.10117 .31821 L
.10133 .3182 L
.10142 .31819 L
.1015 .31817 L
.10181 .31811 L
.1021 .31802 L
.10243 .3179 L
Mistroke
.10274 .31776 L
.10344 .31734 L
.10405 .31685 L
.10461 .31633 L
.10587 .31484 L
.10819 .31097 L
.1107 .30518 L
.11566 .28918 L
.12042 .26865 L
.12501 .2451 L
.12989 .21732 L
.13459 .18972 L
.13959 .1623 L
.14209 .15061 L
.1444 .14183 L
.14556 .13835 L
.14664 .13573 L
.14724 .13459 L
.14778 .13373 L
.14838 .13298 L
.14869 .13268 L
.14903 .13243 L
.14918 .13234 L
.14934 .13226 L
.14948 .1322 L
.14963 .13215 L
.14977 .13212 L
.14992 .1321 L
.15005 .1321 L
.15018 .1321 L
.15034 .13213 L
.15049 .13216 L
.15063 .13221 L
.15077 .13227 L
.15111 .13246 L
.15141 .1327 L
.15192 .13323 L
.15249 .13399 L
.15363 .13612 L
.15484 .13919 L
.15596 .14266 L
.15847 .15242 L
.16325 .17588 L
.16784 .20082 L
.17273 .22628 L
.17743 .24711 L
.17983 .25565 L
.1811 .25947 L
.18243 .26296 L
.18363 .26556 L
Mistroke
.18494 .26784 L
.18552 .26864 L
.18613 .26936 L
.18668 .26987 L
.18725 .27028 L
.18758 .27046 L
.18788 .27058 L
.18803 .27063 L
.18819 .27067 L
.18834 .2707 L
.18847 .27072 L
.18855 .27072 L
.18863 .27073 L
.18878 .27073 L
.18887 .27073 L
.18896 .27072 L
.18904 .27071 L
.18912 .2707 L
.18929 .27067 L
.18947 .27062 L
.1898 .27049 L
.19009 .27035 L
.1904 .27015 L
.19096 .2697 L
.19162 .26898 L
.19223 .26815 L
.19341 .26607 L
.19451 .26357 L
.19701 .25584 L
.19948 .24537 L
.20172 .23341 L
.20654 .19989 L
.21118 .15814 L
.21612 .10473 L
.21858 .07532 L
.22088 .04686 L
.22142 .04024 L
.22201 .03336 L
.22228 .03047 L
.22257 .02777 L
.2227 .02668 L
.22284 .02583 L
.22295 .02526 L
.22308 .02488 L
.22323 .02479 L
.22332 .02491 L
.2234 .02513 L
.22348 .02548 L
.22356 .02588 L
.22373 .02705 L
Mistroke
.22403 .02981 L
.22432 .03291 L
.22545 .04703 L
.23008 .11142 L
.23501 .18193 L
.23975 .24873 L
.24431 .30999 L
.24917 .37032 L
.25384 .42238 L
.25881 .4704 L
.2636 .50917 L
.26821 .53959 L
.27311 .56493 L
.27783 .58294 L
.28041 .59032 L
.28284 .59573 L
.28402 .59782 L
.28526 .59967 L
.28642 .60106 L
.28749 .60203 L
.28803 .60243 L
.28863 .60278 L
.28896 .60293 L
.28926 .60305 L
.28957 .60315 L
.28985 .60322 L
.2901 .60327 L
.29024 .60329 L
.29036 .6033 L
.29049 .60331 L
.29064 .60332 L
.29079 .60332 L
.29093 .60331 L
.29107 .6033 L
.29121 .60329 L
.29134 .60327 L
.29148 .60325 L
.29178 .60318 L
.29206 .6031 L
.29263 .60288 L
.29323 .60255 L
.29433 .60172 L
.29563 .60034 L
.29682 .59871 L
.29911 .59453 L
.30161 .58839 L
.30652 .57152 L
.31124 .54928 L
.31626 .51963 L
.3211 .48613 L
Mistroke
.32575 .45069 L
.3307 .41152 L
.33547 .37458 L
.34005 .34185 L
.34493 .31184 L
.34963 .2885 L
.35462 .26923 L
.35943 .25432 L
.36406 .24119 L
.36898 .22631 L
.37372 .20959 L
.37828 .19078 L
.38313 .16813 L
.38781 .14485 L
.39277 .12045 L
.39525 .10924 L
.39756 .09991 L
.39992 .09185 L
.40216 .08607 L
.40334 .08383 L
.40401 .08285 L
.40463 .08213 L
.40515 .08167 L
.40545 .08146 L
.40572 .0813 L
.406 .08117 L
.40616 .08112 L
.40631 .08108 L
.40645 .08106 L
.40658 .08104 L
.40672 .08103 L
.40687 .08103 L
.40701 .08104 L
.40716 .08106 L
.40731 .0811 L
.40746 .08114 L
.40772 .08123 L
.408 .08137 L
.40863 .08182 L
.40921 .08238 L
.41035 .08389 L
.41142 .08578 L
.41383 .09151 L
.41605 .09837 L
.4208 .11717 L
.42536 .13979 L
.43022 .16807 L
.4349 .19841 L
.43987 .2323 L
.44466 .2643 L
Mistroke
.44927 .29212 L
.45184 .30551 L
.45417 .3159 L
.45663 .32474 L
.45889 .33072 L
.46002 .33286 L
.4606 .33372 L
.46121 .33447 L
.46154 .3348 L
.46183 .33504 L
.46213 .33525 L
.46241 .33541 L
.46256 .33548 L
.46273 .33554 L
.4629 .33559 L
.463 .33561 L
.46309 .33562 L
.46316 .33563 L
.46325 .33564 L
.46339 .33564 L
.46355 .33564 L
.46364 .33563 L
.46372 .33561 L
.46388 .33558 L
.46404 .33553 L
.46433 .33541 L
.46465 .33523 L
.46499 .33497 L
.46561 .33435 L
.46619 .33359 L
.46727 .33169 L
.46843 .32894 L
.46966 .32526 L
.47099 .32031 L
.47341 .30879 L
.47832 .27578 L
.48305 .2325 L
.48807 .17594 L
.49291 .11355 L
.49757 .04895 L
.49881 .03126 L
.49942 .0226 L
.49969 .01882 L
.49983 .01683 L
.49998 .01472 L
.50013 .01629 L
.50028 .01835 L
.50056 .0224 L
.50119 .03132 L
.50252 .05017 L
Mistroke
.50708 .11341 L
.51194 .17602 L
.51661 .22896 L
.52158 .27497 L
.52406 .29338 L
.52636 .30757 L
.52859 .31854 L
.53097 .32724 L
.53221 .33055 L
.53286 .33195 L
.53355 .33319 L
.53415 .33406 L
.53447 .33445 L
.53481 .3348 L
.53513 .33507 L
.53542 .33527 L
.5357 .33543 L
.53598 .33554 L
.53612 .33558 L
.53626 .33561 L
.5364 .33563 L
.53653 .33564 L
.53667 .33564 L
.53683 .33563 L
.53691 .33562 L
.53699 .33561 L
.53714 .33558 L
.5373 .33553 L
.53747 .33546 L
.53779 .3353 L
.53809 .3351 L
.53838 .33487 L
.53946 .33365 L
.54 .33282 L
.5406 .33176 L
.54294 .32604 L
.54546 .31737 L
.55044 .29376 L
.55523 .26502 L
.55984 .23429 L
.56474 .20082 L
.56946 .17002 L
.57448 .14063 L
.57932 .11665 L
.58397 .09829 L
.58638 .09094 L
.58761 .08787 L
.58892 .08513 L
.58956 .08404 L
.59016 .08315 L
Mistroke
.59075 .08242 L
.59129 .08188 L
.5918 .08149 L
.59206 .08134 L
.59235 .0812 L
.59249 .08115 L
.59264 .08111 L
.59271 .08109 L
.5928 .08107 L
.59294 .08105 L
.59308 .08103 L
.59323 .08103 L
.59337 .08104 L
.5935 .08105 L
.59365 .08107 L
.59378 .08111 L
.59393 .08115 L
.59409 .08121 L
.59441 .08137 L
.59471 .08156 L
.59528 .08204 L
.59582 .08264 L
.59702 .08445 L
.59833 .08715 L
.60071 .09382 L
.60324 .10299 L
.60826 .12538 L
.61311 .14943 L
.61776 .17249 L
.62272 .19514 L
.62749 .21415 L
.63208 .2297 L
.63697 .24411 L
.64167 .25753 L
.64667 .27374 L
.65148 .29352 L
.65611 .31778 L
.66104 .3493 L
.66579 .38409 L
.67035 .41983 L
.67521 .45816 L
.67988 .49323 L
.68485 .5267 L
.68964 .55386 L
.69425 .57457 L
.69682 .58368 L
.69915 .59042 L
.70158 .59592 L
.70387 .59969 L
.70504 .60111 L
Mistroke
.70569 .60173 L
.70629 .60222 L
.70684 .60259 L
.70735 .60287 L
.70791 .60309 L
.70822 .60318 L
.70836 .60322 L
.70852 .60325 L
.70866 .60327 L
.7088 .60329 L
.70893 .60331 L
.70907 .60331 L
.70922 .60332 L
.70936 .60332 L
.70952 .60331 L
.7096 .60331 L
.70968 .6033 L
.70984 .60328 L
.70999 .60326 L
.71032 .60318 L
.71061 .6031 L
.71092 .60299 L
.71146 .60273 L
.71197 .60242 L
.71314 .60149 L
.71439 .60012 L
.71558 .59846 L
.71782 .59441 L
.72021 .5887 L
.72243 .58211 L
.72716 .56374 L
.73218 .5373 L
.73702 .50458 L
.74167 .46606 L
.74662 .41748 L
.75139 .36368 L
.75597 .30625 L
.76086 .24032 L
.76555 .17392 L
.77055 .10249 L
.77305 .0674 L
.77415 .05241 L
.77536 .03673 L
.77592 .03035 L
.77621 .02757 L
.77637 .02635 L
.77652 .02549 L
.77665 .02499 L
.77679 .02478 L
.77694 .02494 L
Mistroke
.77708 .02543 L
.77721 .02613 L
.77735 .0271 L
.7776 .02931 L
.77999 .05758 L
.78493 .11677 L
.78969 .16664 L
.79426 .2062 L
.79681 .22428 L
.79913 .23822 L
.80157 .25013 L
.80382 .25872 L
.80612 .26506 L
.80733 .26744 L
.808 .26848 L
.80862 .26926 L
.80917 .26981 L
.80975 .27025 L
.81005 .27042 L
.81033 .27055 L
.81049 .27061 L
.81064 .27065 L
.81072 .27067 L
.81081 .27069 L
.81097 .27071 L
.8111 .27073 L
.81123 .27073 L
.81137 .27073 L
.81152 .27072 L
.81168 .2707 L
.81183 .27067 L
.81196 .27063 L
.81211 .27058 L
.81238 .27048 L
.81266 .27033 L
.81317 .26999 L
.81382 .26941 L
.81441 .26873 L
.81575 .26672 L
.81694 .26439 L
.81819 .26141 L
.82277 .24632 L
.82764 .22445 L
.83234 .19985 L
.83733 .17283 L
.83983 .16021 L
.84214 .14984 L
.84438 .14155 L
.84553 .13818 L
.84613 .13668 L
Mistroke
.84676 .13531 L
.84735 .13426 L
.84799 .13334 L
.84827 .13301 L
.84857 .13272 L
.84885 .13249 L
.84911 .13233 L
.84925 .13226 L
.8494 .1322 L
.84955 .13215 L
.8497 .13212 L
.84984 .1321 L
.84999 .1321 L
.85014 .13211 L
.85027 .13213 L
.8504 .13216 L
.85052 .1322 L
.8508 .13233 L
.85105 .13248 L
.85132 .13268 L
.85196 .13338 L
.85256 .13424 L
.8539 .13697 L
.85509 .1402 L
.85634 .14438 L
.86093 .1649 L
.86581 .19205 L
.87051 .21967 L
.87551 .2479 L
.88032 .27215 L
.88495 .29145 L
.88729 .29943 L
.88988 .30667 L
.89233 .31196 L
.89342 .31381 L
.89462 .31547 L
.89527 .31621 L
.89587 .31679 L
.8965 .31729 L
.89706 .31765 L
.89733 .31779 L
.89762 .31792 L
.89787 .31801 L
.89814 .3181 L
.89843 .31816 L
.89859 .31819 L
.89874 .31821 L
.89888 .31822 L
.89901 .31823 L
.89916 .31823 L
Mistroke
.89929 .31822 L
.89943 .31822 L
.89958 .3182 L
.89972 .31818 L
.89985 .31816 L
.90015 .31809 L
.90046 .31799 L
.90105 .31773 L
.90169 .31735 L
.90284 .31639 L
.90392 .31519 L
.90638 .31133 L
.90862 .30656 L
.91344 .29261 L
.91808 .27522 L
.92301 .25363 L
.92776 .23105 L
.93233 .20876 L
.93719 .18533 L
.94187 .16371 L
.94685 .14204 L
.95164 .12242 L
.95625 .10451 L
.96116 .08639 L
.96588 .07021 L
.96829 .06283 L
.96956 .05935 L
.9709 .05609 L
.9721 .05362 L
.97274 .05251 L
.97342 .05151 L
.97405 .05076 L
.97462 .05024 L
.9749 .05004 L
.97519 .04987 L
.97533 .0498 L
.97548 .04974 L
.9756 .0497 L
.97574 .04967 L
.97586 .04964 L
.97597 .04963 L
.97608 .04962 L
.97619 .04962 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.151576 0.308886 0.0937319 [
[.04527 -0.0125 -6 -9 ]
[.04527 -0.0125 6 0 ]
[.19685 -0.0125 -6 -9 ]
[.19685 -0.0125 6 0 ]
[.34842 -0.0125 -6 -9 ]
[.34842 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65158 -0.0125 -3 -9 ]
[.65158 -0.0125 3 0 ]
[.80315 -0.0125 -3 -9 ]
[.80315 -0.0125 3 0 ]
[.95473 -0.0125 -3 -9 ]
[.95473 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02769 -12 -4.5 ]
[-0.0125 .02769 0 4.5 ]
[-0.0125 .12142 -12 -4.5 ]
[-0.0125 .12142 0 4.5 ]
[-0.0125 .21515 -12 -4.5 ]
[-0.0125 .21515 0 4.5 ]
[-0.0125 .30889 -6 -4.5 ]
[-0.0125 .30889 0 4.5 ]
[-0.0125 .40262 -6 -4.5 ]
[-0.0125 .40262 0 4.5 ]
[-0.0125 .49635 -6 -4.5 ]
[-0.0125 .49635 0 4.5 ]
[-0.0125 .59008 -6 -4.5 ]
[-0.0125 .59008 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 0 m
.04527 .00625 L
s
[(-3)] .04527 -0.0125 0 1 Mshowa
.19685 0 m
.19685 .00625 L
s
[(-2)] .19685 -0.0125 0 1 Mshowa
.34842 0 m
.34842 .00625 L
s
[(-1)] .34842 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.65158 0 m
.65158 .00625 L
s
[(1)] .65158 -0.0125 0 1 Mshowa
.80315 0 m
.80315 .00625 L
s
[(2)] .80315 -0.0125 0 1 Mshowa
.95473 0 m
.95473 .00625 L
s
[(3)] .95473 -0.0125 0 1 Mshowa
.125 Mabswid
.07559 0 m
.07559 .00375 L
s
.1059 0 m
.1059 .00375 L
s
.13622 0 m
.13622 .00375 L
s
.16653 0 m
.16653 .00375 L
s
.22716 0 m
.22716 .00375 L
s
.25748 0 m
.25748 .00375 L
s
.28779 0 m
.28779 .00375 L
s
.31811 0 m
.31811 .00375 L
s
.37874 0 m
.37874 .00375 L
s
.40905 0 m
.40905 .00375 L
s
.43937 0 m
.43937 .00375 L
s
.46968 0 m
.46968 .00375 L
s
.53032 0 m
.53032 .00375 L
s
.56063 0 m
.56063 .00375 L
s
.59095 0 m
.59095 .00375 L
s
.62126 0 m
.62126 .00375 L
s
.68189 0 m
.68189 .00375 L
s
.71221 0 m
.71221 .00375 L
s
.74252 0 m
.74252 .00375 L
s
.77284 0 m
.77284 .00375 L
s
.83347 0 m
.83347 .00375 L
s
.86378 0 m
.86378 .00375 L
s
.8941 0 m
.8941 .00375 L
s
.92441 0 m
.92441 .00375 L
s
.01496 0 m
.01496 .00375 L
s
.98504 0 m
.98504 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02769 m
.00625 .02769 L
s
[(-3)] -0.0125 .02769 1 0 Mshowa
0 .12142 m
.00625 .12142 L
s
[(-2)] -0.0125 .12142 1 0 Mshowa
0 .21515 m
.00625 .21515 L
s
[(-1)] -0.0125 .21515 1 0 Mshowa
0 .30889 m
.00625 .30889 L
s
[(0)] -0.0125 .30889 1 0 Mshowa
0 .40262 m
.00625 .40262 L
s
[(1)] -0.0125 .40262 1 0 Mshowa
0 .49635 m
.00625 .49635 L
s
[(2)] -0.0125 .49635 1 0 Mshowa
0 .59008 m
.00625 .59008 L
s
[(3)] -0.0125 .59008 1 0 Mshowa
.125 Mabswid
0 .04644 m
.00375 .04644 L
s
0 .06518 m
.00375 .06518 L
s
0 .08393 m
.00375 .08393 L
s
0 .10268 m
.00375 .10268 L
s
0 .14017 m
.00375 .14017 L
s
0 .15892 m
.00375 .15892 L
s
0 .17766 m
.00375 .17766 L
s
0 .19641 m
.00375 .19641 L
s
0 .2339 m
.00375 .2339 L
s
0 .25265 m
.00375 .25265 L
s
0 .27139 m
.00375 .27139 L
s
0 .29014 m
.00375 .29014 L
s
0 .32763 m
.00375 .32763 L
s
0 .34638 m
.00375 .34638 L
s
0 .36513 m
.00375 .36513 L
s
0 .38387 m
.00375 .38387 L
s
0 .42136 m
.00375 .42136 L
s
0 .44011 m
.00375 .44011 L
s
0 .45886 m
.00375 .45886 L
s
0 .4776 m
.00375 .4776 L
s
0 .5151 m
.00375 .5151 L
s
0 .53384 m
.00375 .53384 L
s
0 .55259 m
.00375 .55259 L
s
0 .57134 m
.00375 .57134 L
s
0 .00894 m
.00375 .00894 L
s
0 .60883 m
.00375 .60883 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.04527 .61178 m
.04527 .61803 L
s
.19685 .61178 m
.19685 .61803 L
s
.34842 .61178 m
.34842 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65158 .61178 m
.65158 .61803 L
s
.80315 .61178 m
.80315 .61803 L
s
.95473 .61178 m
.95473 .61803 L
s
.125 Mabswid
.07559 .61428 m
.07559 .61803 L
s
.1059 .61428 m
.1059 .61803 L
s
.13622 .61428 m
.13622 .61803 L
s
.16653 .61428 m
.16653 .61803 L
s
.22716 .61428 m
.22716 .61803 L
s
.25748 .61428 m
.25748 .61803 L
s
.28779 .61428 m
.28779 .61803 L
s
.31811 .61428 m
.31811 .61803 L
s
.37874 .61428 m
.37874 .61803 L
s
.40905 .61428 m
.40905 .61803 L
s
.43937 .61428 m
.43937 .61803 L
s
.46968 .61428 m
.46968 .61803 L
s
.53032 .61428 m
.53032 .61803 L
s
.56063 .61428 m
.56063 .61803 L
s
.59095 .61428 m
.59095 .61803 L
s
.62126 .61428 m
.62126 .61803 L
s
.68189 .61428 m
.68189 .61803 L
s
.71221 .61428 m
.71221 .61803 L
s
.74252 .61428 m
.74252 .61803 L
s
.77284 .61428 m
.77284 .61803 L
s
.83347 .61428 m
.83347 .61803 L
s
.86378 .61428 m
.86378 .61803 L
s
.8941 .61428 m
.8941 .61803 L
s
.92441 .61428 m
.92441 .61803 L
s
.01496 .61428 m
.01496 .61803 L
s
.98504 .61428 m
.98504 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02769 m
1 .02769 L
s
.99375 .12142 m
1 .12142 L
s
.99375 .21515 m
1 .21515 L
s
.99375 .30889 m
1 .30889 L
s
.99375 .40262 m
1 .40262 L
s
.99375 .49635 m
1 .49635 L
s
.99375 .59008 m
1 .59008 L
s
.125 Mabswid
.99625 .04644 m
1 .04644 L
s
.99625 .06518 m
1 .06518 L
s
.99625 .08393 m
1 .08393 L
s
.99625 .10268 m
1 .10268 L
s
.99625 .14017 m
1 .14017 L
s
.99625 .15892 m
1 .15892 L
s
.99625 .17766 m
1 .17766 L
s
.99625 .19641 m
1 .19641 L
s
.99625 .2339 m
1 .2339 L
s
.99625 .25265 m
1 .25265 L
s
.99625 .27139 m
1 .27139 L
s
.99625 .29014 m
1 .29014 L
s
.99625 .32763 m
1 .32763 L
s
.99625 .34638 m
1 .34638 L
s
.99625 .36513 m
1 .36513 L
s
.99625 .38387 m
1 .38387 L
s
.99625 .42136 m
1 .42136 L
s
.99625 .44011 m
1 .44011 L
s
.99625 .45886 m
1 .45886 L
s
.99625 .4776 m
1 .4776 L
s
.99625 .5151 m
1 .5151 L
s
.99625 .53384 m
1 .53384 L
s
.99625 .55259 m
1 .55259 L
s
.99625 .57134 m
1 .57134 L
s
.99625 .00894 m
1 .00894 L
s
.99625 .60883 m
1 .60883 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30889 m
1 .30889 L
s
.5 0 m
.5 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .30889 m
.02608 .32756 L
.02847 .34383 L
.02972 .35042 L
.03089 .35536 L
.03218 .35957 L
.03289 .36143 L
.03355 .36286 L
.03478 .36492 L
.03543 .36572 L
.03612 .36636 L
.03672 .36677 L
.03728 .36705 L
.0376 .36716 L
.03789 .36723 L
.03805 .36726 L
.03814 .36727 L
.03823 .36728 L
.03832 .36729 L
.03839 .36729 L
.03855 .3673 L
.03869 .3673 L
.03883 .3673 L
.03898 .36728 L
.03914 .36727 L
.0393 .36724 L
.03946 .36721 L
.03976 .36714 L
.04029 .36695 L
.04087 .36669 L
.04217 .36585 L
.04338 .36483 L
.04563 .36236 L
.04812 .35897 L
.05297 .3507 L
.05763 .34098 L
.06259 .32885 L
.06737 .3154 L
.07197 .30083 L
.07686 .28362 L
.08157 .26553 L
.08657 .24481 L
.0914 .22357 L
.09603 .20214 L
.10097 .17843 L
.10572 .15492 L
.11029 .13188 L
.11516 .10715 L
.11984 .0835 L
.12482 .05909 L
Mistroke
.12961 .0371 L
.13203 .02694 L
.13309 .02279 L
.13422 .01852 L
.13453 .0174 L
.13486 .01624 L
.13514 .01526 L
.1353 .01472 L
.13545 .60315 L
.1356 .60264 L
.13574 .60217 L
.13601 .60129 L
.1366 .59939 L
.13913 .59233 L
.1403 .58969 L
.14154 .58737 L
.1426 .58578 L
.14376 .58446 L
.14436 .58396 L
.14498 .58356 L
.14552 .58331 L
.14582 .5832 L
.1461 .58312 L
.14626 .58309 L
.14643 .58306 L
.14659 .58304 L
.14674 .58302 L
.14687 .58301 L
.14702 .58301 L
.14717 .58301 L
.14732 .58301 L
.1474 .58301 L
.14749 .58302 L
.14764 .58303 L
.1478 .58305 L
.14794 .58307 L
.14862 .5832 L
.14979 .58352 L
.15041 .58371 L
.15106 .58388 L
.15163 .58401 L
.15178 .58403 L
.15195 .58406 L
.15209 .58408 L
.15225 .58409 L
.1524 .5841 L
.15255 .58411 L
.15268 .58411 L
.15283 .58411 L
.15295 .5841 L
Mistroke
.15307 .5841 L
.15321 .58408 L
.15335 .58406 L
.15349 .58404 L
.15365 .58401 L
.15393 .58394 L
.15426 .58382 L
.15457 .58369 L
.15516 .58335 L
.15572 .58292 L
.15677 .58185 L
.1579 .58027 L
.15904 .57821 L
.1603 .57544 L
.16284 .56833 L
.16772 .55006 L
.17242 .52843 L
.17741 .50272 L
.18222 .47631 L
.18684 .44994 L
.19176 .42126 L
.1965 .39329 L
.20105 .36626 L
.20591 .33754 L
.21057 .31036 L
.21295 .29701 L
.21554 .2833 L
.21674 .27757 L
.21739 .27472 L
.21802 .27231 L
.21859 .2704 L
.2189 .26958 L
.21922 .26888 L
.21935 .26866 L
.21949 .26846 L
.21965 .26831 L
.21979 .26823 L
.21993 .26821 L
.22007 .26827 L
.22019 .26838 L
.22032 .26858 L
.2204 .26875 L
.22048 .26896 L
.22063 .26944 L
.22079 .27014 L
.22096 .27115 L
.22111 .27228 L
.22128 .27381 L
.22157 .27763 L
.22171 .2802 L
Mistroke
.22187 .28367 L
.22201 .28745 L
.22216 .29237 L
.22229 .29781 L
.22244 .30516 L
.2227 .32252 L
.22338 .3937 L
.22354 .41035 L
.22371 .42534 L
.22387 .43656 L
.22402 .44505 L
.22417 .45168 L
.22432 .45742 L
.2246 .46479 L
.22476 .46792 L
.22493 .47055 L
.22509 .47251 L
.22523 .47395 L
.22551 .47598 L
.22566 .47677 L
.22581 .47734 L
.22594 .47774 L
.22606 .47802 L
.2262 .47822 L
.22634 .47835 L
.22649 .47838 L
.22665 .47834 L
.22679 .47823 L
.22693 .47807 L
.22708 .47784 L
.22724 .47753 L
.22757 .47675 L
.2282 .47478 L
.22887 .47219 L
.23009 .4667 L
.23509 .43918 L
.23991 .40993 L
.24455 .38076 L
.24948 .34905 L
.25423 .31799 L
.2588 .28772 L
.26366 .25513 L
.26834 .22349 L
.27332 .18968 L
.27812 .15708 L
.28273 .12586 L
.28763 .09299 L
.29236 .0619 L
.29477 .0463 L
.29604 .03819 L
Mistroke
.29738 .0297 L
.29858 .02214 L
.29891 .02008 L
.29926 .01788 L
.29943 .01681 L
.29959 .01581 L
.29974 .0149 L
.2999 .60286 L
.30004 .60197 L
.30017 .60114 L
.30048 .59925 L
.3011 .59543 L
.30221 .58863 L
.30688 .56081 L
.31185 .5327 L
.31663 .50725 L
.32123 .48451 L
.32613 .46242 L
.33085 .44346 L
.33585 .42603 L
.34068 .41194 L
.34533 .40067 L
.35027 .3905 L
.35502 .38161 L
.3596 .3731 L
.36447 .36356 L
.36915 .35387 L
.37414 .34338 L
.37894 .33382 L
.38355 .32607 L
.38593 .32304 L
.38714 .32184 L
.38778 .32131 L
.38847 .32085 L
.38905 .32053 L
.38935 .3204 L
.38968 .32027 L
.38998 .32019 L
.39026 .32013 L
.39039 .3201 L
.39053 .32009 L
.39067 .32007 L
.3908 .32007 L
.39094 .32006 L
.3911 .32007 L
.39124 .32008 L
.39138 .32009 L
.39153 .32012 L
.3917 .32015 L
.39202 .32024 L
Mistroke
.39234 .32036 L
.39269 .32052 L
.39331 .32092 L
.39396 .32148 L
.39455 .32213 L
.39589 .3241 L
.39708 .32647 L
.39833 .32966 L
.40069 .33775 L
.40291 .3476 L
.4076 .37296 L
.40999 .38568 L
.41259 .39762 L
.41509 .40671 L
.4174 .41302 L
.41965 .41741 L
.42093 .41921 L
.4215 .41987 L
.42213 .42048 L
.42271 .42094 L
.42332 .42135 L
.42366 .42153 L
.42396 .42168 L
.42428 .4218 L
.42457 .42189 L
.42483 .42196 L
.42512 .42201 L
.42526 .42203 L
.4254 .42204 L
.42555 .42205 L
.42564 .42206 L
.42571 .42206 L
.42585 .42206 L
.42598 .42206 L
.42612 .42205 L
.42627 .42204 L
.42641 .42202 L
.42655 .422 L
.4268 .42195 L
.42709 .42188 L
.42736 .4218 L
.42798 .42155 L
.42858 .42124 L
.42923 .42082 L
.43146 .41879 L
.43269 .41729 L
.43402 .41537 L
.43645 .41118 L
.44138 .4002 L
.44612 .387 L
Mistroke
.45068 .37239 L
.45554 .35518 L
.46021 .33735 L
.46518 .31732 L
.46996 .29721 L
.47457 .27728 L
.47947 .25558 L
.48418 .23433 L
.48919 .21147 L
.49402 .18926 L
.49624 .17904 L
.49749 .17324 L
.49867 .16781 L
.49926 .16506 L
.49956 .1637 L
.49983 .16245 L
.49998 .16175 L
.50005 .45587 L
.50014 .45548 L
.50048 .45391 L
.50107 .45117 L
.50361 .43943 L
.50846 .41709 L
.51312 .39572 L
.51808 .37322 L
.52285 .35187 L
.52745 .33172 L
.53234 .31082 L
.53704 .29139 L
.54204 .2717 L
.54686 .25391 L
.5515 .23819 L
.55643 .22339 L
.56118 .21149 L
.56575 .20276 L
.56809 .19951 L
.56941 .19809 L
.57061 .19707 L
.57118 .19667 L
.5718 .19633 L
.57238 .19607 L
.5729 .19589 L
.57322 .19581 L
.57352 .19576 L
.57367 .19574 L
.57384 .19572 L
.57393 .19572 L
.57402 .19571 L
.57411 .19571 L
.57419 .19571 L
Mistroke
.57434 .19571 L
.57449 .19572 L
.57464 .19573 L
.57472 .19574 L
.57481 .19575 L
.57512 .19581 L
.5754 .19587 L
.57597 .19607 L
.57659 .19637 L
.57724 .19678 L
.57784 .19727 L
.57892 .19838 L
.58007 .19992 L
.58131 .20202 L
.58265 .20485 L
.58508 .21159 L
.58748 .22042 L
.59002 .23212 L
.59459 .257 L
.59713 .27036 L
.59946 .28062 L
.60061 .2848 L
.60186 .28863 L
.60304 .29156 L
.60414 .29374 L
.60474 .2947 L
.60539 .29558 L
.60593 .29618 L
.60652 .29672 L
.60716 .29717 L
.60752 .29735 L
.60784 .29749 L
.60815 .29759 L
.60843 .29765 L
.60858 .29767 L
.60866 .29768 L
.60875 .29769 L
.60891 .2977 L
.60905 .29771 L
.6092 .29771 L
.60936 .2977 L
.60951 .29768 L
.60965 .29766 L
.60991 .29761 L
.61019 .29754 L
.61052 .29743 L
.61083 .2973 L
.61141 .297 L
.61247 .29626 L
.61362 .29521 L
Mistroke
.61602 .2923 L
.61856 .2884 L
.62314 .27994 L
.62801 .26988 L
.63271 .26001 L
.63769 .2499 L
.6425 .24074 L
.64712 .2322 L
.65204 .2227 L
.65677 .21225 L
.66133 .20028 L
.66617 .18502 L
.67084 .16781 L
.6758 .14691 L
.68058 .12451 L
.68517 .1011 L
.69007 .07442 L
.69477 .04722 L
.69718 .03285 L
.69844 .02516 L
.69913 .02092 L
.69947 .01883 L
.69978 .01692 L
.69992 .01605 L
.70007 .01509 L
.70022 .60313 L
.70035 .60229 L
.70097 .59844 L
.70229 .5902 L
.7046 .57551 L
.70932 .54488 L
.71435 .51159 L
.71918 .47902 L
.72384 .44742 L
.72879 .41374 L
.73356 .3814 L
.73814 .3505 L
.74302 .31792 L
.74772 .28695 L
.75272 .25452 L
.75753 .22387 L
.76216 .19513 L
.76708 .16607 L
.76953 .15298 L
.77072 .1473 L
.77125 .14508 L
.77182 .14292 L
.77234 .14128 L
.77262 .14054 L
.77289 .13999 L
Mistroke
.77304 .13975 L
.7732 .13956 L
.77334 .13944 L
.77347 .13939 L
.7736 .1394 L
.77374 .13949 L
.77388 .13966 L
.77402 .13992 L
.77416 .14033 L
.77432 .14093 L
.77447 .14168 L
.77461 .14256 L
.77488 .14484 L
.77501 .14637 L
.77516 .14843 L
.77546 .1543 L
.77563 .15889 L
.77579 .16422 L
.77608 .17788 L
.77622 .18722 L
.77638 .1998 L
.77696 .26248 L
.77727 .29255 L
.77742 .30418 L
.77759 .31442 L
.77774 .3215 L
.7779 .32758 L
.77805 .33208 L
.77819 .33556 L
.77833 .33836 L
.77848 .34086 L
.77874 .34414 L
.77892 .34573 L
.77907 .34685 L
.77926 .34784 L
.77943 .34853 L
.77959 .34899 L
.77973 .34928 L
.77981 .34939 L
.77989 .34947 L
.77998 .34953 L
.78006 .34956 L
.78022 .34954 L
.78037 .34945 L
.7805 .34932 L
.78064 .34912 L
.78097 .3485 L
.78127 .34776 L
.78243 .34377 L
.78352 .33903 L
Mistroke
.786 .32647 L
.79067 .30025 L
.79564 .27114 L
.80042 .24279 L
.80501 .21552 L
.80991 .18673 L
.81462 .15944 L
.81962 .13121 L
.82445 .10524 L
.82909 .08207 L
.83403 .06057 L
.83648 .05163 L
.83878 .04467 L
.84098 .0395 L
.84222 .03731 L
.84335 .03578 L
.84393 .03516 L
.84454 .03463 L
.84512 .03425 L
.84565 .03399 L
.84597 .03387 L
.84627 .03378 L
.84644 .03375 L
.84659 .03372 L
.84676 .03369 L
.84684 .03368 L
.84694 .03368 L
.84709 .03367 L
.84724 .03366 L
.84739 .03366 L
.84752 .03367 L
.84767 .03367 L
.84783 .03369 L
.84799 .03371 L
.84815 .03373 L
.84875 .03384 L
.8494 .03401 L
.85059 .03436 L
.85115 .03452 L
.85146 .03459 L
.85175 .03465 L
.85202 .0347 L
.85216 .03472 L
.85231 .03473 L
.85244 .03475 L
.85258 .03476 L
.8527 .03476 L
.85282 .03477 L
.85297 .03476 L
.85305 .03476 L
Mistroke
.85314 .03476 L
.85329 .03475 L
.85343 .03473 L
.85359 .03471 L
.85374 .03468 L
.85408 .0346 L
.85436 .03451 L
.85466 .03439 L
.85528 .03406 L
.85584 .03366 L
.85643 .03312 L
.85751 .03185 L
.85875 .02991 L
.86009 .02726 L
.86124 .02451 L
.86252 .02104 L
.86311 .01927 L
.86375 .01726 L
.86406 .01625 L
.86422 .01575 L
.86436 .01528 L
.86449 .01485 L
.86462 .60332 L
.86477 .6028 L
.86491 .60233 L
.86745 .5929 L
.87228 .57223 L
.87694 .55021 L
.88189 .5256 L
.88665 .50142 L
.89124 .47815 L
.89612 .45369 L
.90081 .43068 L
.90581 .40702 L
.91062 .3852 L
.91524 .36528 L
.92017 .34541 L
.92491 .32775 L
.92946 .31224 L
.93432 .29742 L
.93899 .28486 L
.94395 .27331 L
.94873 .26395 L
.95334 .25674 L
.9557 .25387 L
.95702 .25258 L
.95823 .25163 L
.95882 .25125 L
.95947 .25092 L
.96012 .25067 L
Mistroke
.96029 .25062 L
.96048 .25058 L
.96065 .25054 L
.96081 .25051 L
.96096 .25049 L
.96104 .25049 L
.96112 .25048 L
.96121 .25048 L
.9613 .25047 L
.96138 .25047 L
.96146 .25047 L
.9616 .25048 L
.96176 .25049 L
.96184 .2505 L
.96193 .25051 L
.96208 .25054 L
.96239 .25061 L
.96269 .25071 L
.96324 .25097 L
.9638 .25135 L
.96441 .25189 L
.96505 .25263 L
.96565 .25348 L
.96672 .25547 L
.96787 .25835 L
.96909 .26237 L
.97042 .26806 L
.97285 .28231 L
.97619 .30889 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 148.312},
  ImageCacheValid->False]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Compute inverse DTFT ",
  Cell[BoxData[
      \(TraditionalForm\`y[
          n] = \[Integral]\_\(-\[Pi]\)\%\[Pi]\( Y(
              e\^j\[Theta])\) \(e\^jn\[Theta]\) \[DifferentialD]\[Theta]\)]]
}], "Subsubsection"],

Cell[BoxData[
    \(\(yn = \ 
        1/\((2  \[Pi])\)\ \(\[Integral]\_\(-\[Pi]\)\%\[Pi] 
              Y\[Theta]\ Exp[
                I\ n\ \[Theta]] \[DifferentialD]\[Theta]\);\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot resulting time-domain sequence y[n]", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(yn1\  = \ 
      Table[{i, Limit[yn, n \[Rule] i]}, \ {i, 0, \ 
          Length[xn] + Length[hn] - 2}]; 
    g3\  = \ DiscreteListPlot[yn1, \ Red, \ Frame \[Rule] True, 
        PlotRange \[Rule] All, \ Axes \[Rule] {True, False}];\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0529101 0.305869 0.00157381 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.15608 -0.0125 -9 -9 ]
[.15608 -0.0125 9 0 ]
[.28836 -0.0125 -3 -9 ]
[.28836 -0.0125 3 0 ]
[.42063 -0.0125 -9 -9 ]
[.42063 -0.0125 9 0 ]
[.55291 -0.0125 -6 -9 ]
[.55291 -0.0125 6 0 ]
[.68519 -0.0125 -12 -9 ]
[.68519 -0.0125 12 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.94974 -0.0125 -12 -9 ]
[.94974 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0698 -24 -4.5 ]
[-0.0125 .0698 0 4.5 ]
[-0.0125 .14849 -24 -4.5 ]
[-0.0125 .14849 0 4.5 ]
[-0.0125 .22718 -18 -4.5 ]
[-0.0125 .22718 0 4.5 ]
[-0.0125 .30587 -6 -4.5 ]
[-0.0125 .30587 0 4.5 ]
[-0.0125 .38456 -12 -4.5 ]
[-0.0125 .38456 0 4.5 ]
[-0.0125 .46325 -18 -4.5 ]
[-0.0125 .46325 0 4.5 ]
[-0.0125 .54194 -18 -4.5 ]
[-0.0125 .54194 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.15608 0 m
.15608 .00625 L
s
[(2.5)] .15608 -0.0125 0 1 Mshowa
.28836 0 m
.28836 .00625 L
s
[(5)] .28836 -0.0125 0 1 Mshowa
.42063 0 m
.42063 .00625 L
s
[(7.5)] .42063 -0.0125 0 1 Mshowa
.55291 0 m
.55291 .00625 L
s
[(10)] .55291 -0.0125 0 1 Mshowa
.68519 0 m
.68519 .00625 L
s
[(12.5)] .68519 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(15)] .81746 -0.0125 0 1 Mshowa
.94974 0 m
.94974 .00625 L
s
[(17.5)] .94974 -0.0125 0 1 Mshowa
.125 Mabswid
.05026 0 m
.05026 .00375 L
s
.07672 0 m
.07672 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.12963 0 m
.12963 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.20899 0 m
.20899 .00375 L
s
.23545 0 m
.23545 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.31481 0 m
.31481 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.36772 0 m
.36772 .00375 L
s
.39418 0 m
.39418 .00375 L
s
.44709 0 m
.44709 .00375 L
s
.47354 0 m
.47354 .00375 L
s
.5 0 m
.5 .00375 L
s
.52646 0 m
.52646 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.60582 0 m
.60582 .00375 L
s
.63228 0 m
.63228 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.71164 0 m
.71164 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.76455 0 m
.76455 .00375 L
s
.79101 0 m
.79101 .00375 L
s
.84392 0 m
.84392 .00375 L
s
.87037 0 m
.87037 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.92328 0 m
.92328 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0698 m
.00625 .0698 L
s
[(-150)] -0.0125 .0698 1 0 Mshowa
0 .14849 m
.00625 .14849 L
s
[(-100)] -0.0125 .14849 1 0 Mshowa
0 .22718 m
.00625 .22718 L
s
[(-50)] -0.0125 .22718 1 0 Mshowa
0 .30587 m
.00625 .30587 L
s
[(0)] -0.0125 .30587 1 0 Mshowa
0 .38456 m
.00625 .38456 L
s
[(50)] -0.0125 .38456 1 0 Mshowa
0 .46325 m
.00625 .46325 L
s
[(100)] -0.0125 .46325 1 0 Mshowa
0 .54194 m
.00625 .54194 L
s
[(150)] -0.0125 .54194 1 0 Mshowa
.125 Mabswid
0 .08554 m
.00375 .08554 L
s
0 .10127 m
.00375 .10127 L
s
0 .11701 m
.00375 .11701 L
s
0 .13275 m
.00375 .13275 L
s
0 .16423 m
.00375 .16423 L
s
0 .17996 m
.00375 .17996 L
s
0 .1957 m
.00375 .1957 L
s
0 .21144 m
.00375 .21144 L
s
0 .24292 m
.00375 .24292 L
s
0 .25866 m
.00375 .25866 L
s
0 .27439 m
.00375 .27439 L
s
0 .29013 m
.00375 .29013 L
s
0 .32161 m
.00375 .32161 L
s
0 .33735 m
.00375 .33735 L
s
0 .35308 m
.00375 .35308 L
s
0 .36882 m
.00375 .36882 L
s
0 .4003 m
.00375 .4003 L
s
0 .41604 m
.00375 .41604 L
s
0 .43177 m
.00375 .43177 L
s
0 .44751 m
.00375 .44751 L
s
0 .47899 m
.00375 .47899 L
s
0 .49473 m
.00375 .49473 L
s
0 .51046 m
.00375 .51046 L
s
0 .5262 m
.00375 .5262 L
s
0 .55768 m
.00375 .55768 L
s
0 .57342 m
.00375 .57342 L
s
0 .58915 m
.00375 .58915 L
s
0 .60489 m
.00375 .60489 L
s
0 .05406 m
.00375 .05406 L
s
0 .03832 m
.00375 .03832 L
s
0 .02258 m
.00375 .02258 L
s
0 .00685 m
.00375 .00685 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.15608 .61178 m
.15608 .61803 L
s
.28836 .61178 m
.28836 .61803 L
s
.42063 .61178 m
.42063 .61803 L
s
.55291 .61178 m
.55291 .61803 L
s
.68519 .61178 m
.68519 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.94974 .61178 m
.94974 .61803 L
s
.125 Mabswid
.05026 .61428 m
.05026 .61803 L
s
.07672 .61428 m
.07672 .61803 L
s
.10317 .61428 m
.10317 .61803 L
s
.12963 .61428 m
.12963 .61803 L
s
.18254 .61428 m
.18254 .61803 L
s
.20899 .61428 m
.20899 .61803 L
s
.23545 .61428 m
.23545 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.31481 .61428 m
.31481 .61803 L
s
.34127 .61428 m
.34127 .61803 L
s
.36772 .61428 m
.36772 .61803 L
s
.39418 .61428 m
.39418 .61803 L
s
.44709 .61428 m
.44709 .61803 L
s
.47354 .61428 m
.47354 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.52646 .61428 m
.52646 .61803 L
s
.57937 .61428 m
.57937 .61803 L
s
.60582 .61428 m
.60582 .61803 L
s
.63228 .61428 m
.63228 .61803 L
s
.65873 .61428 m
.65873 .61803 L
s
.71164 .61428 m
.71164 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.76455 .61428 m
.76455 .61803 L
s
.79101 .61428 m
.79101 .61803 L
s
.84392 .61428 m
.84392 .61803 L
s
.87037 .61428 m
.87037 .61803 L
s
.89683 .61428 m
.89683 .61803 L
s
.92328 .61428 m
.92328 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0698 m
1 .0698 L
s
.99375 .14849 m
1 .14849 L
s
.99375 .22718 m
1 .22718 L
s
.99375 .30587 m
1 .30587 L
s
.99375 .38456 m
1 .38456 L
s
.99375 .46325 m
1 .46325 L
s
.99375 .54194 m
1 .54194 L
s
.125 Mabswid
.99625 .08554 m
1 .08554 L
s
.99625 .10127 m
1 .10127 L
s
.99625 .11701 m
1 .11701 L
s
.99625 .13275 m
1 .13275 L
s
.99625 .16423 m
1 .16423 L
s
.99625 .17996 m
1 .17996 L
s
.99625 .1957 m
1 .1957 L
s
.99625 .21144 m
1 .21144 L
s
.99625 .24292 m
1 .24292 L
s
.99625 .25866 m
1 .25866 L
s
.99625 .27439 m
1 .27439 L
s
.99625 .29013 m
1 .29013 L
s
.99625 .32161 m
1 .32161 L
s
.99625 .33735 m
1 .33735 L
s
.99625 .35308 m
1 .35308 L
s
.99625 .36882 m
1 .36882 L
s
.99625 .4003 m
1 .4003 L
s
.99625 .41604 m
1 .41604 L
s
.99625 .43177 m
1 .43177 L
s
.99625 .44751 m
1 .44751 L
s
.99625 .47899 m
1 .47899 L
s
.99625 .49473 m
1 .49473 L
s
.99625 .51046 m
1 .51046 L
s
.99625 .5262 m
1 .5262 L
s
.99625 .55768 m
1 .55768 L
s
.99625 .57342 m
1 .57342 L
s
.99625 .58915 m
1 .58915 L
s
.99625 .60489 m
1 .60489 L
s
.99625 .05406 m
1 .05406 L
s
.99625 .03832 m
1 .03832 L
s
.99625 .02258 m
1 .02258 L
s
.99625 .00685 m
1 .00685 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30587 m
1 .30587 L
s
1 0 0 r
.5 Mabswid
.02381 .30587 m
.02381 .40659 L
s
.07672 .30587 m
.07672 .40659 L
s
.12963 .30587 m
.12963 .46797 L
s
.18254 .30587 m
.18254 .33735 L
s
.23545 .30587 m
.23545 .41446 L
s
.28836 .30587 m
.28836 .06508 L
s
.34127 .30587 m
.34127 .26023 L
s
.39418 .30587 m
.39418 .60332 L
s
.44709 .30587 m
.44709 .3279 L
s
.5 .30587 m
.5 .22875 L
s
.55291 .30587 m
.55291 .01472 L
s
.60582 .30587 m
.60582 .29013 L
s
.65873 .30587 m
.65873 .4239 L
s
.71164 .30587 m
.71164 .29171 L
s
.76455 .30587 m
.76455 .12173 L
s
.81746 .30587 m
.81746 .19728 L
s
.87037 .30587 m
.87037 .44122 L
s
.92328 .30587 m
.92328 .29485 L
s
.97619 .30587 m
.97619 .21774 L
s
.015 w
.02381 .40659 Mdot
.07672 .40659 Mdot
.12963 .46797 Mdot
.18254 .33735 Mdot
.23545 .41446 Mdot
.28836 .06508 Mdot
.34127 .26023 Mdot
.39418 .60332 Mdot
.44709 .3279 Mdot
.5 .22875 Mdot
.55291 .01472 Mdot
.60582 .29013 Mdot
.65873 .4239 Mdot
.71164 .29171 Mdot
.76455 .12173 Mdot
.81746 .19728 Mdot
.87037 .44122 Mdot
.92328 .29485 Mdot
.97619 .21774 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Time-domain solution", "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`y[n] = x[n]\ *\ h[n]\)]],
  " (convolution)"
}], "Subsubsection"],

Cell[BoxData[
    \(\(yn\  = 
        ListConvolve[Last\  /@ \ hn, Last\  /@ \ xn, {1, \(-1\)}, 
          0];\)\)], "Input",
  Background->RGBColor[0, 1, 0]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot resulting time-domain sequence y[n]", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(yn2\  = \ {Table[n, \ {n, \ 0, \ Length[yn] - 1}], \ yn}\  // \ 
        Transpose; 
    g6\  = \ DiscreteListPlot[yn2, \ Green, \ Frame \[Rule] True, 
        PlotRange \[Rule] All, \ Axes \[Rule] {True, False}];\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0529101 0.305869 0.00157381 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.15608 -0.0125 -9 -9 ]
[.15608 -0.0125 9 0 ]
[.28836 -0.0125 -3 -9 ]
[.28836 -0.0125 3 0 ]
[.42063 -0.0125 -9 -9 ]
[.42063 -0.0125 9 0 ]
[.55291 -0.0125 -6 -9 ]
[.55291 -0.0125 6 0 ]
[.68519 -0.0125 -12 -9 ]
[.68519 -0.0125 12 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.94974 -0.0125 -12 -9 ]
[.94974 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0698 -24 -4.5 ]
[-0.0125 .0698 0 4.5 ]
[-0.0125 .14849 -24 -4.5 ]
[-0.0125 .14849 0 4.5 ]
[-0.0125 .22718 -18 -4.5 ]
[-0.0125 .22718 0 4.5 ]
[-0.0125 .30587 -6 -4.5 ]
[-0.0125 .30587 0 4.5 ]
[-0.0125 .38456 -12 -4.5 ]
[-0.0125 .38456 0 4.5 ]
[-0.0125 .46325 -18 -4.5 ]
[-0.0125 .46325 0 4.5 ]
[-0.0125 .54194 -18 -4.5 ]
[-0.0125 .54194 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.15608 0 m
.15608 .00625 L
s
[(2.5)] .15608 -0.0125 0 1 Mshowa
.28836 0 m
.28836 .00625 L
s
[(5)] .28836 -0.0125 0 1 Mshowa
.42063 0 m
.42063 .00625 L
s
[(7.5)] .42063 -0.0125 0 1 Mshowa
.55291 0 m
.55291 .00625 L
s
[(10)] .55291 -0.0125 0 1 Mshowa
.68519 0 m
.68519 .00625 L
s
[(12.5)] .68519 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(15)] .81746 -0.0125 0 1 Mshowa
.94974 0 m
.94974 .00625 L
s
[(17.5)] .94974 -0.0125 0 1 Mshowa
.125 Mabswid
.05026 0 m
.05026 .00375 L
s
.07672 0 m
.07672 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.12963 0 m
.12963 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.20899 0 m
.20899 .00375 L
s
.23545 0 m
.23545 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.31481 0 m
.31481 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.36772 0 m
.36772 .00375 L
s
.39418 0 m
.39418 .00375 L
s
.44709 0 m
.44709 .00375 L
s
.47354 0 m
.47354 .00375 L
s
.5 0 m
.5 .00375 L
s
.52646 0 m
.52646 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.60582 0 m
.60582 .00375 L
s
.63228 0 m
.63228 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.71164 0 m
.71164 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.76455 0 m
.76455 .00375 L
s
.79101 0 m
.79101 .00375 L
s
.84392 0 m
.84392 .00375 L
s
.87037 0 m
.87037 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.92328 0 m
.92328 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0698 m
.00625 .0698 L
s
[(-150)] -0.0125 .0698 1 0 Mshowa
0 .14849 m
.00625 .14849 L
s
[(-100)] -0.0125 .14849 1 0 Mshowa
0 .22718 m
.00625 .22718 L
s
[(-50)] -0.0125 .22718 1 0 Mshowa
0 .30587 m
.00625 .30587 L
s
[(0)] -0.0125 .30587 1 0 Mshowa
0 .38456 m
.00625 .38456 L
s
[(50)] -0.0125 .38456 1 0 Mshowa
0 .46325 m
.00625 .46325 L
s
[(100)] -0.0125 .46325 1 0 Mshowa
0 .54194 m
.00625 .54194 L
s
[(150)] -0.0125 .54194 1 0 Mshowa
.125 Mabswid
0 .08554 m
.00375 .08554 L
s
0 .10127 m
.00375 .10127 L
s
0 .11701 m
.00375 .11701 L
s
0 .13275 m
.00375 .13275 L
s
0 .16423 m
.00375 .16423 L
s
0 .17996 m
.00375 .17996 L
s
0 .1957 m
.00375 .1957 L
s
0 .21144 m
.00375 .21144 L
s
0 .24292 m
.00375 .24292 L
s
0 .25866 m
.00375 .25866 L
s
0 .27439 m
.00375 .27439 L
s
0 .29013 m
.00375 .29013 L
s
0 .32161 m
.00375 .32161 L
s
0 .33735 m
.00375 .33735 L
s
0 .35308 m
.00375 .35308 L
s
0 .36882 m
.00375 .36882 L
s
0 .4003 m
.00375 .4003 L
s
0 .41604 m
.00375 .41604 L
s
0 .43177 m
.00375 .43177 L
s
0 .44751 m
.00375 .44751 L
s
0 .47899 m
.00375 .47899 L
s
0 .49473 m
.00375 .49473 L
s
0 .51046 m
.00375 .51046 L
s
0 .5262 m
.00375 .5262 L
s
0 .55768 m
.00375 .55768 L
s
0 .57342 m
.00375 .57342 L
s
0 .58915 m
.00375 .58915 L
s
0 .60489 m
.00375 .60489 L
s
0 .05406 m
.00375 .05406 L
s
0 .03832 m
.00375 .03832 L
s
0 .02258 m
.00375 .02258 L
s
0 .00685 m
.00375 .00685 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.15608 .61178 m
.15608 .61803 L
s
.28836 .61178 m
.28836 .61803 L
s
.42063 .61178 m
.42063 .61803 L
s
.55291 .61178 m
.55291 .61803 L
s
.68519 .61178 m
.68519 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.94974 .61178 m
.94974 .61803 L
s
.125 Mabswid
.05026 .61428 m
.05026 .61803 L
s
.07672 .61428 m
.07672 .61803 L
s
.10317 .61428 m
.10317 .61803 L
s
.12963 .61428 m
.12963 .61803 L
s
.18254 .61428 m
.18254 .61803 L
s
.20899 .61428 m
.20899 .61803 L
s
.23545 .61428 m
.23545 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.31481 .61428 m
.31481 .61803 L
s
.34127 .61428 m
.34127 .61803 L
s
.36772 .61428 m
.36772 .61803 L
s
.39418 .61428 m
.39418 .61803 L
s
.44709 .61428 m
.44709 .61803 L
s
.47354 .61428 m
.47354 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.52646 .61428 m
.52646 .61803 L
s
.57937 .61428 m
.57937 .61803 L
s
.60582 .61428 m
.60582 .61803 L
s
.63228 .61428 m
.63228 .61803 L
s
.65873 .61428 m
.65873 .61803 L
s
.71164 .61428 m
.71164 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.76455 .61428 m
.76455 .61803 L
s
.79101 .61428 m
.79101 .61803 L
s
.84392 .61428 m
.84392 .61803 L
s
.87037 .61428 m
.87037 .61803 L
s
.89683 .61428 m
.89683 .61803 L
s
.92328 .61428 m
.92328 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0698 m
1 .0698 L
s
.99375 .14849 m
1 .14849 L
s
.99375 .22718 m
1 .22718 L
s
.99375 .30587 m
1 .30587 L
s
.99375 .38456 m
1 .38456 L
s
.99375 .46325 m
1 .46325 L
s
.99375 .54194 m
1 .54194 L
s
.125 Mabswid
.99625 .08554 m
1 .08554 L
s
.99625 .10127 m
1 .10127 L
s
.99625 .11701 m
1 .11701 L
s
.99625 .13275 m
1 .13275 L
s
.99625 .16423 m
1 .16423 L
s
.99625 .17996 m
1 .17996 L
s
.99625 .1957 m
1 .1957 L
s
.99625 .21144 m
1 .21144 L
s
.99625 .24292 m
1 .24292 L
s
.99625 .25866 m
1 .25866 L
s
.99625 .27439 m
1 .27439 L
s
.99625 .29013 m
1 .29013 L
s
.99625 .32161 m
1 .32161 L
s
.99625 .33735 m
1 .33735 L
s
.99625 .35308 m
1 .35308 L
s
.99625 .36882 m
1 .36882 L
s
.99625 .4003 m
1 .4003 L
s
.99625 .41604 m
1 .41604 L
s
.99625 .43177 m
1 .43177 L
s
.99625 .44751 m
1 .44751 L
s
.99625 .47899 m
1 .47899 L
s
.99625 .49473 m
1 .49473 L
s
.99625 .51046 m
1 .51046 L
s
.99625 .5262 m
1 .5262 L
s
.99625 .55768 m
1 .55768 L
s
.99625 .57342 m
1 .57342 L
s
.99625 .58915 m
1 .58915 L
s
.99625 .60489 m
1 .60489 L
s
.99625 .05406 m
1 .05406 L
s
.99625 .03832 m
1 .03832 L
s
.99625 .02258 m
1 .02258 L
s
.99625 .00685 m
1 .00685 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30587 m
1 .30587 L
s
0 1 0 r
.5 Mabswid
.02381 .30587 m
.02381 .40659 L
s
.07672 .30587 m
.07672 .40659 L
s
.12963 .30587 m
.12963 .46797 L
s
.18254 .30587 m
.18254 .33735 L
s
.23545 .30587 m
.23545 .41446 L
s
.28836 .30587 m
.28836 .06508 L
s
.34127 .30587 m
.34127 .26023 L
s
.39418 .30587 m
.39418 .60332 L
s
.44709 .30587 m
.44709 .3279 L
s
.5 .30587 m
.5 .22875 L
s
.55291 .30587 m
.55291 .01472 L
s
.60582 .30587 m
.60582 .29013 L
s
.65873 .30587 m
.65873 .4239 L
s
.71164 .30587 m
.71164 .29171 L
s
.76455 .30587 m
.76455 .12173 L
s
.81746 .30587 m
.81746 .19728 L
s
.87037 .30587 m
.87037 .44122 L
s
.92328 .30587 m
.92328 .29485 L
s
.97619 .30587 m
.97619 .21774 L
s
.015 w
.02381 .40659 Mdot
.07672 .40659 Mdot
.12963 .46797 Mdot
.18254 .33735 Mdot
.23545 .41446 Mdot
.28836 .06508 Mdot
.34127 .26023 Mdot
.39418 .60332 Mdot
.44709 .3279 Mdot
.5 .22875 Mdot
.55291 .01472 Mdot
.60582 .29013 Mdot
.65873 .4239 Mdot
.71164 .29171 Mdot
.76455 .12173 Mdot
.81746 .19728 Mdot
.87037 .44122 Mdot
.92328 .29485 Mdot
.97619 .21774 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Compute ",
  Cell[BoxData[
      \(TraditionalForm\`\(Y(e\^j\[Theta])\)\ from\ \ y[n]\)]]
}], "Subsubsection"],

Cell[BoxData[
    \(\(Y\[Theta]\  = \ DTFT[yn2, \[Theta]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot frequency representation", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(g4 = 
        Plot[Abs[Y\[Theta]], {\[Theta], \(-\[Pi]\), \[Pi]}, \ 
          PlotStyle \[Rule] {Green}, \ PlotRange \[Rule] All, 
          PlotPoints \[Rule] 200, \ 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(g5 = 
        Plot[Arg[Y\[Theta]], {\[Theta], \(-\[Pi]\), \[Pi]}, \ 
          PlotStyle \[Rule] {Green}, \ PlotRange \[Rule] All, 
          PlotPoints \[Rule] 200, \ 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(Show[GraphicsArray[{{g4, g5}}], ImageSize \[Rule] 504];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2943 
%%ImageSize: 504 148.328 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00700719 0.47619 [
[ 0 0 0 0 ]
[ 1 .2943 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2943 L
0 .2943 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00700719 0.477324 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.151576 0.014388 0.000733898 [
[.04527 -0.0125 -6 -9 ]
[.04527 -0.0125 6 0 ]
[.19685 -0.0125 -6 -9 ]
[.19685 -0.0125 6 0 ]
[.34842 -0.0125 -6 -9 ]
[.34842 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65158 -0.0125 -3 -9 ]
[.65158 -0.0125 3 0 ]
[.80315 -0.0125 -3 -9 ]
[.80315 -0.0125 3 0 ]
[.95473 -0.0125 -3 -9 ]
[.95473 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01439 -6 -4.5 ]
[-0.0125 .01439 0 4.5 ]
[-0.0125 .16117 -18 -4.5 ]
[-0.0125 .16117 0 4.5 ]
[-0.0125 .30795 -18 -4.5 ]
[-0.0125 .30795 0 4.5 ]
[-0.0125 .45473 -18 -4.5 ]
[-0.0125 .45473 0 4.5 ]
[-0.0125 .60151 -18 -4.5 ]
[-0.0125 .60151 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 0 m
.04527 .00625 L
s
[(-3)] .04527 -0.0125 0 1 Mshowa
.19685 0 m
.19685 .00625 L
s
[(-2)] .19685 -0.0125 0 1 Mshowa
.34842 0 m
.34842 .00625 L
s
[(-1)] .34842 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.65158 0 m
.65158 .00625 L
s
[(1)] .65158 -0.0125 0 1 Mshowa
.80315 0 m
.80315 .00625 L
s
[(2)] .80315 -0.0125 0 1 Mshowa
.95473 0 m
.95473 .00625 L
s
[(3)] .95473 -0.0125 0 1 Mshowa
.125 Mabswid
.07559 0 m
.07559 .00375 L
s
.1059 0 m
.1059 .00375 L
s
.13622 0 m
.13622 .00375 L
s
.16653 0 m
.16653 .00375 L
s
.22716 0 m
.22716 .00375 L
s
.25748 0 m
.25748 .00375 L
s
.28779 0 m
.28779 .00375 L
s
.31811 0 m
.31811 .00375 L
s
.37874 0 m
.37874 .00375 L
s
.40905 0 m
.40905 .00375 L
s
.43937 0 m
.43937 .00375 L
s
.46968 0 m
.46968 .00375 L
s
.53032 0 m
.53032 .00375 L
s
.56063 0 m
.56063 .00375 L
s
.59095 0 m
.59095 .00375 L
s
.62126 0 m
.62126 .00375 L
s
.68189 0 m
.68189 .00375 L
s
.71221 0 m
.71221 .00375 L
s
.74252 0 m
.74252 .00375 L
s
.77284 0 m
.77284 .00375 L
s
.83347 0 m
.83347 .00375 L
s
.86378 0 m
.86378 .00375 L
s
.8941 0 m
.8941 .00375 L
s
.92441 0 m
.92441 .00375 L
s
.01496 0 m
.01496 .00375 L
s
.98504 0 m
.98504 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01439 m
.00625 .01439 L
s
[(0)] -0.0125 .01439 1 0 Mshowa
0 .16117 m
.00625 .16117 L
s
[(200)] -0.0125 .16117 1 0 Mshowa
0 .30795 m
.00625 .30795 L
s
[(400)] -0.0125 .30795 1 0 Mshowa
0 .45473 m
.00625 .45473 L
s
[(600)] -0.0125 .45473 1 0 Mshowa
0 .60151 m
.00625 .60151 L
s
[(800)] -0.0125 .60151 1 0 Mshowa
.125 Mabswid
0 .05108 m
.00375 .05108 L
s
0 .08778 m
.00375 .08778 L
s
0 .12447 m
.00375 .12447 L
s
0 .19786 m
.00375 .19786 L
s
0 .23456 m
.00375 .23456 L
s
0 .27125 m
.00375 .27125 L
s
0 .34464 m
.00375 .34464 L
s
0 .38134 m
.00375 .38134 L
s
0 .41803 m
.00375 .41803 L
s
0 .49142 m
.00375 .49142 L
s
0 .52812 m
.00375 .52812 L
s
0 .56481 m
.00375 .56481 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.04527 .61178 m
.04527 .61803 L
s
.19685 .61178 m
.19685 .61803 L
s
.34842 .61178 m
.34842 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65158 .61178 m
.65158 .61803 L
s
.80315 .61178 m
.80315 .61803 L
s
.95473 .61178 m
.95473 .61803 L
s
.125 Mabswid
.07559 .61428 m
.07559 .61803 L
s
.1059 .61428 m
.1059 .61803 L
s
.13622 .61428 m
.13622 .61803 L
s
.16653 .61428 m
.16653 .61803 L
s
.22716 .61428 m
.22716 .61803 L
s
.25748 .61428 m
.25748 .61803 L
s
.28779 .61428 m
.28779 .61803 L
s
.31811 .61428 m
.31811 .61803 L
s
.37874 .61428 m
.37874 .61803 L
s
.40905 .61428 m
.40905 .61803 L
s
.43937 .61428 m
.43937 .61803 L
s
.46968 .61428 m
.46968 .61803 L
s
.53032 .61428 m
.53032 .61803 L
s
.56063 .61428 m
.56063 .61803 L
s
.59095 .61428 m
.59095 .61803 L
s
.62126 .61428 m
.62126 .61803 L
s
.68189 .61428 m
.68189 .61803 L
s
.71221 .61428 m
.71221 .61803 L
s
.74252 .61428 m
.74252 .61803 L
s
.77284 .61428 m
.77284 .61803 L
s
.83347 .61428 m
.83347 .61803 L
s
.86378 .61428 m
.86378 .61803 L
s
.8941 .61428 m
.8941 .61803 L
s
.92441 .61428 m
.92441 .61803 L
s
.01496 .61428 m
.01496 .61803 L
s
.98504 .61428 m
.98504 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01439 m
1 .01439 L
s
.99375 .16117 m
1 .16117 L
s
.99375 .30795 m
1 .30795 L
s
.99375 .45473 m
1 .45473 L
s
.99375 .60151 m
1 .60151 L
s
.125 Mabswid
.99625 .05108 m
1 .05108 L
s
.99625 .08778 m
1 .08778 L
s
.99625 .12447 m
1 .12447 L
s
.99625 .19786 m
1 .19786 L
s
.99625 .23456 m
1 .23456 L
s
.99625 .27125 m
1 .27125 L
s
.99625 .34464 m
1 .34464 L
s
.99625 .38134 m
1 .38134 L
s
.99625 .41803 m
1 .41803 L
s
.99625 .49142 m
1 .49142 L
s
.99625 .52812 m
1 .52812 L
s
.99625 .56481 m
1 .56481 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 1 0 r
.5 Mabswid
.02381 .04962 m
.02395 .04962 L
.02408 .04963 L
.02423 .04966 L
.02437 .04969 L
.02462 .04978 L
.02489 .04991 L
.02519 .0501 L
.02551 .05034 L
.02608 .0509 L
.02722 .05244 L
.02847 .05474 L
.03109 .06111 L
.03355 .0684 L
.03823 .0842 L
.0432 .10244 L
.04799 .12095 L
.05259 .1397 L
.0575 .16088 L
.06221 .18253 L
.06723 .20661 L
.07206 .2302 L
.07671 .25235 L
.08166 .27413 L
.08642 .29214 L
.091 .30563 L
.09335 .31082 L
.09587 .31492 L
.0971 .31633 L
.09775 .31693 L
.09843 .31743 L
.09903 .31778 L
.09935 .31792 L
.0997 .31804 L
.10001 .31813 L
.10015 .31816 L
.1003 .31818 L
.10044 .3182 L
.10057 .31822 L
.10071 .31822 L
.10086 .31823 L
.10101 .31822 L
.10109 .31822 L
.10117 .31821 L
.10133 .3182 L
.10142 .31819 L
.1015 .31817 L
.10181 .31811 L
.1021 .31802 L
.10243 .3179 L
Mistroke
.10274 .31776 L
.10344 .31734 L
.10405 .31685 L
.10461 .31633 L
.10587 .31484 L
.10819 .31097 L
.1107 .30518 L
.11566 .28918 L
.12042 .26865 L
.12501 .2451 L
.12989 .21732 L
.13459 .18972 L
.13959 .1623 L
.14209 .15061 L
.1444 .14183 L
.14556 .13835 L
.14664 .13573 L
.14724 .13459 L
.14778 .13373 L
.14838 .13298 L
.14869 .13268 L
.14903 .13243 L
.14918 .13234 L
.14934 .13226 L
.14948 .1322 L
.14963 .13215 L
.14977 .13212 L
.14992 .1321 L
.15005 .1321 L
.15018 .1321 L
.15034 .13213 L
.15049 .13216 L
.15063 .13221 L
.15077 .13227 L
.15111 .13246 L
.15141 .1327 L
.15192 .13323 L
.15249 .13399 L
.15363 .13612 L
.15484 .13919 L
.15596 .14266 L
.15847 .15242 L
.16325 .17588 L
.16784 .20082 L
.17273 .22628 L
.17743 .24711 L
.17983 .25565 L
.1811 .25947 L
.18243 .26296 L
.18363 .26556 L
Mistroke
.18494 .26784 L
.18552 .26864 L
.18613 .26936 L
.18668 .26987 L
.18725 .27028 L
.18758 .27046 L
.18788 .27058 L
.18803 .27063 L
.18819 .27067 L
.18834 .2707 L
.18847 .27072 L
.18855 .27072 L
.18863 .27073 L
.18878 .27073 L
.18887 .27073 L
.18896 .27072 L
.18904 .27071 L
.18912 .2707 L
.18929 .27067 L
.18947 .27062 L
.1898 .27049 L
.19009 .27035 L
.1904 .27015 L
.19096 .2697 L
.19162 .26898 L
.19223 .26815 L
.19341 .26607 L
.19451 .26357 L
.19701 .25584 L
.19948 .24537 L
.20172 .23341 L
.20654 .19989 L
.21118 .15814 L
.21612 .10473 L
.21858 .07532 L
.22088 .04686 L
.22142 .04024 L
.22201 .03336 L
.22228 .03047 L
.22257 .02777 L
.2227 .02668 L
.22284 .02583 L
.22295 .02526 L
.22308 .02488 L
.22323 .02479 L
.22332 .02491 L
.2234 .02513 L
.22348 .02548 L
.22356 .02588 L
.22373 .02705 L
Mistroke
.22403 .02981 L
.22432 .03291 L
.22545 .04703 L
.23008 .11142 L
.23501 .18193 L
.23975 .24873 L
.24431 .30999 L
.24917 .37032 L
.25384 .42238 L
.25881 .4704 L
.2636 .50917 L
.26821 .53959 L
.27311 .56493 L
.27783 .58294 L
.28041 .59032 L
.28284 .59573 L
.28402 .59782 L
.28526 .59967 L
.28642 .60106 L
.28749 .60203 L
.28803 .60243 L
.28863 .60278 L
.28896 .60293 L
.28926 .60305 L
.28957 .60315 L
.28985 .60322 L
.2901 .60327 L
.29024 .60329 L
.29036 .6033 L
.29049 .60331 L
.29064 .60332 L
.29079 .60332 L
.29093 .60331 L
.29107 .6033 L
.29121 .60329 L
.29134 .60327 L
.29148 .60325 L
.29178 .60318 L
.29206 .6031 L
.29263 .60288 L
.29323 .60255 L
.29433 .60172 L
.29563 .60034 L
.29682 .59871 L
.29911 .59453 L
.30161 .58839 L
.30652 .57152 L
.31124 .54928 L
.31626 .51963 L
.3211 .48613 L
Mistroke
.32575 .45069 L
.3307 .41152 L
.33547 .37458 L
.34005 .34185 L
.34493 .31184 L
.34963 .2885 L
.35462 .26923 L
.35943 .25432 L
.36406 .24119 L
.36898 .22631 L
.37372 .20959 L
.37828 .19078 L
.38313 .16813 L
.38781 .14485 L
.39277 .12045 L
.39525 .10924 L
.39756 .09991 L
.39992 .09185 L
.40216 .08607 L
.40334 .08383 L
.40401 .08285 L
.40463 .08213 L
.40515 .08167 L
.40545 .08146 L
.40572 .0813 L
.406 .08117 L
.40616 .08112 L
.40631 .08108 L
.40645 .08106 L
.40658 .08104 L
.40672 .08103 L
.40687 .08103 L
.40701 .08104 L
.40716 .08106 L
.40731 .0811 L
.40746 .08114 L
.40772 .08123 L
.408 .08137 L
.40863 .08182 L
.40921 .08238 L
.41035 .08389 L
.41142 .08578 L
.41383 .09151 L
.41605 .09837 L
.4208 .11717 L
.42536 .13979 L
.43022 .16807 L
.4349 .19841 L
.43987 .2323 L
.44466 .2643 L
Mistroke
.44927 .29212 L
.45184 .30551 L
.45417 .3159 L
.45663 .32474 L
.45889 .33072 L
.46002 .33286 L
.4606 .33372 L
.46121 .33447 L
.46154 .3348 L
.46183 .33504 L
.46213 .33525 L
.46241 .33541 L
.46256 .33548 L
.46273 .33554 L
.4629 .33559 L
.463 .33561 L
.46309 .33562 L
.46316 .33563 L
.46325 .33564 L
.46339 .33564 L
.46355 .33564 L
.46364 .33563 L
.46372 .33561 L
.46388 .33558 L
.46404 .33553 L
.46433 .33541 L
.46465 .33523 L
.46499 .33497 L
.46561 .33435 L
.46619 .33359 L
.46727 .33169 L
.46843 .32894 L
.46966 .32526 L
.47099 .32031 L
.47341 .30879 L
.47832 .27578 L
.48305 .2325 L
.48807 .17594 L
.49291 .11355 L
.49757 .04895 L
.49881 .03126 L
.49942 .0226 L
.49969 .01882 L
.49983 .01683 L
.49998 .01472 L
.50013 .01629 L
.50028 .01835 L
.50056 .0224 L
.50119 .03132 L
.50252 .05017 L
Mistroke
.50708 .11341 L
.51194 .17602 L
.51661 .22896 L
.52158 .27497 L
.52406 .29338 L
.52636 .30757 L
.52859 .31854 L
.53097 .32724 L
.53221 .33055 L
.53286 .33195 L
.53355 .33319 L
.53415 .33406 L
.53447 .33445 L
.53481 .3348 L
.53513 .33507 L
.53542 .33527 L
.5357 .33543 L
.53598 .33554 L
.53612 .33558 L
.53626 .33561 L
.5364 .33563 L
.53653 .33564 L
.53667 .33564 L
.53683 .33563 L
.53691 .33562 L
.53699 .33561 L
.53714 .33558 L
.5373 .33553 L
.53747 .33546 L
.53779 .3353 L
.53809 .3351 L
.53838 .33487 L
.53946 .33365 L
.54 .33282 L
.5406 .33176 L
.54294 .32604 L
.54546 .31737 L
.55044 .29376 L
.55523 .26502 L
.55984 .23429 L
.56474 .20082 L
.56946 .17002 L
.57448 .14063 L
.57932 .11665 L
.58397 .09829 L
.58638 .09094 L
.58761 .08787 L
.58892 .08513 L
.58956 .08404 L
.59016 .08315 L
Mistroke
.59075 .08242 L
.59129 .08188 L
.5918 .08149 L
.59206 .08134 L
.59235 .0812 L
.59249 .08115 L
.59264 .08111 L
.59271 .08109 L
.5928 .08107 L
.59294 .08105 L
.59308 .08103 L
.59323 .08103 L
.59337 .08104 L
.5935 .08105 L
.59365 .08107 L
.59378 .08111 L
.59393 .08115 L
.59409 .08121 L
.59441 .08137 L
.59471 .08156 L
.59528 .08204 L
.59582 .08264 L
.59702 .08445 L
.59833 .08715 L
.60071 .09382 L
.60324 .10299 L
.60826 .12538 L
.61311 .14943 L
.61776 .17249 L
.62272 .19514 L
.62749 .21415 L
.63208 .2297 L
.63697 .24411 L
.64167 .25753 L
.64667 .27374 L
.65148 .29352 L
.65611 .31778 L
.66104 .3493 L
.66579 .38409 L
.67035 .41983 L
.67521 .45816 L
.67988 .49323 L
.68485 .5267 L
.68964 .55386 L
.69425 .57457 L
.69682 .58368 L
.69915 .59042 L
.70158 .59592 L
.70387 .59969 L
.70504 .60111 L
Mistroke
.70569 .60173 L
.70629 .60222 L
.70684 .60259 L
.70735 .60287 L
.70791 .60309 L
.70822 .60318 L
.70836 .60322 L
.70852 .60325 L
.70866 .60327 L
.7088 .60329 L
.70893 .60331 L
.70907 .60331 L
.70922 .60332 L
.70936 .60332 L
.70952 .60331 L
.7096 .60331 L
.70968 .6033 L
.70984 .60328 L
.70999 .60326 L
.71032 .60318 L
.71061 .6031 L
.71092 .60299 L
.71146 .60273 L
.71197 .60242 L
.71314 .60149 L
.71439 .60012 L
.71558 .59846 L
.71782 .59441 L
.72021 .5887 L
.72243 .58211 L
.72716 .56374 L
.73218 .5373 L
.73702 .50458 L
.74167 .46606 L
.74662 .41748 L
.75139 .36368 L
.75597 .30625 L
.76086 .24032 L
.76555 .17392 L
.77055 .10249 L
.77305 .0674 L
.77415 .05241 L
.77536 .03673 L
.77592 .03035 L
.77621 .02757 L
.77637 .02635 L
.77652 .02549 L
.77665 .02499 L
.77679 .02478 L
.77694 .02494 L
Mistroke
.77708 .02543 L
.77721 .02613 L
.77735 .0271 L
.7776 .02931 L
.77999 .05758 L
.78493 .11677 L
.78969 .16664 L
.79426 .2062 L
.79681 .22428 L
.79913 .23822 L
.80157 .25013 L
.80382 .25872 L
.80612 .26506 L
.80733 .26744 L
.808 .26848 L
.80862 .26926 L
.80917 .26981 L
.80975 .27025 L
.81005 .27042 L
.81033 .27055 L
.81049 .27061 L
.81064 .27065 L
.81072 .27067 L
.81081 .27069 L
.81097 .27071 L
.8111 .27073 L
.81123 .27073 L
.81137 .27073 L
.81152 .27072 L
.81168 .2707 L
.81183 .27067 L
.81196 .27063 L
.81211 .27058 L
.81238 .27048 L
.81266 .27033 L
.81317 .26999 L
.81382 .26941 L
.81441 .26873 L
.81575 .26672 L
.81694 .26439 L
.81819 .26141 L
.82277 .24632 L
.82764 .22445 L
.83234 .19985 L
.83733 .17283 L
.83983 .16021 L
.84214 .14984 L
.84438 .14155 L
.84553 .13818 L
.84613 .13668 L
Mistroke
.84676 .13531 L
.84735 .13426 L
.84799 .13334 L
.84827 .13301 L
.84857 .13272 L
.84885 .13249 L
.84911 .13233 L
.84925 .13226 L
.8494 .1322 L
.84955 .13215 L
.8497 .13212 L
.84984 .1321 L
.84999 .1321 L
.85014 .13211 L
.85027 .13213 L
.8504 .13216 L
.85052 .1322 L
.8508 .13233 L
.85105 .13248 L
.85132 .13268 L
.85196 .13338 L
.85256 .13424 L
.8539 .13697 L
.85509 .1402 L
.85634 .14438 L
.86093 .1649 L
.86581 .19205 L
.87051 .21967 L
.87551 .2479 L
.88032 .27215 L
.88495 .29145 L
.88729 .29943 L
.88988 .30667 L
.89233 .31196 L
.89342 .31381 L
.89462 .31547 L
.89527 .31621 L
.89587 .31679 L
.8965 .31729 L
.89706 .31765 L
.89733 .31779 L
.89762 .31792 L
.89787 .31801 L
.89814 .3181 L
.89843 .31816 L
.89859 .31819 L
.89874 .31821 L
.89888 .31822 L
.89901 .31823 L
.89916 .31823 L
Mistroke
.89929 .31822 L
.89943 .31822 L
.89958 .3182 L
.89972 .31818 L
.89985 .31816 L
.90015 .31809 L
.90046 .31799 L
.90105 .31773 L
.90169 .31735 L
.90284 .31639 L
.90392 .31519 L
.90638 .31133 L
.90862 .30656 L
.91344 .29261 L
.91808 .27522 L
.92301 .25363 L
.92776 .23105 L
.93233 .20876 L
.93719 .18533 L
.94187 .16371 L
.94685 .14204 L
.95164 .12242 L
.95625 .10451 L
.96116 .08639 L
.96588 .07021 L
.96829 .06283 L
.96956 .05935 L
.9709 .05609 L
.9721 .05362 L
.97274 .05251 L
.97342 .05151 L
.97405 .05076 L
.97462 .05024 L
.9749 .05004 L
.97519 .04987 L
.97533 .0498 L
.97548 .04974 L
.9756 .0497 L
.97574 .04967 L
.97586 .04964 L
.97597 .04963 L
.97608 .04962 L
.97619 .04962 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.00700719 0.97619 0.287295 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.151576 0.308886 0.0937319 [
[.04527 -0.0125 -6 -9 ]
[.04527 -0.0125 6 0 ]
[.19685 -0.0125 -6 -9 ]
[.19685 -0.0125 6 0 ]
[.34842 -0.0125 -6 -9 ]
[.34842 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65158 -0.0125 -3 -9 ]
[.65158 -0.0125 3 0 ]
[.80315 -0.0125 -3 -9 ]
[.80315 -0.0125 3 0 ]
[.95473 -0.0125 -3 -9 ]
[.95473 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02769 -12 -4.5 ]
[-0.0125 .02769 0 4.5 ]
[-0.0125 .12142 -12 -4.5 ]
[-0.0125 .12142 0 4.5 ]
[-0.0125 .21515 -12 -4.5 ]
[-0.0125 .21515 0 4.5 ]
[-0.0125 .30889 -6 -4.5 ]
[-0.0125 .30889 0 4.5 ]
[-0.0125 .40262 -6 -4.5 ]
[-0.0125 .40262 0 4.5 ]
[-0.0125 .49635 -6 -4.5 ]
[-0.0125 .49635 0 4.5 ]
[-0.0125 .59008 -6 -4.5 ]
[-0.0125 .59008 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 0 m
.04527 .00625 L
s
[(-3)] .04527 -0.0125 0 1 Mshowa
.19685 0 m
.19685 .00625 L
s
[(-2)] .19685 -0.0125 0 1 Mshowa
.34842 0 m
.34842 .00625 L
s
[(-1)] .34842 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.65158 0 m
.65158 .00625 L
s
[(1)] .65158 -0.0125 0 1 Mshowa
.80315 0 m
.80315 .00625 L
s
[(2)] .80315 -0.0125 0 1 Mshowa
.95473 0 m
.95473 .00625 L
s
[(3)] .95473 -0.0125 0 1 Mshowa
.125 Mabswid
.07559 0 m
.07559 .00375 L
s
.1059 0 m
.1059 .00375 L
s
.13622 0 m
.13622 .00375 L
s
.16653 0 m
.16653 .00375 L
s
.22716 0 m
.22716 .00375 L
s
.25748 0 m
.25748 .00375 L
s
.28779 0 m
.28779 .00375 L
s
.31811 0 m
.31811 .00375 L
s
.37874 0 m
.37874 .00375 L
s
.40905 0 m
.40905 .00375 L
s
.43937 0 m
.43937 .00375 L
s
.46968 0 m
.46968 .00375 L
s
.53032 0 m
.53032 .00375 L
s
.56063 0 m
.56063 .00375 L
s
.59095 0 m
.59095 .00375 L
s
.62126 0 m
.62126 .00375 L
s
.68189 0 m
.68189 .00375 L
s
.71221 0 m
.71221 .00375 L
s
.74252 0 m
.74252 .00375 L
s
.77284 0 m
.77284 .00375 L
s
.83347 0 m
.83347 .00375 L
s
.86378 0 m
.86378 .00375 L
s
.8941 0 m
.8941 .00375 L
s
.92441 0 m
.92441 .00375 L
s
.01496 0 m
.01496 .00375 L
s
.98504 0 m
.98504 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02769 m
.00625 .02769 L
s
[(-3)] -0.0125 .02769 1 0 Mshowa
0 .12142 m
.00625 .12142 L
s
[(-2)] -0.0125 .12142 1 0 Mshowa
0 .21515 m
.00625 .21515 L
s
[(-1)] -0.0125 .21515 1 0 Mshowa
0 .30889 m
.00625 .30889 L
s
[(0)] -0.0125 .30889 1 0 Mshowa
0 .40262 m
.00625 .40262 L
s
[(1)] -0.0125 .40262 1 0 Mshowa
0 .49635 m
.00625 .49635 L
s
[(2)] -0.0125 .49635 1 0 Mshowa
0 .59008 m
.00625 .59008 L
s
[(3)] -0.0125 .59008 1 0 Mshowa
.125 Mabswid
0 .04644 m
.00375 .04644 L
s
0 .06518 m
.00375 .06518 L
s
0 .08393 m
.00375 .08393 L
s
0 .10268 m
.00375 .10268 L
s
0 .14017 m
.00375 .14017 L
s
0 .15892 m
.00375 .15892 L
s
0 .17766 m
.00375 .17766 L
s
0 .19641 m
.00375 .19641 L
s
0 .2339 m
.00375 .2339 L
s
0 .25265 m
.00375 .25265 L
s
0 .27139 m
.00375 .27139 L
s
0 .29014 m
.00375 .29014 L
s
0 .32763 m
.00375 .32763 L
s
0 .34638 m
.00375 .34638 L
s
0 .36513 m
.00375 .36513 L
s
0 .38387 m
.00375 .38387 L
s
0 .42136 m
.00375 .42136 L
s
0 .44011 m
.00375 .44011 L
s
0 .45886 m
.00375 .45886 L
s
0 .4776 m
.00375 .4776 L
s
0 .5151 m
.00375 .5151 L
s
0 .53384 m
.00375 .53384 L
s
0 .55259 m
.00375 .55259 L
s
0 .57134 m
.00375 .57134 L
s
0 .00894 m
.00375 .00894 L
s
0 .60883 m
.00375 .60883 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.04527 .61178 m
.04527 .61803 L
s
.19685 .61178 m
.19685 .61803 L
s
.34842 .61178 m
.34842 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65158 .61178 m
.65158 .61803 L
s
.80315 .61178 m
.80315 .61803 L
s
.95473 .61178 m
.95473 .61803 L
s
.125 Mabswid
.07559 .61428 m
.07559 .61803 L
s
.1059 .61428 m
.1059 .61803 L
s
.13622 .61428 m
.13622 .61803 L
s
.16653 .61428 m
.16653 .61803 L
s
.22716 .61428 m
.22716 .61803 L
s
.25748 .61428 m
.25748 .61803 L
s
.28779 .61428 m
.28779 .61803 L
s
.31811 .61428 m
.31811 .61803 L
s
.37874 .61428 m
.37874 .61803 L
s
.40905 .61428 m
.40905 .61803 L
s
.43937 .61428 m
.43937 .61803 L
s
.46968 .61428 m
.46968 .61803 L
s
.53032 .61428 m
.53032 .61803 L
s
.56063 .61428 m
.56063 .61803 L
s
.59095 .61428 m
.59095 .61803 L
s
.62126 .61428 m
.62126 .61803 L
s
.68189 .61428 m
.68189 .61803 L
s
.71221 .61428 m
.71221 .61803 L
s
.74252 .61428 m
.74252 .61803 L
s
.77284 .61428 m
.77284 .61803 L
s
.83347 .61428 m
.83347 .61803 L
s
.86378 .61428 m
.86378 .61803 L
s
.8941 .61428 m
.8941 .61803 L
s
.92441 .61428 m
.92441 .61803 L
s
.01496 .61428 m
.01496 .61803 L
s
.98504 .61428 m
.98504 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02769 m
1 .02769 L
s
.99375 .12142 m
1 .12142 L
s
.99375 .21515 m
1 .21515 L
s
.99375 .30889 m
1 .30889 L
s
.99375 .40262 m
1 .40262 L
s
.99375 .49635 m
1 .49635 L
s
.99375 .59008 m
1 .59008 L
s
.125 Mabswid
.99625 .04644 m
1 .04644 L
s
.99625 .06518 m
1 .06518 L
s
.99625 .08393 m
1 .08393 L
s
.99625 .10268 m
1 .10268 L
s
.99625 .14017 m
1 .14017 L
s
.99625 .15892 m
1 .15892 L
s
.99625 .17766 m
1 .17766 L
s
.99625 .19641 m
1 .19641 L
s
.99625 .2339 m
1 .2339 L
s
.99625 .25265 m
1 .25265 L
s
.99625 .27139 m
1 .27139 L
s
.99625 .29014 m
1 .29014 L
s
.99625 .32763 m
1 .32763 L
s
.99625 .34638 m
1 .34638 L
s
.99625 .36513 m
1 .36513 L
s
.99625 .38387 m
1 .38387 L
s
.99625 .42136 m
1 .42136 L
s
.99625 .44011 m
1 .44011 L
s
.99625 .45886 m
1 .45886 L
s
.99625 .4776 m
1 .4776 L
s
.99625 .5151 m
1 .5151 L
s
.99625 .53384 m
1 .53384 L
s
.99625 .55259 m
1 .55259 L
s
.99625 .57134 m
1 .57134 L
s
.99625 .00894 m
1 .00894 L
s
.99625 .60883 m
1 .60883 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30889 m
1 .30889 L
s
.5 0 m
.5 .61803 L
s
0 1 0 r
.5 Mabswid
.02381 .30889 m
.02608 .32756 L
.02847 .34383 L
.02972 .35042 L
.03089 .35536 L
.03218 .35957 L
.03289 .36143 L
.03355 .36286 L
.03478 .36492 L
.03543 .36572 L
.03612 .36636 L
.03672 .36677 L
.03728 .36705 L
.0376 .36716 L
.03789 .36723 L
.03805 .36726 L
.03814 .36727 L
.03823 .36728 L
.03832 .36729 L
.03839 .36729 L
.03855 .3673 L
.03869 .3673 L
.03883 .3673 L
.03898 .36728 L
.03914 .36727 L
.0393 .36724 L
.03946 .36721 L
.03976 .36714 L
.04029 .36695 L
.04087 .36669 L
.04217 .36585 L
.04338 .36483 L
.04563 .36236 L
.04812 .35897 L
.05297 .3507 L
.05763 .34098 L
.06259 .32885 L
.06737 .3154 L
.07197 .30083 L
.07686 .28362 L
.08157 .26553 L
.08657 .24481 L
.0914 .22357 L
.09603 .20214 L
.10097 .17843 L
.10572 .15492 L
.11029 .13188 L
.11516 .10715 L
.11984 .0835 L
.12482 .05909 L
Mistroke
.12961 .0371 L
.13203 .02694 L
.13309 .02279 L
.13422 .01852 L
.13453 .0174 L
.13486 .01624 L
.13514 .01526 L
.1353 .01472 L
.13545 .60315 L
.1356 .60264 L
.13574 .60217 L
.13601 .60129 L
.1366 .59939 L
.13913 .59233 L
.1403 .58969 L
.14154 .58737 L
.1426 .58578 L
.14376 .58446 L
.14436 .58396 L
.14498 .58356 L
.14552 .58331 L
.14582 .5832 L
.1461 .58312 L
.14626 .58309 L
.14643 .58306 L
.14659 .58304 L
.14674 .58302 L
.14687 .58301 L
.14702 .58301 L
.14717 .58301 L
.14732 .58301 L
.1474 .58301 L
.14749 .58302 L
.14764 .58303 L
.1478 .58305 L
.14794 .58307 L
.14862 .5832 L
.14979 .58352 L
.15041 .58371 L
.15106 .58388 L
.15163 .58401 L
.15178 .58403 L
.15195 .58406 L
.15209 .58408 L
.15225 .58409 L
.1524 .5841 L
.15255 .58411 L
.15268 .58411 L
.15283 .58411 L
.15295 .5841 L
Mistroke
.15307 .5841 L
.15321 .58408 L
.15335 .58406 L
.15349 .58404 L
.15365 .58401 L
.15393 .58394 L
.15426 .58382 L
.15457 .58369 L
.15516 .58335 L
.15572 .58292 L
.15677 .58185 L
.1579 .58027 L
.15904 .57821 L
.1603 .57544 L
.16284 .56833 L
.16772 .55006 L
.17242 .52843 L
.17741 .50272 L
.18222 .47631 L
.18684 .44994 L
.19176 .42126 L
.1965 .39329 L
.20105 .36626 L
.20591 .33754 L
.21057 .31036 L
.21295 .29701 L
.21554 .2833 L
.21674 .27757 L
.21739 .27472 L
.21802 .27231 L
.21859 .2704 L
.2189 .26958 L
.21922 .26888 L
.21935 .26866 L
.21949 .26846 L
.21965 .26831 L
.21979 .26823 L
.21993 .26821 L
.22007 .26827 L
.22019 .26838 L
.22032 .26858 L
.2204 .26875 L
.22048 .26896 L
.22063 .26944 L
.22079 .27014 L
.22096 .27115 L
.22111 .27228 L
.22128 .27381 L
.22157 .27763 L
.22171 .2802 L
Mistroke
.22187 .28367 L
.22201 .28745 L
.22216 .29237 L
.22229 .29781 L
.22244 .30516 L
.2227 .32252 L
.22338 .3937 L
.22354 .41035 L
.22371 .42534 L
.22387 .43656 L
.22402 .44505 L
.22417 .45168 L
.22432 .45742 L
.2246 .46479 L
.22476 .46792 L
.22493 .47055 L
.22509 .47251 L
.22523 .47395 L
.22551 .47598 L
.22566 .47677 L
.22581 .47734 L
.22594 .47774 L
.22606 .47802 L
.2262 .47822 L
.22634 .47835 L
.22649 .47838 L
.22665 .47834 L
.22679 .47823 L
.22693 .47807 L
.22708 .47784 L
.22724 .47753 L
.22757 .47675 L
.2282 .47478 L
.22887 .47219 L
.23009 .4667 L
.23509 .43918 L
.23991 .40993 L
.24455 .38076 L
.24948 .34905 L
.25423 .31799 L
.2588 .28772 L
.26366 .25513 L
.26834 .22349 L
.27332 .18968 L
.27812 .15708 L
.28273 .12586 L
.28763 .09299 L
.29236 .0619 L
.29477 .0463 L
.29604 .03819 L
Mistroke
.29738 .0297 L
.29858 .02214 L
.29891 .02008 L
.29926 .01788 L
.29943 .01681 L
.29959 .01581 L
.29974 .0149 L
.2999 .60286 L
.30004 .60197 L
.30017 .60114 L
.30048 .59925 L
.3011 .59543 L
.30221 .58863 L
.30688 .56081 L
.31185 .5327 L
.31663 .50725 L
.32123 .48451 L
.32613 .46242 L
.33085 .44346 L
.33585 .42603 L
.34068 .41194 L
.34533 .40067 L
.35027 .3905 L
.35502 .38161 L
.3596 .3731 L
.36447 .36356 L
.36915 .35387 L
.37414 .34338 L
.37894 .33382 L
.38355 .32607 L
.38593 .32304 L
.38714 .32184 L
.38778 .32131 L
.38847 .32085 L
.38905 .32053 L
.38935 .3204 L
.38968 .32027 L
.38998 .32019 L
.39026 .32013 L
.39039 .3201 L
.39053 .32009 L
.39067 .32007 L
.3908 .32007 L
.39094 .32006 L
.3911 .32007 L
.39124 .32008 L
.39138 .32009 L
.39153 .32012 L
.3917 .32015 L
.39202 .32024 L
Mistroke
.39234 .32036 L
.39269 .32052 L
.39331 .32092 L
.39396 .32148 L
.39455 .32213 L
.39589 .3241 L
.39708 .32647 L
.39833 .32966 L
.40069 .33775 L
.40291 .3476 L
.4076 .37296 L
.40999 .38568 L
.41259 .39762 L
.41509 .40671 L
.4174 .41302 L
.41965 .41741 L
.42093 .41921 L
.4215 .41987 L
.42213 .42048 L
.42271 .42094 L
.42332 .42135 L
.42366 .42153 L
.42396 .42168 L
.42428 .4218 L
.42457 .42189 L
.42483 .42196 L
.42512 .42201 L
.42526 .42203 L
.4254 .42204 L
.42555 .42205 L
.42564 .42206 L
.42571 .42206 L
.42585 .42206 L
.42598 .42206 L
.42612 .42205 L
.42627 .42204 L
.42641 .42202 L
.42655 .422 L
.4268 .42195 L
.42709 .42188 L
.42736 .4218 L
.42798 .42155 L
.42858 .42124 L
.42923 .42082 L
.43146 .41879 L
.43269 .41729 L
.43402 .41537 L
.43645 .41118 L
.44138 .4002 L
.44612 .387 L
Mistroke
.45068 .37239 L
.45554 .35518 L
.46021 .33735 L
.46518 .31732 L
.46996 .29721 L
.47457 .27728 L
.47947 .25558 L
.48418 .23433 L
.48919 .21147 L
.49402 .18926 L
.49624 .17904 L
.49749 .17324 L
.49867 .16781 L
.49926 .16506 L
.49956 .1637 L
.49983 .16245 L
.49998 .16175 L
.50005 .45587 L
.50014 .45548 L
.50048 .45391 L
.50107 .45117 L
.50361 .43943 L
.50846 .41709 L
.51312 .39572 L
.51808 .37322 L
.52285 .35187 L
.52745 .33172 L
.53234 .31082 L
.53704 .29139 L
.54204 .2717 L
.54686 .25391 L
.5515 .23819 L
.55643 .22339 L
.56118 .21149 L
.56575 .20276 L
.56809 .19951 L
.56941 .19809 L
.57061 .19707 L
.57118 .19667 L
.5718 .19633 L
.57238 .19607 L
.5729 .19589 L
.57322 .19581 L
.57352 .19576 L
.57367 .19574 L
.57384 .19572 L
.57393 .19572 L
.57402 .19571 L
.57411 .19571 L
.57419 .19571 L
Mistroke
.57434 .19571 L
.57449 .19572 L
.57464 .19573 L
.57472 .19574 L
.57481 .19575 L
.57512 .19581 L
.5754 .19587 L
.57597 .19607 L
.57659 .19637 L
.57724 .19678 L
.57784 .19727 L
.57892 .19838 L
.58007 .19992 L
.58131 .20202 L
.58265 .20485 L
.58508 .21159 L
.58748 .22042 L
.59002 .23212 L
.59459 .257 L
.59713 .27036 L
.59946 .28062 L
.60061 .2848 L
.60186 .28863 L
.60304 .29156 L
.60414 .29374 L
.60474 .2947 L
.60539 .29558 L
.60593 .29618 L
.60652 .29672 L
.60716 .29717 L
.60752 .29735 L
.60784 .29749 L
.60815 .29759 L
.60843 .29765 L
.60858 .29767 L
.60866 .29768 L
.60875 .29769 L
.60891 .2977 L
.60905 .29771 L
.6092 .29771 L
.60936 .2977 L
.60951 .29768 L
.60965 .29766 L
.60991 .29761 L
.61019 .29754 L
.61052 .29743 L
.61083 .2973 L
.61141 .297 L
.61247 .29626 L
.61362 .29521 L
Mistroke
.61602 .2923 L
.61856 .2884 L
.62314 .27994 L
.62801 .26988 L
.63271 .26001 L
.63769 .2499 L
.6425 .24074 L
.64712 .2322 L
.65204 .2227 L
.65677 .21225 L
.66133 .20028 L
.66617 .18502 L
.67084 .16781 L
.6758 .14691 L
.68058 .12451 L
.68517 .1011 L
.69007 .07442 L
.69477 .04722 L
.69718 .03285 L
.69844 .02516 L
.69913 .02092 L
.69947 .01883 L
.69978 .01692 L
.69992 .01605 L
.70007 .01509 L
.70022 .60313 L
.70035 .60229 L
.70097 .59844 L
.70229 .5902 L
.7046 .57551 L
.70932 .54488 L
.71435 .51159 L
.71918 .47902 L
.72384 .44742 L
.72879 .41374 L
.73356 .3814 L
.73814 .3505 L
.74302 .31792 L
.74772 .28695 L
.75272 .25452 L
.75753 .22387 L
.76216 .19513 L
.76708 .16607 L
.76953 .15298 L
.77072 .1473 L
.77125 .14508 L
.77182 .14292 L
.77234 .14128 L
.77262 .14054 L
.77289 .13999 L
Mistroke
.77304 .13975 L
.7732 .13956 L
.77334 .13944 L
.77347 .13939 L
.7736 .1394 L
.77374 .13949 L
.77388 .13966 L
.77402 .13992 L
.77416 .14033 L
.77432 .14093 L
.77447 .14168 L
.77461 .14256 L
.77488 .14484 L
.77501 .14637 L
.77516 .14843 L
.77546 .1543 L
.77563 .15889 L
.77579 .16422 L
.77608 .17788 L
.77622 .18722 L
.77638 .1998 L
.77696 .26248 L
.77727 .29255 L
.77742 .30418 L
.77759 .31442 L
.77774 .3215 L
.7779 .32758 L
.77805 .33208 L
.77819 .33556 L
.77833 .33836 L
.77848 .34086 L
.77874 .34414 L
.77892 .34573 L
.77907 .34685 L
.77926 .34784 L
.77943 .34853 L
.77959 .34899 L
.77973 .34928 L
.77981 .34939 L
.77989 .34947 L
.77998 .34953 L
.78006 .34956 L
.78022 .34954 L
.78037 .34945 L
.7805 .34932 L
.78064 .34912 L
.78097 .3485 L
.78127 .34776 L
.78243 .34377 L
.78352 .33903 L
Mistroke
.786 .32647 L
.79067 .30025 L
.79564 .27114 L
.80042 .24279 L
.80501 .21552 L
.80991 .18673 L
.81462 .15944 L
.81962 .13121 L
.82445 .10524 L
.82909 .08207 L
.83403 .06057 L
.83648 .05163 L
.83878 .04467 L
.84098 .0395 L
.84222 .03731 L
.84335 .03578 L
.84393 .03516 L
.84454 .03463 L
.84512 .03425 L
.84565 .03399 L
.84597 .03387 L
.84627 .03378 L
.84644 .03375 L
.84659 .03372 L
.84676 .03369 L
.84684 .03368 L
.84694 .03368 L
.84709 .03367 L
.84724 .03366 L
.84739 .03366 L
.84752 .03367 L
.84767 .03367 L
.84783 .03369 L
.84799 .03371 L
.84815 .03373 L
.84875 .03384 L
.8494 .03401 L
.85059 .03436 L
.85115 .03452 L
.85146 .03459 L
.85175 .03465 L
.85202 .0347 L
.85216 .03472 L
.85231 .03473 L
.85244 .03475 L
.85258 .03476 L
.8527 .03476 L
.85282 .03477 L
.85297 .03476 L
.85305 .03476 L
Mistroke
.85314 .03476 L
.85329 .03475 L
.85343 .03473 L
.85359 .03471 L
.85374 .03468 L
.85408 .0346 L
.85436 .03451 L
.85466 .03439 L
.85528 .03406 L
.85584 .03366 L
.85643 .03312 L
.85751 .03185 L
.85875 .02991 L
.86009 .02726 L
.86124 .02451 L
.86252 .02104 L
.86311 .01927 L
.86375 .01726 L
.86406 .01625 L
.86422 .01575 L
.86436 .01528 L
.86449 .01485 L
.86462 .60332 L
.86477 .6028 L
.86491 .60233 L
.86745 .5929 L
.87228 .57223 L
.87694 .55021 L
.88189 .5256 L
.88665 .50142 L
.89124 .47815 L
.89612 .45369 L
.90081 .43068 L
.90581 .40702 L
.91062 .3852 L
.91524 .36528 L
.92017 .34541 L
.92491 .32775 L
.92946 .31224 L
.93432 .29742 L
.93899 .28486 L
.94395 .27331 L
.94873 .26395 L
.95334 .25674 L
.9557 .25387 L
.95702 .25258 L
.95823 .25163 L
.95882 .25125 L
.95947 .25092 L
.96012 .25067 L
Mistroke
.96029 .25062 L
.96048 .25058 L
.96065 .25054 L
.96081 .25051 L
.96096 .25049 L
.96104 .25049 L
.96112 .25048 L
.96121 .25048 L
.9613 .25047 L
.96138 .25047 L
.96146 .25047 L
.9616 .25048 L
.96176 .25049 L
.96184 .2505 L
.96193 .25051 L
.96208 .25054 L
.96239 .25061 L
.96269 .25071 L
.96324 .25097 L
.9638 .25135 L
.96441 .25189 L
.96505 .25263 L
.96565 .25348 L
.96672 .25547 L
.96787 .25835 L
.96909 .26237 L
.97042 .26806 L
.97285 .28231 L
.97619 .30889 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 148.312},
  ImageCacheValid->False]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Show both solutions", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[GraphicsArray[{{g1, g2, g3}, {g4, g5, g6}}], \ 
        ImageSize \[Rule] 504*1.5];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .40558 
%%ImageSize: 756 306.622 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00965678 0.31746 [
[ 0 0 0 0 ]
[ 1 .40558 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .40558 L
0 .40558 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00965678 0.321429 0.193595 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.151576 0.014388 0.000733898 [
[.04527 -0.0125 -6 -9 ]
[.04527 -0.0125 6 0 ]
[.19685 -0.0125 -6 -9 ]
[.19685 -0.0125 6 0 ]
[.34842 -0.0125 -6 -9 ]
[.34842 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65158 -0.0125 -3 -9 ]
[.65158 -0.0125 3 0 ]
[.80315 -0.0125 -3 -9 ]
[.80315 -0.0125 3 0 ]
[.95473 -0.0125 -3 -9 ]
[.95473 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01439 -6 -4.5 ]
[-0.0125 .01439 0 4.5 ]
[-0.0125 .16117 -18 -4.5 ]
[-0.0125 .16117 0 4.5 ]
[-0.0125 .30795 -18 -4.5 ]
[-0.0125 .30795 0 4.5 ]
[-0.0125 .45473 -18 -4.5 ]
[-0.0125 .45473 0 4.5 ]
[-0.0125 .60151 -18 -4.5 ]
[-0.0125 .60151 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 0 m
.04527 .00625 L
s
[(-3)] .04527 -0.0125 0 1 Mshowa
.19685 0 m
.19685 .00625 L
s
[(-2)] .19685 -0.0125 0 1 Mshowa
.34842 0 m
.34842 .00625 L
s
[(-1)] .34842 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.65158 0 m
.65158 .00625 L
s
[(1)] .65158 -0.0125 0 1 Mshowa
.80315 0 m
.80315 .00625 L
s
[(2)] .80315 -0.0125 0 1 Mshowa
.95473 0 m
.95473 .00625 L
s
[(3)] .95473 -0.0125 0 1 Mshowa
.125 Mabswid
.07559 0 m
.07559 .00375 L
s
.1059 0 m
.1059 .00375 L
s
.13622 0 m
.13622 .00375 L
s
.16653 0 m
.16653 .00375 L
s
.22716 0 m
.22716 .00375 L
s
.25748 0 m
.25748 .00375 L
s
.28779 0 m
.28779 .00375 L
s
.31811 0 m
.31811 .00375 L
s
.37874 0 m
.37874 .00375 L
s
.40905 0 m
.40905 .00375 L
s
.43937 0 m
.43937 .00375 L
s
.46968 0 m
.46968 .00375 L
s
.53032 0 m
.53032 .00375 L
s
.56063 0 m
.56063 .00375 L
s
.59095 0 m
.59095 .00375 L
s
.62126 0 m
.62126 .00375 L
s
.68189 0 m
.68189 .00375 L
s
.71221 0 m
.71221 .00375 L
s
.74252 0 m
.74252 .00375 L
s
.77284 0 m
.77284 .00375 L
s
.83347 0 m
.83347 .00375 L
s
.86378 0 m
.86378 .00375 L
s
.8941 0 m
.8941 .00375 L
s
.92441 0 m
.92441 .00375 L
s
.01496 0 m
.01496 .00375 L
s
.98504 0 m
.98504 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01439 m
.00625 .01439 L
s
[(0)] -0.0125 .01439 1 0 Mshowa
0 .16117 m
.00625 .16117 L
s
[(200)] -0.0125 .16117 1 0 Mshowa
0 .30795 m
.00625 .30795 L
s
[(400)] -0.0125 .30795 1 0 Mshowa
0 .45473 m
.00625 .45473 L
s
[(600)] -0.0125 .45473 1 0 Mshowa
0 .60151 m
.00625 .60151 L
s
[(800)] -0.0125 .60151 1 0 Mshowa
.125 Mabswid
0 .05108 m
.00375 .05108 L
s
0 .08778 m
.00375 .08778 L
s
0 .12447 m
.00375 .12447 L
s
0 .19786 m
.00375 .19786 L
s
0 .23456 m
.00375 .23456 L
s
0 .27125 m
.00375 .27125 L
s
0 .34464 m
.00375 .34464 L
s
0 .38134 m
.00375 .38134 L
s
0 .41803 m
.00375 .41803 L
s
0 .49142 m
.00375 .49142 L
s
0 .52812 m
.00375 .52812 L
s
0 .56481 m
.00375 .56481 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.04527 .61178 m
.04527 .61803 L
s
.19685 .61178 m
.19685 .61803 L
s
.34842 .61178 m
.34842 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65158 .61178 m
.65158 .61803 L
s
.80315 .61178 m
.80315 .61803 L
s
.95473 .61178 m
.95473 .61803 L
s
.125 Mabswid
.07559 .61428 m
.07559 .61803 L
s
.1059 .61428 m
.1059 .61803 L
s
.13622 .61428 m
.13622 .61803 L
s
.16653 .61428 m
.16653 .61803 L
s
.22716 .61428 m
.22716 .61803 L
s
.25748 .61428 m
.25748 .61803 L
s
.28779 .61428 m
.28779 .61803 L
s
.31811 .61428 m
.31811 .61803 L
s
.37874 .61428 m
.37874 .61803 L
s
.40905 .61428 m
.40905 .61803 L
s
.43937 .61428 m
.43937 .61803 L
s
.46968 .61428 m
.46968 .61803 L
s
.53032 .61428 m
.53032 .61803 L
s
.56063 .61428 m
.56063 .61803 L
s
.59095 .61428 m
.59095 .61803 L
s
.62126 .61428 m
.62126 .61803 L
s
.68189 .61428 m
.68189 .61803 L
s
.71221 .61428 m
.71221 .61803 L
s
.74252 .61428 m
.74252 .61803 L
s
.77284 .61428 m
.77284 .61803 L
s
.83347 .61428 m
.83347 .61803 L
s
.86378 .61428 m
.86378 .61803 L
s
.8941 .61428 m
.8941 .61803 L
s
.92441 .61428 m
.92441 .61803 L
s
.01496 .61428 m
.01496 .61803 L
s
.98504 .61428 m
.98504 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01439 m
1 .01439 L
s
.99375 .16117 m
1 .16117 L
s
.99375 .30795 m
1 .30795 L
s
.99375 .45473 m
1 .45473 L
s
.99375 .60151 m
1 .60151 L
s
.125 Mabswid
.99625 .05108 m
1 .05108 L
s
.99625 .08778 m
1 .08778 L
s
.99625 .12447 m
1 .12447 L
s
.99625 .19786 m
1 .19786 L
s
.99625 .23456 m
1 .23456 L
s
.99625 .27125 m
1 .27125 L
s
.99625 .34464 m
1 .34464 L
s
.99625 .38134 m
1 .38134 L
s
.99625 .41803 m
1 .41803 L
s
.99625 .49142 m
1 .49142 L
s
.99625 .52812 m
1 .52812 L
s
.99625 .56481 m
1 .56481 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 1 0 r
.5 Mabswid
.02381 .04962 m
.02395 .04962 L
.02408 .04963 L
.02423 .04966 L
.02437 .04969 L
.02462 .04978 L
.02489 .04991 L
.02519 .0501 L
.02551 .05034 L
.02608 .0509 L
.02722 .05244 L
.02847 .05474 L
.03109 .06111 L
.03355 .0684 L
.03823 .0842 L
.0432 .10244 L
.04799 .12095 L
.05259 .1397 L
.0575 .16088 L
.06221 .18253 L
.06723 .20661 L
.07206 .2302 L
.07671 .25235 L
.08166 .27413 L
.08642 .29214 L
.091 .30563 L
.09335 .31082 L
.09587 .31492 L
.0971 .31633 L
.09775 .31693 L
.09843 .31743 L
.09903 .31778 L
.09935 .31792 L
.0997 .31804 L
.10001 .31813 L
.10015 .31816 L
.1003 .31818 L
.10044 .3182 L
.10057 .31822 L
.10071 .31822 L
.10086 .31823 L
.10101 .31822 L
.10109 .31822 L
.10117 .31821 L
.10133 .3182 L
.10142 .31819 L
.1015 .31817 L
.10181 .31811 L
.1021 .31802 L
.10243 .3179 L
Mistroke
.10274 .31776 L
.10344 .31734 L
.10405 .31685 L
.10461 .31633 L
.10587 .31484 L
.10819 .31097 L
.1107 .30518 L
.11566 .28918 L
.12042 .26865 L
.12501 .2451 L
.12989 .21732 L
.13459 .18972 L
.13959 .1623 L
.14209 .15061 L
.1444 .14183 L
.14556 .13835 L
.14664 .13573 L
.14724 .13459 L
.14778 .13373 L
.14838 .13298 L
.14869 .13268 L
.14903 .13243 L
.14918 .13234 L
.14934 .13226 L
.14948 .1322 L
.14963 .13215 L
.14977 .13212 L
.14992 .1321 L
.15005 .1321 L
.15018 .1321 L
.15034 .13213 L
.15049 .13216 L
.15063 .13221 L
.15077 .13227 L
.15111 .13246 L
.15141 .1327 L
.15192 .13323 L
.15249 .13399 L
.15363 .13612 L
.15484 .13919 L
.15596 .14266 L
.15847 .15242 L
.16325 .17588 L
.16784 .20082 L
.17273 .22628 L
.17743 .24711 L
.17983 .25565 L
.1811 .25947 L
.18243 .26296 L
.18363 .26556 L
Mistroke
.18494 .26784 L
.18552 .26864 L
.18613 .26936 L
.18668 .26987 L
.18725 .27028 L
.18758 .27046 L
.18788 .27058 L
.18803 .27063 L
.18819 .27067 L
.18834 .2707 L
.18847 .27072 L
.18855 .27072 L
.18863 .27073 L
.18878 .27073 L
.18887 .27073 L
.18896 .27072 L
.18904 .27071 L
.18912 .2707 L
.18929 .27067 L
.18947 .27062 L
.1898 .27049 L
.19009 .27035 L
.1904 .27015 L
.19096 .2697 L
.19162 .26898 L
.19223 .26815 L
.19341 .26607 L
.19451 .26357 L
.19701 .25584 L
.19948 .24537 L
.20172 .23341 L
.20654 .19989 L
.21118 .15814 L
.21612 .10473 L
.21858 .07532 L
.22088 .04686 L
.22142 .04024 L
.22201 .03336 L
.22228 .03047 L
.22257 .02777 L
.2227 .02668 L
.22284 .02583 L
.22295 .02526 L
.22308 .02488 L
.22323 .02479 L
.22332 .02491 L
.2234 .02513 L
.22348 .02548 L
.22356 .02588 L
.22373 .02705 L
Mistroke
.22403 .02981 L
.22432 .03291 L
.22545 .04703 L
.23008 .11142 L
.23501 .18193 L
.23975 .24873 L
.24431 .30999 L
.24917 .37032 L
.25384 .42238 L
.25881 .4704 L
.2636 .50917 L
.26821 .53959 L
.27311 .56493 L
.27783 .58294 L
.28041 .59032 L
.28284 .59573 L
.28402 .59782 L
.28526 .59967 L
.28642 .60106 L
.28749 .60203 L
.28803 .60243 L
.28863 .60278 L
.28896 .60293 L
.28926 .60305 L
.28957 .60315 L
.28985 .60322 L
.2901 .60327 L
.29024 .60329 L
.29036 .6033 L
.29049 .60331 L
.29064 .60332 L
.29079 .60332 L
.29093 .60331 L
.29107 .6033 L
.29121 .60329 L
.29134 .60327 L
.29148 .60325 L
.29178 .60318 L
.29206 .6031 L
.29263 .60288 L
.29323 .60255 L
.29433 .60172 L
.29563 .60034 L
.29682 .59871 L
.29911 .59453 L
.30161 .58839 L
.30652 .57152 L
.31124 .54928 L
.31626 .51963 L
.3211 .48613 L
Mistroke
.32575 .45069 L
.3307 .41152 L
.33547 .37458 L
.34005 .34185 L
.34493 .31184 L
.34963 .2885 L
.35462 .26923 L
.35943 .25432 L
.36406 .24119 L
.36898 .22631 L
.37372 .20959 L
.37828 .19078 L
.38313 .16813 L
.38781 .14485 L
.39277 .12045 L
.39525 .10924 L
.39756 .09991 L
.39992 .09185 L
.40216 .08607 L
.40334 .08383 L
.40401 .08285 L
.40463 .08213 L
.40515 .08167 L
.40545 .08146 L
.40572 .0813 L
.406 .08117 L
.40616 .08112 L
.40631 .08108 L
.40645 .08106 L
.40658 .08104 L
.40672 .08103 L
.40687 .08103 L
.40701 .08104 L
.40716 .08106 L
.40731 .0811 L
.40746 .08114 L
.40772 .08123 L
.408 .08137 L
.40863 .08182 L
.40921 .08238 L
.41035 .08389 L
.41142 .08578 L
.41383 .09151 L
.41605 .09837 L
.4208 .11717 L
.42536 .13979 L
.43022 .16807 L
.4349 .19841 L
.43987 .2323 L
.44466 .2643 L
Mistroke
.44927 .29212 L
.45184 .30551 L
.45417 .3159 L
.45663 .32474 L
.45889 .33072 L
.46002 .33286 L
.4606 .33372 L
.46121 .33447 L
.46154 .3348 L
.46183 .33504 L
.46213 .33525 L
.46241 .33541 L
.46256 .33548 L
.46273 .33554 L
.4629 .33559 L
.463 .33561 L
.46309 .33562 L
.46316 .33563 L
.46325 .33564 L
.46339 .33564 L
.46355 .33564 L
.46364 .33563 L
.46372 .33561 L
.46388 .33558 L
.46404 .33553 L
.46433 .33541 L
.46465 .33523 L
.46499 .33497 L
.46561 .33435 L
.46619 .33359 L
.46727 .33169 L
.46843 .32894 L
.46966 .32526 L
.47099 .32031 L
.47341 .30879 L
.47832 .27578 L
.48305 .2325 L
.48807 .17594 L
.49291 .11355 L
.49757 .04895 L
.49881 .03126 L
.49942 .0226 L
.49969 .01882 L
.49983 .01683 L
.49998 .01472 L
.50013 .01629 L
.50028 .01835 L
.50056 .0224 L
.50119 .03132 L
.50252 .05017 L
Mistroke
.50708 .11341 L
.51194 .17602 L
.51661 .22896 L
.52158 .27497 L
.52406 .29338 L
.52636 .30757 L
.52859 .31854 L
.53097 .32724 L
.53221 .33055 L
.53286 .33195 L
.53355 .33319 L
.53415 .33406 L
.53447 .33445 L
.53481 .3348 L
.53513 .33507 L
.53542 .33527 L
.5357 .33543 L
.53598 .33554 L
.53612 .33558 L
.53626 .33561 L
.5364 .33563 L
.53653 .33564 L
.53667 .33564 L
.53683 .33563 L
.53691 .33562 L
.53699 .33561 L
.53714 .33558 L
.5373 .33553 L
.53747 .33546 L
.53779 .3353 L
.53809 .3351 L
.53838 .33487 L
.53946 .33365 L
.54 .33282 L
.5406 .33176 L
.54294 .32604 L
.54546 .31737 L
.55044 .29376 L
.55523 .26502 L
.55984 .23429 L
.56474 .20082 L
.56946 .17002 L
.57448 .14063 L
.57932 .11665 L
.58397 .09829 L
.58638 .09094 L
.58761 .08787 L
.58892 .08513 L
.58956 .08404 L
.59016 .08315 L
Mistroke
.59075 .08242 L
.59129 .08188 L
.5918 .08149 L
.59206 .08134 L
.59235 .0812 L
.59249 .08115 L
.59264 .08111 L
.59271 .08109 L
.5928 .08107 L
.59294 .08105 L
.59308 .08103 L
.59323 .08103 L
.59337 .08104 L
.5935 .08105 L
.59365 .08107 L
.59378 .08111 L
.59393 .08115 L
.59409 .08121 L
.59441 .08137 L
.59471 .08156 L
.59528 .08204 L
.59582 .08264 L
.59702 .08445 L
.59833 .08715 L
.60071 .09382 L
.60324 .10299 L
.60826 .12538 L
.61311 .14943 L
.61776 .17249 L
.62272 .19514 L
.62749 .21415 L
.63208 .2297 L
.63697 .24411 L
.64167 .25753 L
.64667 .27374 L
.65148 .29352 L
.65611 .31778 L
.66104 .3493 L
.66579 .38409 L
.67035 .41983 L
.67521 .45816 L
.67988 .49323 L
.68485 .5267 L
.68964 .55386 L
.69425 .57457 L
.69682 .58368 L
.69915 .59042 L
.70158 .59592 L
.70387 .59969 L
.70504 .60111 L
Mistroke
.70569 .60173 L
.70629 .60222 L
.70684 .60259 L
.70735 .60287 L
.70791 .60309 L
.70822 .60318 L
.70836 .60322 L
.70852 .60325 L
.70866 .60327 L
.7088 .60329 L
.70893 .60331 L
.70907 .60331 L
.70922 .60332 L
.70936 .60332 L
.70952 .60331 L
.7096 .60331 L
.70968 .6033 L
.70984 .60328 L
.70999 .60326 L
.71032 .60318 L
.71061 .6031 L
.71092 .60299 L
.71146 .60273 L
.71197 .60242 L
.71314 .60149 L
.71439 .60012 L
.71558 .59846 L
.71782 .59441 L
.72021 .5887 L
.72243 .58211 L
.72716 .56374 L
.73218 .5373 L
.73702 .50458 L
.74167 .46606 L
.74662 .41748 L
.75139 .36368 L
.75597 .30625 L
.76086 .24032 L
.76555 .17392 L
.77055 .10249 L
.77305 .0674 L
.77415 .05241 L
.77536 .03673 L
.77592 .03035 L
.77621 .02757 L
.77637 .02635 L
.77652 .02549 L
.77665 .02499 L
.77679 .02478 L
.77694 .02494 L
Mistroke
.77708 .02543 L
.77721 .02613 L
.77735 .0271 L
.7776 .02931 L
.77999 .05758 L
.78493 .11677 L
.78969 .16664 L
.79426 .2062 L
.79681 .22428 L
.79913 .23822 L
.80157 .25013 L
.80382 .25872 L
.80612 .26506 L
.80733 .26744 L
.808 .26848 L
.80862 .26926 L
.80917 .26981 L
.80975 .27025 L
.81005 .27042 L
.81033 .27055 L
.81049 .27061 L
.81064 .27065 L
.81072 .27067 L
.81081 .27069 L
.81097 .27071 L
.8111 .27073 L
.81123 .27073 L
.81137 .27073 L
.81152 .27072 L
.81168 .2707 L
.81183 .27067 L
.81196 .27063 L
.81211 .27058 L
.81238 .27048 L
.81266 .27033 L
.81317 .26999 L
.81382 .26941 L
.81441 .26873 L
.81575 .26672 L
.81694 .26439 L
.81819 .26141 L
.82277 .24632 L
.82764 .22445 L
.83234 .19985 L
.83733 .17283 L
.83983 .16021 L
.84214 .14984 L
.84438 .14155 L
.84553 .13818 L
.84613 .13668 L
Mistroke
.84676 .13531 L
.84735 .13426 L
.84799 .13334 L
.84827 .13301 L
.84857 .13272 L
.84885 .13249 L
.84911 .13233 L
.84925 .13226 L
.8494 .1322 L
.84955 .13215 L
.8497 .13212 L
.84984 .1321 L
.84999 .1321 L
.85014 .13211 L
.85027 .13213 L
.8504 .13216 L
.85052 .1322 L
.8508 .13233 L
.85105 .13248 L
.85132 .13268 L
.85196 .13338 L
.85256 .13424 L
.8539 .13697 L
.85509 .1402 L
.85634 .14438 L
.86093 .1649 L
.86581 .19205 L
.87051 .21967 L
.87551 .2479 L
.88032 .27215 L
.88495 .29145 L
.88729 .29943 L
.88988 .30667 L
.89233 .31196 L
.89342 .31381 L
.89462 .31547 L
.89527 .31621 L
.89587 .31679 L
.8965 .31729 L
.89706 .31765 L
.89733 .31779 L
.89762 .31792 L
.89787 .31801 L
.89814 .3181 L
.89843 .31816 L
.89859 .31819 L
.89874 .31821 L
.89888 .31822 L
.89901 .31823 L
.89916 .31823 L
Mistroke
.89929 .31822 L
.89943 .31822 L
.89958 .3182 L
.89972 .31818 L
.89985 .31816 L
.90015 .31809 L
.90046 .31799 L
.90105 .31773 L
.90169 .31735 L
.90284 .31639 L
.90392 .31519 L
.90638 .31133 L
.90862 .30656 L
.91344 .29261 L
.91808 .27522 L
.92301 .25363 L
.92776 .23105 L
.93233 .20876 L
.93719 .18533 L
.94187 .16371 L
.94685 .14204 L
.95164 .12242 L
.95625 .10451 L
.96116 .08639 L
.96588 .07021 L
.96829 .06283 L
.96956 .05935 L
.9709 .05609 L
.9721 .05362 L
.97274 .05251 L
.97342 .05151 L
.97405 .05076 L
.97462 .05024 L
.9749 .05004 L
.97519 .04987 L
.97533 .0498 L
.97548 .04974 L
.9756 .0497 L
.97574 .04967 L
.97586 .04964 L
.97597 .04963 L
.97608 .04962 L
.97619 .04962 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00965678 0.64881 0.193595 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.151576 0.308886 0.0937319 [
[.04527 -0.0125 -6 -9 ]
[.04527 -0.0125 6 0 ]
[.19685 -0.0125 -6 -9 ]
[.19685 -0.0125 6 0 ]
[.34842 -0.0125 -6 -9 ]
[.34842 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65158 -0.0125 -3 -9 ]
[.65158 -0.0125 3 0 ]
[.80315 -0.0125 -3 -9 ]
[.80315 -0.0125 3 0 ]
[.95473 -0.0125 -3 -9 ]
[.95473 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02769 -12 -4.5 ]
[-0.0125 .02769 0 4.5 ]
[-0.0125 .12142 -12 -4.5 ]
[-0.0125 .12142 0 4.5 ]
[-0.0125 .21515 -12 -4.5 ]
[-0.0125 .21515 0 4.5 ]
[-0.0125 .30889 -6 -4.5 ]
[-0.0125 .30889 0 4.5 ]
[-0.0125 .40262 -6 -4.5 ]
[-0.0125 .40262 0 4.5 ]
[-0.0125 .49635 -6 -4.5 ]
[-0.0125 .49635 0 4.5 ]
[-0.0125 .59008 -6 -4.5 ]
[-0.0125 .59008 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 0 m
.04527 .00625 L
s
[(-3)] .04527 -0.0125 0 1 Mshowa
.19685 0 m
.19685 .00625 L
s
[(-2)] .19685 -0.0125 0 1 Mshowa
.34842 0 m
.34842 .00625 L
s
[(-1)] .34842 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.65158 0 m
.65158 .00625 L
s
[(1)] .65158 -0.0125 0 1 Mshowa
.80315 0 m
.80315 .00625 L
s
[(2)] .80315 -0.0125 0 1 Mshowa
.95473 0 m
.95473 .00625 L
s
[(3)] .95473 -0.0125 0 1 Mshowa
.125 Mabswid
.07559 0 m
.07559 .00375 L
s
.1059 0 m
.1059 .00375 L
s
.13622 0 m
.13622 .00375 L
s
.16653 0 m
.16653 .00375 L
s
.22716 0 m
.22716 .00375 L
s
.25748 0 m
.25748 .00375 L
s
.28779 0 m
.28779 .00375 L
s
.31811 0 m
.31811 .00375 L
s
.37874 0 m
.37874 .00375 L
s
.40905 0 m
.40905 .00375 L
s
.43937 0 m
.43937 .00375 L
s
.46968 0 m
.46968 .00375 L
s
.53032 0 m
.53032 .00375 L
s
.56063 0 m
.56063 .00375 L
s
.59095 0 m
.59095 .00375 L
s
.62126 0 m
.62126 .00375 L
s
.68189 0 m
.68189 .00375 L
s
.71221 0 m
.71221 .00375 L
s
.74252 0 m
.74252 .00375 L
s
.77284 0 m
.77284 .00375 L
s
.83347 0 m
.83347 .00375 L
s
.86378 0 m
.86378 .00375 L
s
.8941 0 m
.8941 .00375 L
s
.92441 0 m
.92441 .00375 L
s
.01496 0 m
.01496 .00375 L
s
.98504 0 m
.98504 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02769 m
.00625 .02769 L
s
[(-3)] -0.0125 .02769 1 0 Mshowa
0 .12142 m
.00625 .12142 L
s
[(-2)] -0.0125 .12142 1 0 Mshowa
0 .21515 m
.00625 .21515 L
s
[(-1)] -0.0125 .21515 1 0 Mshowa
0 .30889 m
.00625 .30889 L
s
[(0)] -0.0125 .30889 1 0 Mshowa
0 .40262 m
.00625 .40262 L
s
[(1)] -0.0125 .40262 1 0 Mshowa
0 .49635 m
.00625 .49635 L
s
[(2)] -0.0125 .49635 1 0 Mshowa
0 .59008 m
.00625 .59008 L
s
[(3)] -0.0125 .59008 1 0 Mshowa
.125 Mabswid
0 .04644 m
.00375 .04644 L
s
0 .06518 m
.00375 .06518 L
s
0 .08393 m
.00375 .08393 L
s
0 .10268 m
.00375 .10268 L
s
0 .14017 m
.00375 .14017 L
s
0 .15892 m
.00375 .15892 L
s
0 .17766 m
.00375 .17766 L
s
0 .19641 m
.00375 .19641 L
s
0 .2339 m
.00375 .2339 L
s
0 .25265 m
.00375 .25265 L
s
0 .27139 m
.00375 .27139 L
s
0 .29014 m
.00375 .29014 L
s
0 .32763 m
.00375 .32763 L
s
0 .34638 m
.00375 .34638 L
s
0 .36513 m
.00375 .36513 L
s
0 .38387 m
.00375 .38387 L
s
0 .42136 m
.00375 .42136 L
s
0 .44011 m
.00375 .44011 L
s
0 .45886 m
.00375 .45886 L
s
0 .4776 m
.00375 .4776 L
s
0 .5151 m
.00375 .5151 L
s
0 .53384 m
.00375 .53384 L
s
0 .55259 m
.00375 .55259 L
s
0 .57134 m
.00375 .57134 L
s
0 .00894 m
.00375 .00894 L
s
0 .60883 m
.00375 .60883 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.04527 .61178 m
.04527 .61803 L
s
.19685 .61178 m
.19685 .61803 L
s
.34842 .61178 m
.34842 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65158 .61178 m
.65158 .61803 L
s
.80315 .61178 m
.80315 .61803 L
s
.95473 .61178 m
.95473 .61803 L
s
.125 Mabswid
.07559 .61428 m
.07559 .61803 L
s
.1059 .61428 m
.1059 .61803 L
s
.13622 .61428 m
.13622 .61803 L
s
.16653 .61428 m
.16653 .61803 L
s
.22716 .61428 m
.22716 .61803 L
s
.25748 .61428 m
.25748 .61803 L
s
.28779 .61428 m
.28779 .61803 L
s
.31811 .61428 m
.31811 .61803 L
s
.37874 .61428 m
.37874 .61803 L
s
.40905 .61428 m
.40905 .61803 L
s
.43937 .61428 m
.43937 .61803 L
s
.46968 .61428 m
.46968 .61803 L
s
.53032 .61428 m
.53032 .61803 L
s
.56063 .61428 m
.56063 .61803 L
s
.59095 .61428 m
.59095 .61803 L
s
.62126 .61428 m
.62126 .61803 L
s
.68189 .61428 m
.68189 .61803 L
s
.71221 .61428 m
.71221 .61803 L
s
.74252 .61428 m
.74252 .61803 L
s
.77284 .61428 m
.77284 .61803 L
s
.83347 .61428 m
.83347 .61803 L
s
.86378 .61428 m
.86378 .61803 L
s
.8941 .61428 m
.8941 .61803 L
s
.92441 .61428 m
.92441 .61803 L
s
.01496 .61428 m
.01496 .61803 L
s
.98504 .61428 m
.98504 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02769 m
1 .02769 L
s
.99375 .12142 m
1 .12142 L
s
.99375 .21515 m
1 .21515 L
s
.99375 .30889 m
1 .30889 L
s
.99375 .40262 m
1 .40262 L
s
.99375 .49635 m
1 .49635 L
s
.99375 .59008 m
1 .59008 L
s
.125 Mabswid
.99625 .04644 m
1 .04644 L
s
.99625 .06518 m
1 .06518 L
s
.99625 .08393 m
1 .08393 L
s
.99625 .10268 m
1 .10268 L
s
.99625 .14017 m
1 .14017 L
s
.99625 .15892 m
1 .15892 L
s
.99625 .17766 m
1 .17766 L
s
.99625 .19641 m
1 .19641 L
s
.99625 .2339 m
1 .2339 L
s
.99625 .25265 m
1 .25265 L
s
.99625 .27139 m
1 .27139 L
s
.99625 .29014 m
1 .29014 L
s
.99625 .32763 m
1 .32763 L
s
.99625 .34638 m
1 .34638 L
s
.99625 .36513 m
1 .36513 L
s
.99625 .38387 m
1 .38387 L
s
.99625 .42136 m
1 .42136 L
s
.99625 .44011 m
1 .44011 L
s
.99625 .45886 m
1 .45886 L
s
.99625 .4776 m
1 .4776 L
s
.99625 .5151 m
1 .5151 L
s
.99625 .53384 m
1 .53384 L
s
.99625 .55259 m
1 .55259 L
s
.99625 .57134 m
1 .57134 L
s
.99625 .00894 m
1 .00894 L
s
.99625 .60883 m
1 .60883 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30889 m
1 .30889 L
s
.5 0 m
.5 .61803 L
s
0 1 0 r
.5 Mabswid
.02381 .30889 m
.02608 .32756 L
.02847 .34383 L
.02972 .35042 L
.03089 .35536 L
.03218 .35957 L
.03289 .36143 L
.03355 .36286 L
.03478 .36492 L
.03543 .36572 L
.03612 .36636 L
.03672 .36677 L
.03728 .36705 L
.0376 .36716 L
.03789 .36723 L
.03805 .36726 L
.03814 .36727 L
.03823 .36728 L
.03832 .36729 L
.03839 .36729 L
.03855 .3673 L
.03869 .3673 L
.03883 .3673 L
.03898 .36728 L
.03914 .36727 L
.0393 .36724 L
.03946 .36721 L
.03976 .36714 L
.04029 .36695 L
.04087 .36669 L
.04217 .36585 L
.04338 .36483 L
.04563 .36236 L
.04812 .35897 L
.05297 .3507 L
.05763 .34098 L
.06259 .32885 L
.06737 .3154 L
.07197 .30083 L
.07686 .28362 L
.08157 .26553 L
.08657 .24481 L
.0914 .22357 L
.09603 .20214 L
.10097 .17843 L
.10572 .15492 L
.11029 .13188 L
.11516 .10715 L
.11984 .0835 L
.12482 .05909 L
Mistroke
.12961 .0371 L
.13203 .02694 L
.13309 .02279 L
.13422 .01852 L
.13453 .0174 L
.13486 .01624 L
.13514 .01526 L
.1353 .01472 L
.13545 .60315 L
.1356 .60264 L
.13574 .60217 L
.13601 .60129 L
.1366 .59939 L
.13913 .59233 L
.1403 .58969 L
.14154 .58737 L
.1426 .58578 L
.14376 .58446 L
.14436 .58396 L
.14498 .58356 L
.14552 .58331 L
.14582 .5832 L
.1461 .58312 L
.14626 .58309 L
.14643 .58306 L
.14659 .58304 L
.14674 .58302 L
.14687 .58301 L
.14702 .58301 L
.14717 .58301 L
.14732 .58301 L
.1474 .58301 L
.14749 .58302 L
.14764 .58303 L
.1478 .58305 L
.14794 .58307 L
.14862 .5832 L
.14979 .58352 L
.15041 .58371 L
.15106 .58388 L
.15163 .58401 L
.15178 .58403 L
.15195 .58406 L
.15209 .58408 L
.15225 .58409 L
.1524 .5841 L
.15255 .58411 L
.15268 .58411 L
.15283 .58411 L
.15295 .5841 L
Mistroke
.15307 .5841 L
.15321 .58408 L
.15335 .58406 L
.15349 .58404 L
.15365 .58401 L
.15393 .58394 L
.15426 .58382 L
.15457 .58369 L
.15516 .58335 L
.15572 .58292 L
.15677 .58185 L
.1579 .58027 L
.15904 .57821 L
.1603 .57544 L
.16284 .56833 L
.16772 .55006 L
.17242 .52843 L
.17741 .50272 L
.18222 .47631 L
.18684 .44994 L
.19176 .42126 L
.1965 .39329 L
.20105 .36626 L
.20591 .33754 L
.21057 .31036 L
.21295 .29701 L
.21554 .2833 L
.21674 .27757 L
.21739 .27472 L
.21802 .27231 L
.21859 .2704 L
.2189 .26958 L
.21922 .26888 L
.21935 .26866 L
.21949 .26846 L
.21965 .26831 L
.21979 .26823 L
.21993 .26821 L
.22007 .26827 L
.22019 .26838 L
.22032 .26858 L
.2204 .26875 L
.22048 .26896 L
.22063 .26944 L
.22079 .27014 L
.22096 .27115 L
.22111 .27228 L
.22128 .27381 L
.22157 .27763 L
.22171 .2802 L
Mistroke
.22187 .28367 L
.22201 .28745 L
.22216 .29237 L
.22229 .29781 L
.22244 .30516 L
.2227 .32252 L
.22338 .3937 L
.22354 .41035 L
.22371 .42534 L
.22387 .43656 L
.22402 .44505 L
.22417 .45168 L
.22432 .45742 L
.2246 .46479 L
.22476 .46792 L
.22493 .47055 L
.22509 .47251 L
.22523 .47395 L
.22551 .47598 L
.22566 .47677 L
.22581 .47734 L
.22594 .47774 L
.22606 .47802 L
.2262 .47822 L
.22634 .47835 L
.22649 .47838 L
.22665 .47834 L
.22679 .47823 L
.22693 .47807 L
.22708 .47784 L
.22724 .47753 L
.22757 .47675 L
.2282 .47478 L
.22887 .47219 L
.23009 .4667 L
.23509 .43918 L
.23991 .40993 L
.24455 .38076 L
.24948 .34905 L
.25423 .31799 L
.2588 .28772 L
.26366 .25513 L
.26834 .22349 L
.27332 .18968 L
.27812 .15708 L
.28273 .12586 L
.28763 .09299 L
.29236 .0619 L
.29477 .0463 L
.29604 .03819 L
Mistroke
.29738 .0297 L
.29858 .02214 L
.29891 .02008 L
.29926 .01788 L
.29943 .01681 L
.29959 .01581 L
.29974 .0149 L
.2999 .60286 L
.30004 .60197 L
.30017 .60114 L
.30048 .59925 L
.3011 .59543 L
.30221 .58863 L
.30688 .56081 L
.31185 .5327 L
.31663 .50725 L
.32123 .48451 L
.32613 .46242 L
.33085 .44346 L
.33585 .42603 L
.34068 .41194 L
.34533 .40067 L
.35027 .3905 L
.35502 .38161 L
.3596 .3731 L
.36447 .36356 L
.36915 .35387 L
.37414 .34338 L
.37894 .33382 L
.38355 .32607 L
.38593 .32304 L
.38714 .32184 L
.38778 .32131 L
.38847 .32085 L
.38905 .32053 L
.38935 .3204 L
.38968 .32027 L
.38998 .32019 L
.39026 .32013 L
.39039 .3201 L
.39053 .32009 L
.39067 .32007 L
.3908 .32007 L
.39094 .32006 L
.3911 .32007 L
.39124 .32008 L
.39138 .32009 L
.39153 .32012 L
.3917 .32015 L
.39202 .32024 L
Mistroke
.39234 .32036 L
.39269 .32052 L
.39331 .32092 L
.39396 .32148 L
.39455 .32213 L
.39589 .3241 L
.39708 .32647 L
.39833 .32966 L
.40069 .33775 L
.40291 .3476 L
.4076 .37296 L
.40999 .38568 L
.41259 .39762 L
.41509 .40671 L
.4174 .41302 L
.41965 .41741 L
.42093 .41921 L
.4215 .41987 L
.42213 .42048 L
.42271 .42094 L
.42332 .42135 L
.42366 .42153 L
.42396 .42168 L
.42428 .4218 L
.42457 .42189 L
.42483 .42196 L
.42512 .42201 L
.42526 .42203 L
.4254 .42204 L
.42555 .42205 L
.42564 .42206 L
.42571 .42206 L
.42585 .42206 L
.42598 .42206 L
.42612 .42205 L
.42627 .42204 L
.42641 .42202 L
.42655 .422 L
.4268 .42195 L
.42709 .42188 L
.42736 .4218 L
.42798 .42155 L
.42858 .42124 L
.42923 .42082 L
.43146 .41879 L
.43269 .41729 L
.43402 .41537 L
.43645 .41118 L
.44138 .4002 L
.44612 .387 L
Mistroke
.45068 .37239 L
.45554 .35518 L
.46021 .33735 L
.46518 .31732 L
.46996 .29721 L
.47457 .27728 L
.47947 .25558 L
.48418 .23433 L
.48919 .21147 L
.49402 .18926 L
.49624 .17904 L
.49749 .17324 L
.49867 .16781 L
.49926 .16506 L
.49956 .1637 L
.49983 .16245 L
.49998 .16175 L
.50005 .45587 L
.50014 .45548 L
.50048 .45391 L
.50107 .45117 L
.50361 .43943 L
.50846 .41709 L
.51312 .39572 L
.51808 .37322 L
.52285 .35187 L
.52745 .33172 L
.53234 .31082 L
.53704 .29139 L
.54204 .2717 L
.54686 .25391 L
.5515 .23819 L
.55643 .22339 L
.56118 .21149 L
.56575 .20276 L
.56809 .19951 L
.56941 .19809 L
.57061 .19707 L
.57118 .19667 L
.5718 .19633 L
.57238 .19607 L
.5729 .19589 L
.57322 .19581 L
.57352 .19576 L
.57367 .19574 L
.57384 .19572 L
.57393 .19572 L
.57402 .19571 L
.57411 .19571 L
.57419 .19571 L
Mistroke
.57434 .19571 L
.57449 .19572 L
.57464 .19573 L
.57472 .19574 L
.57481 .19575 L
.57512 .19581 L
.5754 .19587 L
.57597 .19607 L
.57659 .19637 L
.57724 .19678 L
.57784 .19727 L
.57892 .19838 L
.58007 .19992 L
.58131 .20202 L
.58265 .20485 L
.58508 .21159 L
.58748 .22042 L
.59002 .23212 L
.59459 .257 L
.59713 .27036 L
.59946 .28062 L
.60061 .2848 L
.60186 .28863 L
.60304 .29156 L
.60414 .29374 L
.60474 .2947 L
.60539 .29558 L
.60593 .29618 L
.60652 .29672 L
.60716 .29717 L
.60752 .29735 L
.60784 .29749 L
.60815 .29759 L
.60843 .29765 L
.60858 .29767 L
.60866 .29768 L
.60875 .29769 L
.60891 .2977 L
.60905 .29771 L
.6092 .29771 L
.60936 .2977 L
.60951 .29768 L
.60965 .29766 L
.60991 .29761 L
.61019 .29754 L
.61052 .29743 L
.61083 .2973 L
.61141 .297 L
.61247 .29626 L
.61362 .29521 L
Mistroke
.61602 .2923 L
.61856 .2884 L
.62314 .27994 L
.62801 .26988 L
.63271 .26001 L
.63769 .2499 L
.6425 .24074 L
.64712 .2322 L
.65204 .2227 L
.65677 .21225 L
.66133 .20028 L
.66617 .18502 L
.67084 .16781 L
.6758 .14691 L
.68058 .12451 L
.68517 .1011 L
.69007 .07442 L
.69477 .04722 L
.69718 .03285 L
.69844 .02516 L
.69913 .02092 L
.69947 .01883 L
.69978 .01692 L
.69992 .01605 L
.70007 .01509 L
.70022 .60313 L
.70035 .60229 L
.70097 .59844 L
.70229 .5902 L
.7046 .57551 L
.70932 .54488 L
.71435 .51159 L
.71918 .47902 L
.72384 .44742 L
.72879 .41374 L
.73356 .3814 L
.73814 .3505 L
.74302 .31792 L
.74772 .28695 L
.75272 .25452 L
.75753 .22387 L
.76216 .19513 L
.76708 .16607 L
.76953 .15298 L
.77072 .1473 L
.77125 .14508 L
.77182 .14292 L
.77234 .14128 L
.77262 .14054 L
.77289 .13999 L
Mistroke
.77304 .13975 L
.7732 .13956 L
.77334 .13944 L
.77347 .13939 L
.7736 .1394 L
.77374 .13949 L
.77388 .13966 L
.77402 .13992 L
.77416 .14033 L
.77432 .14093 L
.77447 .14168 L
.77461 .14256 L
.77488 .14484 L
.77501 .14637 L
.77516 .14843 L
.77546 .1543 L
.77563 .15889 L
.77579 .16422 L
.77608 .17788 L
.77622 .18722 L
.77638 .1998 L
.77696 .26248 L
.77727 .29255 L
.77742 .30418 L
.77759 .31442 L
.77774 .3215 L
.7779 .32758 L
.77805 .33208 L
.77819 .33556 L
.77833 .33836 L
.77848 .34086 L
.77874 .34414 L
.77892 .34573 L
.77907 .34685 L
.77926 .34784 L
.77943 .34853 L
.77959 .34899 L
.77973 .34928 L
.77981 .34939 L
.77989 .34947 L
.77998 .34953 L
.78006 .34956 L
.78022 .34954 L
.78037 .34945 L
.7805 .34932 L
.78064 .34912 L
.78097 .3485 L
.78127 .34776 L
.78243 .34377 L
.78352 .33903 L
Mistroke
.786 .32647 L
.79067 .30025 L
.79564 .27114 L
.80042 .24279 L
.80501 .21552 L
.80991 .18673 L
.81462 .15944 L
.81962 .13121 L
.82445 .10524 L
.82909 .08207 L
.83403 .06057 L
.83648 .05163 L
.83878 .04467 L
.84098 .0395 L
.84222 .03731 L
.84335 .03578 L
.84393 .03516 L
.84454 .03463 L
.84512 .03425 L
.84565 .03399 L
.84597 .03387 L
.84627 .03378 L
.84644 .03375 L
.84659 .03372 L
.84676 .03369 L
.84684 .03368 L
.84694 .03368 L
.84709 .03367 L
.84724 .03366 L
.84739 .03366 L
.84752 .03367 L
.84767 .03367 L
.84783 .03369 L
.84799 .03371 L
.84815 .03373 L
.84875 .03384 L
.8494 .03401 L
.85059 .03436 L
.85115 .03452 L
.85146 .03459 L
.85175 .03465 L
.85202 .0347 L
.85216 .03472 L
.85231 .03473 L
.85244 .03475 L
.85258 .03476 L
.8527 .03476 L
.85282 .03477 L
.85297 .03476 L
.85305 .03476 L
Mistroke
.85314 .03476 L
.85329 .03475 L
.85343 .03473 L
.85359 .03471 L
.85374 .03468 L
.85408 .0346 L
.85436 .03451 L
.85466 .03439 L
.85528 .03406 L
.85584 .03366 L
.85643 .03312 L
.85751 .03185 L
.85875 .02991 L
.86009 .02726 L
.86124 .02451 L
.86252 .02104 L
.86311 .01927 L
.86375 .01726 L
.86406 .01625 L
.86422 .01575 L
.86436 .01528 L
.86449 .01485 L
.86462 .60332 L
.86477 .6028 L
.86491 .60233 L
.86745 .5929 L
.87228 .57223 L
.87694 .55021 L
.88189 .5256 L
.88665 .50142 L
.89124 .47815 L
.89612 .45369 L
.90081 .43068 L
.90581 .40702 L
.91062 .3852 L
.91524 .36528 L
.92017 .34541 L
.92491 .32775 L
.92946 .31224 L
.93432 .29742 L
.93899 .28486 L
.94395 .27331 L
.94873 .26395 L
.95334 .25674 L
.9557 .25387 L
.95702 .25258 L
.95823 .25163 L
.95882 .25125 L
.95947 .25092 L
.96012 .25067 L
Mistroke
.96029 .25062 L
.96048 .25058 L
.96065 .25054 L
.96081 .25051 L
.96096 .25049 L
.96104 .25049 L
.96112 .25048 L
.96121 .25048 L
.9613 .25047 L
.96138 .25047 L
.96146 .25047 L
.9616 .25048 L
.96176 .25049 L
.96184 .2505 L
.96193 .25051 L
.96208 .25054 L
.96239 .25061 L
.96269 .25071 L
.96324 .25097 L
.9638 .25135 L
.96441 .25189 L
.96505 .25263 L
.96565 .25348 L
.96672 .25547 L
.96787 .25835 L
.96909 .26237 L
.97042 .26806 L
.97285 .28231 L
.97619 .30889 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00965678 0.97619 0.193595 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0529101 0.305869 0.00157381 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.15608 -0.0125 -9 -9 ]
[.15608 -0.0125 9 0 ]
[.28836 -0.0125 -3 -9 ]
[.28836 -0.0125 3 0 ]
[.42063 -0.0125 -9 -9 ]
[.42063 -0.0125 9 0 ]
[.55291 -0.0125 -6 -9 ]
[.55291 -0.0125 6 0 ]
[.68519 -0.0125 -12 -9 ]
[.68519 -0.0125 12 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.94974 -0.0125 -12 -9 ]
[.94974 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0698 -24 -4.5 ]
[-0.0125 .0698 0 4.5 ]
[-0.0125 .14849 -24 -4.5 ]
[-0.0125 .14849 0 4.5 ]
[-0.0125 .22718 -18 -4.5 ]
[-0.0125 .22718 0 4.5 ]
[-0.0125 .30587 -6 -4.5 ]
[-0.0125 .30587 0 4.5 ]
[-0.0125 .38456 -12 -4.5 ]
[-0.0125 .38456 0 4.5 ]
[-0.0125 .46325 -18 -4.5 ]
[-0.0125 .46325 0 4.5 ]
[-0.0125 .54194 -18 -4.5 ]
[-0.0125 .54194 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.15608 0 m
.15608 .00625 L
s
[(2.5)] .15608 -0.0125 0 1 Mshowa
.28836 0 m
.28836 .00625 L
s
[(5)] .28836 -0.0125 0 1 Mshowa
.42063 0 m
.42063 .00625 L
s
[(7.5)] .42063 -0.0125 0 1 Mshowa
.55291 0 m
.55291 .00625 L
s
[(10)] .55291 -0.0125 0 1 Mshowa
.68519 0 m
.68519 .00625 L
s
[(12.5)] .68519 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(15)] .81746 -0.0125 0 1 Mshowa
.94974 0 m
.94974 .00625 L
s
[(17.5)] .94974 -0.0125 0 1 Mshowa
.125 Mabswid
.05026 0 m
.05026 .00375 L
s
.07672 0 m
.07672 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.12963 0 m
.12963 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.20899 0 m
.20899 .00375 L
s
.23545 0 m
.23545 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.31481 0 m
.31481 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.36772 0 m
.36772 .00375 L
s
.39418 0 m
.39418 .00375 L
s
.44709 0 m
.44709 .00375 L
s
.47354 0 m
.47354 .00375 L
s
.5 0 m
.5 .00375 L
s
.52646 0 m
.52646 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.60582 0 m
.60582 .00375 L
s
.63228 0 m
.63228 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.71164 0 m
.71164 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.76455 0 m
.76455 .00375 L
s
.79101 0 m
.79101 .00375 L
s
.84392 0 m
.84392 .00375 L
s
.87037 0 m
.87037 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.92328 0 m
.92328 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0698 m
.00625 .0698 L
s
[(-150)] -0.0125 .0698 1 0 Mshowa
0 .14849 m
.00625 .14849 L
s
[(-100)] -0.0125 .14849 1 0 Mshowa
0 .22718 m
.00625 .22718 L
s
[(-50)] -0.0125 .22718 1 0 Mshowa
0 .30587 m
.00625 .30587 L
s
[(0)] -0.0125 .30587 1 0 Mshowa
0 .38456 m
.00625 .38456 L
s
[(50)] -0.0125 .38456 1 0 Mshowa
0 .46325 m
.00625 .46325 L
s
[(100)] -0.0125 .46325 1 0 Mshowa
0 .54194 m
.00625 .54194 L
s
[(150)] -0.0125 .54194 1 0 Mshowa
.125 Mabswid
0 .08554 m
.00375 .08554 L
s
0 .10127 m
.00375 .10127 L
s
0 .11701 m
.00375 .11701 L
s
0 .13275 m
.00375 .13275 L
s
0 .16423 m
.00375 .16423 L
s
0 .17996 m
.00375 .17996 L
s
0 .1957 m
.00375 .1957 L
s
0 .21144 m
.00375 .21144 L
s
0 .24292 m
.00375 .24292 L
s
0 .25866 m
.00375 .25866 L
s
0 .27439 m
.00375 .27439 L
s
0 .29013 m
.00375 .29013 L
s
0 .32161 m
.00375 .32161 L
s
0 .33735 m
.00375 .33735 L
s
0 .35308 m
.00375 .35308 L
s
0 .36882 m
.00375 .36882 L
s
0 .4003 m
.00375 .4003 L
s
0 .41604 m
.00375 .41604 L
s
0 .43177 m
.00375 .43177 L
s
0 .44751 m
.00375 .44751 L
s
0 .47899 m
.00375 .47899 L
s
0 .49473 m
.00375 .49473 L
s
0 .51046 m
.00375 .51046 L
s
0 .5262 m
.00375 .5262 L
s
0 .55768 m
.00375 .55768 L
s
0 .57342 m
.00375 .57342 L
s
0 .58915 m
.00375 .58915 L
s
0 .60489 m
.00375 .60489 L
s
0 .05406 m
.00375 .05406 L
s
0 .03832 m
.00375 .03832 L
s
0 .02258 m
.00375 .02258 L
s
0 .00685 m
.00375 .00685 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.15608 .61178 m
.15608 .61803 L
s
.28836 .61178 m
.28836 .61803 L
s
.42063 .61178 m
.42063 .61803 L
s
.55291 .61178 m
.55291 .61803 L
s
.68519 .61178 m
.68519 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.94974 .61178 m
.94974 .61803 L
s
.125 Mabswid
.05026 .61428 m
.05026 .61803 L
s
.07672 .61428 m
.07672 .61803 L
s
.10317 .61428 m
.10317 .61803 L
s
.12963 .61428 m
.12963 .61803 L
s
.18254 .61428 m
.18254 .61803 L
s
.20899 .61428 m
.20899 .61803 L
s
.23545 .61428 m
.23545 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.31481 .61428 m
.31481 .61803 L
s
.34127 .61428 m
.34127 .61803 L
s
.36772 .61428 m
.36772 .61803 L
s
.39418 .61428 m
.39418 .61803 L
s
.44709 .61428 m
.44709 .61803 L
s
.47354 .61428 m
.47354 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.52646 .61428 m
.52646 .61803 L
s
.57937 .61428 m
.57937 .61803 L
s
.60582 .61428 m
.60582 .61803 L
s
.63228 .61428 m
.63228 .61803 L
s
.65873 .61428 m
.65873 .61803 L
s
.71164 .61428 m
.71164 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.76455 .61428 m
.76455 .61803 L
s
.79101 .61428 m
.79101 .61803 L
s
.84392 .61428 m
.84392 .61803 L
s
.87037 .61428 m
.87037 .61803 L
s
.89683 .61428 m
.89683 .61803 L
s
.92328 .61428 m
.92328 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0698 m
1 .0698 L
s
.99375 .14849 m
1 .14849 L
s
.99375 .22718 m
1 .22718 L
s
.99375 .30587 m
1 .30587 L
s
.99375 .38456 m
1 .38456 L
s
.99375 .46325 m
1 .46325 L
s
.99375 .54194 m
1 .54194 L
s
.125 Mabswid
.99625 .08554 m
1 .08554 L
s
.99625 .10127 m
1 .10127 L
s
.99625 .11701 m
1 .11701 L
s
.99625 .13275 m
1 .13275 L
s
.99625 .16423 m
1 .16423 L
s
.99625 .17996 m
1 .17996 L
s
.99625 .1957 m
1 .1957 L
s
.99625 .21144 m
1 .21144 L
s
.99625 .24292 m
1 .24292 L
s
.99625 .25866 m
1 .25866 L
s
.99625 .27439 m
1 .27439 L
s
.99625 .29013 m
1 .29013 L
s
.99625 .32161 m
1 .32161 L
s
.99625 .33735 m
1 .33735 L
s
.99625 .35308 m
1 .35308 L
s
.99625 .36882 m
1 .36882 L
s
.99625 .4003 m
1 .4003 L
s
.99625 .41604 m
1 .41604 L
s
.99625 .43177 m
1 .43177 L
s
.99625 .44751 m
1 .44751 L
s
.99625 .47899 m
1 .47899 L
s
.99625 .49473 m
1 .49473 L
s
.99625 .51046 m
1 .51046 L
s
.99625 .5262 m
1 .5262 L
s
.99625 .55768 m
1 .55768 L
s
.99625 .57342 m
1 .57342 L
s
.99625 .58915 m
1 .58915 L
s
.99625 .60489 m
1 .60489 L
s
.99625 .05406 m
1 .05406 L
s
.99625 .03832 m
1 .03832 L
s
.99625 .02258 m
1 .02258 L
s
.99625 .00685 m
1 .00685 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30587 m
1 .30587 L
s
0 1 0 r
.5 Mabswid
.02381 .30587 m
.02381 .40659 L
s
.07672 .30587 m
.07672 .40659 L
s
.12963 .30587 m
.12963 .46797 L
s
.18254 .30587 m
.18254 .33735 L
s
.23545 .30587 m
.23545 .41446 L
s
.28836 .30587 m
.28836 .06508 L
s
.34127 .30587 m
.34127 .26023 L
s
.39418 .30587 m
.39418 .60332 L
s
.44709 .30587 m
.44709 .3279 L
s
.5 .30587 m
.5 .22875 L
s
.55291 .30587 m
.55291 .01472 L
s
.60582 .30587 m
.60582 .29013 L
s
.65873 .30587 m
.65873 .4239 L
s
.71164 .30587 m
.71164 .29171 L
s
.76455 .30587 m
.76455 .12173 L
s
.81746 .30587 m
.81746 .19728 L
s
.87037 .30587 m
.87037 .44122 L
s
.92328 .30587 m
.92328 .29485 L
s
.97619 .30587 m
.97619 .21774 L
s
.015 w
.02381 .40659 Mdot
.07672 .40659 Mdot
.12963 .46797 Mdot
.18254 .33735 Mdot
.23545 .41446 Mdot
.28836 .06508 Mdot
.34127 .26023 Mdot
.39418 .60332 Mdot
.44709 .3279 Mdot
.5 .22875 Mdot
.55291 .01472 Mdot
.60582 .29013 Mdot
.65873 .4239 Mdot
.71164 .29171 Mdot
.76455 .12173 Mdot
.81746 .19728 Mdot
.87037 .44122 Mdot
.92328 .29485 Mdot
.97619 .21774 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.211989 0.321429 0.395928 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.151576 0.014388 0.000733898 [
[.04527 -0.0125 -6 -9 ]
[.04527 -0.0125 6 0 ]
[.19685 -0.0125 -6 -9 ]
[.19685 -0.0125 6 0 ]
[.34842 -0.0125 -6 -9 ]
[.34842 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65158 -0.0125 -3 -9 ]
[.65158 -0.0125 3 0 ]
[.80315 -0.0125 -3 -9 ]
[.80315 -0.0125 3 0 ]
[.95473 -0.0125 -3 -9 ]
[.95473 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01439 -6 -4.5 ]
[-0.0125 .01439 0 4.5 ]
[-0.0125 .16117 -18 -4.5 ]
[-0.0125 .16117 0 4.5 ]
[-0.0125 .30795 -18 -4.5 ]
[-0.0125 .30795 0 4.5 ]
[-0.0125 .45473 -18 -4.5 ]
[-0.0125 .45473 0 4.5 ]
[-0.0125 .60151 -18 -4.5 ]
[-0.0125 .60151 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 0 m
.04527 .00625 L
s
[(-3)] .04527 -0.0125 0 1 Mshowa
.19685 0 m
.19685 .00625 L
s
[(-2)] .19685 -0.0125 0 1 Mshowa
.34842 0 m
.34842 .00625 L
s
[(-1)] .34842 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.65158 0 m
.65158 .00625 L
s
[(1)] .65158 -0.0125 0 1 Mshowa
.80315 0 m
.80315 .00625 L
s
[(2)] .80315 -0.0125 0 1 Mshowa
.95473 0 m
.95473 .00625 L
s
[(3)] .95473 -0.0125 0 1 Mshowa
.125 Mabswid
.07559 0 m
.07559 .00375 L
s
.1059 0 m
.1059 .00375 L
s
.13622 0 m
.13622 .00375 L
s
.16653 0 m
.16653 .00375 L
s
.22716 0 m
.22716 .00375 L
s
.25748 0 m
.25748 .00375 L
s
.28779 0 m
.28779 .00375 L
s
.31811 0 m
.31811 .00375 L
s
.37874 0 m
.37874 .00375 L
s
.40905 0 m
.40905 .00375 L
s
.43937 0 m
.43937 .00375 L
s
.46968 0 m
.46968 .00375 L
s
.53032 0 m
.53032 .00375 L
s
.56063 0 m
.56063 .00375 L
s
.59095 0 m
.59095 .00375 L
s
.62126 0 m
.62126 .00375 L
s
.68189 0 m
.68189 .00375 L
s
.71221 0 m
.71221 .00375 L
s
.74252 0 m
.74252 .00375 L
s
.77284 0 m
.77284 .00375 L
s
.83347 0 m
.83347 .00375 L
s
.86378 0 m
.86378 .00375 L
s
.8941 0 m
.8941 .00375 L
s
.92441 0 m
.92441 .00375 L
s
.01496 0 m
.01496 .00375 L
s
.98504 0 m
.98504 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01439 m
.00625 .01439 L
s
[(0)] -0.0125 .01439 1 0 Mshowa
0 .16117 m
.00625 .16117 L
s
[(200)] -0.0125 .16117 1 0 Mshowa
0 .30795 m
.00625 .30795 L
s
[(400)] -0.0125 .30795 1 0 Mshowa
0 .45473 m
.00625 .45473 L
s
[(600)] -0.0125 .45473 1 0 Mshowa
0 .60151 m
.00625 .60151 L
s
[(800)] -0.0125 .60151 1 0 Mshowa
.125 Mabswid
0 .05108 m
.00375 .05108 L
s
0 .08778 m
.00375 .08778 L
s
0 .12447 m
.00375 .12447 L
s
0 .19786 m
.00375 .19786 L
s
0 .23456 m
.00375 .23456 L
s
0 .27125 m
.00375 .27125 L
s
0 .34464 m
.00375 .34464 L
s
0 .38134 m
.00375 .38134 L
s
0 .41803 m
.00375 .41803 L
s
0 .49142 m
.00375 .49142 L
s
0 .52812 m
.00375 .52812 L
s
0 .56481 m
.00375 .56481 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.04527 .61178 m
.04527 .61803 L
s
.19685 .61178 m
.19685 .61803 L
s
.34842 .61178 m
.34842 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65158 .61178 m
.65158 .61803 L
s
.80315 .61178 m
.80315 .61803 L
s
.95473 .61178 m
.95473 .61803 L
s
.125 Mabswid
.07559 .61428 m
.07559 .61803 L
s
.1059 .61428 m
.1059 .61803 L
s
.13622 .61428 m
.13622 .61803 L
s
.16653 .61428 m
.16653 .61803 L
s
.22716 .61428 m
.22716 .61803 L
s
.25748 .61428 m
.25748 .61803 L
s
.28779 .61428 m
.28779 .61803 L
s
.31811 .61428 m
.31811 .61803 L
s
.37874 .61428 m
.37874 .61803 L
s
.40905 .61428 m
.40905 .61803 L
s
.43937 .61428 m
.43937 .61803 L
s
.46968 .61428 m
.46968 .61803 L
s
.53032 .61428 m
.53032 .61803 L
s
.56063 .61428 m
.56063 .61803 L
s
.59095 .61428 m
.59095 .61803 L
s
.62126 .61428 m
.62126 .61803 L
s
.68189 .61428 m
.68189 .61803 L
s
.71221 .61428 m
.71221 .61803 L
s
.74252 .61428 m
.74252 .61803 L
s
.77284 .61428 m
.77284 .61803 L
s
.83347 .61428 m
.83347 .61803 L
s
.86378 .61428 m
.86378 .61803 L
s
.8941 .61428 m
.8941 .61803 L
s
.92441 .61428 m
.92441 .61803 L
s
.01496 .61428 m
.01496 .61803 L
s
.98504 .61428 m
.98504 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01439 m
1 .01439 L
s
.99375 .16117 m
1 .16117 L
s
.99375 .30795 m
1 .30795 L
s
.99375 .45473 m
1 .45473 L
s
.99375 .60151 m
1 .60151 L
s
.125 Mabswid
.99625 .05108 m
1 .05108 L
s
.99625 .08778 m
1 .08778 L
s
.99625 .12447 m
1 .12447 L
s
.99625 .19786 m
1 .19786 L
s
.99625 .23456 m
1 .23456 L
s
.99625 .27125 m
1 .27125 L
s
.99625 .34464 m
1 .34464 L
s
.99625 .38134 m
1 .38134 L
s
.99625 .41803 m
1 .41803 L
s
.99625 .49142 m
1 .49142 L
s
.99625 .52812 m
1 .52812 L
s
.99625 .56481 m
1 .56481 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .04962 m
.02395 .04962 L
.02408 .04963 L
.02423 .04966 L
.02437 .04969 L
.02462 .04978 L
.02489 .04991 L
.02519 .0501 L
.02551 .05034 L
.02608 .0509 L
.02722 .05244 L
.02847 .05474 L
.03109 .06111 L
.03355 .0684 L
.03823 .0842 L
.0432 .10244 L
.04799 .12095 L
.05259 .1397 L
.0575 .16088 L
.06221 .18253 L
.06723 .20661 L
.07206 .2302 L
.07671 .25235 L
.08166 .27413 L
.08642 .29214 L
.091 .30563 L
.09335 .31082 L
.09587 .31492 L
.0971 .31633 L
.09775 .31693 L
.09843 .31743 L
.09903 .31778 L
.09935 .31792 L
.0997 .31804 L
.10001 .31813 L
.10015 .31816 L
.1003 .31818 L
.10044 .3182 L
.10057 .31822 L
.10071 .31822 L
.10086 .31823 L
.10101 .31822 L
.10109 .31822 L
.10117 .31821 L
.10133 .3182 L
.10142 .31819 L
.1015 .31817 L
.10181 .31811 L
.1021 .31802 L
.10243 .3179 L
Mistroke
.10274 .31776 L
.10344 .31734 L
.10405 .31685 L
.10461 .31633 L
.10587 .31484 L
.10819 .31097 L
.1107 .30518 L
.11566 .28918 L
.12042 .26865 L
.12501 .2451 L
.12989 .21732 L
.13459 .18972 L
.13959 .1623 L
.14209 .15061 L
.1444 .14183 L
.14556 .13835 L
.14664 .13573 L
.14724 .13459 L
.14778 .13373 L
.14838 .13298 L
.14869 .13268 L
.14903 .13243 L
.14918 .13234 L
.14934 .13226 L
.14948 .1322 L
.14963 .13215 L
.14977 .13212 L
.14992 .1321 L
.15005 .1321 L
.15018 .1321 L
.15034 .13213 L
.15049 .13216 L
.15063 .13221 L
.15077 .13227 L
.15111 .13246 L
.15141 .1327 L
.15192 .13323 L
.15249 .13399 L
.15363 .13612 L
.15484 .13919 L
.15596 .14266 L
.15847 .15242 L
.16325 .17588 L
.16784 .20082 L
.17273 .22628 L
.17743 .24711 L
.17983 .25565 L
.1811 .25947 L
.18243 .26296 L
.18363 .26556 L
Mistroke
.18494 .26784 L
.18552 .26864 L
.18613 .26936 L
.18668 .26987 L
.18725 .27028 L
.18758 .27046 L
.18788 .27058 L
.18803 .27063 L
.18819 .27067 L
.18834 .2707 L
.18847 .27072 L
.18855 .27072 L
.18863 .27073 L
.18878 .27073 L
.18887 .27073 L
.18896 .27072 L
.18904 .27071 L
.18912 .2707 L
.18929 .27067 L
.18947 .27062 L
.1898 .27049 L
.19009 .27035 L
.1904 .27015 L
.19096 .2697 L
.19162 .26898 L
.19223 .26815 L
.19341 .26607 L
.19451 .26357 L
.19701 .25584 L
.19948 .24537 L
.20172 .23341 L
.20654 .19989 L
.21118 .15814 L
.21612 .10473 L
.21858 .07532 L
.22088 .04686 L
.22142 .04024 L
.22201 .03336 L
.22228 .03047 L
.22257 .02777 L
.2227 .02668 L
.22284 .02583 L
.22295 .02526 L
.22308 .02488 L
.22323 .02479 L
.22332 .02491 L
.2234 .02513 L
.22348 .02548 L
.22356 .02588 L
.22373 .02705 L
Mistroke
.22403 .02981 L
.22432 .03291 L
.22545 .04703 L
.23008 .11142 L
.23501 .18193 L
.23975 .24873 L
.24431 .30999 L
.24917 .37032 L
.25384 .42238 L
.25881 .4704 L
.2636 .50917 L
.26821 .53959 L
.27311 .56493 L
.27783 .58294 L
.28041 .59032 L
.28284 .59573 L
.28402 .59782 L
.28526 .59967 L
.28642 .60106 L
.28749 .60203 L
.28803 .60243 L
.28863 .60278 L
.28896 .60293 L
.28926 .60305 L
.28957 .60315 L
.28985 .60322 L
.2901 .60327 L
.29024 .60329 L
.29036 .6033 L
.29049 .60331 L
.29064 .60332 L
.29079 .60332 L
.29093 .60331 L
.29107 .6033 L
.29121 .60329 L
.29134 .60327 L
.29148 .60325 L
.29178 .60318 L
.29206 .6031 L
.29263 .60288 L
.29323 .60255 L
.29433 .60172 L
.29563 .60034 L
.29682 .59871 L
.29911 .59453 L
.30161 .58839 L
.30652 .57152 L
.31124 .54928 L
.31626 .51963 L
.3211 .48613 L
Mistroke
.32575 .45069 L
.3307 .41152 L
.33547 .37458 L
.34005 .34185 L
.34493 .31184 L
.34963 .2885 L
.35462 .26923 L
.35943 .25432 L
.36406 .24119 L
.36898 .22631 L
.37372 .20959 L
.37828 .19078 L
.38313 .16813 L
.38781 .14485 L
.39277 .12045 L
.39525 .10924 L
.39756 .09991 L
.39992 .09185 L
.40216 .08607 L
.40334 .08383 L
.40401 .08285 L
.40463 .08213 L
.40515 .08167 L
.40545 .08146 L
.40572 .0813 L
.406 .08117 L
.40616 .08112 L
.40631 .08108 L
.40645 .08106 L
.40658 .08104 L
.40672 .08103 L
.40687 .08103 L
.40701 .08104 L
.40716 .08106 L
.40731 .0811 L
.40746 .08114 L
.40772 .08123 L
.408 .08137 L
.40863 .08182 L
.40921 .08238 L
.41035 .08389 L
.41142 .08578 L
.41383 .09151 L
.41605 .09837 L
.4208 .11717 L
.42536 .13979 L
.43022 .16807 L
.4349 .19841 L
.43987 .2323 L
.44466 .2643 L
Mistroke
.44927 .29212 L
.45184 .30551 L
.45417 .3159 L
.45663 .32474 L
.45889 .33072 L
.46002 .33286 L
.4606 .33372 L
.46121 .33447 L
.46154 .3348 L
.46183 .33504 L
.46213 .33525 L
.46241 .33541 L
.46256 .33548 L
.46273 .33554 L
.4629 .33559 L
.463 .33561 L
.46309 .33562 L
.46316 .33563 L
.46325 .33564 L
.46339 .33564 L
.46355 .33564 L
.46364 .33563 L
.46372 .33561 L
.46388 .33558 L
.46404 .33553 L
.46433 .33541 L
.46465 .33523 L
.46499 .33497 L
.46561 .33435 L
.46619 .33359 L
.46727 .33169 L
.46843 .32894 L
.46966 .32526 L
.47099 .32031 L
.47341 .30879 L
.47832 .27578 L
.48305 .2325 L
.48807 .17594 L
.49291 .11355 L
.49757 .04895 L
.49881 .03126 L
.49942 .0226 L
.49969 .01882 L
.49983 .01683 L
.49998 .01472 L
.50013 .01629 L
.50028 .01835 L
.50056 .0224 L
.50119 .03132 L
.50252 .05017 L
Mistroke
.50708 .11341 L
.51194 .17602 L
.51661 .22896 L
.52158 .27497 L
.52406 .29338 L
.52636 .30757 L
.52859 .31854 L
.53097 .32724 L
.53221 .33055 L
.53286 .33195 L
.53355 .33319 L
.53415 .33406 L
.53447 .33445 L
.53481 .3348 L
.53513 .33507 L
.53542 .33527 L
.5357 .33543 L
.53598 .33554 L
.53612 .33558 L
.53626 .33561 L
.5364 .33563 L
.53653 .33564 L
.53667 .33564 L
.53683 .33563 L
.53691 .33562 L
.53699 .33561 L
.53714 .33558 L
.5373 .33553 L
.53747 .33546 L
.53779 .3353 L
.53809 .3351 L
.53838 .33487 L
.53946 .33365 L
.54 .33282 L
.5406 .33176 L
.54294 .32604 L
.54546 .31737 L
.55044 .29376 L
.55523 .26502 L
.55984 .23429 L
.56474 .20082 L
.56946 .17002 L
.57448 .14063 L
.57932 .11665 L
.58397 .09829 L
.58638 .09094 L
.58761 .08787 L
.58892 .08513 L
.58956 .08404 L
.59016 .08315 L
Mistroke
.59075 .08242 L
.59129 .08188 L
.5918 .08149 L
.59206 .08134 L
.59235 .0812 L
.59249 .08115 L
.59264 .08111 L
.59271 .08109 L
.5928 .08107 L
.59294 .08105 L
.59308 .08103 L
.59323 .08103 L
.59337 .08104 L
.5935 .08105 L
.59365 .08107 L
.59378 .08111 L
.59393 .08115 L
.59409 .08121 L
.59441 .08137 L
.59471 .08156 L
.59528 .08204 L
.59582 .08264 L
.59702 .08445 L
.59833 .08715 L
.60071 .09382 L
.60324 .10299 L
.60826 .12538 L
.61311 .14943 L
.61776 .17249 L
.62272 .19514 L
.62749 .21415 L
.63208 .2297 L
.63697 .24411 L
.64167 .25753 L
.64667 .27374 L
.65148 .29352 L
.65611 .31778 L
.66104 .3493 L
.66579 .38409 L
.67035 .41983 L
.67521 .45816 L
.67988 .49323 L
.68485 .5267 L
.68964 .55386 L
.69425 .57457 L
.69682 .58368 L
.69915 .59042 L
.70158 .59592 L
.70387 .59969 L
.70504 .60111 L
Mistroke
.70569 .60173 L
.70629 .60222 L
.70684 .60259 L
.70735 .60287 L
.70791 .60309 L
.70822 .60318 L
.70836 .60322 L
.70852 .60325 L
.70866 .60327 L
.7088 .60329 L
.70893 .60331 L
.70907 .60331 L
.70922 .60332 L
.70936 .60332 L
.70952 .60331 L
.7096 .60331 L
.70968 .6033 L
.70984 .60328 L
.70999 .60326 L
.71032 .60318 L
.71061 .6031 L
.71092 .60299 L
.71146 .60273 L
.71197 .60242 L
.71314 .60149 L
.71439 .60012 L
.71558 .59846 L
.71782 .59441 L
.72021 .5887 L
.72243 .58211 L
.72716 .56374 L
.73218 .5373 L
.73702 .50458 L
.74167 .46606 L
.74662 .41748 L
.75139 .36368 L
.75597 .30625 L
.76086 .24032 L
.76555 .17392 L
.77055 .10249 L
.77305 .0674 L
.77415 .05241 L
.77536 .03673 L
.77592 .03035 L
.77621 .02757 L
.77637 .02635 L
.77652 .02549 L
.77665 .02499 L
.77679 .02478 L
.77694 .02494 L
Mistroke
.77708 .02543 L
.77721 .02613 L
.77735 .0271 L
.7776 .02931 L
.77999 .05758 L
.78493 .11677 L
.78969 .16664 L
.79426 .2062 L
.79681 .22428 L
.79913 .23822 L
.80157 .25013 L
.80382 .25872 L
.80612 .26506 L
.80733 .26744 L
.808 .26848 L
.80862 .26926 L
.80917 .26981 L
.80975 .27025 L
.81005 .27042 L
.81033 .27055 L
.81049 .27061 L
.81064 .27065 L
.81072 .27067 L
.81081 .27069 L
.81097 .27071 L
.8111 .27073 L
.81123 .27073 L
.81137 .27073 L
.81152 .27072 L
.81168 .2707 L
.81183 .27067 L
.81196 .27063 L
.81211 .27058 L
.81238 .27048 L
.81266 .27033 L
.81317 .26999 L
.81382 .26941 L
.81441 .26873 L
.81575 .26672 L
.81694 .26439 L
.81819 .26141 L
.82277 .24632 L
.82764 .22445 L
.83234 .19985 L
.83733 .17283 L
.83983 .16021 L
.84214 .14984 L
.84438 .14155 L
.84553 .13818 L
.84613 .13668 L
Mistroke
.84676 .13531 L
.84735 .13426 L
.84799 .13334 L
.84827 .13301 L
.84857 .13272 L
.84885 .13249 L
.84911 .13233 L
.84925 .13226 L
.8494 .1322 L
.84955 .13215 L
.8497 .13212 L
.84984 .1321 L
.84999 .1321 L
.85014 .13211 L
.85027 .13213 L
.8504 .13216 L
.85052 .1322 L
.8508 .13233 L
.85105 .13248 L
.85132 .13268 L
.85196 .13338 L
.85256 .13424 L
.8539 .13697 L
.85509 .1402 L
.85634 .14438 L
.86093 .1649 L
.86581 .19205 L
.87051 .21967 L
.87551 .2479 L
.88032 .27215 L
.88495 .29145 L
.88729 .29943 L
.88988 .30667 L
.89233 .31196 L
.89342 .31381 L
.89462 .31547 L
.89527 .31621 L
.89587 .31679 L
.8965 .31729 L
.89706 .31765 L
.89733 .31779 L
.89762 .31792 L
.89787 .31801 L
.89814 .3181 L
.89843 .31816 L
.89859 .31819 L
.89874 .31821 L
.89888 .31822 L
.89901 .31823 L
.89916 .31823 L
Mistroke
.89929 .31822 L
.89943 .31822 L
.89958 .3182 L
.89972 .31818 L
.89985 .31816 L
.90015 .31809 L
.90046 .31799 L
.90105 .31773 L
.90169 .31735 L
.90284 .31639 L
.90392 .31519 L
.90638 .31133 L
.90862 .30656 L
.91344 .29261 L
.91808 .27522 L
.92301 .25363 L
.92776 .23105 L
.93233 .20876 L
.93719 .18533 L
.94187 .16371 L
.94685 .14204 L
.95164 .12242 L
.95625 .10451 L
.96116 .08639 L
.96588 .07021 L
.96829 .06283 L
.96956 .05935 L
.9709 .05609 L
.9721 .05362 L
.97274 .05251 L
.97342 .05151 L
.97405 .05076 L
.97462 .05024 L
.9749 .05004 L
.97519 .04987 L
.97533 .0498 L
.97548 .04974 L
.9756 .0497 L
.97574 .04967 L
.97586 .04964 L
.97597 .04963 L
.97608 .04962 L
.97619 .04962 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.211989 0.64881 0.395928 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.151576 0.308886 0.0937319 [
[.04527 -0.0125 -6 -9 ]
[.04527 -0.0125 6 0 ]
[.19685 -0.0125 -6 -9 ]
[.19685 -0.0125 6 0 ]
[.34842 -0.0125 -6 -9 ]
[.34842 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65158 -0.0125 -3 -9 ]
[.65158 -0.0125 3 0 ]
[.80315 -0.0125 -3 -9 ]
[.80315 -0.0125 3 0 ]
[.95473 -0.0125 -3 -9 ]
[.95473 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02769 -12 -4.5 ]
[-0.0125 .02769 0 4.5 ]
[-0.0125 .12142 -12 -4.5 ]
[-0.0125 .12142 0 4.5 ]
[-0.0125 .21515 -12 -4.5 ]
[-0.0125 .21515 0 4.5 ]
[-0.0125 .30889 -6 -4.5 ]
[-0.0125 .30889 0 4.5 ]
[-0.0125 .40262 -6 -4.5 ]
[-0.0125 .40262 0 4.5 ]
[-0.0125 .49635 -6 -4.5 ]
[-0.0125 .49635 0 4.5 ]
[-0.0125 .59008 -6 -4.5 ]
[-0.0125 .59008 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 0 m
.04527 .00625 L
s
[(-3)] .04527 -0.0125 0 1 Mshowa
.19685 0 m
.19685 .00625 L
s
[(-2)] .19685 -0.0125 0 1 Mshowa
.34842 0 m
.34842 .00625 L
s
[(-1)] .34842 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.65158 0 m
.65158 .00625 L
s
[(1)] .65158 -0.0125 0 1 Mshowa
.80315 0 m
.80315 .00625 L
s
[(2)] .80315 -0.0125 0 1 Mshowa
.95473 0 m
.95473 .00625 L
s
[(3)] .95473 -0.0125 0 1 Mshowa
.125 Mabswid
.07559 0 m
.07559 .00375 L
s
.1059 0 m
.1059 .00375 L
s
.13622 0 m
.13622 .00375 L
s
.16653 0 m
.16653 .00375 L
s
.22716 0 m
.22716 .00375 L
s
.25748 0 m
.25748 .00375 L
s
.28779 0 m
.28779 .00375 L
s
.31811 0 m
.31811 .00375 L
s
.37874 0 m
.37874 .00375 L
s
.40905 0 m
.40905 .00375 L
s
.43937 0 m
.43937 .00375 L
s
.46968 0 m
.46968 .00375 L
s
.53032 0 m
.53032 .00375 L
s
.56063 0 m
.56063 .00375 L
s
.59095 0 m
.59095 .00375 L
s
.62126 0 m
.62126 .00375 L
s
.68189 0 m
.68189 .00375 L
s
.71221 0 m
.71221 .00375 L
s
.74252 0 m
.74252 .00375 L
s
.77284 0 m
.77284 .00375 L
s
.83347 0 m
.83347 .00375 L
s
.86378 0 m
.86378 .00375 L
s
.8941 0 m
.8941 .00375 L
s
.92441 0 m
.92441 .00375 L
s
.01496 0 m
.01496 .00375 L
s
.98504 0 m
.98504 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02769 m
.00625 .02769 L
s
[(-3)] -0.0125 .02769 1 0 Mshowa
0 .12142 m
.00625 .12142 L
s
[(-2)] -0.0125 .12142 1 0 Mshowa
0 .21515 m
.00625 .21515 L
s
[(-1)] -0.0125 .21515 1 0 Mshowa
0 .30889 m
.00625 .30889 L
s
[(0)] -0.0125 .30889 1 0 Mshowa
0 .40262 m
.00625 .40262 L
s
[(1)] -0.0125 .40262 1 0 Mshowa
0 .49635 m
.00625 .49635 L
s
[(2)] -0.0125 .49635 1 0 Mshowa
0 .59008 m
.00625 .59008 L
s
[(3)] -0.0125 .59008 1 0 Mshowa
.125 Mabswid
0 .04644 m
.00375 .04644 L
s
0 .06518 m
.00375 .06518 L
s
0 .08393 m
.00375 .08393 L
s
0 .10268 m
.00375 .10268 L
s
0 .14017 m
.00375 .14017 L
s
0 .15892 m
.00375 .15892 L
s
0 .17766 m
.00375 .17766 L
s
0 .19641 m
.00375 .19641 L
s
0 .2339 m
.00375 .2339 L
s
0 .25265 m
.00375 .25265 L
s
0 .27139 m
.00375 .27139 L
s
0 .29014 m
.00375 .29014 L
s
0 .32763 m
.00375 .32763 L
s
0 .34638 m
.00375 .34638 L
s
0 .36513 m
.00375 .36513 L
s
0 .38387 m
.00375 .38387 L
s
0 .42136 m
.00375 .42136 L
s
0 .44011 m
.00375 .44011 L
s
0 .45886 m
.00375 .45886 L
s
0 .4776 m
.00375 .4776 L
s
0 .5151 m
.00375 .5151 L
s
0 .53384 m
.00375 .53384 L
s
0 .55259 m
.00375 .55259 L
s
0 .57134 m
.00375 .57134 L
s
0 .00894 m
.00375 .00894 L
s
0 .60883 m
.00375 .60883 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.04527 .61178 m
.04527 .61803 L
s
.19685 .61178 m
.19685 .61803 L
s
.34842 .61178 m
.34842 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65158 .61178 m
.65158 .61803 L
s
.80315 .61178 m
.80315 .61803 L
s
.95473 .61178 m
.95473 .61803 L
s
.125 Mabswid
.07559 .61428 m
.07559 .61803 L
s
.1059 .61428 m
.1059 .61803 L
s
.13622 .61428 m
.13622 .61803 L
s
.16653 .61428 m
.16653 .61803 L
s
.22716 .61428 m
.22716 .61803 L
s
.25748 .61428 m
.25748 .61803 L
s
.28779 .61428 m
.28779 .61803 L
s
.31811 .61428 m
.31811 .61803 L
s
.37874 .61428 m
.37874 .61803 L
s
.40905 .61428 m
.40905 .61803 L
s
.43937 .61428 m
.43937 .61803 L
s
.46968 .61428 m
.46968 .61803 L
s
.53032 .61428 m
.53032 .61803 L
s
.56063 .61428 m
.56063 .61803 L
s
.59095 .61428 m
.59095 .61803 L
s
.62126 .61428 m
.62126 .61803 L
s
.68189 .61428 m
.68189 .61803 L
s
.71221 .61428 m
.71221 .61803 L
s
.74252 .61428 m
.74252 .61803 L
s
.77284 .61428 m
.77284 .61803 L
s
.83347 .61428 m
.83347 .61803 L
s
.86378 .61428 m
.86378 .61803 L
s
.8941 .61428 m
.8941 .61803 L
s
.92441 .61428 m
.92441 .61803 L
s
.01496 .61428 m
.01496 .61803 L
s
.98504 .61428 m
.98504 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02769 m
1 .02769 L
s
.99375 .12142 m
1 .12142 L
s
.99375 .21515 m
1 .21515 L
s
.99375 .30889 m
1 .30889 L
s
.99375 .40262 m
1 .40262 L
s
.99375 .49635 m
1 .49635 L
s
.99375 .59008 m
1 .59008 L
s
.125 Mabswid
.99625 .04644 m
1 .04644 L
s
.99625 .06518 m
1 .06518 L
s
.99625 .08393 m
1 .08393 L
s
.99625 .10268 m
1 .10268 L
s
.99625 .14017 m
1 .14017 L
s
.99625 .15892 m
1 .15892 L
s
.99625 .17766 m
1 .17766 L
s
.99625 .19641 m
1 .19641 L
s
.99625 .2339 m
1 .2339 L
s
.99625 .25265 m
1 .25265 L
s
.99625 .27139 m
1 .27139 L
s
.99625 .29014 m
1 .29014 L
s
.99625 .32763 m
1 .32763 L
s
.99625 .34638 m
1 .34638 L
s
.99625 .36513 m
1 .36513 L
s
.99625 .38387 m
1 .38387 L
s
.99625 .42136 m
1 .42136 L
s
.99625 .44011 m
1 .44011 L
s
.99625 .45886 m
1 .45886 L
s
.99625 .4776 m
1 .4776 L
s
.99625 .5151 m
1 .5151 L
s
.99625 .53384 m
1 .53384 L
s
.99625 .55259 m
1 .55259 L
s
.99625 .57134 m
1 .57134 L
s
.99625 .00894 m
1 .00894 L
s
.99625 .60883 m
1 .60883 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30889 m
1 .30889 L
s
.5 0 m
.5 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .30889 m
.02608 .32756 L
.02847 .34383 L
.02972 .35042 L
.03089 .35536 L
.03218 .35957 L
.03289 .36143 L
.03355 .36286 L
.03478 .36492 L
.03543 .36572 L
.03612 .36636 L
.03672 .36677 L
.03728 .36705 L
.0376 .36716 L
.03789 .36723 L
.03805 .36726 L
.03814 .36727 L
.03823 .36728 L
.03832 .36729 L
.03839 .36729 L
.03855 .3673 L
.03869 .3673 L
.03883 .3673 L
.03898 .36728 L
.03914 .36727 L
.0393 .36724 L
.03946 .36721 L
.03976 .36714 L
.04029 .36695 L
.04087 .36669 L
.04217 .36585 L
.04338 .36483 L
.04563 .36236 L
.04812 .35897 L
.05297 .3507 L
.05763 .34098 L
.06259 .32885 L
.06737 .3154 L
.07197 .30083 L
.07686 .28362 L
.08157 .26553 L
.08657 .24481 L
.0914 .22357 L
.09603 .20214 L
.10097 .17843 L
.10572 .15492 L
.11029 .13188 L
.11516 .10715 L
.11984 .0835 L
.12482 .05909 L
Mistroke
.12961 .0371 L
.13203 .02694 L
.13309 .02279 L
.13422 .01852 L
.13453 .0174 L
.13486 .01624 L
.13514 .01526 L
.1353 .01472 L
.13545 .60315 L
.1356 .60264 L
.13574 .60217 L
.13601 .60129 L
.1366 .59939 L
.13913 .59233 L
.1403 .58969 L
.14154 .58737 L
.1426 .58578 L
.14376 .58446 L
.14436 .58396 L
.14498 .58356 L
.14552 .58331 L
.14582 .5832 L
.1461 .58312 L
.14626 .58309 L
.14643 .58306 L
.14659 .58304 L
.14674 .58302 L
.14687 .58301 L
.14702 .58301 L
.14717 .58301 L
.14732 .58301 L
.1474 .58301 L
.14749 .58302 L
.14764 .58303 L
.1478 .58305 L
.14794 .58307 L
.14862 .5832 L
.14979 .58352 L
.15041 .58371 L
.15106 .58388 L
.15163 .58401 L
.15178 .58403 L
.15195 .58406 L
.15209 .58408 L
.15225 .58409 L
.1524 .5841 L
.15255 .58411 L
.15268 .58411 L
.15283 .58411 L
.15295 .5841 L
Mistroke
.15307 .5841 L
.15321 .58408 L
.15335 .58406 L
.15349 .58404 L
.15365 .58401 L
.15393 .58394 L
.15426 .58382 L
.15457 .58369 L
.15516 .58335 L
.15572 .58292 L
.15677 .58185 L
.1579 .58027 L
.15904 .57821 L
.1603 .57544 L
.16284 .56833 L
.16772 .55006 L
.17242 .52843 L
.17741 .50272 L
.18222 .47631 L
.18684 .44994 L
.19176 .42126 L
.1965 .39329 L
.20105 .36626 L
.20591 .33754 L
.21057 .31036 L
.21295 .29701 L
.21554 .2833 L
.21674 .27757 L
.21739 .27472 L
.21802 .27231 L
.21859 .2704 L
.2189 .26958 L
.21922 .26888 L
.21935 .26866 L
.21949 .26846 L
.21965 .26831 L
.21979 .26823 L
.21993 .26821 L
.22007 .26827 L
.22019 .26838 L
.22032 .26858 L
.2204 .26875 L
.22048 .26896 L
.22063 .26944 L
.22079 .27014 L
.22096 .27115 L
.22111 .27228 L
.22128 .27381 L
.22157 .27763 L
.22171 .2802 L
Mistroke
.22187 .28367 L
.22201 .28745 L
.22216 .29237 L
.22229 .29781 L
.22244 .30516 L
.2227 .32252 L
.22338 .3937 L
.22354 .41035 L
.22371 .42534 L
.22387 .43656 L
.22402 .44505 L
.22417 .45168 L
.22432 .45742 L
.2246 .46479 L
.22476 .46792 L
.22493 .47055 L
.22509 .47251 L
.22523 .47395 L
.22551 .47598 L
.22566 .47677 L
.22581 .47734 L
.22594 .47774 L
.22606 .47802 L
.2262 .47822 L
.22634 .47835 L
.22649 .47838 L
.22665 .47834 L
.22679 .47823 L
.22693 .47807 L
.22708 .47784 L
.22724 .47753 L
.22757 .47675 L
.2282 .47478 L
.22887 .47219 L
.23009 .4667 L
.23509 .43918 L
.23991 .40993 L
.24455 .38076 L
.24948 .34905 L
.25423 .31799 L
.2588 .28772 L
.26366 .25513 L
.26834 .22349 L
.27332 .18968 L
.27812 .15708 L
.28273 .12586 L
.28763 .09299 L
.29236 .0619 L
.29477 .0463 L
.29604 .03819 L
Mistroke
.29738 .0297 L
.29858 .02214 L
.29891 .02008 L
.29926 .01788 L
.29943 .01681 L
.29959 .01581 L
.29974 .0149 L
.2999 .60286 L
.30004 .60197 L
.30017 .60114 L
.30048 .59925 L
.3011 .59543 L
.30221 .58863 L
.30688 .56081 L
.31185 .5327 L
.31663 .50725 L
.32123 .48451 L
.32613 .46242 L
.33085 .44346 L
.33585 .42603 L
.34068 .41194 L
.34533 .40067 L
.35027 .3905 L
.35502 .38161 L
.3596 .3731 L
.36447 .36356 L
.36915 .35387 L
.37414 .34338 L
.37894 .33382 L
.38355 .32607 L
.38593 .32304 L
.38714 .32184 L
.38778 .32131 L
.38847 .32085 L
.38905 .32053 L
.38935 .3204 L
.38968 .32027 L
.38998 .32019 L
.39026 .32013 L
.39039 .3201 L
.39053 .32009 L
.39067 .32007 L
.3908 .32007 L
.39094 .32006 L
.3911 .32007 L
.39124 .32008 L
.39138 .32009 L
.39153 .32012 L
.3917 .32015 L
.39202 .32024 L
Mistroke
.39234 .32036 L
.39269 .32052 L
.39331 .32092 L
.39396 .32148 L
.39455 .32213 L
.39589 .3241 L
.39708 .32647 L
.39833 .32966 L
.40069 .33775 L
.40291 .3476 L
.4076 .37296 L
.40999 .38568 L
.41259 .39762 L
.41509 .40671 L
.4174 .41302 L
.41965 .41741 L
.42093 .41921 L
.4215 .41987 L
.42213 .42048 L
.42271 .42094 L
.42332 .42135 L
.42366 .42153 L
.42396 .42168 L
.42428 .4218 L
.42457 .42189 L
.42483 .42196 L
.42512 .42201 L
.42526 .42203 L
.4254 .42204 L
.42555 .42205 L
.42564 .42206 L
.42571 .42206 L
.42585 .42206 L
.42598 .42206 L
.42612 .42205 L
.42627 .42204 L
.42641 .42202 L
.42655 .422 L
.4268 .42195 L
.42709 .42188 L
.42736 .4218 L
.42798 .42155 L
.42858 .42124 L
.42923 .42082 L
.43146 .41879 L
.43269 .41729 L
.43402 .41537 L
.43645 .41118 L
.44138 .4002 L
.44612 .387 L
Mistroke
.45068 .37239 L
.45554 .35518 L
.46021 .33735 L
.46518 .31732 L
.46996 .29721 L
.47457 .27728 L
.47947 .25558 L
.48418 .23433 L
.48919 .21147 L
.49402 .18926 L
.49624 .17904 L
.49749 .17324 L
.49867 .16781 L
.49926 .16506 L
.49956 .1637 L
.49983 .16245 L
.49998 .16175 L
.50005 .45587 L
.50014 .45548 L
.50048 .45391 L
.50107 .45117 L
.50361 .43943 L
.50846 .41709 L
.51312 .39572 L
.51808 .37322 L
.52285 .35187 L
.52745 .33172 L
.53234 .31082 L
.53704 .29139 L
.54204 .2717 L
.54686 .25391 L
.5515 .23819 L
.55643 .22339 L
.56118 .21149 L
.56575 .20276 L
.56809 .19951 L
.56941 .19809 L
.57061 .19707 L
.57118 .19667 L
.5718 .19633 L
.57238 .19607 L
.5729 .19589 L
.57322 .19581 L
.57352 .19576 L
.57367 .19574 L
.57384 .19572 L
.57393 .19572 L
.57402 .19571 L
.57411 .19571 L
.57419 .19571 L
Mistroke
.57434 .19571 L
.57449 .19572 L
.57464 .19573 L
.57472 .19574 L
.57481 .19575 L
.57512 .19581 L
.5754 .19587 L
.57597 .19607 L
.57659 .19637 L
.57724 .19678 L
.57784 .19727 L
.57892 .19838 L
.58007 .19992 L
.58131 .20202 L
.58265 .20485 L
.58508 .21159 L
.58748 .22042 L
.59002 .23212 L
.59459 .257 L
.59713 .27036 L
.59946 .28062 L
.60061 .2848 L
.60186 .28863 L
.60304 .29156 L
.60414 .29374 L
.60474 .2947 L
.60539 .29558 L
.60593 .29618 L
.60652 .29672 L
.60716 .29717 L
.60752 .29735 L
.60784 .29749 L
.60815 .29759 L
.60843 .29765 L
.60858 .29767 L
.60866 .29768 L
.60875 .29769 L
.60891 .2977 L
.60905 .29771 L
.6092 .29771 L
.60936 .2977 L
.60951 .29768 L
.60965 .29766 L
.60991 .29761 L
.61019 .29754 L
.61052 .29743 L
.61083 .2973 L
.61141 .297 L
.61247 .29626 L
.61362 .29521 L
Mistroke
.61602 .2923 L
.61856 .2884 L
.62314 .27994 L
.62801 .26988 L
.63271 .26001 L
.63769 .2499 L
.6425 .24074 L
.64712 .2322 L
.65204 .2227 L
.65677 .21225 L
.66133 .20028 L
.66617 .18502 L
.67084 .16781 L
.6758 .14691 L
.68058 .12451 L
.68517 .1011 L
.69007 .07442 L
.69477 .04722 L
.69718 .03285 L
.69844 .02516 L
.69913 .02092 L
.69947 .01883 L
.69978 .01692 L
.69992 .01605 L
.70007 .01509 L
.70022 .60313 L
.70035 .60229 L
.70097 .59844 L
.70229 .5902 L
.7046 .57551 L
.70932 .54488 L
.71435 .51159 L
.71918 .47902 L
.72384 .44742 L
.72879 .41374 L
.73356 .3814 L
.73814 .3505 L
.74302 .31792 L
.74772 .28695 L
.75272 .25452 L
.75753 .22387 L
.76216 .19513 L
.76708 .16607 L
.76953 .15298 L
.77072 .1473 L
.77125 .14508 L
.77182 .14292 L
.77234 .14128 L
.77262 .14054 L
.77289 .13999 L
Mistroke
.77304 .13975 L
.7732 .13956 L
.77334 .13944 L
.77347 .13939 L
.7736 .1394 L
.77374 .13949 L
.77388 .13966 L
.77402 .13992 L
.77416 .14033 L
.77432 .14093 L
.77447 .14168 L
.77461 .14256 L
.77488 .14484 L
.77501 .14637 L
.77516 .14843 L
.77546 .1543 L
.77563 .15889 L
.77579 .16422 L
.77608 .17788 L
.77622 .18722 L
.77638 .1998 L
.77696 .26248 L
.77727 .29255 L
.77742 .30418 L
.77759 .31442 L
.77774 .3215 L
.7779 .32758 L
.77805 .33208 L
.77819 .33556 L
.77833 .33836 L
.77848 .34086 L
.77874 .34414 L
.77892 .34573 L
.77907 .34685 L
.77926 .34784 L
.77943 .34853 L
.77959 .34899 L
.77973 .34928 L
.77981 .34939 L
.77989 .34947 L
.77998 .34953 L
.78006 .34956 L
.78022 .34954 L
.78037 .34945 L
.7805 .34932 L
.78064 .34912 L
.78097 .3485 L
.78127 .34776 L
.78243 .34377 L
.78352 .33903 L
Mistroke
.786 .32647 L
.79067 .30025 L
.79564 .27114 L
.80042 .24279 L
.80501 .21552 L
.80991 .18673 L
.81462 .15944 L
.81962 .13121 L
.82445 .10524 L
.82909 .08207 L
.83403 .06057 L
.83648 .05163 L
.83878 .04467 L
.84098 .0395 L
.84222 .03731 L
.84335 .03578 L
.84393 .03516 L
.84454 .03463 L
.84512 .03425 L
.84565 .03399 L
.84597 .03387 L
.84627 .03378 L
.84644 .03375 L
.84659 .03372 L
.84676 .03369 L
.84684 .03368 L
.84694 .03368 L
.84709 .03367 L
.84724 .03366 L
.84739 .03366 L
.84752 .03367 L
.84767 .03367 L
.84783 .03369 L
.84799 .03371 L
.84815 .03373 L
.84875 .03384 L
.8494 .03401 L
.85059 .03436 L
.85115 .03452 L
.85146 .03459 L
.85175 .03465 L
.85202 .0347 L
.85216 .03472 L
.85231 .03473 L
.85244 .03475 L
.85258 .03476 L
.8527 .03476 L
.85282 .03477 L
.85297 .03476 L
.85305 .03476 L
Mistroke
.85314 .03476 L
.85329 .03475 L
.85343 .03473 L
.85359 .03471 L
.85374 .03468 L
.85408 .0346 L
.85436 .03451 L
.85466 .03439 L
.85528 .03406 L
.85584 .03366 L
.85643 .03312 L
.85751 .03185 L
.85875 .02991 L
.86009 .02726 L
.86124 .02451 L
.86252 .02104 L
.86311 .01927 L
.86375 .01726 L
.86406 .01625 L
.86422 .01575 L
.86436 .01528 L
.86449 .01485 L
.86462 .60332 L
.86477 .6028 L
.86491 .60233 L
.86745 .5929 L
.87228 .57223 L
.87694 .55021 L
.88189 .5256 L
.88665 .50142 L
.89124 .47815 L
.89612 .45369 L
.90081 .43068 L
.90581 .40702 L
.91062 .3852 L
.91524 .36528 L
.92017 .34541 L
.92491 .32775 L
.92946 .31224 L
.93432 .29742 L
.93899 .28486 L
.94395 .27331 L
.94873 .26395 L
.95334 .25674 L
.9557 .25387 L
.95702 .25258 L
.95823 .25163 L
.95882 .25125 L
.95947 .25092 L
.96012 .25067 L
Mistroke
.96029 .25062 L
.96048 .25058 L
.96065 .25054 L
.96081 .25051 L
.96096 .25049 L
.96104 .25049 L
.96112 .25048 L
.96121 .25048 L
.9613 .25047 L
.96138 .25047 L
.96146 .25047 L
.9616 .25048 L
.96176 .25049 L
.96184 .2505 L
.96193 .25051 L
.96208 .25054 L
.96239 .25061 L
.96269 .25071 L
.96324 .25097 L
.9638 .25135 L
.96441 .25189 L
.96505 .25263 L
.96565 .25348 L
.96672 .25547 L
.96787 .25835 L
.96909 .26237 L
.97042 .26806 L
.97285 .28231 L
.97619 .30889 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.211989 0.97619 0.395928 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0529101 0.305869 0.00157381 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.15608 -0.0125 -9 -9 ]
[.15608 -0.0125 9 0 ]
[.28836 -0.0125 -3 -9 ]
[.28836 -0.0125 3 0 ]
[.42063 -0.0125 -9 -9 ]
[.42063 -0.0125 9 0 ]
[.55291 -0.0125 -6 -9 ]
[.55291 -0.0125 6 0 ]
[.68519 -0.0125 -12 -9 ]
[.68519 -0.0125 12 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.94974 -0.0125 -12 -9 ]
[.94974 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0698 -24 -4.5 ]
[-0.0125 .0698 0 4.5 ]
[-0.0125 .14849 -24 -4.5 ]
[-0.0125 .14849 0 4.5 ]
[-0.0125 .22718 -18 -4.5 ]
[-0.0125 .22718 0 4.5 ]
[-0.0125 .30587 -6 -4.5 ]
[-0.0125 .30587 0 4.5 ]
[-0.0125 .38456 -12 -4.5 ]
[-0.0125 .38456 0 4.5 ]
[-0.0125 .46325 -18 -4.5 ]
[-0.0125 .46325 0 4.5 ]
[-0.0125 .54194 -18 -4.5 ]
[-0.0125 .54194 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.15608 0 m
.15608 .00625 L
s
[(2.5)] .15608 -0.0125 0 1 Mshowa
.28836 0 m
.28836 .00625 L
s
[(5)] .28836 -0.0125 0 1 Mshowa
.42063 0 m
.42063 .00625 L
s
[(7.5)] .42063 -0.0125 0 1 Mshowa
.55291 0 m
.55291 .00625 L
s
[(10)] .55291 -0.0125 0 1 Mshowa
.68519 0 m
.68519 .00625 L
s
[(12.5)] .68519 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(15)] .81746 -0.0125 0 1 Mshowa
.94974 0 m
.94974 .00625 L
s
[(17.5)] .94974 -0.0125 0 1 Mshowa
.125 Mabswid
.05026 0 m
.05026 .00375 L
s
.07672 0 m
.07672 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.12963 0 m
.12963 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.20899 0 m
.20899 .00375 L
s
.23545 0 m
.23545 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.31481 0 m
.31481 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.36772 0 m
.36772 .00375 L
s
.39418 0 m
.39418 .00375 L
s
.44709 0 m
.44709 .00375 L
s
.47354 0 m
.47354 .00375 L
s
.5 0 m
.5 .00375 L
s
.52646 0 m
.52646 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.60582 0 m
.60582 .00375 L
s
.63228 0 m
.63228 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.71164 0 m
.71164 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.76455 0 m
.76455 .00375 L
s
.79101 0 m
.79101 .00375 L
s
.84392 0 m
.84392 .00375 L
s
.87037 0 m
.87037 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.92328 0 m
.92328 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0698 m
.00625 .0698 L
s
[(-150)] -0.0125 .0698 1 0 Mshowa
0 .14849 m
.00625 .14849 L
s
[(-100)] -0.0125 .14849 1 0 Mshowa
0 .22718 m
.00625 .22718 L
s
[(-50)] -0.0125 .22718 1 0 Mshowa
0 .30587 m
.00625 .30587 L
s
[(0)] -0.0125 .30587 1 0 Mshowa
0 .38456 m
.00625 .38456 L
s
[(50)] -0.0125 .38456 1 0 Mshowa
0 .46325 m
.00625 .46325 L
s
[(100)] -0.0125 .46325 1 0 Mshowa
0 .54194 m
.00625 .54194 L
s
[(150)] -0.0125 .54194 1 0 Mshowa
.125 Mabswid
0 .08554 m
.00375 .08554 L
s
0 .10127 m
.00375 .10127 L
s
0 .11701 m
.00375 .11701 L
s
0 .13275 m
.00375 .13275 L
s
0 .16423 m
.00375 .16423 L
s
0 .17996 m
.00375 .17996 L
s
0 .1957 m
.00375 .1957 L
s
0 .21144 m
.00375 .21144 L
s
0 .24292 m
.00375 .24292 L
s
0 .25866 m
.00375 .25866 L
s
0 .27439 m
.00375 .27439 L
s
0 .29013 m
.00375 .29013 L
s
0 .32161 m
.00375 .32161 L
s
0 .33735 m
.00375 .33735 L
s
0 .35308 m
.00375 .35308 L
s
0 .36882 m
.00375 .36882 L
s
0 .4003 m
.00375 .4003 L
s
0 .41604 m
.00375 .41604 L
s
0 .43177 m
.00375 .43177 L
s
0 .44751 m
.00375 .44751 L
s
0 .47899 m
.00375 .47899 L
s
0 .49473 m
.00375 .49473 L
s
0 .51046 m
.00375 .51046 L
s
0 .5262 m
.00375 .5262 L
s
0 .55768 m
.00375 .55768 L
s
0 .57342 m
.00375 .57342 L
s
0 .58915 m
.00375 .58915 L
s
0 .60489 m
.00375 .60489 L
s
0 .05406 m
.00375 .05406 L
s
0 .03832 m
.00375 .03832 L
s
0 .02258 m
.00375 .02258 L
s
0 .00685 m
.00375 .00685 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.15608 .61178 m
.15608 .61803 L
s
.28836 .61178 m
.28836 .61803 L
s
.42063 .61178 m
.42063 .61803 L
s
.55291 .61178 m
.55291 .61803 L
s
.68519 .61178 m
.68519 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.94974 .61178 m
.94974 .61803 L
s
.125 Mabswid
.05026 .61428 m
.05026 .61803 L
s
.07672 .61428 m
.07672 .61803 L
s
.10317 .61428 m
.10317 .61803 L
s
.12963 .61428 m
.12963 .61803 L
s
.18254 .61428 m
.18254 .61803 L
s
.20899 .61428 m
.20899 .61803 L
s
.23545 .61428 m
.23545 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.31481 .61428 m
.31481 .61803 L
s
.34127 .61428 m
.34127 .61803 L
s
.36772 .61428 m
.36772 .61803 L
s
.39418 .61428 m
.39418 .61803 L
s
.44709 .61428 m
.44709 .61803 L
s
.47354 .61428 m
.47354 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.52646 .61428 m
.52646 .61803 L
s
.57937 .61428 m
.57937 .61803 L
s
.60582 .61428 m
.60582 .61803 L
s
.63228 .61428 m
.63228 .61803 L
s
.65873 .61428 m
.65873 .61803 L
s
.71164 .61428 m
.71164 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.76455 .61428 m
.76455 .61803 L
s
.79101 .61428 m
.79101 .61803 L
s
.84392 .61428 m
.84392 .61803 L
s
.87037 .61428 m
.87037 .61803 L
s
.89683 .61428 m
.89683 .61803 L
s
.92328 .61428 m
.92328 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0698 m
1 .0698 L
s
.99375 .14849 m
1 .14849 L
s
.99375 .22718 m
1 .22718 L
s
.99375 .30587 m
1 .30587 L
s
.99375 .38456 m
1 .38456 L
s
.99375 .46325 m
1 .46325 L
s
.99375 .54194 m
1 .54194 L
s
.125 Mabswid
.99625 .08554 m
1 .08554 L
s
.99625 .10127 m
1 .10127 L
s
.99625 .11701 m
1 .11701 L
s
.99625 .13275 m
1 .13275 L
s
.99625 .16423 m
1 .16423 L
s
.99625 .17996 m
1 .17996 L
s
.99625 .1957 m
1 .1957 L
s
.99625 .21144 m
1 .21144 L
s
.99625 .24292 m
1 .24292 L
s
.99625 .25866 m
1 .25866 L
s
.99625 .27439 m
1 .27439 L
s
.99625 .29013 m
1 .29013 L
s
.99625 .32161 m
1 .32161 L
s
.99625 .33735 m
1 .33735 L
s
.99625 .35308 m
1 .35308 L
s
.99625 .36882 m
1 .36882 L
s
.99625 .4003 m
1 .4003 L
s
.99625 .41604 m
1 .41604 L
s
.99625 .43177 m
1 .43177 L
s
.99625 .44751 m
1 .44751 L
s
.99625 .47899 m
1 .47899 L
s
.99625 .49473 m
1 .49473 L
s
.99625 .51046 m
1 .51046 L
s
.99625 .5262 m
1 .5262 L
s
.99625 .55768 m
1 .55768 L
s
.99625 .57342 m
1 .57342 L
s
.99625 .58915 m
1 .58915 L
s
.99625 .60489 m
1 .60489 L
s
.99625 .05406 m
1 .05406 L
s
.99625 .03832 m
1 .03832 L
s
.99625 .02258 m
1 .02258 L
s
.99625 .00685 m
1 .00685 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .30587 m
1 .30587 L
s
1 0 0 r
.5 Mabswid
.02381 .30587 m
.02381 .40659 L
s
.07672 .30587 m
.07672 .40659 L
s
.12963 .30587 m
.12963 .46797 L
s
.18254 .30587 m
.18254 .33735 L
s
.23545 .30587 m
.23545 .41446 L
s
.28836 .30587 m
.28836 .06508 L
s
.34127 .30587 m
.34127 .26023 L
s
.39418 .30587 m
.39418 .60332 L
s
.44709 .30587 m
.44709 .3279 L
s
.5 .30587 m
.5 .22875 L
s
.55291 .30587 m
.55291 .01472 L
s
.60582 .30587 m
.60582 .29013 L
s
.65873 .30587 m
.65873 .4239 L
s
.71164 .30587 m
.71164 .29171 L
s
.76455 .30587 m
.76455 .12173 L
s
.81746 .30587 m
.81746 .19728 L
s
.87037 .30587 m
.87037 .44122 L
s
.92328 .30587 m
.92328 .29485 L
s
.97619 .30587 m
.97619 .21774 L
s
.015 w
.02381 .40659 Mdot
.07672 .40659 Mdot
.12963 .46797 Mdot
.18254 .33735 Mdot
.23545 .41446 Mdot
.28836 .06508 Mdot
.34127 .26023 Mdot
.39418 .60332 Mdot
.44709 .3279 Mdot
.5 .22875 Mdot
.55291 .01472 Mdot
.60582 .29013 Mdot
.65873 .4239 Mdot
.71164 .29171 Mdot
.76455 .12173 Mdot
.81746 .19728 Mdot
.87037 .44122 Mdot
.92328 .29485 Mdot
.97619 .21774 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{756, 306.562},
  ImageCacheValid->False]
}, Open  ]]
}, Open  ]]
}, Closed]]
},
FrontEndVersion->"4.1 for Macintosh",
ScreenRectangle->{{0, 1280}, {0, 832}},
ScreenStyleEnvironment->"Working",
WindowSize->{800, 556},
WindowMargins->{{Automatic, 81}, {112, Automatic}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
CellLabelAutoDelete->True,
Magnification->1,
StyleDefinitions -> "Classroom.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 50, 0, 62, "Title"],

Cell[CellGroupData[{
Cell[1780, 54, 99, 4, 59, "Section"],

Cell[CellGroupData[{
Cell[1904, 62, 60, 0, 49, "Subsection"],
Cell[1967, 64, 189, 3, 79, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2193, 72, 37, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[2255, 76, 59, 0, 43, "Subsubsection"],
Cell[2317, 78, 118, 2, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2472, 85, 67, 0, 43, "Subsubsection"],
Cell[2542, 87, 820, 15, 143, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3411, 108, 45, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[3481, 112, 62, 0, 43, "Subsubsection"],
Cell[3546, 114, 330, 6, 110, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3913, 125, 67, 0, 34, "Subsubsection"],
Cell[3983, 127, 227, 4, 46, "Text"],
Cell[4213, 133, 551, 10, 158, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4801, 148, 48, 0, 34, "Subsubsection"],
Cell[4852, 150, 367, 8, 64, "Text"],
Cell[5222, 160, 302, 4, 110, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5561, 169, 83, 1, 34, "Subsubsection"],
Cell[5647, 172, 683, 12, 190, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6367, 189, 83, 1, 34, "Subsubsection"],
Cell[6453, 192, 684, 12, 190, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[7186, 210, 39, 0, 32, "Subsection"],
Cell[7228, 212, 333, 7, 46, "Text"],
Cell[7564, 221, 541, 10, 142, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8142, 236, 41, 0, 32, "Subsection"],

Cell[CellGroupData[{
Cell[8208, 240, 45, 0, 42, "Subsubsection"],
Cell[8256, 242, 67, 1, 46, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8360, 248, 43, 0, 42, "Subsubsection"],
Cell[8406, 250, 58, 1, 46, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8501, 256, 104, 4, 42, "Subsubsection"],
Cell[8608, 262, 74, 1, 46, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8731, 269, 109, 4, 32, "Subsection"],
Cell[8843, 275, 136, 3, 62, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9016, 283, 50, 0, 32, "Subsection"],
Cell[9069, 285, 181, 3, 62, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9287, 293, 48, 0, 32, "Subsection"],
Cell[9338, 295, 141, 2, 62, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9516, 302, 40, 0, 32, "Subsection"],
Cell[9559, 304, 396, 7, 126, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[10004, 317, 59, 0, 39, "Section"],
Cell[10066, 319, 175, 6, 44, "Text"],

Cell[CellGroupData[{
Cell[10266, 329, 122, 4, 49, "Subsection"],

Cell[CellGroupData[{
Cell[10413, 337, 120, 2, 63, "Input"],
Cell[10536, 341, 56, 1, 62, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[10641, 348, 128, 4, 49, "Subsection"],

Cell[CellGroupData[{
Cell[10794, 356, 131, 4, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[10950, 364, 118, 2, 47, "Input"],
Cell[11071, 368, 112, 2, 79, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[11232, 376, 171, 5, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[11428, 385, 592, 11, 111, "Input"],
Cell[12023, 398, 58029, 1889, 70, 18377, 1396, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[70113, 2294, 97, 3, 49, "Subsection"],

Cell[CellGroupData[{
Cell[70235, 2301, 43, 0, 43, "Subsubsection"],
Cell[70281, 2303, 46, 1, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[70364, 2309, 47, 0, 43, "Subsubsection"],
Cell[70414, 2311, 310, 6, 95, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[70761, 2322, 96, 1, 33, "Subsubsection"],
Cell[70860, 2325, 187, 5, 47, "Input"],

Cell[CellGroupData[{
Cell[71072, 2334, 357, 7, 79, "Input"],
Cell[71432, 2343, 113122, 2413, 70, 15021, 1199, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[184615, 4763, 105, 3, 49, "Subsection"],

Cell[CellGroupData[{
Cell[184745, 4770, 213, 8, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[184983, 4782, 105, 2, 47, "Input"],
Cell[185091, 4786, 107, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[185235, 4793, 55, 1, 47, "Input"],
Cell[185293, 4796, 185, 3, 70, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[185527, 4805, 203, 4, 34, "Subsubsection"],
Cell[185733, 4811, 176, 4, 47, "Input"],

Cell[CellGroupData[{
Cell[185934, 4819, 369, 7, 79, "Input"],
Cell[186306, 4828, 223768, 4763, 70, 29420, 2361, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[410147, 9599, 50, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[410222, 9603, 50, 0, 49, "Subsection"],
Cell[410275, 9605, 287, 6, 63, "Input"],
Cell[410565, 9613, 469, 9, 95, "Input"],

Cell[CellGroupData[{
Cell[411059, 9626, 121, 3, 47, "Input"],
Cell[411183, 9631, 118239, 2808, 157, 20093, 1593, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[529471, 12445, 50, 0, 49, "Subsection"],
Cell[529524, 12447, 251, 6, 63, "Input"],
Cell[529778, 12455, 469, 9, 95, "Input"],

Cell[CellGroupData[{
Cell[530272, 12468, 121, 3, 47, "Input"],
Cell[530396, 12473, 115676, 2785, 157, 20130, 1602, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[646133, 15265, 128, 3, 39, "Section"],

Cell[CellGroupData[{
Cell[646286, 15272, 158, 7, 49, "Subsection"],
Cell[646447, 15281, 251, 6, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[646735, 15292, 156, 7, 49, "Subsection"],

Cell[CellGroupData[{
Cell[646916, 15303, 44, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[646985, 15307, 150, 2, 47, "Input"],
Cell[647138, 15311, 32807, 832, 186, 5935, 496, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[679994, 16149, 55, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[680074, 16153, 148, 2, 47, "Input"],
Cell[680225, 16157, 5526, 458, 70, 5404, 454, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[685812, 16622, 47, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[685884, 16626, 151, 3, 34, "Subsubsection"],
Cell[686038, 16631, 281, 5, 79, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[686356, 16641, 54, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[686435, 16645, 580, 11, 111, "Input"],
Cell[687018, 16658, 30799, 2179, 70, 30744, 2177, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[717866, 18843, 235, 6, 43, "Subsubsection"],
Cell[718104, 18851, 194, 4, 62, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[718335, 18860, 65, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[718425, 18864, 265, 5, 63, "Input"],
Cell[718693, 18871, 7821, 650, 186, 7699, 646, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[726575, 19528, 42, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[726642, 19532, 122, 4, 43, "Subsubsection"],
Cell[726767, 19538, 158, 4, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[726962, 19547, 65, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[727052, 19551, 246, 4, 63, "Input"],
Cell[727301, 19557, 7821, 650, 186, 7699, 646, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[735171, 20213, 129, 4, 43, "Subsubsection"],
Cell[735303, 20219, 73, 1, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[735413, 20225, 54, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[735492, 20229, 562, 11, 111, "Input"],
Cell[736057, 20242, 30799, 2179, 157, 30744, 2177, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[766917, 22428, 41, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[766983, 22432, 125, 2, 47, "Input"],
Cell[767111, 22436, 75988, 5591, 315, 75933, 5589, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False]
}, Open  ]]
}, Open  ]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

